
//There are no checks in this file, since all routines are functions, not intrinsics. This will be changed at some point...
//Moreover there will be a way to access the underlying Jacobian of a Kummer surface, once a data type for the general
//Kummer surface exists - probably overriding the existing type SrfKum.
//If you find a bug or a mistake in the formulas - or if you have a comment- please send an email to 
//jansteffenmueller@gmail.com


//This function computes the Kummer surface of the Jacobian of a genus 2 curve 
function GeneralKummerSurface(C)
 return GeneralKummerSurface(Jacobian(C));
end function;



//This function computes the Kummer surface of a genus 2 Jacobian 
function GeneralKummerSurface(J)
 C:=Curve(J);
 k:=BaseRing(C);
 P<x1,x2,x3,x4>:=ProjectiveSpace(k,3);
 f,h:=HyperellipticPolynomials(C);
 f0:=Coefficient(f,0);
 f1:=Coefficient(f,1);
 f2:=Coefficient(f,2);
 f3:=Coefficient(f,3);
 f4:=Coefficient(f,4);  
 f5:=Coefficient(f,5);
 f6:=Coefficient(f,6);
 h0:=Coefficient(h,0);
 h1:=Coefficient(h,1);
 h2:=Coefficient(h,2);
 h3:=Coefficient(h,3);
  
 K2:=x2^2-4*x1*x3;
 K1:=-4*f2*x1^2*x3-4*f6*x3^3-4*f0*x1^3
 -h3*h1*(x2^2*x3-2*x1*x3^2)-x2*x3^2*h2*h3-x1*x2*x3*h1*h2
 -x1^2*x3*h1^2-2*x1*x2*x3*f3-h0^2*x1^3-x1*x3^2*h2^2
 -2*x2*x3^2*f5-x3^3*h3^2
 -4*f4*x1*x3^2-2*f1*x1^2*x2-h0*h1*x1^2*x2-h0*h2*(x1*x2^2-2*x1^2*x3)-h0*h3*(x2^3-3*x1*x2*x3);  
 K0:=(-4*f0*f2 - f0*h1^2 + f1^2 + f1*h0*h1 - f2*h0^2)*x1^4 + (-4*f0*f3 - 2*f0*h1*h2 +
    f1*h0*h2 - f3*h0^2)*x1^3*x2 + (2*f0*h1*h3 - 2*f1*f3 - f1*h0*h3 - f1*h1*h2 + 
    2*f2*h0*h2 - f3*h0*h1)*x1^3*x3 + (-4*f0*f4 - 2*f0*h1*h3 - f0*h2^2 + f1*h0*h3
    - f4*h0^2)*x1^2*x2^2 + (4*f0*f5 + 2*f0*h2*h3 - 4*f1*f4 - f1*h1*h3 - f1*h2^2 
    + 2*f2*h0*h3 + f3*h0*h2 - 2*f4*h0*h1 + f5*h0^2)*x1^2*x2*x3 + (-4*f0*f6 - 
    f0*h3^2 + 2*f1*f5 + f1*h2*h3 - 4*f2*f4 - f2*h2^2 + f3^2 + f3*h0*h3 + 
    f3*h1*h2 - f4*h1^2 + f5*h0*h1 - f6*h0^2)*x1^2*x3^2 + (-4*f0*f5 - 2*f0*h2*h3 
    - f5*h0^2)*x1*x2^3 + (8*f0*f6 + 2*f0*h3^2 - 4*f1*f5 - 2*f1*h2*h3 + f3*h0*h3 
    - 2*f5*h0*h1 + 2*f6*h0^2)*x1*x2^2*x3 + (4*f1*f6 + f1*h3^2 - 4*f2*f5 - 
    2*f2*h2*h3 + f3*h1*h3 + 2*f4*h0*h3 - f5*h0*h2 - f5*h1^2 + 
    2*f6*h0*h1)*x1*x2*x3^2 + (-2*f3*f5 - f3*h2*h3 + 2*f4*h1*h3 - f5*h0*h3 - 
    f5*h1*h2 + 2*f6*h0*h2)*x1*x3^3 + (-4*f0*f6 - f0*h3^2 - f6*h0^2)*x2^4 + 
    (-4*f1*f6 - f1*h3^2 - 2*f6*h0*h1)*x2^3*x3 + (-4*f2*f6 - f2*h3^2 + f5*h0*h3 -
    2*f6*h0*h2 - f6*h1^2)*x2^2*x3^2 + (-4*f3*f6 - f3*h3^2 + f5*h1*h3 - 
    2*f6*h1*h2)*x2*x3^3 + (-4*f4*f6 - f4*h3^2 + f5^2 + f5*h2*h3 - f6*h2^2)*x3^4;
 
 Keqn:=K2*x4^2+K1*x4+K0;
 S:=Scheme(P,Keqn);
 return S; 
end function;

//The function kappa computes the Kummer coordinates of a point on the Jacobian of a genus 2 curve.
//P can be represented as an unordered pair of two points P1 and P2 on C. We have to make a case distinction,
//where we distinguish between the following cases 
// - P1 and P2 are distinct affine points, P1 is not -P2.
// - P1=P2 is affine.
// - P1 is affine, but P2 is at infinity. 
// - P1=P2 is at infinity.
// - P1=-P2, so P=0.
function kappa(P) 
 J:=Parent(P);
 C:=Curve(J);
 K:=GeneralKummerSurface(J);
 a:=P[1]; b:=P[2]; d:=P[3]; 
 if Degree(a) eq 2 then  //P1 and P2 are affine, say P1=(x,y),P2=(u,v)
  xudiffsq:=Discriminant(a);  //(x-u)^2
  f,h:=HyperellipticPolynomials(C);
  f0:=Coefficient(f,0);
  f1:=Coefficient(f,1);
  f2:=Coefficient(f,2);
  f3:=Coefficient(f,3);
  f4:=Coefficient(f,4);  
  f5:=Coefficient(f,5);
  f6:=Coefficient(f,6);
  h0:=Coefficient(h,0);
  h1:=Coefficient(h,1);
  h2:=Coefficient(h,2);
  h3:=Coefficient(h,3);
  x1:=1;
  x2:=-Coefficient(a,1);
  x3:=Coefficient(a,0);
  if xudiffsq ne 0 then  // P1 is not equal to P2
   b1:=Coefficient(b, 1);  
   b0:=Coefficient(b, 0);
   yvprod:=b1^2*x3+b0*b1*x2+b0^2;  //y*v
   hxu:=h0*h3*x2^3 + h1*h3*x2^2*x3 + h0*h2*x1*x2^2 + h2*h3*x2*x3^2 + (-3*h0*h3 + 
      h1*h2)*x1*x2*x3 + h0*h1*x1^2*x2 + h3^2*x3^3 + (-2*h1*h3 + h2^2)*x1*x3^2 + (-2*h0*h2 + 
      h1^2)*x1^2*x3 + h0^2*x1^3;
   fxu:=f0*f6*x2^6 + f1*f6*x2^5*x3 + f0*f5*x1*x2^5 + f2*f6*x2^4*x3^2 + (-6*f0*f6 + 
      f1*f5)*x1*x2^4*x3 + f0*f4*x1^2*x2^4 + f3*f6*x2^3*x3^3 + (-5*f1*f6 + f2*f5)*x1*x2^3*x3^2
      + (-5*f0*f5 + f1*f4)*x1^2*x2^3*x3 + f0*f3*x1^3*x2^3 + f4*f6*x2^2*x3^4 + (-4*f2*f6 + 
      f3*f5)*x1*x2^2*x3^3 + (9*f0*f6 - 4*f1*f5 + f2*f4)*x1^2*x2^2*x3^2 + (-4*f0*f4 + 
      f1*f3)*x1^3*x2^2*x3 + f0*f2*x1^4*x2^2 + f5*f6*x2*x3^5 + (-3*f3*f6 + f4*f5)*x1*x2*x3^4 + 
      (5*f1*f6 - 3*f2*f5 + f3*f4)*x1^2*x2*x3^3 + (5*f0*f5 - 3*f1*f4 + f2*f3)*x1^3*x2*x3^2 + 
      (-3*f0*f3 + f1*f2)*x1^4*x2*x3 + f0*f1*x1^5*x2 + f6^2*x3^6 + (-2*f4*f6 + f5^2)*x1*x3^5 + 
      (2*f2*f6 - 2*f3*f5 + f4^2)*x1^2*x3^4 + (-2*f0*f6 + 2*f1*f5 - 2*f2*f4 + f3^2)*x1^3*x3^3
      + (2*f0*f4 - 2*f1*f3 + f2^2)*x1^4*x3^2 + (-2*f0*f2 + f1^2)*x1^5*x3 + f0^2*x1^6;
    if yvprod ne 0 then
     hxvhuysum:=fxu/yvprod-yvprod-hxu; //h(x)*v+h(u)*y when y and v are nonzero 
    else              
      if b1 ne 0 then
       x:=-b0/b1;
       hx:=Evaluate(h,x);
       u:=x2-x;
       v:=Evaluate(b,u);
       hxvhuysum:=hx*v;  //h(x)*v+h(u)*y when y=0
      else 
       hxvhuysum:=0;  //h(x)*v+h(u)*y when y=v=0
      end if;                  
    end if;
    F0:=2*f0+f1*x2+2*f2*x3+f3*x2*x3+2*f4*x3^2+f5*x2*x3^2+2*f6*x3^3; 
    x4:=(F0-2*yvprod-hxvhuysum)/xudiffsq;
    return [1,x2,x3,x4];
  else  //P1=P2. Then x1,x2,x3 are as before, but x4 is uniquely determined by the equation of the surface.
    _,l:=IsSquare(a);
    x:=-Coefficient(l,0);
    P<z> := PolynomialRing(BaseRing(K) : Global := false);
    s:=[1,x2,x3];
    pol := Evaluate(DefiningPolynomial(K), s cat [z]);
    x4 := -Coefficient(pol,0)/Coefficient(pol,1);
    return [1,x2,x3,x4];
  end if;
 elif Degree(a) eq 1 then //P1 is affine, but P2 is at infinity.
   x3:=-Coefficient(a,0);
   PR<x>:=Parent(a);
   k:=BaseRing(J);
    f,h:=HyperellipticPolynomials(C);
    f5:=Coefficient(f,5);
    f6:=Coefficient(f,6);
    h3:=Coefficient(h,3);
    yinf:=Coefficient(b, 3);
    y1:=Evaluate(b,x3);     
    yvprod:=yinf*y1;
    hxu:=h3*Evaluate(h,x3);
    fxu:=f6*Evaluate(f,x3);
    if yvprod ne 0 then
      hxvhuysum:=fxu/yvprod-yvprod-hxu;
    elif yinf ne 0 then
     hxvhuysum:=Evaluate(h,x3)*yinf;
    elif y1 ne 0 then
     hxvhuysum:=h3*y1;
    else
     hxvhuysum:=0;
    end if;
    x4:=f5*x3^2+2*f6*x3^3-2*yvprod-hxvhuysum;  
  return [0,1,x3,x4];   
 elif Degree(b) eq 3 then //2 distinct points at infinity in P.
   f,h:=HyperellipticPolynomials(C);
   f4:=Coefficient(f,4);
   f5:=Coefficient(f,5);
   f6:=Coefficient(f,6);
   h2:=Coefficient(h,2);
   h3:=Coefficient(h,3);
   x4:=(f5^2-4*f4*f6-h3^2*f4-h2^2*f6+h2*h3*f5)/(4*f6+h3^2); //4*f6+h3^2=0 can't happen, since otherwise there's only one point at infinity
   return [0,0,1,x4];   
 else  //P=0.
   return [0,0,0,1];
 end if;    
end function;

//The following function computes the image on the Kummer surface K of a point P on the Jacobian of a genus 2 curve.
function Kappa(K,P) 
 return K!(kappa(P)); 
end function;


//BMdata computes the matrix of biquadratic forms B (see the discussion below) in two sets
//of quadruples x and y. J is the Jacobian of a genus 2 curve.
function BMdata(x,y,J)
 x1:=x[1];x2:=x[2];x3:=x[3];x4:=x[4];
 y1:=y[1];y2:=y[2];y3:=y[3];y4:=y[4];
 C:=Curve(J);
 f,h:=HyperellipticPolynomials(C);
 f0:=Coefficient(f,0);
 f1:=Coefficient(f,1);
 f2:=Coefficient(f,2);
 f3:=Coefficient(f,3);
 f4:=Coefficient(f,4);  
 f5:=Coefficient(f,5);
 f6:=Coefficient(f,6);
 h0:=Coefficient(h,0);
 h1:=Coefficient(h,1);
 h2:=Coefficient(h,2);
 h3:=Coefficient(h,3);

b11:=x1^2*y4^2+y3^2*x2^2*f5^2+x3^2*y2^2*f5^2-4*x1^2*y3^2*f6*f2-4*y4*x3^2*f6*y1-4*y3*y4*x2^2*f6-4*x3^2*f6*f2*y1^2-4*x2^2*f6*y3^2*f4-4*x2^2*f6*f0*y1^2-4*y2^2*x1^2*f6*f0-4*x3^2*f6*y2^2*f4-4*x3^2*f6*y2*f3*y1+8*y2*f0*f6*x1*x2*y1+4*f1*y2*f6*x1*x3*y1+4*y3*f1*x1*f6*x2*y1+4*x3*f6*x2*y3*f3*y1+8*y3*x1*f2*x3*f6*y1-2*y3*x3*f5^2*x2*y2+2*x3*y2*y4*x1*f5+4*y3*y4*x1*f6*x3-2*y3*y4*x1*f5*x2+4*x3*y2*y4*f6*x2-4*x3*f6*x2*f1*y1^2+8*x3*f6*x2*y3*y2*f4-4*x1^2*y3*y2*f6*f1+4*y3*x1*y2*f3*x3*f6-4*y3^2*x1*f3*x2*f6-x2^2*y1^2*f6*h0^2-x2^2*y1^2*f0*h3^2-x3^2*y1^2*f6*h1^2-x3^2*y1^2*f2*h3^2-y2^2*x1^2*f6*h0^2-y2^2*x1^2*f0*h3^2-x3^2*y2^2*f4*h3^2-x1^2*y3^2*f6*h1^2-x1^2*y3^2*f2*h3^2-y3^2*x2^2*f6*h2^2-y3^2*x2^2*f4*h3^2-x3^2*y2^2*f6*h2^2-y4*x3^2*y1*h3^2-y3*y4*x2^2*h3^2-2*y3*x2*y2*f6*h0*h2*x1+y3*x1*f5*x2*h0*h3*y2+2*y3*x1*y2*x3*f6*h1*h2+x3*y2*y4*x2*h3^2+x3*y2*y4*x1*h2*h3-y3*y4*x1*x2*h2*h3-x1^2*y4*h0*h3*y2+x1*y1*y4*h1*h3*x3-x3*y2^2*x1*f5*h0*h3+x1*y1*y4*h0*h3*x2+2*y3*x3*x2*y2*f6*h2^2+y3*y4*x1*x3*h3^2+2*y3*x3*x2*y2*f4*h3^2+y3*x1*y2*x3*f3*h3^2+y3*x1*x2*y1*f1*h3^2+x3*y2*f5*y1*h0*h3*x2-2*x3^2*y2*y1*f6*h1*h2+x3^2*y2*f5*y1*h1*h3-y3^2*x1*x2*f3*h3^2+2*y3*x1*x3*y1*f2*h3^2-x1^2*y3*y2*f1*h3^2-2*x1^2*y3*y2*f6*h0*h1-2*y3*x3*x2*y2*f5*h2*h3+2*y2*x1*x2*y1*f6*h0^2+2*y2*x1*x2*y1*f0*h3^2+y2*x1*x3*y1*f1*h3^2+2*y2*x1*x3*y1*f6*h0*h1-x3^2*y2*y1*f3*h3^2-x3*x2*y1^2*f1*h3^2-2*x3*x2*y1^2*f6*h0*h1+2*x3*y2^2*f6*h0*h2*x1+x3^2*y2^2*f5*h2*h3+y3^2*x2^2*f5*h2*h3+2*y3*x1*x2*y1*f6*h0*h1+2*y3*x1*x3*y1*f6*h1^2+2*x3*x2*y3*y1*f6*h1*h2-y3*x2*f5*y1*h1*h3*x3+x3*x2*y3*y1*f3*h3^2-y3*x2^2*f5*y1*h0*h3-2*y3^2*x1*x2*f6*h1*h2-x1^2*y4*h1*h3*y3+2*y3*x2^2*f6*h0*h2*y1-x3*y2*x1*f5*h1*h3*y3-2*x3*y2*f6*x2*h0*h2*y1+y3^2*x1*f5*x2*h1*h3+x4^2*y1^2+y3*x4*x3*y1*h3^2+2*y3*x4*x2*f5*y1+4*y3*x4*x3*f6*y1+y3*x4*x2*y1*h2*h3-y1^2*x4*h0*h3*x2-2*x4*x3*y2*f5*y1-x4*x3*y2*y1*h2*h3+x1*y1*h0*h3*y2*x4+4*y3*x4*x2*y2*f6+y3*x4*x2*y2*h3^2+x1*y1*h1*h3*y3*x4-4*x4*x3*y2^2*f6-x4*x3*y2^2*h3^2-4*y3^2*x1*f6*x4-y3^2*x1*x4*h3^2-2*y4*x1*x4*y1-y1^2*x4*h1*h3*x3;
b12:=4*f1*x3^2*f6*y1^2+4*x3^2*f5*f2*y1^2+4*y4*x3^2*f5*y1+2*y3*y4*f5*x2^2+4*y2^2*f0*f5*x1^2+4*y3^2*x1^2*f5*f2+4*x3^2*y2^2*f6*f3+4*y3^2*f1*x1^2*f6+4*y3^2*x2^2*f6*f3+4*y2*y4*x3^2*f6+2*y3*y4*x1^2*f3+4*f0*f5*x2^2*y1^2+2*x1*x2*y4^2-8*y3*x3*y2*f6*x2*f3-2*x3*f5*x2*y3*f3*y1-8*y3*x3*f6*x2*f2*y1+4*y3*f1*x1*f6*x2*y2+8*y3^2*f6*x2*x1*f2-8*y3*x1*f2*x3*y2*f6-2*y3*x1*y2*f3*x3*f5-8*y3*f0*f6*x1*x2*y1-4*f1*y2*f5*x1*x3*y1+2*y3^2*x1*f3*x2*f5-4*x1*x2*y3*f5*f1*y1+4*y3*y2*f1*x1^2*f5+8*y3*y2*f0*x1^2*f6-4*y3*f1*f6*x2^2*y1+4*y3*y4*x1*x2*f4-4*y3*y4*x3*f6*x2-4*y3*y4*x3*x1*f5-2*y4*x1*f3*x3*y1-2*y2*y4*x3*f5*x2-4*y2*y4*x1*f4*x3-8*y3*f1*f6*x1*x3*y1-8*y3*x1*f2*x3*f5*y1+4*f1*y2*f6*x3*x2*y1-8*y2*f0*f5*x1*x2*y1-4*f1*y2^2*f6*x1*x3-8*y2*f0*x1*f6*x3*y1+4*f1*f5*x3*x2*y1^2+8*y2*f2*x3^2*f6*y1+2*x3^2*y2*f5*f3*y1+8*f0*x3*f6*x2*y1^2+x3^2*y2^2*f3*h3^2+x2^2*y1^2*f5*h0^2+x3^2*y1^2*f5*h1^2+y2^2*x1^2*f5*h0^2+x1^2*y3^2*f5*h1^2+x1^2*y3^2*f1*h3^2+y3^2*x2^2*f3*h3^2+y2*y4*x3^2*h3^2+x3^2*y1^2*f1*h3^2+x3^2*y2*y1*f3*h2*h3-2*x3^2*y2*f4*y1*h1*h3+x1*f3*x3*y1*h0*h3*y2-2*y2*x1*x3*y1*f5*h0*h1-2*y2*x1*x3*y1*f1*h2*h3+2*y2^2*x1*f4*x3*h0*h3+2*y2^2*x1^2*f0*h2*h3-2*y2*x1*x3*y1*f6*h0^2-2*y2*x1*x3*y1*f0*h3^2-2*y2*x1*x2*y1*f5*h0^2-4*y2*x1*x2*y1*f0*h2*h3+2*x3^2*y2^2*f6*h1*h2-x3*y2*y4*x2*h2*h3-2*x3*x2*y3*y1*f6*h1^2-y4*x1*x3*y1*h1*h2-x3^2*y2^2*f5*h1*h3+y3^2*x1*x2*f3*h2*h3+2*y3^2*x2^2*f6*h1*h2+2*x1*y3*f3*y1*h1*h3*x3+2*y3*x2*f4*y1*h1*h3*x3-y3*x2^2*y1*f1*h3^2-2*y3*x2^2*y1*f6*h0*h1-y3*x1*y2*x3*f3*h2*h3+y3*x1*y2*x3*f5*h0*h3-y3*x1*y2*x3*f5*h1*h2+y3*x1*x2*y2*f1*h3^2+2*y3*x1*x2*y2*f6*h0*h1+2*y3^2*x1*x2*f6*h0*h2-2*y3*x1*y2*x3*f2*h3^2-2*y3*x1*y2*x3*f6*h0*h2-2*y3*x1*y2*x3*f6*h1^2+2*y3*x2*y2*f5*h1*h3*x3+2*x1^2*y3*y2*f6*h0^2+2*x1^2*y3*y2*f0*h3^2-2*y3*x1*x2*f4*h0*h3*y2+2*x1^2*y3*y2*f5*h0*h1-4*y3*x3*x2*y2*f6*h1*h2-2*y3*x3*x2*y2*f3*h3^2-x3*x2*y3*y1*f5*h1*h2-2*x3*x2*y3*y1*f6*h0*h2-2*x3*x2*y3*y1*f2*h3^2+2*y3^2*x1*x2*f6*h1^2+2*y3^2*x1*x2*f2*h3^2-2*y3*x1*x3*y1*f5*h1^2-2*y3*x1*x3*y1*f1*h3^2-4*y3*x1*x3*y1*f6*h0*h1-2*y3*x1*x2*y1*f6*h0^2-2*y3*x1*x2*y1*f0*h3^2-2*y3*x1*x2*y1*f5*h0*h1-y3*x1^2*f3*h0*h3*y2+2*x1^2*y3*y2*f1*h2*h3-y3^2*x1*x2*f5*h0*h3+y3^2*x1*x2*f5*h1*h2+y3*x2*y2*f5*h0*h2*x1+2*x1^2*y3^2*f2*h2*h3+2*x1^2*y3^2*f6*h0*h1+2*y3*x2^2*f4*y1*h0*h3-x3*x2*y3*y1*f3*h2*h3+x3*x2*y3*y1*f5*h0*h3-4*y3*x1*x3*y1*f2*h2*h3-2*y3*x1*x2*y1*f1*h2*h3-x3^2*f3*y1^2*h1*h3+2*x3*x2*y1^2*f5*h0*h1+2*x3*x2*y1^2*f6*h0^2+2*x3*x2*y1^2*f0*h3^2-y2^2*x1*x3*f1*h3^2-x3*f3*y1^2*h0*h3*x2-2*y2^2*x1*x3*f6*h0*h1-x3*y2^2*f5*h0*h2*x1+2*x3*x2*y1^2*f1*h2*h3+2*x3^2*y1^2*f2*h2*h3+2*x3^2*y1^2*f6*h0*h1+2*y4*x3^2*y1*h2*h3+2*x2^2*y1^2*f0*h2*h3-2*x3*y2*f4*y1*h0*h3*x2-x3^2*y2*y1*f5*h0*h3+x3^2*y2*y1*f5*h1*h2+2*x3^2*y2*y1*f6*h0*h2+2*x3^2*y2*y1*f6*h1^2+2*x3^2*y2*y1*f2*h3^2+y2*x3*x2*y1*f1*h3^2+2*y2*x3*x2*y1*f6*h0*h1+y3*y4*x1*x2*h2^2-y4*x1*x3*y1*h0*h3+x2*y1*y4*h1*h3*x3+y2*x1^2*y4*h0*h2+x2^2*y1*y4*h0*h3-x2*y1*y4*h0*h2*x1+x1*y3*f3*y1*h0*h3*x2-x3*y2*y4*x1*h2^2-x1*x2*y4*h0*h3*y2+y3*y4*x1^2*h0*h3-x3*y2*y4*x1*h1*h3+y3*y4*x2^2*h2*h3+y3*y4*x1^2*h1*h2-y3*y4*x3*x2*h3^2-2*y3*y4*x1*x3*h2*h3-y3*f5*x2^2*h0*h2*y1+2*y2*x1*f4*x3*h1*h3*y3-y3^2*f5*x2^2*h1*h3+y2*x3*f5*x2*h0*h2*y1-2*y3^2*x1*x2*f4*h1*h3-y3^2*x1^2*f3*h1*h3+2*x4^2*y2*y1+2*x4*x3*f3*y1^2+2*x4*x3*y2^2*f5+4*y3^2*x4*x1*f5+4*y3^2*x4*x2*f6+y3^2*x4*x2*h3^2-2*y4*x4*x2*y1-2*y2*y4*x1*x4+x4*x3*y1^2*h1*h2+x4*x3*y1^2*h0*h3+x2*y1^2*h0*h2*x4-y2*y1*x4*h0*h2*x1-y2*y1*x4*h0*h3*x2+y2^2*x1*h0*h3*x4+x4*x3*y2^2*h2*h3+4*x4*x3*y2*f4*y1+x4*x3*y2*y1*h2^2-2*y3*x2*y2*f5*x4+2*y3^2*x1*x4*h2*h3-4*y3*x4*x3*f5*y1-2*y3*x4*x3*y1*h2*h3-2*x1*x4*y3*f3*y1-x1*x4*y3*y1*h0*h3-x1*x4*y3*y1*h1*h2-4*y3*x4*x2*f4*y1-y3*x4*x2*y1*h1*h3-y3*x4*x2*y1*h2^2-4*y3*x4*x3*y2*f6+y2*x1*h1*h3*y3*x4-y3*x4*x3*y2*h3^2-y3*x4*x2*y2*h2*h3;
b13:=-2*y3^2*f1*x1^2*f5+4*y3*y4*x3^2*f6+8*f0*x1^2*f2*y1^2-2*x3^2*f5*f1*y1^2+8*y3^2*x3^2*f6*f4+4*y4*x1^2*f0*y1+8*y2^2*f0*f6*x2^2+2*x1*x3*y4^2-2*y3^2*x3^2*f5^2-2*f1^2*x1^2*y1^2+4*x1*x3*y3*y2*f5*f2-4*y3^2*f1*x1*f6*x2+2*y3*x1^2*f3*f1*y1+2*y3*x2^2*f5*f1*y1+4*y3*x3^2*y2*f6*f3+4*y3*y4*x1*f4*x3+2*y3*x3^2*f5*f3*y1+4*y3^2*x3*f6*x2*f3+4*x1^2*f0*y2*f3*y1+4*y2*f0*f5*x2^2*y1-8*y3*y2*f0*x1*f6*x2+2*y3*x2*y2*f5*x1*f1+8*y3*x2*y2*f6*x3*f2+2*x1*f3*x3*f1*y1^2+4*f0*f3*x1*x2*y1^2+4*f1*y2*f4*x1*x3*y1+8*x1*x3*y3*f6*f0*y1+8*x1*x3*y3*f4*f2*y1-4*x1^2*f0*y2*y3*f5+4*y3*x2^2*y2*f6*f1+2*y3*y4*x3*f5*x2-4*f0*f5*x3*x2*y1^2+8*y2*f0*x1*x2*f4*y1-8*y2*f0*x3*f6*x2*y1+4*y3*x2*f5*x3*f2*y1+4*y3*x1*f4*x2*f1*y1+2*y4*f1*x1*x2*y1+4*y4*f2*x1*x3*y1-4*y2*f1*x3^2*f6*y1-2*x1*x3*y3*f3^2*y1+2*y2*y4*x1*f3*x3+2*x1*x3*y2^2*f5*f1+2*x3*y2*f5*x2*f1*y1+4*y2^2*f0*f5*x1*x2+4*x3*y2^2*f6*x2*f1+2*x1*x3*f3*y3^2*f5+y4*x1^2*y1*h0^2+y3*y4*x3^2*h3^2+2*y2^2*x2^2*f6*h0^2+2*y2^2*x2^2*f0*h3^2+2*y3^2*x3^2*f6*h2^2+2*y3^2*x3^2*f4*h3^2+2*x1^2*y1^2*f0*h1^2+2*x1^2*y1^2*h0^2*f2+y2*x2^2*y1*f5*h0^2+2*y2*x2^2*y1*f0*h2*h3+y2*x3*x2*y1*f5*h0*h1+y2*x3*x2*y1*f1*h2*h3+2*x1^2*y2*y1*f0*h1*h2+x1^2*y2*y1*h0^2*f3-y2^2*x1*f3*x3*h0*h3-2*f2*x1*x3*y1*h0*h3*y2-2*y2*x3*x2*y1*f6*h0^2-x3^2*y2*y1*f1*h3^2-2*f1*x1*x2*y1*h0*h3*y2+4*y2*x1*x2*y1*f0*h1*h3+2*y2*x1*x2*y1*f0*h2^2+2*y2*x1*x2*y1*f4*h0^2-y4*x3*x2*y1*h0*h3+2*y3*x3^2*y2*f6*h1*h2+y3*x1*y2*x3*f5*h1^2+2*y3*x1*x3*y1*f6*h0^2+x1*x3*y3^2*f5*h1*h2-x3*x2*y1^2*f5*h0^2+y2*x2*y4*h0*h2*x1-y3*y4*x1^2*h0*h2-y3*y4*x1*x3*h1*h3+x3*y2*y4*x1*h1*h2+4*y3*x3*x2*y2*f6*h0*h2-x3^2*y1^2*f5*h0*h1-2*x3*x2*y1^2*f0*h2*h3+2*x3*x2*y3*y1*f2*h2*h3+y3*x1^2*y1*f3*h0*h1+y3*x3^2*y2*f3*h3^2-2*y3*x1*f4*x3*h0*h3*y2-2*y3*x3*f5*y2*h0*h3*x2-x1^2*y3*y2*f5*h0^2+y3*x1*y2*x3*f5*h0*h2+2*y3*x1*y2*x3*f2*h2*h3+y3*x1^2*y1*f1*h0*h3+2*x1*x2*y1^2*f0*h1*h2+x1*x2*y1^2*h0^2*f3+2*y2^2*x1*x2*f0*h2*h3+y2^2*x1*x2*f5*h0^2+x3*y2^2*x2*f1*h3^2+y2^2*x1*x3*f5*h0*h1-2*x1^2*y3*y2*f0*h2*h3-x3^2*y1^2*f1*h2*h3-2*y3*x1*x3*y1*f3*h1*h2+x3*x2*y3*y1*f5*h1^2-y3^2*x1*x2*f1*h3^2+y2*x2^2*y4*h0*h3+y2*x2*y4*h1*h3*x3-x3*y2*y4*x1*h0*h3+y3*y4*x3*x2*h2*h3+y4*x1*x2*y1*h0*h1-y4*x1*x3*y1*h0*h2-y4*x3^2*y1*h1*h3+y4*x1*x3*y1*h1^2+2*x3*y2^2*x2*f6*h0*h1+2*y2*x1*x3*y1*f4*h0*h1+y2*x1*x3*y1*h1*h3*f1+y2*x1*x3*y1*h2^2*f1+y2^2*x1*x3*f1*h2*h3-2*x3^2*y2*y1*f6*h0*h1-y2*f1*x1^2*y1*h0*h2-y3*y4*x1*x2*h0*h3+y3*y4*x1*x3*h2^2+y3*x1^2*y1*f1*h1*h2-y3*x2*f3*y1*h1*h3*x3-2*y3*x3*f4*y1*h0*h3*x2+2*y3*x1*x3*y1*h2^2*f2-2*y3*x1^2*f2*y1*h0*h2+x1*x3*y3^2*f3*h2*h3+x1*x3*y3^2*f5*h0*h3+2*y3*x1*x3*y1*f0*h3^2+y3*x3^2*y1*f3*h2*h3+y3*x3^2*y1*f5*h0*h3+y3*x3^2*y1*f5*h1*h2-2*y3*x1*x3*y1*f3*h0*h3+2*y3*x2^2*y2*f6*h0*h1+2*y3*x1*x3*y1*f4*h1^2-2*y2*x3*x2*y1*f0*h3^2-2*x1^2*y1^2*f1*h0*h1+2*y3*x3*x2*y2*f6*h1^2+2*y3*x3*x2*y2*f2*h3^2-2*y3^2*x1*x2*f6*h0*h1-2*y3*x3^2*f4*y1*h1*h3-y3*x3^2*f5*y2*h1*h3+y3^2*x3*x2*f3*h3^2-2*y3^2*x3^2*f5*h2*h3-x1^2*y3^2*f5*h0*h1+x1*x3*y1^2*f3*h0*h1+x1*x3*y1^2*f1*h0*h3+x1*x3*y1^2*f1*h1*h2-2*f0*x1*y1^2*h1*h3*x3+2*y3*x1*x2*y1*f4*h0*h1+y3*x1*x2*y1*h1*h3*f1-y3*x2^2*f3*y1*h0*h3-2*y3^2*x3*f6*h0*h2*x1+2*y3^2*x3*x2*f6*h1*h2+y3*x1*x2*y2*f5*h0*h1+y3*x1*x2*y2*f1*h2*h3-2*y3*x1*x2*y2*f6*h0^2+y3*x2^2*y2*f1*h3^2-2*y3*x1*f2*y1*h0*h3*x2+y3*x2^2*y1*f5*h0*h1+y3*x2^2*y1*f1*h2*h3-x1^2*y3^2*f1*h2*h3-2*y3*x1*x2*y2*f0*h3^2+x3*x2*y3*y1*f5*h0*h2-y3*x2*f3*y1*h0*h2*x1+y3*x1*x2*y1*h2^2*f1-f1*x2*y1^2*h0*h2*x1-x3*f3*y2*y1*h0*h2*x1-2*x3*f2*y1^2*h0*h2*x1-y3*y2*f3*x1*h1*h3*x3-2*x1*y3^2*f4*h1*h3*x3-y3^2*f5*x2*h1*h3*x3-2*y3*x3^2*f6*h0*h2*y1-2*x1^2*f0*y1*h1*h3*y3+2*y3*x4^2*y1+4*y3*x4*x3*f4*y1-y3^2*x1*x4*h1*h3-x4*x3*y1^2*h0*h2+4*f0*x1*x4*y1^2+x1*x4*y1^2*h0^2+y2^2*x2*h0*h3*x4+4*y3^2*x4*x3*f6+y3^2*x4*x3*h3^2+2*y4*x4*x3*y1-2*y2*y4*x4*x2+2*y3*y4*x1*x4-x4*x3*y2*y1*h0*h3+y2*x2*h0*h2*y1*x4+y2*x1*x4*y1*h0*h1+2*y2*f1*x1*x4*y1+2*y3*x4*x2*f3*y1-y3*x4*x3*y1*h1*h3+4*y3*x1*f2*x4*y1+y3*x4*x2*y1*h1*h2-x1*x4*y3*y1*h0*h2+x1*x4*y3*y1*h1^2-y3*x4*x2*y1*h0*h3+y3*x4*x3*y1*h2^2+2*y3*x3*f5*x4*y2-x1*x4*y3*y2*h0*h3+y2*x2*h1*h3*y3*x4+y3*x4*x3*y2*h2*h3;
b14:=4*y2^2*f6*x1^2*f1^2+4*f0*f3^2*x1^2*y1^2-16*f6*x1^2*f0^2*y1^2+4*x2^2*f6*f1^2*y1^2-16*y3^2*f2*x3^2*f6^2+4*y3*y4*x3^2*f5^2-16*f0*f6^2*x2^2*y3^2+4*f0*f5^2*x1^2*y3^2+4*y2^2*f0*f5^2*x2^2+4*x1^2*f4*f1^2*y1^2-16*y2^2*f0*f6^2*x3^2+4*x3^2*f5^2*f0*y1^2+4*x3^2*f5^2*y3^2*f4-16*x3^2*f6*f4^2*y3^2+8*f0*f6*x1*x3*y2*f3*y1-8*f1*x3*f6*x1*y2*f2*y1-8*y2*f0*f5*f4*x1*x3*y1-2*x3*y2*f5*x1*f1*f3*y1-4*y2^2*f0*f5^2*x1*x3-8*x3*f6*x2*f1*y2^2*f4+2*x3*y2^2*f5^2*x2*f1-8*y3*x3*y2*f5*x2*f6*f1-16*x3*f6*x2*f2*y3*y2*f4-8*y2*y4*x3*f6*x2*f2+16*f0*f2*f6*x1*x3*y1^2-16*f0*f6*x2^2*y2^2*f4-16*y3*y4*x3^2*f6*f4-8*y3*y4*x3*f6*x2*f3-8*y3*y4*f6*x1^2*f0-12*y4*f0*x1*x2*f5*y1-4*y2*y4*x3^2*f6*f3-8*y3*f1*x3^2*f6*f5*y1+8*y3^2*x3^2*f5*f6*f3-8*x3*f6*x2*f3*y3^2*f4-16*y3^2*x3*f6^2*x2*f1-8*f0*x1*f6*x2*f1*y1^2-16*y3*y2*f1*f6^2*x3^2+2*y3*x2^2*y2*f5^2*f1+16*y3*f2*f6*x1^2*f0*y1-16*y3*f0*f4*f6*x1*x3*y1-16*y3*f2^2*x3*f6*x1*y1-8*y2*f0*f5*f6*x3^2*y1+8*y3*f0*f6*f3*x1*x2*y1-8*y3*f0*f4*x1*x2*f5*y1-8*y3*x1*f2*x2*f1*f6*y1-8*y3*x1*f2*x3*y2*f6*f3-8*y3*y2*f0*x1^2*f6*f3+4*y3^2*x1^2*f3*f6*f1-16*f6*x1^2*f0*y3^2*f4-8*y3^2*x3*f5*x1*f6*f1-4*y3*x3*f5^2*x2*f1*y1-4*x3^2*f6*f3^2*y3*y1-4*y3*x3*y2*f5^2*x1*f1-16*y3*y2*f0*f6^2*x3*x2-8*y3*y4*x1*f2*x3*f6-8*f1^2*f6*x1*x3*y1^2-8*f0*f3*f5*x1*x3*y1^2-8*x3*f6*x2*f2*y3*f3*y1-8*y2*f0*f5*f3*x1*x2*y1-8*y2^2*f0*f6*x3*x2*f5-16*y2*f0*f5*x1^2*f2*y1-8*y3*f1^2*x1^2*f6*y1-16*y2^2*f2*f6*x1^2*f0-16*y2^2*f0*f6*f3*x1*x2-4*y3*y4*f1*x1*f6*x2-8*y2*y4*f0*x1*f6*x2-4*y2*y4*x1*f2*x3*f5-4*y2*y4*x2^2*f6*f1-8*y2*f1*f6*x1^2*f0*y1+4*y2*f5*x1^2*f1^2*y1-2*f1*x1*x2*f5*y3*f3*y1-4*y3^2*x1*f3^2*x3*f6-8*y3*x1*y2*f3*x2*f6*f1+8*y4*f0*f6*x1*x3*y1-8*y3^2*f0*f5*x1*f6*x2-2*y2*y4*f1*x1*x2*f5-4*y2*y4*f0*f5*x1^2-8*y4*x3*f6*x2*f1*y1-16*y4*f0*f6*x2^2*y1+2*y3^2*x2*f5^2*x3*f3+16*y3*x1*f3*x3*f1*f6*y1+8*y3*f0*f5^2*x1*x3*y1-8*x3*f6*x2*f3*f0*y1^2-8*y3*y2*f0*f5*f6*x2^2+2*y4*x1^2*f3*f1*y1-2*y3*y4*x1*f3*x3*f5-16*f0*f4*x1^2*f2*y1^2+4*y3*x3*f5^2*x2*y2*f2-8*x2^2*f6*f1*y3*y2*f4-4*y3*f0*f5^2*x2^2*y1-4*x2^2*f6*f1*y3*f3*y1-4*y4*x3*x1*f5*f1*y1-8*y3*x3*f5*x1*f4*f1*y1-4*x3*y2^2*f6*x1*f1*f3+16*y3^2*f0*x1*f6^2*x3-16*x3^2*f6*f4*f0*y1^2-4*y2*f0*f5^2*x3*x2*y1-8*x3*f6*x2*f1*y2*f3*y1-32*y2*f0*f6*x1*x2*f2*y1+4*y2*f6*x1*x2*f1^2*y1-8*y3*f0*f5*x1^2*f3*y1+2*y3*x3^2*f5^2*y2*f3-4*y3*y2*f0*f5^2*x1*x2-16*f0*f5*x1*x2*f2*y1^2-16*f0*f6*x2^2*f2*y1^2+4*x3^2*f6*f3*f1*y1^2+4*f1^2*x1*x2*f5*y1^2-8*y4*f4*x1^2*f0*y1-16*f0*f6*x2^2*y2*f3*y1+16*y3*f0*f6^2*x3^2*y1-8*x3^2*f6*f3*y3*y2*f4-x1^2*y1^2*f6*h0^4-4*x1^2*y1^2*f0^2*h3^2+x2^2*y1^2*f1^2*h3^2+x3^2*y1^2*f5^2*h0^2-x3^2*y2^2*f0*h3^4+y2^2*x1^2*f1^2*h3^2+y2^2*x2^2*f5^2*h0^2-4*x3^2*y2^2*f6^2*h0^2-y3^2*x2^2*f0*h3^4-4*y3^2*x2^2*f6^2*h0^2+x1^2*y1^2*f1^2*h2^2+y3^2*x3^2*f5^2*h2^2-y3^2*x3^2*f2*h3^4-4*y3^2*x3^2*f6^2*h1^2-y3^2*x3^2*f6*h2^4-4*y3^2*x3^2*f4^2*h3^2+h0*h2*x1^2*y4^2+x1^2*y3^2*f5^2*h0^2+x1^2*y1^2*f3^2*h0^2-y3*x1*x2*y2*f6*h0*h1^2*h2-y3*x1*x2*y2*f3*h0*h1*h3^2-4*y3*x2^2*y2*f0*f6*h2*h3+y3*x2^2*y2*f6*h0^2*h2*h3+4*y3*x3*y2*f6*f3*h0*h3*x2-2*y3*x1*y2*x3*f5^2*h0*h1-4*y3*x1*y2*x3*f1*f5*h2*h3-3*y3*x1*y2*x3*f5*h0*h1*h2*h3-y3*x1*y2*x3*f1*h2^2*h3^2+y3*x3^2*y1*f2*h3^3*h1+2*x1^2*y3*f5*f1*y1*h0*h2+x1^2*y3*y1*f1*h2^2*h3*h0+2*y3^2*x3^2*f3*f5*h3^2+y3^2*x3^2*f5*h0*h3^3+y3^2*x3^2*f3*h2*h3^3-4*y3*x1*x3*y1*f2^2*h3^2+x1*y3*y2*f1*h3^3*h1*x3-2*y3*x3^2*y2*f3*f6*h2^2-2*y3*x3^2*y2*f3*f4*h3^2+4*y3*x3^2*y2*f4*f6*h0*h3+y3*x3^2*y2*f6*h0*h2^2*h3+4*x1^2*y3^2*f1*f6*h0*h3+2*x1^2*y3^2*f1*f6*h1*h2+x1^2*y3^2*f1*h0*h3^3+2*x1^2*y3^2*f3*f6*h0*h1-x1^2*y3^2*f6*h0^2*h2^2+4*y3^2*x3^2*f4*f5*h2*h3+2*y2^2*x1*f0*h3^3*h1*x3-4*y3*x1*y2*x3*f2*f6*h1*h2-2*y3*x1*x2*y1*f1*f2*h3^2-y3*x1*x2*y1*f6*h0*h1^3-4*y3*x3^2*y1*f5*f6*h0*h1-2*y3*x3^2*y1*f1*f5*h3^2+4*x3^2*y1^2*f0*f5*h2*h3+8*y3*x3*x2*y2*f4*f6*h0*h2-x1^2*y3*y2*f3*h0^2*h3^2-2*y3*x2^2*y2*f5*f6*h0^2+4*y2*x1*x2*y1*f0*f5*h0*h3-4*x3^2*y1^2*f0*f6*h1*h3+y3*x2^2*y2*f5^2*h0*h1+x3^2*y1^2*f5*h0^2*h2*h3-2*x3*x2*y1^2*f0*f3*h3^2-4*x3^2*y1^2*f0*f6*h2^2+x3*y2^2*x2*f2*h3^3*h0-8*y3^2*x3*x2*f6^2*h0*h1-y3^2*x3*x2*f5^2*h0*h3+4*y2^2*x1^2*f1*f6*h0*h1+2*y3*x1^2*y1*f6*h0^3*h2+y3^2*x3*x2*f5^2*h1*h2+2*y3^2*x3*x2*f3*f5*h2*h3-y3^2*x3*x2*f5*h0*h2*h3^2+y3^2*x3*x2*f5*h1*h2^2*h3-4*x1*x3*y3^2*f5*f6*h0*h1-2*x1*x3*y3^2*f1*f5*h3^2-4*x1*x3*y3^2*f1*f6*h2*h3-x1*x3*y3^2*f1*h2*h3^3-2*y3^2*x3*f5^2*h0*h2*x1-4*y3*x1*x2*y1*f2*f6*h0*h1-4*x1^2*y3^2*f4*f6*h0^2-2*y3^2*x3*x2*f3*f4*h3^2-2*y3*x3*x2*y2*f5*h0*h2^2*h3-4*x1^2*y3^2*f0*f4*h3^2-x1^2*y3^2*f4*h0^2*h3^2-x1^2*y3^2*f0*h1*h3^3+x2^2*y1^2*f1*h0*h1*h3^2+8*x1*x3*y3^2*f0*f6*h3^2-8*y3^2*x3^2*f2*f6*h3^2+4*y3^2*x2^2*f6*f3*h0*h3-2*x1*x3*y1^2*f3*f5*h0^2+2*y3*x1*x3*y1*f1*h1*h2*h3^2-x1*x3*y3^2*f6*h1^2*h2^2-y3^2*x1*x2*f5*h0^2*h3^2-4*x3*x2*y1^2*f0*f6*h1*h2-3*x3*x2*y1^2*f6*h0^2*h1*h2-x3*x2*y1^2*f3*h0^2*h3^2-4*x1^2*y1^2*f0*f2*h1*h3+8*y3*x1*x3*y1*f2*f6*h0*h2-y3*x1*x3*y1*f2*h1^2*h3^2-4*y3*x1*x3*y1*f6*h0^2*h2^2+y3*x2*y1*f5*h1^3*h3*x3+y3*x3*y1*f5*h0^2*h3^2*x2+4*y3*x1*x3*y1*f1*f6*h0*h3+8*y3*x1*x3*y1*f1*f6*h1*h2+4*y3*x1*x3*y1*f1*f3*h3^2+y3*x1*x3*y1*f1*h0*h3^3-x3*x2*y3*y1*f6*h1^3*h2-2*x3*x2*y3*y1*f2*f3*h3^2-x3*x2*y3*y1*f3*h1^2*h3^2-4*x1^2*y3*y2*f6*f1*h0*h2+4*y3*x2*y2*f6*f2*h0*h2*x1-2*y3*x2*y2*f6*h0^2*h2^2*x1-y3*x1*x2*y2*f5^2*h0^2+4*x1*x2*y1^2*f1*f5*h0*h1+2*x1*x2*y1^2*f1^2*h2*h3+x1*x2*y1^2*f1*h0*h1*h2*h3-x1^2*y1^2*f0*h0^2*h3^2+x1^2*y3^2*f1*f3*h3^2+x1^2*y1^2*f3*h0^3*h3+4*x1^2*y1^2*f1*f4*h0*h1+x1^2*y1^2*f1^2*h1*h3+x1^2*y1^2*f1*h0*h1^2*h3+4*f0*f5*x2^2*y1^2*h0*h3-8*x1^2*y1^2*f0*f6*h0^2-4*x1^2*y1^2*f0*f4*h1^2-x1^2*y1^2*f2*h0^2*h1*h3-4*y3*x1*x3*y1*f0*f6*h2^2-4*y3*x1*x3*y1*f0*f4*h3^2-y3*x1*x3*y1*f4*h0^2*h3^2-3*y3*x1*x3*y1*f0*h1*h3^3-8*y3*x1^2*y1*f1*f6*h0*h1-2*y3*x1^2*y1*f1*h0*h1*h3^2+4*y3*x2*f5*f2*y1*h1*h3*x3-4*y3*x3*x2*y2*f6^2*h0^2+2*y3*x1*x2*y1*f3*f6*h0^2+2*y3*x1*x2*y1*f0*f3*h3^2+y3*x1*x2*y1*f3*h0^2*h3^2-2*x3*x2*y3*y1*f5^2*h0*h1-8*y3*x3^2*y2*f6^2*h0*h1-2*y3*x3^2*y2*f6*h0*h1*h3^2-y3*x3^2*y2*f1*h3^4-2*y3*x3*x2*y2*f5^2*h0*h2+y3*x3*x2*y2*f5^2*h1^2+4*y3*x3*x2*y2*f2*f5*h2*h3+y3*x3*x2*y2*f5*h1^2*h2*h3-y3*x3^2*y2*f5^2*h0*h3+y3*x3^2*y2*f5^2*h1*h2+2*y3*x3^2*y2*f3*f5*h2*h3-y3*x3^2*y2*f5*h0*h2*h3^2+y3*x3^2*y2*f5*h1*h2^2*h3-y3*x1*x2*y2*f0*h2^2*h3^2+4*x1*x3*
     y1^2*f0*f2*h3^2-2*y3^2*x1*x2*f0*f5*h3^2-y2^2*x1*x2*f3*h0^2*h3^2+y3*x1*x2*y2*f5*h0^2*h2*h3+6*y3*x1*x3*y1*f6*h0*h1^2*h2-4*y3*x2^2*y1*f1*f6*h0*h3-2*y3*x2^2*y1*f1*f6*h1*h2-2*y3*x2^2*y1*f3*f6*h0*h1-y3*x2^2*y1*f6*h0*h1^2*h2-y3*x2^2*y1*f3*h0*h1*h3^2+8*y3*x1*x3*y1*f3*f6*h0*h1-4*x3*x2*y3*y1*f1*f5*h2*h3-3*x3*x2*y3*y1*f5*h0*h1*h2*h3-x3*x2*y3*y1*f1*h2^2*h3^2+2*x3^2*f5*y3*f3*y1*h1*h3+4*y3*x3^2*f2*f6*y1*h1*h3+y3*x3^2*y1*f5*h1^2*h2*h3+2*y3*x1*x2*y2*f6*h0^2*h1*h3+4*x1^2*y3^2*f0*f5*h2*h3+x1^2*y3^2*f5*h0^2*h2*h3-y2^2*x1*x3*f1*f3*h3^2-4*x1*x2*y1^2*f0*f5*h1^2-x1*x2*y1^2*f6*h0^3*h1+2*x3^2*y1^2*f1*f6*h1*h2+x3^2*y1^2*f1*f3*h3^2+x3^2*y1^2*f1*h0*h3^3+2*x3^2*y1^2*f3*f6*h0*h1-x3^2*y1^2*f6*h0*h1^2*h2+4*y2^2*f0*f5*x1^2*h0*h3-2*x1^2*y2*y1*f1*f6*h0^2+y3*x2*y2*f2*h3^2*h0*h2*x1-4*y2*x3*x2*y1*f0*f5*h2*h3+4*x1*x3*y1^2*f0*f6*h1^2-2*y2*x1*x3*y1*f0*f5*h2^2-4*y2*x1*x3*y1*f0*f4*h2*h3+2*y2*x1*x3*y1*f0*h1*h2*h3^2-y2*x1*x3*y1*f0*h2^3*h3-2*y2*x1*x3*y1*f4*f5*h0^2-y2*x1*x3*y1*f3*f5*h0*h1+2*y2*x2*f5*f1*y1*h0*h2*x1+4*y2^2*x3^2*f6*f3*h0*h3+x3*y2^2*x2*f6*h0^2*h2*h3+6*y2*x1*x3*y1*f1*f6*h0*h2-2*x3*y2^2*x2*f1*f6*h2^2-x1^2*y2*y1*f1*h0^2*h3^2-4*x1^2*y2*y1*f0*f6*h0*h1-x1^2*y2*y1*f6*h0^3*h1+x1^2*y2*y1*f0*h0*h1*h3^2+y2*x2*y1*f5*h0*h1^2*h3*x3-8*y2*x1*x2*y1*f2*f6*h0^2+2*y2*x1*x2*y1*f6*h0^3*h2-8*y2*x1*x2*y1*f0*f2*h3^2-y2*x1*x2*y1*f2*h0^2*h3^2+2*y2*x1*x3*y1*f0*f3*h3^2+y2*x1*x3*y1*f3*h0^2*h3^2-y2*x3*x2*y1*f0*h2^2*h3^2+y2*x3*x2*y1*f5*h0^2*h2*h3-y2*x1*x3*y1*f4*h0^2*h2*h3+4*y2^2*x3*f6*x2*f2*h0*h3+2*y3*x1*y2*x3*f3*h0*h2*h3^2-y2*x3*x2*y1*f3*h0*h1*h3^2+x1*y1^2*f4*h0^2*h1*h3*x3+4*x1^2*y1^2*f0*f3*h0*h3-2*x1*x2*y1^2*f1*f6*h0^2-2*x1*x2*y1^2*f0*f1*h3^2-x1*x2*y1^2*f1*h0^2*h3^2-4*x1*x2*y1^2*f0*f6*h0*h1+x1*x2*y1^2*f0*h0*h1*h3^2+4*x2^2*y1^2*f1*f6*h0*h1-x1*x3*y1^2*f6*h0^2*h1^2-2*x1*x3*y1^2*f1^2*h3^2-2*x1*x3*y1^2*f1*h0*h1*h3^2-x1*x2*y1^2*f0*h1^2*h2*h3-4*x1*x2*y1^2*f2*f5*h0^2-x1*x2*y1^2*f2*h0^2*h2*h3-x1*f1*f3*y1^2*h0*h3*x2+4*f0*f4*x1*y1^2*h0*h3*x2+2*y3*x1*x3*y1*f5^2*h0^2-2*y3^2*x3^2*f5*h1*h2*h3^2+y3^2*x3^2*f5*h2^3*h3-y3^2*x3^2*f4*h2^2*h3^2-4*y3^2*x1*x2*f0*f6*h2*h3-y3^2*x1*x2*f0*h2*h3^3-2*y3^2*x1*x2*f5*f6*h0^2-y3*x2^2*y1*f1*f3*h3^2+2*y3*x2*f5*f2*y1*h0*h2*x1+4*y3*x1*x2*y1*f0*f6*h1*h2-4*y3*x1*x3*y1*f1*f4*h2*h3-8*y3*x1*x3*y1*f2*f6*h1^2-4*y3*x1^2*y1*f0*f5*h0*h3-4*y3*x1^2*y1*f0*f5*h1*h2-4*y3*x1^2*y1*f0*f3*h2*h3-y3*x1^2*y1*f0*h1*h2^2*h3-2*y3*x1^2*y1*f3*f5*h0^2-y3*x1^2*y1*f5*h0^3*h3-y3*x1^2*y1*f3*h0^2*h2*h3-y3*x3^2*y1*f3*h0*h3^3+2*y3*x2^2*f5*f2*y1*h0*h3+y2*x2^2*y1*f6*h0^3*h3+y3^2*x3*x2*f3*h1*h3^3-2*x3*x2*y1^2*f3*f6*h0^2-x1^2*y1^2*f0*h1^3*h3-4*x1^2*y1^2*f2*f4*h0^2-2*x1^2*f1*f3*y1^2*h0*h2-4*x2^2*y1^2*f0*f6*h1^2-4*x2^2*y1^2*f2*f6*h0^2-4*y3*x1*x2*y2*f0*f5*h2*h3+4*y3^2*x3*x2*f3*f6*h1*h3+4*y3^2*x3*x2*f4*f6*h0*h3+y3^2*x3*x2*f6*h0*h2^2*h3+y3^2*x3*x2*f4*h0*h3^3-2*y3*x1*x2*y1*f0*f5*h2^2-4*y3*x1*x2*y1*f0*f4*h2*h3-y3*x1*x2*y1*f0*h2^3*h3-2*y3*x1*x2*y1*f4*f5*h0^2-y3*x1*x2*y1*f1*f5*h0*h3-y3*x1*x2*y1*f1*f5*h1*h2-y3*x1*x2*y1*f3*f5*h0*h1-y3*x1*x2*y1*f1*f3*h2*h3-y3*x1*x2*y1*f3*h0*h1*h2*h3+y2^2*x3^2*f3*h3^3*h0+x2^2*y1^2*f5*h0^3*h3+x2*y1^2*f5*h0^2*h1*h3*x3-8*x1*x3*y1^2*f1*f6*h0*h1-4*y2*x3*x2*y1*f3*f6*h0*h1-x1^2*f3*f1*y1*h0*h3*y2+4*f4*x1^2*f0*y1*h0*h3*y2-4*x1^2*y2*y1*f0*f5*h1^2-8*x1^2*y2*y1*f0*f2*h2*h3-x1^2*y2*y1*f0*h1^2*h2*h3-x1^2*y2*y1*f2*h0^2*h2*h3+y2*x2*y1*f1*h2^2*h3*h0*x1-y2*x3*x2*y1*f5^2*h0^2-y2*x1*x2*y1*f0*h1*h2^2*h3-2*y2*x1*x2*y1*f3*f5*h0^2+y2*x1*x2*y1*f5*h0^3*h3-4*y2*x1*x2*y1*f0*f3*h2*h3-4*y2^2*x2^2*f0*f4*h3^2+y2*x2^2*f5*f1*y1*h0*h3+y2*x2^2*y1*f5*h0^2*h1*h3+y2*x2^2*y1*f1*h2*h3^2*h0-4*x1^2*y1^2*f0*f2*h2^2-x2^2*y1^2*f0*h1^2*h3^2+4*y2*x3*x2*y1*f1*f6*h0*h3+4*x2^2*y2^2*f6*f1*h0*h3-4*y2^2*x1^2*f2*f6*h0^2-4*y2^2*x1^2*f0*f2*h3^2-y2^2*x1^2*f0*h1^2*h3^2-y2^2*x1^2*f2*h0^2*h3^2+4*y3^2*x3^2*f5*f6*h0*h3-8*x3^2*y2^2*f0*f6*h3^2-x3^2*y2^2*f6*h0^2*h3^2-x3*y2^2*x2*f6*h0*h1*h2^2-y3*x2^2*y1*f5^2*h0^2+4*y3^2*x3^2*f3*f6*h2*h3+4*y3*x1*x2*y2*f1*f6*h0*h3-2*y3*x2^2*y2*f1*f6*h2^2-8*y3^2*x3^2*f4*f6*h2^2-6*y3^2*x2*f6*f3*h0*h2*x1-y3^2*x2*f3*h3^2*h0*h2*x1-3*y3^2*x2*f6*h1*h2^2*h0*x1+2*y3*x1*x2*y1*f0*h1*h2*h3^2-8*y3*x3^2*y2*f1*f6*h3^2+x3*y2*y4*x1*h2^2*h3*h0-y3*y4*x1*x2*f1*h3^2-2*y3*y4*x1*x2*f6*h0*h1-2*x1*f2*y1*y4*h0*h3*x2+2*x3*f5*y3*f3*y1*h0*h2*x1+8*y3*x3^2*y1*f0*f6*h3^2+y3*x3^2*y1*f0*h3^4+4*y3*x3^2*y1*f6^2*h0^2+y3*x3^2*y1*f6*h0^2*h3^2-4*y3*x3*x2*y2*f5*f6*h0*h1-2*y3*x3*x2*y2*f1*f5*h3^2-2*y3*x3*x2*y2*f5*h0*h1*h3^2-4*y3*x3*x2*y2*f1*f6*h2*h3-y3*x3*x2*y2*f1*h2*h3^3+y3*x3^2*y2*f4*h0*h3^3-4*y3*x3^2*y2*f4*f6*h1*h2-y3*x3^2*y2*f4*h1*h2*h3^2+y3*x3*y2*f3*h3^3*h0*x2-2*y3*x1*y2*x3*f6*h0^2*h2*h3-2*y3*x1*y2*x3*f3*f6*h1^2+y3*x1*y2*x3*f6*h0*h1^2*h3-y3*x1*y2*x3*f6*h1^3*h2-2*y3*x1*y2*x3*f2*f3*h3^2-y3*x2^2*y2*f0*h2*h3^3+y3^2*x2^2*f3*h3^3*h0+2*y3^2*x2^2*f6*h1*h2*h0*h3+y3*x2^2*y1*f2*h2*h3^2*h0+y3*x3*y1*f3*h2^2*h3*h0*x1+2*x3*x2*y3*y1*f3*h0*h2*h3^2-x3*y2*y4*x1*f5*h1^2-2*x3*y2*y4*x2*f6*h1^2-y2*y4*x3^2*f3*h3^2-2*y2*y4*x3^2*f6*h1*h2+3*x3*y2*y4*x1*f5*h0*h2-y2*y4*x1*x2*f5*h0*h1-y2*y4*x1*x2*f1*h2*h3-4*y4*x3*x2*y1*f6*h0*h1-2*y2*y4*x1^2*f0*h2*h3-2*y2*y4*x1*x2*f0*h3^2+y2*x3^2*f5*y4*h1*h3+2*y4*x1*x3*y1*f6*h0^2-2*y4*x1*x3*y1*f5*h0*h1-2*y4*x1*x3*y1*f1*h2*h3-y3*x2^2*h2*h3^2*y4*h0-3*y3*x2*f5*y4*h0*h2*x1-2*y3*y4*x1^2*f6*h0^2-2*y3*y4*x1^2*f0*h3^2+4*x3*y2*y4*x2*f6*h0*h2+x3*y2*y4*x2*h3^2*h0*h2-2*x1^2*f2*y1*y4*h0*h2-2*x3*y2*y4*x1*f2*h2*h3-4*y2*x1*x3*y1*f2*f6*h0*h1-y2*x1*x3*y1*f1*f5*h0*h3+y2^2*x1^2*f5*h0^3*h3-4*y2^2*x1^2*f0*f6*h1^2+4*y2*x2^2*y1*f0*f6*h0*h3-8*y2*x2^2*y1*f0*f6*h1*h2-4*y2*x2^2*y1*f3*f6*h0^2-y2*x2^2*y1*f6*h0^2*h1*h2-4*y2*x2^2*y1*f0*f3*h3^2-y2*x2^2*y1*f0*h1*h2*h3^2-4*y2^2*x2^2*f0*f6*h1*h3-4*y2^2*x2^2*f0*f6*h2^2-y2^2*x2^2*f6*h0^2*h2^2-y2^2*x2^2*f4*h0^2*h3^2-y2^2*x2^2*f0*h1*h3^3-4*x2^2*y1^2*f0*f2*h3^2+x3^2*y2*y1*f6*h0*h1^2*h3-4*x1^2*y2*y1*f2*f5*h0^2-8*y2^2*x1*x2*f0*f6*h1*h2-y2^2*x1*x2*f6*h0^2*h1*h2+y2^2*x1*x2*f0*h0*h3^3-y2^2*x1*x2*f0*h1*h2*h3^2+x2^2*y2^2*f1*h3^3*h0+y2^2*x1^2*f1*h0*h1*h3^2-4*y2^2*x1*x2*f0*f3*h3^2+2*y2^2*x3^2*f6*h1*h2*h0*h3-4*x3*y2^2*x2*f4*f6*h0*h1-x3*y2^2*x2*f4*h0*h1*h3^2+y2^2*x1*x2*f5*h0^2*h1*h3-4*y2^2*x2^2*f4*f6*h0^2-y2*x2^2*y1*f3*h0^2*h3^2+x1^2*y1*f4*h0^3*h3*y2-y2*x1*x2*
     y1*f6*h0^2*h1^2-y2^2*x1*x3*f5^2*h0^2-y2*x1*x2*y1*f3*h0^2*h2*h3-y2^2*x1*x3*f1*h0*h3^3-2*y2^2*x1*x3*f3*f6*h0*h1-y2^2*x1*x3*f6*h0*h1^2*h2-y2^2*x1*x3*f3*h0*h1*h3^2-2*x3^2*y2*y1*f0*f5*h3^2-4*x3^2*y2*y1*f0*f6*h2*h3-x3^2*y2*y1*f0*h2*h3^3-2*x3^2*y2*y1*f5*f6*h0^2-x3^2*y2*y1*f5*h0^2*h3^2-4*y3*x1*x3*y1*f4*f5*h0*h1-2*y3*x1*x3*y1*f1*f5*h2^2+8*y3*x1*x3*y1*f0*f5*h2*h3-y3*x2^2*y1*f1*h0*h3^3-y3*x3^2*y1*f3^2*h3^2-4*y3*x3^2*y1*f3*f6*h0*h3-4*y3*x3^2*y1*f3*f6*h1*h2+y3*x2^2*y1*f5*h1^2*h0*h3+4*y3^2*x3^2*f5*f6*h1*h2-4*x3^2*y1^2*f4*f6*h0^2-x3^2*y1^2*f6*h0^2*h2^2-4*x3^2*y1^2*f0*f4*h3^2-x3^2*y1^2*f4*h0^2*h3^2-x3^2*y1^2*f0*h1*h3^3-x1^2*y1^2*f1*h0^2*h3*h2+4*x3^2*y1^2*f1*f6*h0*h3+y2^2*f1*x1*x2*f5*h0*h3-2*x3*y2^2*x2*f1*f4*h3^2-2*x1^2*y2*y1*f0*f1*h3^2+2*y2*x2*f5*f1*y1*h1*h3*x3+x2*y2^2*f1*h3^2*h0*h2*x1+2*y2^2*x1*f2*x3*f5*h0*h3-x1^2*y3^2*f6*h0*h1^2*h2-x1*x3*y3^2*f3^2*h3^2-4*x1*x3*y3^2*f3*f6*h0*h3-x1*x3*y3^2*f3*h0*h3^3-4*x1*x3*y3^2*f3*f6*h1*h2-8*y3^2*x3^2*f6^2*h0*h2-2*y3^2*x3^2*f6*h0*h2*h3^2-y3^2*x3^2*f6*h1^2*h3^2-4*y4*x2^2*y1*f6*h0^2-4*y4*x2^2*y1*f0*h3^2-2*y3*y4*x3*x2*f3*h3^2+2*y3*x2*f5*y4*h1*h3*x3+10*y3*y4*x1*x3*f6*h0*h2-2*y3*y4*x1*x3*f6*h1^2-2*y3*y4*x1*x3*f2*h3^2+4*y3*y4*x3^2*f5*h2*h3-6*y4*x1*x2*y1*f0*h2*h3-3*y4*x1*x2*y1*f5*h0^2+y4*x1^2*y1*f3*h0*h1-y2*x1*x3*y1*f3*h0*h1*h2*h3+2*y2*x1*x3*y1*f0*f5*h1*h3-2*y2*x1*x3*y1*f1*f6*h1^2-2*y2*x1*x3*y1*f1*f2*h3^2-y2*x1*x3*y1*f6*h0*h1^3+4*y2*x1*x3*y1*f0*f6*h1*h2+2*y2*x1*x3*y1*f3*f6*h0^2+2*x2*y2^2*f6*f1*h0*h2*x1+4*y2^2*x1*x2*f0*f6*h0*h3+y2^2*x1*x2*f6*h0^3*h3-4*y2^2*x1*x3*f1*f6*h0*h3-2*y2^2*x1*x3*f1*f6*h1*h2-y2^2*x3^2*f5*h0*h3^2*h1+x3*y2^2*x2*f5^2*h0*h1+2*x3*y2^2*x2*f1*f5*h2*h3+x3*y2^2*x2*f5*h0*h1*h2*h3+8*y2*x1*x2*y1*f0*f6*h0*h2+8*x1*x3*y1^2*f0*f6*h0*h2+4*x1*x3*y1^2*f2*f6*h0^2+2*x1*x3*y1^2*f6*h0^3*h2+2*x1*x3*y1^2*f0*h1^2*h3^2+x1*x3*y1^2*f2*h0^2*h3^2+4*f0*f4*x1*y1^2*h1*h3*x3-4*x1*x3*y1^2*f0*f5*h0*h3-4*x1*x3*y1^2*f0*f5*h1*h2-4*x1*x3*y1^2*f0*f3*h2*h3-x1*x3*y1^2*f0*h1*h2^2*h3-x1*x3*y1^2*f3*h0^2*h2*h3-4*y3*x3^2*y1*f1*f6*h2*h3-4*x3*x2*y3*y1*f2*f6*h1*h2-2*x3*x2*y3*y1*f3*f6*h1^2-8*y3^2*x3*x2*f1*f6*h3^2-2*y3^2*x3*x2*f6*h0*h1*h3^2-y3^2*x3*x2*f1*h3^4+4*x1*x3*y3^2*f6^2*h0^2+x1*x3*y3^2*f6*h0^2*h3^2-4*y3^2*x3*x2*f4*f6*h1*h2+2*y3^2*x3*x2*f6*h1^2*h2*h3-y3^2*x3*x2*f6*h1*h2^3-y3^2*x3*x2*f4*h1*h2*h3^2-4*x1^2*y3*y2*f0*f6*h1*h2-3*x1^2*y3*y2*f6*h0^2*h1*h2-y3*x3*x2*y2*f0*h3^4+y3*x1*x3*y1*f0*h2^2*h3^2+3*y3*x1*x3*y1*f5*h0^2*h2*h3-2*y3*x1*x3*y1*f4*h0*h1*h2*h3-y3*x1*x3*y1*f1*h2^3*h3-y3*x3^2*y1*f1*h2*h3^3-y3*x3^2*y1*f6*h1^2*h2^2-y3*x1*y2*x3*f3*h1^2*h3^2+y3*x1*x3*f5*h0^2*h3^2*y2-y3*x3*x2*y2*f6*h1^2*h2^2-4*y3*x3*x2*y2*f2*f4*h3^2-y3*x3*x2*y2*f4*h1^2*h3^2-8*y3*x3*x2*y2*f0*f6*h3^2-y3*x3*x2*y2*f6*h0^2*h3^2-4*y3*x1*x2*y2*f1*f6*h1*h2-2*y3*x1*x2*y2*f1*f3*h3^2-y3*x1*x2*y1*f4*h0^2*h2*h3+y3*x1*x2*y2*f1*h0*h3^3-4*y3*x1*x2*y2*f3*f6*h0*h1-2*y3*x2^2*y2*f0*f5*h3^2-2*x1^2*y3*y2*f3*f6*h0^2-2*x1^2*y3*y2*f0*f3*h3^2+2*y3*x2^2*y2*f1*f5*h2*h3+y3*x2^2*y2*f5*h0*h1*h2*h3-2*y3*x2^2*y2*f1*f4*h3^2-4*y3*x2^2*y2*f4*f6*h0*h1-y3*x2^2*y2*f6*h0*h1*h2^2-y3*x2^2*y2*f4*h0*h1*h3^2+y3*x2^2*y2*f2*h3^3*h0+4*y3*x2^2*y2*f6*f2*h0*h3+2*y3*x3*x2*y2*f4*h0*h2*h3^2-4*y3*x3*x2*y2*f2*f6*h2^2+2*y3*x3*x2*y2*f6*h0*h2^3-4*y3*x3*x2*y2*f4*f6*h1^2-y3*x3^2*y2*f6*h1*h2^3+4*x1*y3*y2*f6*f1*h1*h3*x3+x3*y2^2*x1*f5*h1^2*h0*h3+x3*y2^2*x1*f2*h2*h3^2*h0-2*y2*x3*x2*y1*f1*f3*h3^2+y2*x3*x2*y1*f1*h0*h3^3-2*y3*x3^2*y1*f6*h0*h1*h2*h3-x1*x3*y1^2*f5*h0^3*h3-2*y2*y4*x1*x2*f6*h0^2-4*y2^2*x1*x3*f0*f5*h2*h3-y2^2*x1*x3*f0*h2^2*h3^2-3*y2^2*x1*x3*f5*h0^2*h2*h3+8*y2^2*f0*x1*f6*h1*h3*x3+y2*x2^2*y1*f0*h0*h3^3-2*x3*y2^2*x2*f0*f5*h3^2-4*x3*y2^2*x2*f0*f6*h2*h3-x3*y2^2*x2*f0*h2*h3^3-2*x3*y2^2*x2*f5*f6*h0^2-x3*y2^2*x2*f5*h0^2*h3^2+2*y4*x1*x3*y1*f0*h3^2-2*y3^2*x3*x2*f3*f6*h2^2+2*y3*x1*x2*y1*f0*f5*h1*h3+6*y3*x1*x2*y1*f1*f6*h0*h2-2*y3*x1*x2*y1*f1*f6*h1^2+2*y3^2*x3*f4*h3^2*h0*h2*x1+8*y3^2*x3*f6*f4*h0*h2*x1-2*y3^2*x3*f5*h2^2*h3*h0*x1+2*y3^2*x3*f6*h2^3*h0*x1-4*x1^2*y3^2*f0*f6*h1*h3-4*x1^2*y3^2*f0*f6*h2^2+2*y3*x1*x3*y1*f3*h0*h1*h3^2+y3*x2*y1*f2*h2^2*h3*h0*x1+4*y3*x1^2*y1*f0*f2*h3^2+2*y3*x1^2*y1*f0*h1^2*h3^2+y3*x1^2*y1*f2*h0^2*h3^2+y3*x3^2*y1*f6*h1^3*h3+8*y3*x1^2*y1*f0*f6*h0*h2+4*y3*x1^2*y1*f0*f6*h1^2+4*y3*x1^2*y1*f2*f6*h0^2-4*y3*x2^2*y1*f0*f5*h2*h3-y3*x2^2*y1*f0*h2^2*h3^2-y3*x1*x3*y1*f6*h1^4-8*y3^2*x2^2*f0*f6*h3^2-y3^2*x2^2*f6*h0^2*h3^2-2*y3*x1^2*y1*f1^2*h3^2-y3*x1^2*y1*f6*h0^2*h1^2+x1*x3*y3^2*f0*h3^4-4*y3*x1*x3*y1*f4*f6*h0^2-12*y3*x1*x3*y1*f0*f6*h1*h3-y2*x1*x3*y1*f1*f5*h1*h2-2*x3*y2*y4*x2*f2*h3^2+x1*y1^2*f4*h0^3*h3*x2+4*x1^2*y1^2*f0*f3*h1*h2-8*x1*x2*y1^2*f0*f2*h2*h3+x1*x2*y1^2*f0*h0*h2^2*h3-x2^2*y1^2*f2*h0^2*h3^2-y2*x1*x3*y1*f1*f3*h2*h3-4*y2*x1*x2*y1*f0*f5*h1*h2+4*y2*x1*x2*y1*f0*h0*h2*h3^2+4*y2*x1*x2*y1*f1*f6*h0*h1+y2*x1*x2*y1*f1^2*h3^2-8*y2*x1*x2*y1*f0*f6*h1^2-y2*x3*x2*y1*f6*h0*h1^2*h2+4*x1^2*y2*y1*f1*f5*h0*h1+x1^2*y2*y1*f1*h0*h1*h2*h3-4*y2*x3*x2*y1*f1*f6*h1*h2+2*x1^2*y2*y1*f1^2*h2*h3+2*y2*x3*x2*y1*f6*h0^2*h1*h3-4*y2^2*x1*x2*f3*f6*h0^2+4*y2^2*x2^2*f0*f5*h2*h3+y2^2*x2^2*f5*h0^2*h2*h3+y4*x1^2*y1*f1*h0*h3+y4*x1^2*y1*f1*h1*h2-2*y4*x1^2*y1*f0*h1*h3-2*y4*x1^2*y1*f0*h2^2-2*y4*x1^2*y1*f4*h0^2-4*y3*y4*x3*x2*f6*h1*h2-y3*y4*x1*x3*f3*h2*h3-3*y3*y4*x1*x3*f5*h0*h3+2*y3*x2^2*f5*y4*h0*h3-y3*y4*x1*x3*f5*h1*h2-2*y4*x3*x2*y1*f1*h3^2+y4*x1*x2*y1*h0^2*h2*h3-2*y2*y4*x2^2*f6*h0*h1-y3*x2*h2^2*h3*y4*h0*x1-4*y3*y4*x3^2*f6*h2^2-4*y3*y4*x3^2*f4*h3^2-y2*y4*x1^2*f5*h0^2-y2*y4*x1^2*h0^2*h2*h3-y2*y4*x2^2*f1*h3^2-y3*x2^2*y2*f5*h0^2*h3^2+4*f4*x1^2*f0*y1*h1*h3*y3+y3^2*x1*x2*h0*h1^2*f6*h3+x3*x2*y1*f1*h3^3*h1*y3+2*y3*x3^2*f6*h2^3*h0*y1+2*y2*x2^2*f6*f1*h0*h2*y1+x3*y2*x2*h3^2*f2*h0*h2*y1+8*f0*f6*x2^2*y1*h1*h3*y3+4*y3^2*x1*f2*x3*f6*h1*h3-2*h0*h2*y3^2*x1*f6*h1*h3*x3-3*h0^2*h2*y3*x2^2*f5*y1*h3-3*h1*h3*y3^2*x3^2*f5^2+4*h1*h3*x1*x3*y3*y2*f5*f2+4*h1*h3*y3*x3^2*y2*f6*f3+2*h1*h3*y3*x2*y2*f5*x1*f1+2*h1*h3*x1*x3*f3*y3^2*f5+3*h1*h3*y3^2*x3^2*f6*h2^2+2*y2*x1*f2*x3*f5*h0*h2*y1-2*y3*x3^2*f5*h2^2*h3*h0*y1+y3^2*x1*x3*h3^3*f2*h1-h0*h2*x1^2*y4*h1*h3*y3+x1^2*y2*y1*f0*h2^2*h3*h0+4*y2*x3*f6*x2*f2*h0*h2*y1+x1^2*y1*h0^2*f4*h1*h3*y3-y3^2*x2*f5*h1^2*h3^2*x3+2*x2^2*y1*h3^3*f0*h1*y3-4*h0*h2*x3*f6*x2*f1*y1^2+8*
     y3*x3^2*f6*f4*h0*h2*y1-6*h0*h2*x3^2*f6*y2*f3*y1+2*x3*x1*f5*f1*y1^2*h0*h2+x3*y2*x1*h2^2*h3*f2*h0*y1-2*x3*y2*x2*f6*h0^2*h2^2*y1-y3^2*x2^2*f5*h1*h3^2*h0+2*y3*x3^2*h3^2*f4*h0*h2*y1+2*h1^2*h3*y3*x3^2*y2*f6*h2+h1^3*h3*y3*x1*y2*x3*f5+h1^2*h3*x1*x3*y3^2*f5*h2+h1*h3^3*y3*x3^2*y2*f3+h1*h3*x1^2*y3*y2*f5*h0^2+2*h1*h3*x1^2*y1^2*f0*h0*h2+y3^2*x1*x3*f6*h1^3*h3-h1^2*h3^2*y3*x3^2*f5*y2-2*y3*x3^2*f5^2*h0*h2*y1+x1*x3*y1^2*f1*h2^2*h3*h0+4*x3*f6*x2*f1*y1*h1*h3*y3-h0*h2*x3^2*y2*y1*f3*h3^2-3*h0*h2^2*x3^2*y2*y1*f6*h1+2*h0*h2*x3^2*y2*f5*y1*h1*h3+2*h0*h2*y3*x3*x2*y2*f6*h1*h3+h1^2*h3*y3*x1*x2*y2*f5*h0+h0*h3*x3*x2*y3*y1*f6*h1^2-2*h0^2*h3*x3*x2*y3*y1*f6*h2+2*h0*h3*y3^2*x1*x2*f5*h1*h2+2*h0*h3*y3^2*x4*x1*f5+h0*h3*x4*x3*f3*y1^2+4*y3^2*x4*x3*f5*h2*h3-y3*x1*x3*y1*f6*h0^2*h1*h3-2*x2^2*y1^2*f6*h0^3*h2+4*y3^2*x3^2*f6*f4*h1*h3-8*x2^2*y1^2*f0*f6*h0*h2+y3*x1*x2*y1*f1*h0*h2*h3^2+x3^2*y2*y1*f6*h0^2*h2*h3-y3*x1*x3*y1*f5*h0*h1^2*h3+x1^2*y3^2*f6*h0^2*h1*h3+y3^2*x3^2*h3^3*f4*h1+8*x3*x2*y3*y1*f3*f6*h0*h2+4*x3*x2*y3*y1*f6*h0*h1*h2^2+y3*x3*x2*y2*f6*h1^3*h3+y3*x3*x2*y2*f2*h1*h3^3-x1^2*y3*y2*f0*h1*h2*h3^2+y3*x2^2*y2*f6*h0*h1^2*h3+4*y3*x3*x2*y2*f2*f6*h1*h3-y3*x1*x2*y1*h0*h1*h3^2*f2+y3*x1*y2*x3*f2*h3^2*h1*h2+y4*x1*x3*y1*h0*h1*h2*h3-h0*h2*x3^2*y1^2*f2*h3^2-h1^2*h3^2*x1*y3^2*f4*x3-8*h0*h2*x2^2*f6*y3^2*f4-8*h0*h2*y4*x3^2*f6*y1+8*h0*h2*y3*x1*y2*f3*x3*f6+4*h0^2*h2^2*y3*x2^2*f6*y1+2*h0*h2*x3^2*y2^2*f5^2-8*h0*h2*x1^2*y3^2*f6*f2-8*h0*h2*y3*y4*x2^2*f6-h0*h3^2*y3^2*x1*x2*f4*h1-h1*h3*y3^2*f1*x1^2*f5+4*h0^2*h2^2*x3*y2^2*f6*x1+2*h0*h2^2*x3^2*y2^2*f5*h3-h1*h3*x3^2*f5*f1*y1^2+h1*h3*y3*x2^2*f5*f1*y1+2*h1*h3*y3*y4*x1*f4*x3+2*h1*h3*x1^2*f0*y2*f3*y1+2*h1*h3*y2*f0*f5*x2^2*y1+2*h1*h3*f0*f3*x1*x2*y1^2+2*h1*h3*f1*y2*f4*x1*x3*y1+4*h1*h3*x1*x3*y3*f4*f2*y1+4*h1*h3*y2*f0*x1*x2*f4*y1+2*h1*h3*y3*x1*f4*x2*f1*y1+h1*h3*y4*f1*x1*x2*y1-h1*h3*x1*x3*y3*f3^2*y1+h1*h3*y2*y4*x1*f3*x3+h1*h3*x1*x3*y2^2*f5*f1+2*h1*h3*y2^2*f0*f5*x1*x2+h1*h3*y2^2*x2^2*f6*h0^2-2*h0*h2^3*x3^2*y2^2*f6+2*h0*h2*y3^2*x2^2*f5^2-2*h0*h2^3*y3^2*x2^2*f6-h0*h2*y4*x3^2*y1*h3^2+4*h0*h2^2*y3*x1*y2*x3*f6*h1-8*h0*h2*x3^2*f6*y2^2*f4-h0*h2*x1^2*y3^2*f2*h3^2-2*h0*h2*x3^2*y2^2*f4*h3^2-8*h0*h2*x3^2*f6*f2*y1^2-2*h0*h2*y3^2*x2^2*f4*h3^2-2*h0^3*h2*y2^2*x1^2*f6-h1*h3^2*f2*x1*x3*y1*h0*y2+h1*h3*y2*x1*x2*y1*f4*h0^2-h1*h3^2*x3*x2*y1^2*f0*h2+h1*h3^2*x3*x2*y3*y1*f2*h2+h1^2*h3*x3*y2^2*x2*f6*h0+h1^2*h3*y2*x1*x3*y1*f4*h0+h1*h3*y3*x1*x3*y1*h2^2*f2+h1^3*h3*y3*x1*x3*y1*f4-h1^2*h3^2*y3*x3^2*f4*y1+h0*h2*y2*x1*x3*y1*f1*h3^2+4*h0^2*h2*y2*x1*x3*y1*f6*h1+h0*h2*y3*y4*x1*x3*h3^2-8*h0*h2*y2^2*x1^2*f6*f0+h1^2*h3*y3*x1*x2*y1*f4*h0+2*h0*h3*x3^2*f5*f2*y1^2+2*h0*h3*y4*x3^2*f5*y1+2*h0*h3*y3^2*x1^2*f5*f2+h0*h3*y3*y4*x1^2*f3-4*h0*h3*y3*x3*f6*x2*f2*y1+4*h0*h3*y3^2*f6*x2*x1*f2-4*h0*h3*y3*x1*f2*x3*y2*f6-4*h0*h3*y3*f0*f6*x1*x2*y1+h0*h3*y3^2*x1*f3*x2*f5+2*h0*h3*y3*y2*f1*x1^2*f5+4*h0*h3*y3*y2*f0*x1^2*f6+2*h0*h3*y3*y4*x1*x2*f4-h0*h3*y4*x1*f3*x3*y1-2*h0*h3*y2*y4*x1*f4*x3-4*h0*h3*y3*x1*f2*x3*f5*y1-4*h0*h3*y2*f0*x1*f6*x3*y1+2*h0*h3*f1*f5*x3*x2*y1^2+4*h0*h3*y2*f2*x3^2*f6*y1+h0*h3*x3^2*y2*f5*f3*y1+4*h0*h3*f0*x3*f6*x2*y1^2-h0*h3^2*x3^2*y2*f4*y1*h1+h0^2*h3^2*y2^2*x1*f4*x3-h0^3*h3*y2*x1*x3*y1*f6-h0*h3^3*y2*x1*x3*y1*f0+h0^2*h3*y3^2*x1*x2*f6*h2-h0*h3^3*y3*x1*y2*x3*f2+h0^3*h3*x1^2*y3*y2*f6+h0*h3^3*x1^2*y3*y2*f0-h0^2*h3^2*y3*x1*x2*f4*y2-h0*h3^3*x3*x2*y3*y1*f2+h0*h3^3*y3^2*x1*x2*f2-h0^3*h3*y3*x1*x2*y1*f6-h0*h3^3*y3*x1*x2*y1*f0+h0^2*h3^2*y3*x2^2*f4*y1+h0^3*h3*x3*x2*y1^2*f6+h0*h3^3*x3*x2*y1^2*f0+h0^2*h3*x3^2*y1^2*f6*h1-h0^2*h3^2*x3*y2*f4*y1*x2+h0*h3^3*x3^2*y2*y1*f2-2*h0*h3*y3*x4*x2*f4*y1-h0*h3*x1*x4*y3*f3*y1+2*h0*h3*x4*x3*y2*f4*y1+4*h0^2*h2*y3*x1*x2*y1*f6*h1-h1^2*h3*y3*x1*x3*y1*f3*h2-2*x1*x4*y1^2*f0*h2^2-y3*x4*x3*y1*h1*h2*f5-2*y3*x4*x3*y1*f2*h3^2-12*y2*f0*f5*x1*x4*y1-2*y3*x4*x3*y1*h1^2*f6-2*x1*x4*y1^2*h0^2*f4-x2*x4*y1^2*h0^2*h2*h3-4*y2^2*x1*x4*f6*h0^2+2*x1*x4*f1*f3*y1^2+4*y3*x4*x2*y2*h0*h2*f6-4*f0*f5*x2*x4*y1^2-3*x1*x4*y4*h0*h3*y2-h1*h3*y2*y4*x4*x2-16*y2^2*f0*x1*f6*x4-y2*x4*x2*y1*f1*h2*h3-4*y3^2*x4*x3*h3^2*f4-4*y3^2*x4*x2*f6*f3+2*x1*x4*y3*y1*h3^2*f0-2*x4*x3*f5*y3*f3*y1+2*x1*x4*y4^2+2*y4*x4^2*y1-4*y2^2*x1*x4*h3^2*f0+2*h1*h3*y3*x4*x3*f4*y1+h1*h3*y3*x4*x2*f3*y1+h1*h3*y2*f1*x1*x4*y1+h1*h3*x1*x4*y3*y1*h0*h2+2*h0*h2^2*y3^2*x2^2*f5*h3+h0*h2*y1^2*x4^2+4*y3^2*x3*f5^2*x4-h0*h2*y1^2*x4*h1*h3*x3-8*f0*f4*x1*x4*y1^2-8*f0*x3*f6*x4*y1^2-2*x1*f2*y1^2*h0*h2*x4-2*x2*x4*y1^2*f0*h2*h3-2*x1*x4*y1^2*f0*h1*h3+x1*x4*y1^2*f3*h0*h1+x1*x4*y1^2*h0*h3*f1+x1*x4*y1^2*h1*h2*f1-x2*x4*y1^2*h0^2*f5-2*x4*x3*y1^2*f6*h0^2-2*x4*x3*y1^2*h3^2*f0+y2*x1*x4*y1*h0^2*h2*h3-y2*x3*h2^2*h3*h0*y1*x4+2*y2^2*x3*f5*h0*h3*x4-3*y2*x1*x4*y1*h0^2*f5-3*y2*x3*f5*h0*h2*y1*x4-4*x4*x2*y2^2*f6*f1-2*x4*x2*y2^2*f6*h0*h1-y2^2*x3*h2*h3^2*h0*x4-2*y2*x4*x2*f5*f1*y1-x4*x2*y2^2*h3^2*f1-x4*x3*y2*y1*h3^2*f1-2*x4*x3*y2*y1*f6*h0*h1-4*f1*y2*f6*x3*x4*y1-2*y2*x4*x2*y1*f6*h0^2-2*y2*x4*x2*y1*h3^2*f0-6*y2*x1*x4*y1*f0*h2*h3-2*x1*f2*y1*h0*h3*y2*x4-8*y2*f0*f6*x2*x4*y1-y2*x4*x2*y1*h0*h1*f5-y3^2*x4*x2*h3^2*f3-2*y3*x4*x2*y1*h2*h3*f2-4*y3^2*x4*x3*f6*h2^2+y3*x4*x2*y1*h2^2*h3*h0-8*y3*x4*x3*y2*f6*f3-2*y3^2*x4*x2*f6*h1*h2-4*x1*x4*y3*f5*f1*y1+y3*x4*x2*y2*h0*h2*h3^2-16*y3^2*x3*f6*x4*f4-2*x1*x4*y3*y1*f1*h2*h3+y3^2*x2*f5*h1*h3*x4+8*x1*x4*y3*f6*f0*y1-8*y3*x4*x3*f2*f6*y1+10*y3*x4*x3*y1*h0*h2*f6-y3*x4*x3*y1*f3*h2*h3+3*y3*x4*x2*y1*f5*h0*h2-y3*x4*x2*y1*f5*h1^2-4*y3*x4*x2*f5*f2*y1+2*x1*x4*y3*y1*f6*h0^2-2*x1*x4*y3*y1*h0*h1*f5-3*y3*x4*x3*y1*h0*h3*f5-8*y3*x4*x2*y2*f6*f2-4*x1*x4*y3*y2*f6*h0*h1-8*x1*x4*y3*y2*f6*f1-2*x1*x4*y3*y2*h3^2*f1-2*y3*x4*x2*y2*f2*h3^2-2*y3*x4*x2*y2*h1^2*f6-4*y3*x4*x3*y2*f6*h1*h2-2*y3*x4*x3*y2*h3^2*f3+2*y2*x3*f5*h1*h3*y3*x4-y1*y4*x4*h1*h3*x3+y4*x1*x4*y1*h1^2-2*y2*y4*x4*x3*f5-3*y1*y4*x4*h0*h3*x2-x1*x4*y4*h1*h3*y3-y3*y4*x4*x2*h2*h3-6*y4*x1*x4*y1*h0*h2+4*y4*x1*f2*x4*y1-y2*y4*x3*x4*h2*h3-3*y3*y4*x4*x3*h3^2-2*y3*y4*x2*f5*x4-12*y3*y4*x4*x3*f6+h0*h2*y3*x4*x3*y1*h3^2-8*h0*h2*y3^2*x1*f6*x4-h0*h2*y3^2*x1*x4*h3^2-8*h0*h2*x4*x3*y2^2*f6;

b22:=-2*y3^2*f1*x1^2*f5-4*y3*y4*x3^2*f6-8*f0*x1^2*f2*y1^2-2*x3^2*f5*f1*y1^2-8*y3^2*x3^2*f6*f4-4*y4*x1^2*f0*y1-8*y2^2*f0*f6*x2^2-4*y2^2*f2*f6*x3^2-4*x1^2*f0*y2^2*f4-4*x1^2*f2*y3^2*f4-4*x1^2*f0*y3^2*f6-4*x2^2*y3^2*f6*f2-2*y2*y4*f5*x3^2-2*y2*y4*f1*x1^2-4*y3*y4*x1^2*f2-4*y4*f4*x3^2*y1-4*f6*x3^2*f0*y1^2-4*f4*x3^2*f2*y1^2-4*f0*f4*x2^2*y1^2+x2^2*y4^2+2*y3^2*x3^2*f5^2+2*f1^2*x1^2*y1^2-4*y3^2*f1*x1*f6*x2-2*y3*x1^2*f3*f1*y1-4*y3*x3^2*y2*f6*f3-2*y3*x3^2*f5*f3*y1-4*y3^2*x3*f6*x2*f3-4*x1^2*f0*y2*f3*y1-4*y2*f0*f5*x2^2*y1-4*y3*x2*y2*f5*x1*f1-2*x1*f3*x3*f1*y1^2-4*f0*f3*x1*x2*y1^2-4*x1^2*f0*y2*y3*f5-4*y3*x2^2*y2*f6*f1-4*f0*f5*x3*x2*y1^2-4*y2*f1*x3^2*f6*y1+2*y2*y4*x1*f3*x3-4*x3*y2*f5*x2*f1*y1-4*y2^2*f0*f5*x1*x2-4*x3*y2^2*f6*x2*f1-2*x1*x3*f3*y3^2*f5+y3^2*x1^2*f3^2+x3^2*f3^2*y1^2-4*f1*f4*x3*x2*y1^2-4*y3^2*f2*f5*x2*x1-4*y2*f2*f5*x3^2*y1+8*y2^2*f0*f6*x1*x3+8*y2*f0*f5*x1*x3*y1+8*y3*x3*f6*x2*f1*y1+8*y3*f1*f5*x1*x3*y1+8*y3*f0*f5*x2*x1*y1-4*f1*x1^2*y3*y2*f4-2*y4*f3*x3*x2*y1-2*y3*y4*x2*x1*f3+8*y3*y2*f1*x1*f6*x3+8*y3*f0*x2^2*f6*y1-y4*x1^2*y1*h0^2-y3*y4*x3^2*h3^2-2*y2^2*x2^2*f6*h0^2-2*y2^2*x2^2*f0*h3^2-2*y3^2*x3^2*f6*h2^2-2*y3^2*x3^2*f4*h3^2-2*x1^2*y1^2*f0*h1^2-2*x1^2*y1^2*h0^2*f2-y2^2*x1^2*f0*h2^2-y2^2*x1^2*f4*h0^2-x3^2*y2^2*f6*h1^2-x3^2*y2^2*f2*h3^2-x1^2*y3^2*f4*h1^2-x1^2*y3^2*h2^2*f2-x1^2*y3^2*f6*h0^2-x1^2*y3^2*f0*h3^2-y3^2*x2^2*f6*h1^2-y3^2*x2^2*f2*h3^2-x2^2*y1^2*f0*h2^2-x2^2*y1^2*f4*h0^2-x3^2*y1^2*f4*h1^2-x3^2*y1^2*h2^2*f2-x3^2*y1^2*f6*h0^2-x3^2*y1^2*f0*h3^2-y3*y4*x1^2*h1^2-y4*x3^2*y1*h2^2-y2*x2^2*y1*f5*h0^2-2*y2*x2^2*y1*f0*h2*h3-2*y2*x3*x2*y1*f5*h0*h1-2*y2*x3*x2*y1*f1*h2*h3-2*x1^2*y2*y1*f0*h1*h2-x1^2*y2*y1*h0^2*f3-y2^2*x1*f3*x3*h0*h3-x3^2*y2*y1*f1*h3^2+y4*x3*x2*y1*h0*h3-2*y3*x3^2*y2*f6*h1*h2-x1*x3*y3^2*f5*h1*h2-x3*x2*y1^2*f5*h0^2+2*y3*y4*x1*x3*h1*h3+x3*y2*y4*x1*h1*h2-x3^2*y1^2*f5*h0*h1-2*x3*x2*y1^2*f0*h2*h3-y3*x1^2*y1*f3*h0*h1-y3*x3^2*y2*f3*h3^2-x1^2*y3*y2*f5*h0^2-y3*x1^2*y1*f1*h0*h3-2*x1*x2*y1^2*f0*h1*h2-x1*x2*y1^2*h0^2*f3-2*y2^2*x1*x2*f0*h2*h3-y2^2*x1*x2*f5*h0^2-x3*y2^2*x2*f1*h3^2-2*x1^2*y3*y2*f0*h2*h3-x3^2*y1^2*f1*h2*h3-y3^2*x1*x2*f1*h3^2-y2*x2^2*y4*h0*h3+x3*y2*y4*x1*h0*h3+2*y4*x1*x3*y1*h0*h2-2*x3*y2^2*x2*f6*h0*h1-2*x3^2*y2*y1*f6*h0*h1+y2*f1*x1^2*y1*h0*h2+y3*y4*x1*x2*h0*h3-y3*x1^2*y1*f1*h1*h2+2*y3*x1^2*f2*y1*h0*h2-x1*x3*y3^2*f3*h2*h3-x1*x3*y3^2*f5*h0*h3-y3*x3^2*y1*f3*h2*h3-y3*x3^2*y1*f5*h0*h3-y3*x3^2*y1*f5*h1*h2-2*y3*x2^2*y2*f6*h0*h1+2*x1^2*y1^2*f1*h0*h1-2*y3^2*x1*x2*f6*h0*h1+2*y3*x3^2*f4*y1*h1*h3+y3*x3^2*f5*y2*h1*h3-y3^2*x3*x2*f3*h3^2+2*y3^2*x3^2*f5*h2*h3-x1^2*y3^2*f5*h0*h1-x1*x3*y1^2*f3*h0*h1-x1*x3*y1^2*f1*h0*h3-x1*x3*y1^2*f1*h1*h2+2*f0*x1*y1^2*h1*h3*x3-y3*x2^2*f3*y1*h0*h3+2*y3^2*x3*f6*h0*h2*x1-2*y3^2*x3*x2*f6*h1*h2-2*y3*x1*x2*y2*f5*h0*h1-2*y3*x1*x2*y2*f1*h2*h3-y3*x2^2*y2*f1*h3^2-x1^2*y3^2*f1*h2*h3+f1*x2*y1^2*h0*h2*x1+2*x3*f2*y1^2*h0*h2*x1+2*x1*y3^2*f4*h1*h3*x3+y3^2*f5*x2*h1*h3*x3+2*y3*x3^2*f6*h0*h2*y1+2*x1^2*f0*y1*h1*h3*y3+f1*x2^2*y1^2*h0*h3+4*y2*x1*x3*y1*f0*h2*h3-x3^2*y2*y1*f5*h0*h2+2*y3*x2^2*y1*f6*h0^2+2*y3*x2^2*y1*f0*h3^2+4*y3*x1*x2*y1*f0*h2*h3+2*y3*x1*x2*y1*f5*h0^2-x1^2*y3*y2*h2^2*f1+x3^2*y1^2*f3*h0*h3-2*x2^2*y1^2*f0*h1*h3+x3^2*y1^2*f3*h1*h2-y2*y4*x3^2*h2*h3-y2*y4*x1^2*h0*h1-y3*y4*x1*x2*h1*h2-y4*x3*x2*y1*h1*h2-x3^2*y2*y1*f5*h1^2-2*x3^2*y2*y1*f2*h2*h3+2*f4*x3^2*y1*h0*h3*y2+2*y2*x1*x3*y1*f5*h0^2+2*y2^2*x1*x3*f6*h0^2+y2^2*f5*x3^2*h0*h3+2*x3*f3*y2*y1*h0*h3*x2+x3^2*f3*y2*y1*h1*h3-2*x3^2*y2^2*f6*h0*h2+2*y2^2*x1*x3*f0*h3^2+y2^2*f1*x1^2*h0*h3-2*y2^2*x1^2*f0*h1*h3+2*x1*y3^2*f4*h0*h3*x2+y3^2*f5*x2^2*h0*h3-2*y3^2*x1*x2*f2*h2*h3-2*y3^2*x2^2*f6*h0*h2-y3^2*x1*x2*f5*h1^2+x1^2*y3^2*f3*h0*h3+x1^2*y3^2*f3*h1*h2-y3^2*x1*x2*f5*h0*h2+2*x3*f2*y1^2*h0*h3*x2-2*x3*x2*y1^2*f4*h0*h1-x3*x2*y1^2*h1*h3*f1-x3*x2*y1^2*h2^2*f1+2*y3*x1*y2*x3*f1*h3^2+4*y3*x1*y2*x3*f6*h0*h1-2*x1^2*y3*y2*f4*h0*h1-x1^2*y3*y2*h1*h3*f1+y3*y2*f3*x1^2*h0*h2+2*y3*y2*f3*x1*h0*h3*x2+2*y3*x1^2*f2*h0*h3*y2+4*y3*x1*x3*y1*f5*h0*h1+4*y3*x1*x3*y1*f1*h2*h3+2*x3*x2*y3*y1*f1*h3^2+4*x3*x2*y3*y1*f6*h0*h1+f3*x3*x2*y1^2*h0*h2+y3^2*x2*x1*f3*h1*h3-x2^2*y4*h1*h3*y3-x2^2*y4*h0*h2*y1-x2*x4*y1^2*h0*h1+x4^2*y2^2-4*f0*x1*x4*y1^2-x1*x4*y1^2*h0^2-y2^2*x2*h0*h3*x4-4*y3^2*x4*x3*f6-y3^2*x4*x3*h3^2-4*y4*x4*x3*y1-4*y3*y4*x1*x4+x4*x3*y2*y1*h0*h3+2*y3*x4*x2*f3*y1+2*y3*x4*x3*y1*h1*h3+y3*x4*x2*y1*h1*h2+2*x1*x4*y3*y1*h0*h2+y3*x4*x2*y1*h0*h3+x1*x4*y3*y2*h0*h3-2*f1*x2*x4*y1^2-4*x3*x4*f2*y1^2-x4*x3*y1^2*h1^2-2*x3*f3*x4*y2*y1-y2^2*x4*h0*h2*x1-y2^2*x4*h1*h3*x3-x4*x3*y2*y1*h1*h2-4*x4*x1*y3^2*f4-y3^2*x1*x4*h2^2-2*y3^2*f5*x2*x4-y3^2*x4*x2*h2*h3-2*y3*y2*f3*x1*x4-x1*x4*y3*y2*h1*h2;
b23:=2*y4*x2^2*f1*y1+4*f0*f3*x2^2*y1^2+4*y2^2*f0*x1^2*f3+4*f1*y2^2*f6*x3^2+4*f0*f5*x3^2*y1^2+4*f4*x3^2*f1*y1^2+4*y3^2*x2^2*f6*f1+4*y3^2*f0*f5*x1^2+4*x1^2*f1*y3^2*f4+4*y2*y4*f0*x1^2+2*y4*f3*x3^2*y1+4*y3*y4*x1^2*f1+2*x3*x2*y4^2+2*y3*x1^2*y2*f3*f1-8*y3*y2*f0*f6*x1*x3-2*x1*x2*f1*y3*f3*y1+4*y3^2*f1*f5*x2*x1+8*y3^2*f0*f6*x2*x1-8*y3*f0*f4*x2*x1*y1-8*y3*f0*f5*x1*x3*y1-8*y3*f0*x2*f6*x3*y1-4*y3*f1*f5*x3*x2*y1-8*y3*x3*f4*x1*f1*y1+2*x3*f3*x2*f1*y1^2+8*f0*f4*x2*x3*y1^2-2*y3*y4*x3*f3*x1-2*x3*f3*x1*f1*y2*y1-8*y2*f0*f4*x1*x3*y1+4*y2*f0*x3*f5*x2*y1-8*y2*f0*x2*x1*f3*y1+4*y2*f1*f5*x3^2*y1+8*y2*f6*x3^2*f0*y1+4*f0*x2*x1*y2*y3*f5+8*f0*x1^2*y3*y2*f4+4*y4*f2*x2*x3*y1-4*y4*f1*x1*x3*y1-2*y2*y4*x1*x2*f1-4*y2*y4*x3*x1*f2-4*y4*f0*x2*x1*y1-4*y2^2*f0*f5*x1*x3-4*y3*f0*x2^2*f5*y1-8*y3*x3*y2*f6*x2*f1-4*y3*x3*y2*f5*x1*f1+x1^2*y3^2*h2^2*f1+x1^2*y3^2*f5*h0^2+y3^2*x2^2*f1*h3^2+y2*y4*x1^2*h0^2+x2^2*y1^2*h0^2*f3+x3^2*y1^2*h2^2*f1+x3^2*y1^2*f5*h0^2+y2^2*x1^2*h0^2*f3+x3^2*y2^2*f1*h3^2+y3*x2*y4*h0*h2*x1+2*x3^2*y2*y1*f0*h3^2+2*y2^2*x3*x1*f2*h0*h3-2*y2^2*x1*x3*f0*h2*h3-2*y2*x1*x3*y1*f0*h2^2-y2^2*x1*f1*h1*h3*x3-2*y2*x1*x2*y1*h0^2*f3+2*y2*x2*f1*y1*h0*h2*x1-4*y2*x1*x2*y1*f0*h1*h2+y4*x3^2*y1*h0*h3-2*y3*x1*y2*x3*f0*h3^2+2*y3^2*x1*x2*f0*h3^2+2*x3^2*y1^2*f4*h0*h1+2*x3^2*y1^2*f0*h2*h3+x3*x2*y1^2*f3*h0*h1+2*x2^2*y1^2*f0*h1*h2-y3^2*f3*x1*h0*h3*x2+x3*x2*y1^2*f1*h1*h2+2*x3*x2*y1^2*f0*h1*h3+2*x3*x2*y1^2*f0*h2^2+2*x3^2*y2*y1*f6*h0^2-2*f2*x2*x3*y1*h0*h3*y2+y2*x2*f1*y1*h1*h3*x3+2*y2*x3*x2*y1*f0*h2*h3+y2*x3*x2*y1*f5*h0^2-y2^2*x1^2*f1*h0*h2-2*x3*x2*y3*y1*f6*h0^2-x3*x2*y1^2*f1*h0*h3+2*x3*x2*y1^2*f4*h0^2+y3*x1*x2*y2*f5*h0^2-2*y3*x2^2*y1*f0*h2*h3-2*y3*x1*x2*y1*f0*h2^2+x3*y3*f3*y1*h0*h3*x2-2*x3*x2*y3*y1*f5*h0*h1-2*x3*x2*y3*y1*f1*h2*h3-2*x3*x2*y3*y1*f0*h3^2-2*y3*x1^2*y2*f2*h0*h2-4*y3*x3*x2*y2*f6*h0*h1+x1^2*y3*y2*f3*h0*h1-x1^2*y3*y2*f1*h0*h3+x1^2*y3*y2*f1*h1*h2+2*x1^2*y3*y2*f0*h2^2+2*y3^2*x1*x2*f5*h0*h1-y3^2*f3*x1^2*h0*h2-2*y3*x1*x3*y1*f5*h0^2+2*x3*y3*f3*y1*h0*h2*x1+2*x1^2*y3^2*f4*h0*h1+2*x1^2*y3^2*f0*h2*h3+2*y3^2*x1*x2*f1*h2*h3+2*y3^2*x1*x2*f6*h0^2+2*y3^2*x2^2*f6*h0*h1+2*x1^2*y3*y2*f4*h0^2-y3*x2^2*y1*f5*h0^2+2*y3*x2*f2*y1*h0*h2*x1-y3*x1*x2*y1*f3*h0*h1+y3*x1*x2*y1*f1*h0*h3-y3*x1*x2*y1*f1*h1*h2-2*y3*x1*x2*y1*f0*h1*h3+y2*x3^2*y4*h1*h3+y4*x3*x2*y1*h1^2+y4*x3^2*y1*h1*h2-y4*x1*x2*y1*h0^2+y4*x2^2*y1*h0*h1-2*y4*x1*x3*y1*h0*h1+2*y3*y4*x1^2*h0*h1+y3*x2^2*y4*h0*h3-y3*y4*x1*x3*h0*h3-y3*y4*x1*x3*h1*h2-x3*y2*y4*x1*h1^2-y3*x2*y4*h1*h3*x3-y2*y4*x1*x2*h0*h1-y2*x3*y4*h0*h3*x2+y3*x3*f3*x1*h0*h3*y2-2*y3*x1*x2*y1*f4*h0^2-2*y3*x1*x3*y1*h2^2*f1-2*y3*x1*y2*x3*f6*h0^2+2*y3*x1*x2*y2*f0*h2*h3-2*y3*x1*y2*f2*h0*h3*x2-2*y3*x1*y2*x3*f5*h0*h1-2*y3*x1*y2*x3*f1*h2*h3-2*y3*x3*x2*y2*f1*h3^2-4*y3*x1*x3*y1*f4*h0*h1-4*y3*x1*x3*y1*f0*h2*h3+2*y3*x2^2*f2*y1*h0*h3+2*x1^2*y3*y2*f0*h1*h3-x3*y2*y4*x1*h0*h2+2*x3^2*y2*y1*f5*h0*h1+2*x3^2*y2^2*f6*h0*h1+2*y2^2*x1^2*f0*h1*h2+2*x3^2*y2*y1*f1*h2*h3-y2^2*x1*x3*f5*h0^2-y2*x1*x3*y1*f3*h0*h1+y2*x1*x3*y1*f1*h0*h3-y2*x1*x3*y1*f1*h1*h2-2*y2*x1*x3*y1*f0*h1*h3-f3*x3^2*y1*h0*h3*y2-2*y2*x1*x3*y1*f4*h0^2+y2*x1*x2*f1*h1*h3*y3-f3*x3^2*y1^2*h0*h2-2*f2*x2*x3*y1^2*h0*h2-x2^2*f1*y1^2*h0*h2+2*y2*x3*x1*f2*h0*h2*y1-x2^2*f1*y1*h1*h3*y3-4*y3*x4*x1*f1*y1-4*y3*x2*f2*x4*y1-y3*y2*x4*h1*h3*x3+y2^2*x3*h0*h3*x4+x1*x4*y3*y2*h1^2+2*y3*x4^2*y2+y2^2*x1*x4*h0*h1+4*f0*x4*x2*y1^2+x2*x4*y1^2*h0^2+4*x3*x4*f1*y1^2+2*x4*y2^2*x1*f1+2*x4*x3*y1^2*h0*h1+y2*x3*h0*h2*y1*x4-y2*x1*x4*y1*h0^2-2*x4*y2*x2*f1*y1-4*y2*x4*x1*f0*y1-y2*x4*x2*y1*h0*h1+4*y3*x4*x1*y2*f2-y3*x4*x2*y1*h0*h2-y3*x4*x3*y1*h0*h3+2*y3^2*f3*x1*x4-2*y2*y4*x3*x4-2*y3*y4*x4*x2+y3^2*x1*x4*h0*h3+y3^2*x1*x4*h1*h2+y3^2*x2*h1*h3*x4-2*x3*x4*y3*f3*y1-2*x1*x4*y3*y1*h0*h1-y3*x4*x3*y1*h1*h2-y3*x4*x2*y1*h1^2-y3*y2*x4*h0*h3*x2;
b24:=16*f5*x1^2*f0^2*y1^2+16*y3^2*f1*x3^2*f6^2-2*x1^2*f3*f1^2*y1^2-2*x3^2*f5^2*f3*y3^2+8*y3*y4*x3*f5*x1*f2+2*y2*x3*f3*x2*f5*f1*y1-24*y2*f0*f6*x2*x3*f3*y1+8*y2*f0*f5*x2*x3*f4*y1+8*y2*f1*f5*x1^2*f0*y1+4*y2*f0*x1^2*f3^2*y1+16*y2*x1^2*f6*f0^2*y1+8*y3*f0*f4*x2^2*f5*y1+8*y4*x3*f4*x1*f1*y1+4*y4*x3*f5*x2*f1*y1-8*y4*f0*f5*x3*x1*y1+16*y2*f0*f4^2*x3*x1*y1+8*y2*f6*x3*x1*f1^2*y1+8*y2*f0*f5^2*x3^2*y1+4*y2*x2^2*f6*f1^2*y1+8*f0*f4*x2*x1*y2*f3*y1+8*f0*f5^2*x3*x1*y2*y3+2*y3*y4*x3*f5*x2*f3+8*f1*x3*f6*x2*y2*f2*y1-16*y3*y2*f2*f0*f6*x1^2+8*y3*y2*f0*f5*f4*x2*x1+8*y3*x2*f2*x1*y2*f6*f1+2*y3*x2*y2*f3*x1*f5*f1+8*y3*y2*f1*x3^2*f6*f5+16*y3*x3*f4^2*x1*f1*y1+16*y3*f2^2*f5*x3*x1*y1+4*y3*x3^2*f3^2*y2*f6+16*y3*y2*f0*f6^2*x3^2-16*y2*f0*f6*x3^2*f4*y1+16*f0^2*f6*x2*x1*y1^2+4*f0*f3^2*x2*x1*y1^2+8*y3*f5*x1^2*f1^2*y1+8*y3*f2*x3^2*f6*f3*y1-16*y3*f1*x3^2*f6*f4*y1+8*y2^2*f0*f5*x3*x1*f4+16*y3*f0*f4^2*x2*x1*y1+4*y2^2*f0*f5*f3*x2*x1+8*f1*y2^2*f6*x3*x1*f2-16*y3*f0*f5*f3*x2*x1*y1-16*y3^2*f0*f4*f6*x2*x1-8*y4*f0*f6*x3*x2*y1+8*y2^2*f0*f6*x2^2*f3+4*y2^2*f0*f5^2*x3*x2+4*y3*x2^2*y2*f3*f6*f1+8*y3*x3*f3*x2*y2*f6*f2-16*y3*x3*f3*x1*y2*f6*f1-16*f0*f6*x3*x1*y3*y2*f4+4*y2^2*f6*x2*x1*f1^2+8*f0*x2^2*f6*f1*y1^2+8*x3^2*f6*f3*y3^2*f4-16*y3*f0*f5*f2*x1^2*y1+16*y3*f2^2*x3*f6*x2*y1+8*y3*f1*f5^2*x3^2*y1-16*y2^2*f0*f6*x3*x1*f3+8*y4*f0*f4*x2*x1*y1-16*f0*f6*x3*x2*f2*y1^2+8*f0*x1^2*f3*f2*y1^2+8*y3*x3*y2*f4*x1*f5*f1+4*y3^2*x3*f3^2*x2*f6+8*y3*x2*f2*x1*f5*f1*y1-16*y3*f0*f2*f6*x2*x1*y1+16*y3*f2^2*x3*f6*x1*y2+8*y3*y2*x1^2*f6*f1^2+8*y3^2*x3*f5*x2*f6*f1-24*y3*y2*f0*f3*f6*x2*x1+4*y3*x3*y2*f5^2*x2*f1+8*y3^2*x3*f3*x1*f6*f2+8*y3^2*x3*f5^2*x1*f1-16*y3^2*x3*f4*x1*f6*f1+16*y3*y2*f0*f5*f6*x3*x2+4*x3*f3*x2*y2^2*f6*f1+2*y2*y4*x3^2*f5*f3+4*y3*y4*x2^2*f6*f1+4*y2*y4*x3*f5*x2*f2-2*y2*y4*x3*f3^2*x1+2*y2*y4*x1^2*f3*f1+4*y3*y2*f0*f5^2*x2^2-2*x1^2*f3*f1*y3^2*f5+8*f5*x3*x1*f1^2*y1^2-16*f0*f5*x3*x1*f2*y1^2+8*f0*f5*f1*x2*x1*y1^2+4*f0*x2^2*f5*y2*f3*y1+16*y2*f1*f0*f6*x2*x1*y1+4*y2*f5*x2*x1*f1^2*y1+8*y2^2*f0*f6*x3^2*f5-8*y3*y4*f6*f0*x2*x1+2*y2*y4*x2^2*f5*f1+4*y2*y4*x2*f4*x1*f1+4*y3*y4*x2*f5*x1*f1+4*y4*f0*x2^2*f5*y1+8*y3*y4*x3^2*f6*f3+8*y3*y4*x3*f6*x2*f2-8*y3*y4*x3*f6*x1*f1-8*y2*y4*f0*f6*x3*x1+8*y2*y4*x3*f4*x1*f2+2*y4*x2*f3*x1*f1*y1+8*y4*f0*x1^2*f3*y1-16*y3*f0*f6*x2*x3*f4*y1-16*y3*x3*f3*x2*f1*f6*y1+8*y3^2*f0*f5^2*x2*x1+2*y3*x3*f3^3*x1*y1-16*y3*x3*f3*x1*f5*f1*y1-8*f0*f6*x3*x1*y3*f3*y1-8*y3*x3*f3*x1*f4*f2*y1+8*y3*f0*f5^2*x3*x2*y1+8*y2^2*f1*x1^2*f6*f0+8*f1*f5*x3*x1*y2*f2*y1-16*y2*f0*f5*x3*x1*f3*y1-16*y2*f0*f6*x3*x1*f2*y1+8*y3*f6*x2*x1*f1^2*y1+8*y3*f0*f4*x1^2*f3*y1+8*x3*f6*x2*f1^2*y1^2+8*f0*f4*x3*x1*f3*y1^2-2*x3^2*f5*f3*f1*y1^2-16*y3*f0*f6*x2^2*f3*y1+8*y3*x2^2*f2*f1*f6*y1+8*y3^2*f0*f6*x2^2*f5+8*y3*x3*f4*x2*f5*f1*y1+16*y3^2*f0*f6^2*x3*x2+2*x4*x3*y2^2*f6*h0*h1+x1^2*y1^2*f5*h0^4+y3^2*x3^2*f1*h3^4+h0*h3*x2^2*y4^2-4*y3*x1*x3*y1*f0*f6*h0*h3+y3*x1*y2*x3*f6*h1^4-4*y3*x3^2*y1*f1*f6*h2^2+y3*x2^2*f3^2*y1*h0*h3+4*y3*x1*x2*y1*f2*f5*h0*h1+12*y3*x1*x2*y1*f0*f5*h0*h3+8*y3*x1*x3*y1*f1*f5*h0*h3-4*y3*x3^2*y1*f1*f4*h3^2-3*y3*x1*x3*y1*f1*h1*h2^2*h3+3*y3*x2^2*y1*f0*h0*h3^3-y3*x2*y1*h2^2*f2*h1*h3*x3+y3*x1*x3*y1*f6*h0^2*h1*h2+y3*x1*x2*y1*f0*h2^4-4*y3*x1*x3*y1*f0*f6*h1*h2+2*y3*x2^2*y1*f0*f5*h2^2+y3*x1^2*y1*f5*h0^2*h1^2+8*x3*x2*y3*y1*f0*f5*h2*h3+2*x1*x3*y3^2*f2*f3*h3^2+x1*x3*y3^2*f2*h0*h3^3-2*y3*x1*x3*y1*f4*h0^2*h2*h3+2*y3*x1^2*y1*f0*h2^2*f3+y3*x1^2*y1*h0^2*h2^2*f3+y3*x2^2*y1*f0*h2^3*h3+5*y3*x1*x3*y1*f5*h0^2*h1*h3-x1^2*y3^2*f1*f5*h1*h2+y3*x3^2*y1*f5*h0*h1*h2*h3-x1^2*y3*y1*h2^3*f1*h0+4*x1*x3*y3^2*f5^2*h0*h1+x1*x3*y3^2*f5*h0*h1*h2*h3+x1*x3*y3^2*f6*h1^3*h2-8*y3*x1*x2*y1*f0*f5*h1*h2+y3*x1^2*y1*f4*h0^3*h3+5*y3*x1*x3*y1*f1*h0*h2*h3^2-8*y3*x1*x3*y1*f1*f5*h1*h2-8*y3*x1*x3*y1*f1*f3*h2*h3+y2^2*x1*f2*h0^2*h3^2*x2-4*x3^2*y2*y1*f0*f4*h3^2+2*x1^2*y2*y1*f5*h0^2*f1-2*x3^2*y2^2*f6*h0*h1^2*h3+y2^2*x3^2*f4*h0*h3^2*h1+8*x1^2*y2*y1*f0*f6*h0^2-y2^2*x2^2*f5*h0^2*h1*h3-3*y2^2*x1^2*f0*h0*h1*h3^2+2*y2^2*x1^2*f0*f1*h3^2+y2^2*x1^2*f6*h0^3*h1-y2^2*x2^2*f1*h2*h3^2*h0-2*y2^2*x1^2*f0*h2^2*h3*h0+2*y2^2*x1^2*f1*f6*h0^2+y2*x2^2*y1*f3*f5*h0^2+4*y2*x1*x3*y1*f2*h2*h3*f1+y2*x2^2*y1*f6*h0^2*h1^2+8*y2*x1*x2*y1*f0*f6*h0*h1+2*y3*x1*x3*y1*h1^2*h2*h3*f2+8*y3*x3*x2*y2*f0*f6*h2*h3-4*y3*x2*f2*y2*f5*h1*h3*x3+2*y3*x2^2*y1*f1*f6*h1^2+y3*x1^2*y1*f1*h0*h1*h2*h3-4*x1*x3*y3^2*f1*f6*h2^2-4*y2*x3*x2*y1*f1*h0*h2*h3^2+y2*x3*x2*y1*f3*f5*h0*h1+2*x3^2*y2*y1*f5^2*h0^2+3*y3^2*x1*x2*f4*h0^2*h3^2-4*y3^2*x1*x2*f4*f6*h0^2-4*y3^2*x1*x2*f0*f6*h2^2+y3^2*x3*x2*f3^2*h3^2+4*y3*x1^2*y1*f1^2*h2*h3-y3*x1^2*y1*f5*h0^3*h2+x3*x2*y3*y1*f6*h1^4-4*y3*x1*x3*y1*h1*h2*f4*f2+y3*x1*x3*y1*f2*h0*h2^2*h3+x1*x3*y3^2*f1*h2^2*h3^2+y3^2*x3*x2*f1*h2*h3^3+2*y3^2*x3*x2*f1*f5*h3^2-y3^2*x3^2*f5*h1*h2^2*h3+8*y3^2*x3^2*f6^2*h0*h1-2*y3^2*x3^2*f3*f5*h2*h3+3*y3^2*x3^2*f5*h0*h2*h3^2+2*y3*x2*f4*h0*h3^2*y2*h1*x3+2*y3^2*x3^2*f6*h0*h1*h3^2+2*y3^2*x2^2*f5*f6*h0^2-3*y3^2*x2^2*f6*h0^2*h2*h3+2*y3*x1*y2*x3*f5^2*h0^2-3*y3^2*x3^2*f4*h0*h3^3-3*y3^2*x3^2*f6*h0*h2^2*h3+2*y3^2*x1*x2*f5^2*h0^2-8*y3*x1*x2*y1*f0*f3*h2*h3+4*y3*x1*x2*y1*f2*h2*h3*f1+y3*x2^2*y1*f3*h1*h2*h0*h3+2*x3*x2*y3*y1*f5^2*h0^2-8*y3*x1*y2*x3*f1*f6*h1*h2+4*y3^2*x3*x2*f6^2*h0^2-x1^2*y3^2*f3*f5*h0*h1-2*x1^2*y3^2*f5*h0^2*h1*h3+y3^2*x3*x2*f0*h3^4-2*x1^2*y3^2*f1*h0*h2*h3^2-x1^2*y3^2*f1*f3*h2*h3-4*y3*x2*f2*f4*y1*h1*h3*x3-4*y3*x3*f5*f2*y1*h0*h3*x2+12*x3*x2*y3*y1*f1*f6*h0*h3+y3*x1*x3*y1*h2^4*f1+2*y3*x1*x3*y1*f4*h2^2*h0*h1+4*y3*x1*x3*y1*f4*h1*h3*f1+y3*x1*x3*y1*f4*h1^2*h3*h0+y3*x3^2*y1*f6*h1^3*h2+4*y3*f0*f5*x1*y1*h1*h3*x3+2*y3*x3^2*y1*f3*f6*h1^2+2*y3*x2^2*y1*f1*f2*h3^2+8*y3*x1*x2*y1*f0*f4*h1*h3-4*y3*x1*x3*y1*f3*f4*h0*h2-5*x1^2*y3^2*f1*f5*h0*h3+y3*x3^2*y2*f6*h1^2*h2^2+x1*x3*y3^2*f3*h1^2*h3^2+2*y3*x2^2*y1*f4*f5*h0^2+4*y3*f1*f6*x3*y1*h0*h2*x1+y3*x1*x2*y2*f1*f5*h1*h2+y3^2*x3^2*f4*h1*h2*h3^2+4*y3^2*x3^2*f4*f6*h1*h2+y3^2*x3^2*f6*h1*h2^3-y3^2*x3^2*f5^2*h1*h2+2*y3*x3^2*y1*f2*f3*h3^2+2*y3^2*x3^2*f3*f4*h3^2-12*y3^2*x3^2*f4*f6*h0*h3+5*x3*x2*y3*y1*f6*h0^2*h1*h3+2*y3^2*x3^2*f3*f6*h2^2-y3*x2*y1*f4*h1^2*h0*h2*x1-4*y3*x3*f5*x1*f2*h0*h3*y2+4*x3*x2*y3*y1*f4*f5*h0*h1-y3^2*x2^2*f3*f5*h0*h3-11*y3*x1*x2*y2*f1*f5*h0*h3+2*y3*x1*x2*y1*f1^2*h3^2+
     y3*x2*y1*f3*h1*h2^2*h0*x1+8*y3*x1*x2*y1*f1*f6*h0*h1+4*y3*x1*x2*y1*h0^2*f4^2-4*y3*x2^2*y1*f3*f6*h0^2-4*y3*x1*f4*f1*y1*h0*h3*x2-4*y3*x2*f2*f4*y1*h0*h2*x1+3*y3*x2^2*y1*f6*h0^3*h3-4*y3*x2^2*y1*f0*f3*h3^2+8*x3*x2*y3*y1*f2*f6*h0*h2-2*y3*x1*x3*y1*h0*h1*h3^2*f2+4*x3*x2*y3*y1*f2^2*h3^2-y2*y4*x3^2*h3^2*h0*h2-3*y2*y4*x3^2*f5*h0*h3-y4*x2^2*y1*h0^2*h2*h3+2*y4*x2^2*y1*f0*h2*h3+y4*x2^2*y1*f5*h0^2-y2*y4*h0^2*h3^2*x2^2+x3*y2*y4*x1*h3^2*h0^2+y2*y4*x1^2*f3*h0*h1-3*y2*y4*x1^2*f1*h0*h3+y2*y4*x3^2*f5*h1*h2-2*x3*y2*y4*x1*f0*h3^2+2*x3*y2*y4*x1*h2^2*f2-y4*x1^2*y1*h0^3*h3-2*x1^2*f1*y1*y4*h0*h2+y4*x3*x2*y1*h3^2*h0^2-4*y4*x1^2*y1*f0*h0*h3+2*y4*x1^2*y1*h0^2*f3-y4*x3*x2*y1*h0*h1*h2*h3-2*y4*x1*x3*y1*f5*h0^2+x3*y2*y4*x2*f5*h1^2+y2*y4*x2^2*f5*h0*h1-2*y4*x3*x2*y1*f6*h0^2+2*y4*x1*x3*y1*h2^2*f1+2*y3*y4*x3*x2*f2*h3^2-2*y2*x3^2*f4*y4*h1*h3-2*y3*y4*x1*x2*f6*h0^2-y3*y4*x2^2*h0*h1*h3^2-y3*y4*x1*x2*h0*h1*h2*h3+y3*y4*x2^2*f1*h3^2+2*y3*y4*x2^2*f6*h0*h1+y2*y4*x2^2*f1*h2*h3+4*y3*y4*x3^2*f6*h1*h2+y2*y4*x1*x2*h2^2*f1-y2*y4*x1^2*h0^2*h1*h3+y2*y4*x1^2*f1*h1*h2-y2*x2^2*f3*y4*h0*h3-y3*y4*x3^2*h0*h3^3-2*y3*y4*x1*x2*f0*h3^2+2*y3*y4*x3^2*f3*h3^2-4*y3*y4*x3^2*h0*h3*f6-2*y3*x3^2*f5*y4*h1*h3+y3*x2^2*y2*f1*f3*h3^2-8*y3*x1*y2*x3*f3*f6*h0*h1+12*y3*x1*y2*x3*f1*f6*h0*h3-2*y3*x3*f3*y2*f5*h0*h3*x2-4*y3*x1*x2*y2*f5*h0^2*h1*h3+y3*x1*x2*y2*f3*f5*h0*h1+3*x1^2*y3*y2*f2*h0^2*h3^2-4*x1^2*y3*y2*f0*f6*h1^2-y3*x3*y2*f3*h2^2*h3*h0*x1+6*y3*x1*x2*y2*f0*f5*h1*h3-2*y3*x1*y2*x3*f6*h0*h1^2*h2-4*y3*x3*x2*y2*f2*f6*h0*h3-y3*x2*y2*f2*h2^2*h3*h0*x1+6*y3*x1*x2*y2*f1*f6*h0*h2-2*y3*x2*f2*y2*f5*h0*h2*x1-4*y3*x1*x2*y2*f0*f6*h0*h3-12*y3*x1*x2*y2*f0*f6*h1*h2+4*y4*x1^2*y1*f0*h1*h2-y3*x3^2*y2*f6*h1^3*h3-y3*x3^2*y2*f2*h3^3*h1+y3*x2^2*y2*f5^2*h0^2-2*x3*y2*y4*x1*f6*h0^2-2*y3*y4*x1*x3*f1*h3^2-2*y3*x2^2*f4*y4*h0*h3+2*y3*y4*x1*x3*f5*h1^2-2*x2^2*f2*y1*y4*h0*h3+2*y4*x1*x2*y1*f0*h2^2-2*y3*x1*y2*x3*f1*h1*h2*h3^2+y3*x1*x2*y2*f1*f3*h2*h3-4*y3*x1*x2*y2*f1*h0*h2*h3^2+y3*x1*x2*y2*h0*h1*h3^2*f2-4*x1^2*y3*y2*f0*f2*h3^2+2*x1^2*y3*y2*f1^2*h3^2+y2*x1*x3*y1*f1*h0*h1*h3^2+y2*x2^2*y1*f1^2*h3^2-12*y2*x3*x2*y1*f0*f6*h1*h2+4*y3*x1*y2*x3*f1*f4*h2*h3-4*y3*x1*x3*y1*f3*h1*h3*f2+5*y3*x1*y2*x3*f6*h0^2*h1*h3+y3*x1*x3*y1*f0*h1*h2*h3^2+2*y3*x3^2*y2*f1*f5*h3^2+y2^2*x3*f4*h0^2*h3^2*x2+x1^2*y3*y2*f6*h0^2*h1^2+4*y2*x3*x2*y1*f2*f6*h0*h1+5*y3*x1*x2*y1*f0*h0*h2*h3^2-4*y3*x1^2*y1*f2*f5*h0^2+2*y2^2*x2^2*f3*f6*h0^2+4*y3*x1*x3*y1*f2*f5*h0*h2+y3*x2*y1*f3*h1^2*h2*h3*x3+y3*x1*y2*x3*f5*h0^2*h2*h3+y2*y4*x3^2*f3*h2*h3+4*y3*x1*x2*y2*f2*f6*h0*h1+8*y3*x1*y2*x3*f2*f6*h0*h2+x1*x3*y1^2*f0*h2^3*h1-x3^2*y1^2*f1*f3*h2*h3+8*x1*x3*y1^2*f1*f5*h0*h1+8*x3*x2*y1^2*f1*f6*h0*h1+x1*x2*y1^2*f0*h0^2*h3^2+4*x1*x2*y1^2*f0*f3*h1*h2+x1*x2*y1^2*f0*h1^2*h2^2-2*f1*f3*x2*y1^2*h0*h2*x1+8*y3*x3^2*y2*f0*f6*h3^2+4*y3*x1*x2*y2*f0*f4*h2*h3+2*y3*y4*x3*x2*f6*h1^2+4*x3*x2*y3*y1*f1*f4*h2*h3+y3*x1*x2*y2*f4*h0^2*h2*h3-4*x1^2*y3*y2*f2*f6*h0^2+y3*x2^2*f4*h0^2*h3^2*y2-x3^2*y1^2*f3*f5*h0*h1-4*x1*x3*y1^2*f2*f5*h0^2+4*x1*x2*y1^2*f0*f5*h0*h1+4*x1*x2*y1^2*f0*h2*h3*f1+3*x1*x2*y1^2*f1*h0^2*h2*h3+y2^2*x1*x2*f1^2*h3^2+2*y3^2*x2^2*f0*f5*h3^2-4*x1*x3*y3^2*f1*f4*h3^2-4*x3*x2*y1^2*f0*f2*h3^2-4*x3*x2*y1^2*f0*h0*h2*h3^2+3*x3*x2*y1^2*f2*h0^2*h3^2+2*x1^2*y1^2*f0*f3*h1^2-3*x1^2*y1^2*f0*h0*h3*h1^2+2*x1^2*y1^2*h0^2*f3*f2+x1^2*y1^2*h0^2*h1*h2*f2+2*x2^2*y1^2*f1*f6*h0^2+2*x2^2*y1^2*f0*f1*h3^2+4*x2^2*y1^2*f0*f6*h0*h1+x2^2*y1^2*f6*h0^3*h1+x1*x2*y1^2*f3^2*h0^2+x3*y2^2*x2*f0*h2^2*h3^2+4*y3^2*x2^2*f0*f6*h2*h3-8*y3*x1*x3*y1*f3*f5*h0*h1+4*x1^2*y2*y1*f0^2*h3^2-3*y3*x1*x3*y1*f5*h0*h1^2*h2-4*y3^2*x1*x2*f0*f4*h3^2+y3*x3^2*y2*f3^2*h3^2+y3*y4*x1*x2*h3^2*h0^2+8*y3*x1*y2*x3*f0*f5*h2*h3+2*x3*y2*y4*x1*f4*h1^2-y3*x3^2*y1*f1*h1*h3^3+4*x1^2*y1^2*f0*h1*h2*f2-y2*x1^2*y1*f4*h0^3*h2+y2^2*x1*x2*f6*h0^2*h1^2+y3*x3^2*y2*f1*h2*h3^3+4*y3*x1*y2*x3*f4*f5*h0*h1-4*y3*x1*y2*x3*f1*f3*h3^2+3*y3^2*x3^2*f5^2*h0*h3+y3*x2^2*y1*f6*h0*h1^3+x1*x3*y1^2*f5*h0^2*h1^2+4*y2^2*x1^2*f0*f6*h0*h1-y3*x1*x3*y1*h1^3*h2*f4-y3*x3^2*y1*f5*h1^3*h3+x1^2*y2*y1*f0*h1^2*h2^2-4*f1*y2*f4*x2*y1*h0*h2*x1+y3*x3^2*y2*f0*h3^4+4*y3*x3*x2*y2*f1*f5*h2*h3-y2*x1^2*y1*f0*h2^3*h0-2*y2*x1^2*f2*y4*h0*h2+y2*x1*x3*y1*f0*h2^4+y2*x3*x2*y1*f1*f3*h2*h3+y3*x3^2*y2*f6*h0^2*h3^2+y3^2*x2^2*f0*h2*h3^3-2*y3*x3*f3*y2*f5*h0*h2*x1+y2^2*x1*x3*f0*h2^3*h3+2*x1*x3*y1^2*f0*h2^2*f3-x1*x3*y1^2*f4*h0^2*h1*h2+4*y3*x3^2*y1*f5^2*h0*h1+2*y3*x1^2*y1*f4*h0^2*f3+4*x1*x3*y1^2*f0*f4*h0*h3+4*x1*x3*y1^2*f0*f4*h1*h2+2*x1*x3*y1^2*f4*h0^2*f3+x1*x3*y1^2*f4*h0^3*h3+x1*x3*y1^2*h0^2*h2^2*f3+x3*x2*y1^2*f6*h0^2*h1^2-4*x1*x3*y1^2*f0*f5*h0*h2-4*x1*x3*y1^2*f0*f5*h1^2-8*x1*x3*y1^2*f0*f2*h2*h3-x1*x3*y1^2*f0*h0*h2^2*h3-2*x1*x3*y1^2*f0*h1^2*h2*h3+2*x1*x3*y1^2*f2*h0^2*h2*h3-f1*f3*x2^2*y1^2*h0*h3+4*x1*x3*y1^2*f1^2*h2*h3-4*x3*x2*y1^2*f0*f6*h1^2-x1*x3*y1^2*f5*h0^3*h2-5*x3^2*y1^2*f1*f5*h0*h3-x3^2*y1^2*f1*f5*h1*h2-2*x3^2*y1^2*f5*h0^2*h1*h3-2*x1^2*y1^2*f3*f1*h0*h1-x1^2*y1^2*h1*h2*f1^2+8*x1^2*y1^2*f5*f0*h0^2+8*x1^2*y1^2*h2*h3*f0^2+2*x1^2*y1^2*h2*h3*f0*h0^2-x2*y1^2*f1*h1*h2^2*h0*x1+x1*x2*y1^2*f6*h0^4+4*x1*x2*y1^2*f0^2*h3^2+8*x1*x2*y1^2*f0*f6*h0^2+2*x3*x2*y1^2*f1^2*h3^2-x3*x2*y1^2*f1*h0*h1*h3^2+y3^2*x3*x2*f6*h0^2*h3^2+8*y3^2*x3^2*f1*f6*h3^2-4*y3*x1^2*y1*f0*f5*h1^2-4*y2^2*x1*x3*f0*f3*h3^2+x2^2*f2*y1*h0^2*h3^2*y2-2*x3^2*y1^2*f1*h0*h2*h3^2+y3*x1*x3*y1*h1^4*f5+2*y3*x1*x2*y2*f4*f5*h0^2+y3*x2^2*y2*f0*h2^2*h3^2-4*y3*x1*x3*y1*h0*h3*f4*f2+x1*x3*y1^2*f1*h0*h1*h2*h3+y3^2*x1*x2*f0*h2^2*h3^2+3*x1^2*y1^2*h0*h3*f1^2+3*x1^2*y1^2*h0^2*h3*f1*h1-2*y4*x3*x2*y1*f0*h3^2+4*y3*x3*x2*y2*f2*f6*h1*h2+y3*x3^2*y1*f1*h2^2*h3^2-2*x2*f3*x1*f1*y1*h0*h3*y2-8*x3*x2*y3*y1*f3*f6*h0*h1-x1^2*y1^2*h1^2*h2*f1*h0+y2*x3*x2*y1*h0*h1*h3^2*f2-3*y3*x3*x2*y2*f6*h0*h1^2*h3+y3*x3^2*y1*f3*h1^2*h3^2+x1^2*y2*y1*f0*h0^2*h3^2-3*x1^2*y1^2*h0^3*h3*f2+2*y4*x1*x2*y1*f4*h0^2+4*y3*x1*y2*x3*f2^2*h3^2+x1*x2*y1^2*f5*h0^3*h1+8*y3^2*x3*x2*f0*f6*h3^2+x1^2*y1^2*f0*h1^3*h2+3*x3^2*y2*y1*f4*h0^2*h3^2+8*y2*x1*x3*y1*f1*f6*h0*h1+2*x1*x2*y1^2*f5*h0^2*f1-4*x3*x2*y1^2*f2*f6*h0^2+y3*x1^2*y1*f0*h2^3*h1+2*y3*x1*x2*y2*f1*f2*h3^2+2*x1*x3*y3^2*f3*f6*h1^2-3*x2^2*y1^2*f0*h0*h1*h3^2-8*x3*x2*y3*y1*f1*f6*h1*h2+4*y3*x3^2*y2*f6^2*h0^2+y3*x3^2*y1*f2*h0*h3^3+
     y3^2*x3*x2*f6*h1^2*h2^2-x1*x3*y3^2*f1*h1*h3^3-8*x1*x3*y3^2*f4*f6*h0*h1+x3*y2^2*x2*f1*f3*h3^2-x2^2*y1^2*f1*h1*h2*h0*h3-12*x1^2*y1^2*f0*h0*h3*f2+y2^2*x2^2*f6*h0^2*h1*h2-x3*y2^2*x2*f5*h1^2*h0*h3-x2*y2^2*f5*f1*h1*h3*x3-x3*y2^2*x1*f4*h1^2*h0*h3+x3*y2^2*x1*f3*h1*h2*h0*h3+2*y2^2*x1*x3*f1*f2*h3^2-4*y2^2*x1*x3*f3*f6*h0^2-y2*x2*y1*f4*h0*h1^2*h3*x3+8*y2*x1*x3*y1*f0*f4*h1*h3+x1^2*y2*y1*f3^2*h0^2+12*y2*x1*x3*y1*f0*f5*h0*h3-4*x3^2*y2*y1*f0*f6*h2^2-11*y2*x3*x2*y1*f1*f5*h0*h3+4*y2*x3*x2*y1*f0*f4*h2*h3-y2*x1*y1*f3*h0*h1^2*h3*x3+6*y2*x3*x2*y1*f1*f6*h0*h2-3*y2*x1*x2*y1*f0*h0*h2^2*h3+x1^2*y2*y1*f6*h0^4+y2*x3*x2*y1*f4*h0^2*h2*h3-4*y2*x1*x2*y1*f0*f4*h0*h3+4*y2*x1*x2*y1*f0*f4*h1*h2+2*y2*x1*x2*y1*f0*h2^2*f3+y2*x1*x2*y1*f0*h2^3*h1+12*y2^2*x1*x3*f0*f6*h0*h3-8*y2^2*x1*x3*f0*f6*h1*h2+3*y2^2*x1*x3*f6*h0^3*h3+3*y2^2*x1*x3*f0*h0*h3^3-4*x3^2*y2*y1*f4*f6*h0^2-4*x3^2*y2*y1*f6*h0^2*h1*h3+5*y2*x1*x3*y1*f0*h0*h2*h3^2+2*y2*x1*x3*y1*f1^2*h3^2+2*x2*f2*y1*h0^2*h3*y2*h2*x1-4*y2*x3*x2*y1*f0*f6*h0*h3+2*y2*x3*x2*y1*f1*f6*h1^2-2*y2*x1*f1*f3*y1*h1*h3*x3-4*x3*f4*x1*f1*y1*h0*h3*y2+y2*x1*x3*y1*f6*h0^2*h1^2-8*y2*x1*x3*y1*f0*f5*h1*h2-8*y2*x1*x3*y1*f0*f3*h2*h3-4*y2*x1*x3*y1*f3*f5*h0^2+3*y2*x1*x3*y1*f5*h0^3*h3+2*y2*x1*x2*y1*f4*h0^2*f3-y2*x1*x2*y1*f4*h0^3*h3+y2*x1*x2*y1*h0^2*h2^2*f3+y2*x1*x2*y1*f5*h0^2*h1^2+2*y2*x1*x2*y1*f1^2*h2*h3+4*x1^2*y2*y1*f0*f3*h1*h2+4*y2*x2^2*y1*f1*f6*h0*h1-2*y2*x1^2*f1*f3*y1*h0*h2-4*y2*f0*f4*x1^2*y1*h0*h2-y2*x1^2*y1*f1*h1*h2^2*h0+4*y2*x1*x2*y1*f1*f5*h0*h1+y2*x3*x2*y1*f1*f5*h1*h2+x1^2*y2*y1*f5*h0^3*h1-2*y2^2*x2^2*f5*f1*h0*h3-y2^2*x1*x2*f4*h0^2*h1*h3-2*y2*x1*x3*y1*f0*h1*h2^2*h3-4*y2*x3*x2*y1*f5*h0^2*h1*h3+2*x3^2*y2^2*f0*f5*h3^2+4*x3^2*y2^2*f0*f6*h2*h3+x3^2*y2^2*f0*h2*h3^3+2*x3^2*y2^2*f5*f6*h0^2-3*x3^2*y2^2*f6*h0^2*h2*h3-4*y2*x1*x3*y1*f0*f6*h1^2-4*y2*x1*x3*y1*f2*f6*h0^2-4*y2*x1*x3*y1*f0*f2*h3^2-y2*x1*x3*y1*f2*h0^2*h3^2+8*y2*x1*x3*y1*f0*f4*h2^2+4*y2*x1*x3*y1*h0^2*f4^2+y2*x1*x3*y1*h0^2*f4*h2^2+6*y2*x3*x2*y1*f0*f5*h1*h3+2*y2*x3*x2*y1*f0*f5*h2^2+y2*x3*x2*y1*f0*h2^3*h3+2*y2*x3*x2*y1*f4*f5*h0^2+2*y2*x3*x2*y1*f1*f2*h3^2+y2*x3*x2*y1*f6*h0*h1^3-6*y2*x3*x2*y1*f3*f6*h0^2-y2*x3*x2*y1*f6*h0^3*h3-6*y2*x3*x2*y1*f0*f3*h3^2+3*y2*x3*x2*y1*f3*h0^2*h3^2-2*f1*y2*f4*x2^2*y1*h0*h3-2*f1*y2*f4*x2*y1*h1*h3*x3+8*x3^2*y2*y1*f0*f5*h2*h3+x3^2*y2*y1*f0*h2^2*h3^2-x3^2*y2*y1*f5*h0^2*h2*h3-y2*x2*y1*h2^3*f1*h0*x1+4*y2*x1*x2*y1*f1*f6*h0^2+4*y2*x1*x2*y1*f0*f1*h3^2+y2*x1*x2*y1*f1*h0^2*h3^2+2*y2*x1*x2*y1*f6*h0^3*h1+4*y2*x1*x3*y1*f2*f5*h0*h1-12*y2^2*x2^2*f0*f6*h0*h3-y2*x3*x2*y1*f0*h0*h3^3+4*y2^2*x1*x3*f2*f6*h0*h1-2*y2^2*x1*x3*f6*h0^2*h1*h2+y2^2*x1*x3*f6*h0*h1^3-x3*y2^2*x1*h2^2*f2*h0*h3+2*x3*y2^2*x2*f1*f6*h1*h2+2*x3*y2^2*x2*f3*f6*h0*h1+x3*y2^2*x2*f6*h0*h1^2*h2+x3*y2^2*x2*f3*h0*h1*h3^2+y2^2*x1^2*f2*h0^2*h3*h2-y2^2*x1^2*f3*f1*h0*h3-y2^2*x3^2*f5*f3*h0*h3+x3*y2^2*x2*f5^2*h0^2+y2^2*x3*f3^2*x1*h0*h3+2*y2^2*x1*x3*f1*f6*h1^2-y2^2*x1^2*f1*h1*h2*h0*h3+4*y2^2*x2^2*f0*f6*h1*h2-3*y2^2*x2^2*f6*h0^3*h3+2*y2^2*x2^2*f0*f3*h3^2-3*y2^2*x2^2*f0*h0*h3^3+y2^2*x2^2*f0*h1*h2*h3^2+y2^2*x2^2*f3*h0^2*h3^2+2*y2^2*x1*x3*f4*f5*h0^2-x2*y2^2*f5*f1*h0*h2*x1-x2*y2^2*f1*h2^2*h3*h0*x1-2*y2^2*x2*f4*x1*f1*h0*h3+4*y2^2*x1*x2*f1*f6*h0*h1+2*y2^2*x1*x2*f0*f3*h2*h3+y2^2*x1*x2*f0*h1*h2^2*h3+y2^2*x1*x2*f3*h0^2*h2*h3+2*y2^2*x1*x2*f0*f5*h1*h2+y2^2*x1*x2*f3*f5*h0^2-2*y2*x1*x3*y1*f5*h0^2*h1*h2-4*y2^2*x3*f4*x1*f2*h0*h3+2*y2^2*x1*x3*f0*f5*h2^2+4*x1^2*y2*y1*f0*f5*h0*h1+4*x1^2*y2*y1*f0*h2*h3*f1+3*x1^2*y2*y1*f1*h0^2*h2*h3+2*y2*x1*x3*y1*f5*h1^2*f1+y2*x1*x3*y1*f5*h1^3*h0+2*y2*x1*x3*y1*f2*h0*h1*h2*h3+4*y2^2*x1*x3*f0*f4*h2*h3-2*y2^2*x1*x3*f0*h1*h2*h3^2-2*y2^2*x3*f5*x2*f2*h0*h3-x3*y2^2*x2*f2*h2*h3^2*h0+4*x3*y2^2*x2*f0*f5*h2*h3-y2^2*x3^2*f5*h1*h2*h0*h3-y2*x2^2*y1*f4*h0^2*h1*h3-y2*x2^2*y1*h2^2*f1*h0*h3-2*x3^2*y2*y1*f5*h0*h1^2*h3+2*x3^2*f3*y1*h0*h3^2*y2*h1+y2*x3*x2*y1*f3*h0*h1*h2*h3+2*y2*x2^2*y1*f0*f5*h1*h2+2*y2*x2^2*y1*f0*f3*h2*h3+y2*x2^2*y1*f0*h1*h2^2*h3+y2*x2^2*y1*f3*h0^2*h2*h3-4*y3^2*x1*x2*f6*h0^2*h1*h3-2*y3^2*x2*f3*f5*h1*h3*x3+8*y3*x1^2*y1*f1*f5*h0*h1-2*y3*x1*x3*y1*f3*f4*h1^2-y3*x1*x3*y1*h1*h2^3*f2-2*y3*x1*x3*y1*f3*h2^2*f2-y3*x1*x3*y1*f3*h1^3*h3-y3*x1*x3*y1*f3*h2^3*h0-2*y3*x1*x3*y1*f0*f3*h3^2-4*y3*x1*x2*y1*f0*f6*h1^2-4*y3*x1*x2*y1*f2*f6*h0^2-4*y3*x1*x2*y1*f0*f2*h3^2-y3*x1*x2*y1*f2*h0^2*h3^2+8*y3*x1*x2*y1*f0*f4*h2^2+4*x1*x3*y3^2*f2*f6*h0*h3+4*x1*x3*y3^2*f2*f6*h1*h2-2*x1*x3*y3^2*f6*h0*h1*h2^2-x1*x3*y3^2*f6*h0*h1^2*h3-x1*x3*y3^2*f2*h3^2*h1*h2-4*x1*x3*y3^2*f1*f6*h1*h3+2*x1*x3*y3^2*f4*h0*h1*h3^2+4*y3*x3^2*y1*f2*f6*h0*h3+4*y3*x3^2*y1*f2*f6*h1*h2-y3*x3^2*y1*f6*h0*h1^2*h3-y3*x3^2*y1*f2*h3^2*h1*h2-4*y3*x3^2*y1*f1*f6*h1*h3-8*y3*x3^2*y1*f4*f6*h0*h1+2*y3*x3^2*y1*f4*h0*h1*h3^2+2*y3*x1*x2*y1*f5*h1^2*f1+y3*x1*x2*y1*f5*h1^3*h0+8*x3*x2*y3*y1*f2*f6*h1^2-4*x3*x2*y3*y1*f4*f6*h0^2-4*x3*x2*y3*y1*f0*f6*h2^2-4*x3*x2*y3*y1*f0*f4*h3^2-x3*x2*y3*y1*f4*h0^2*h3^2+4*y3*x1^2*y1*f0*f4*h0*h3+4*y3*x1^2*y1*f0*f4*h1*h2-y3*x1^2*y1*f0*h0*h2^2*h3-y3*x1^2*y1*f4*h0^2*h1*h2+y3*x1*x2*y1*f6*h0^2*h1^2+4*y3*x2^2*y1*f0*f4*h2*h3+y3*x2*f3^2*y1*h0*h2*x1-4*y3*x1^2*f4*f1*y1*h0*h2+8*x1*x3*y3^2*f1*f5*h2*h3-2*y3*x1*x3*y1*f3*f6*h0^2-y3*x1*x3*y1*f6*h0^3*h3-y3*x1*x3*y1*f0*h0*h3^3+8*y3*x1*x3*y1*f4^2*h0*h1+8*y3*x1*x3*y1*f4*h2^2*f1+y3*x1*x3*y1*f1*h1^2*h3^2+2*x3*x2*y3*y1*f1*f5*h2^2+x3*x2*y3*y1*f1*h2^3*h3+3*y3*x1*x3*y1*f3^2*h0*h3+3*y3*x1*x3*y1*f3^2*h1*h2+y3*x1*x3*y1*f3*h0^2*h3^2+y3*x1*x3*y1*f3*h1^2*h2^2-4*x3*x2*y3*y1*f1*f3*h3^2+3*x3*x2*y3*y1*f1*h0*h3^3-y3*x2^2*y1*h2^2*f2*h0*h3-4*y3*x2^2*f2*f4*y1*h0*h3+8*y3*x3^2*y1*f1*f5*h2*h3+4*y3*x2^2*y1*f2*f6*h0*h1+12*y3*x2^2*y1*f0*f6*h0*h3-8*y3*x2^2*y1*f0*f6*h1*h2-4*y3*x1*x2*y1*f3*f5*h0^2+3*y3*x1*x2*y1*f5*h0^3*h3-y3*x2*y1*h2^3*f2*h0*x1+4*y3^2*x3*x2*f3*f6*h1*h2+4*y3^2*x3*x2*f5*f6*h0*h1+3*y3^2*x3*x2*f5*h0*h1*h3^2+4*y3^2*x3*x2*f1*f6*h2*h3+8*y3^2*x1*x2*f0*f5*h2*h3-y3^2*x1*x2*f5*h0^2*h2*h3-4*y3*x1^2*y1*f0*f5*h0*h2-8*y3*x1^2*y1*f0*f2*h2*h3+2*y3*x1^2*y1*f2*h0^2*h2*h3+y3*x2*f3^2*y1*h1*h3*x3+8*y3*x1*x3*y1*f2^2*h2*h3+8*y3*x1*x3*y1*f2*h1^2*f5+y3*x1*x3*y1*f5*h0^2*h2^2-y3^2*x2*f5*h1^2*h2*h3*x3-y3^2*x2^2*f5*h1*h2*h0*h3-y3*x2*y1*f4*h1^3*h3*x3-4*y3*x3^2*f5*f2*y1*h1*h3-y3*x2^2*y1*f4*h1^2*h0*h3+
     x3*x2*y3*y1*f0*h2^2*h3^2+2*y3*x1^2*f3*h0^2*h3*y2*h2-y3*x1*x2*y2*f6*h0^3*h3-6*y3*x1*x2*y2*f0*f3*h3^2-y3*x1*x2*y2*f0*h0*h3^3+3*y3*x1*x2*y2*f3*h0^2*h3^2-4*y3*x3^2*y2*f6*f2*h1*h3+3*y3*x1*y2*x3*f1*h0*h3^3-4*y3*x1*y2*x3*f4*f6*h0^2-4*y3*x1*y2*x3*f0*f6*h2^2-4*y3*x1*y2*x3*f0*f4*h3^2-y3*x1*y2*x3*f4*h0^2*h3^2+y3*x1*y2*x3*f0*h2^2*h3^2+2*y3*x1*x2*y2*f1*f6*h1^2+y3*x1*x2*y2*f6*h0*h1^3+4*y3*x3^2*y2*f3*f6*h1*h2+4*y3*x3^2*y2*f5*f6*h0*h1+3*y3*x3^2*y2*f5*h0*h1*h3^2+4*y3*x3^2*y2*f1*f6*h2*h3-6*y3*x1*x2*y2*f3*f6*h0^2+8*y3*x1*y2*x3*f2*f6*h1^2+y3*x1*y2*x3*f2*h1^2*h3^2+2*y3*x2^2*y2*f1*f6*h1*h2+2*y3*x2^2*y2*f3*f6*h0*h1+y3*x2^2*y2*f6*h0*h1^2*h2+y3*x2^2*y2*f3*h0*h1*h3^2-4*x1^2*y3*y2*f0*h0*h2*h3^2+y3*x1*x2*y2*f0*h2^3*h3+y3*x1*x2*y2*f3*h0*h1*h2*h3+2*y3*x1*x2*y2*f0*f5*h2^2+2*y3*x3*x2*y2*f3*f6*h1^2+y3*x3*x2*y2*f6*h1^3*h2+2*y3*x3*x2*y2*f2*f3*h3^2-y3*x3*x2*y2*f2*h0*h3^3+y3*x3*x2*y2*f3*h1^2*h3^2+4*y3*x3*x2*y2*f0*f5*h3^2+2*y3*x3*x2*y2*f0*h2*h3^3+4*y3*x3*x2*y2*f5*f6*h0^2+y3*x3*x2*y2*f5*h0^2*h3^2+2*y3*x1*y2*x3*f1*f5*h2^2+2*y3*x1*y2*x3*f4*h0*h1*h2*h3+y3*x1*y2*x3*f1*h2^3*h3-y3*x2*y2*f5*h1^3*h3*x3-2*x1^2*y3*y2*f1*h2^2*h3*h0+8*x1^2*y3*y2*f1*f6*h0*h1-x1^2*y3*y2*f1*h0*h1*h3^2-2*y3*x3^2*f3*y2*f5*h1*h3-2*y3*x2^2*f2*y2*f5*h0*h3-y3*x2^2*y2*f5*h1^2*h0*h3-y3*x2^2*y2*f2*h2*h3^2*h0-y3*x3^2*y2*f5*h1^2*h2*h3+2*y3*x3*x2*y2*f5^2*h0*h1+y3*x3*x2*y2*f1*h2^2*h3^2+4*y3*x2^2*y2*f0*f5*h2*h3-4*y4*x1*x3*y1*f0*h2*h3+2*y4*x1*x3*y1*h0^2*h2*h3+2*y4*x1*x2*y1*f0*h1*h3+y4*x1*x2*y1*f3*h0*h1-y4*x1*x2*y1*f1*h0*h3+y4*x1*x2*y1*f1*h1*h2-2*x3*f3*y1*y4*h0*h2*x1-2*x2*f2*y1*y4*h0*h2*x1+4*y4*x1*x3*y1*f4*h0*h1-5*x3*f3*y1*y4*h0*h3*x2+2*y4*x3*x2*y1*f5*h0*h1+2*y4*x3*x2*y1*f1*h2*h3-y2*x2*f3*y4*h1*h3*x3-2*y2*x3*f4*y4*h0*h3*x2+2*y2*y4*x1*x2*f4*h0*h1+y2*y4*x1*x2*h1*h3*f1-y2*x2*f3*y4*h0*h2*x1+2*x3*y2*y4*x1*f3*h0*h3-2*x3*y2*y4*x1*f3*h1*h2-2*y2*x1*f2*y4*h0*h3*x2+x3*y2*y4*x2*f5*h0*h2+2*x3*y2*y4*x2*f2*h2*h3-2*y3*x2*f4*y4*h1*h3*x3+4*y3*y4*x1*x3*f2*h2*h3-2*y3*x1*f3*y4*h1*h3*x3-5*y3*x1*f3*y4*h0*h3*x2+2*y3*y4*x1*x2*f5*h0*h1+2*y3*y4*x1*x2*f1*h2*h3+2*y3*y4*x3*x2*f6*h0*h2-4*y3*y4*x1*x3*f6*h0*h1+2*y3*y4*x1*x3*h0*h1*h3^2+y3*y4*x3*x2*f3*h2*h3-y3*y4*x3*x2*f5*h0*h3+y3*y4*x3*x2*f5*h1*h2-2*y3*x3^2*h1*h2^2*f6*h0*y1+y3*x1*x2*y1*h0^2*f4*h2^2+y2*x1^2*f2*h0^2*h2^2*y1-y2*x2^2*f5*f1*h0*h2*y1-y3^2*x1*x3*f5*h1^3*h3-x3*y2*x1*f4*h1^2*h0*h2*y1-4*y3^2*x3*f6*x2*f2*h1*h3-2*x2^2*y1*f0*h2*h3^2*h1*y3-2*x1*x2*y1*f0*h2^2*h1*h3*y3-4*y3^2*x3^2*f3*f6*h1*h3-x3*y2*x1*h2^2*f2*h1*h3*y3+y2*x3*f3^2*x1*h1*h3*y3-x3*y2*x1*f4*h1^3*h3*y3+2*x3*f3*y1^2*h0^2*h2*h3*x2+2*y3^2*x1*f3*h1*h3^2*h0*x2+2*y3*x1*x2*y1*h2*h3*f2*h0*h1-2*y3*x3*x2*f6*h1^2*h0*h2*y1-y3*x3*x2*f3*h2^2*h3*h0*y1+x1^2*f1*y1^2*h0^2*h2^2+2*x3*x2*y3*y1*h2*h3*f4*h0*h1-x3*y2*x1*h2^3*f2*h0*y1-4*x1^2*y1^2*f0*f3*h0*h2-2*x1^2*y1^2*f0*h1*h2^2*h0-x1^2*y1^2*h0^3*f3*h2+y2*x3*f3^2*x1*h0*h2*y1-4*f0*f4*x2*x1*y1^2*h0*h2+x2*f2*y1^2*h0^2*h2^2*x1+x3*y2*x1*f3*h1*h2^2*h0*y1-2*y3*x1*x2*h0^2*h1*f5*h2*y1-2*y2*x3*f5*x2*f2*h0*h2*y1+y3^2*x2*f4*h1^2*h3^2*x3-4*y3^2*x3*f5*x1*f2*h1*h3-2*x3*x2*y1^2*f1*h2^2*h3*h0+y3*x1*x2*y1*h3^2*f1*h0*h1-y3*x3*x2*y2*h3^2*f2*h1*h2-2*y3*x2^2*h0^2*h1*f6*h2*y1-2*y3*x3*f5*x2*f3*h0*h2*y1+x3*x2*y3*y1*h0^2*f5*h2*h3+x2^2*f2*y1^2*h0^2*h2*h3-x1*x2*y1^2*h0^3*f4*h2-y2*x1*x2*y1*h0^2*f4*h1*h2-x1*x3*y1^2*h2^3*f1*h0-y3^2*x3*x2*h3^3*f2*h1+y2*x3^2*f4*h1^2*h3^2*y3-2*y2*x2*f4*x1*f1*h1*h3*y3-2*x2^2*y1^2*f0*h2^2*h3*h0-2*y3^2*x1*x2*h0*h1^2*f5*h3+x3*x2*y3*y1*f2*h1^2*h3^2-2*x3*x2*y1*f1*h2*h3^2*h1*y3-2*x2*f3*x1*f1*y1*h1*h3*y3-2*x1^2*y1*f0*h1^2*h2*h3*y3+y3^2*x3^2*f5*h1^2*h3^2-y3^2*x3*x2*f6*h1^3*h3+x3*y2*x1*f3*h1^2*h2*h3*y3-4*y2*x3*f4*x1*f2*h1*h3*y3-4*y2*x3*f4*x1*f2*h0*h2*y1-y2*x2^2*f5*f1*h1*h3*y3-x3*y2*x2*h2^2*h3*f2*h0*y1-x1*x2*y1*f3*h0*h1^2*h3*y3+y3^2*x2^2*f4*h1*h3^2*h0-2*y3^2*x2^2*h0*h1^2*f6*h3-x1*x2*y1^2*f0*h2^3*h0-4*x3*f4*x1*f1*y1^2*h0*h2-y2*x1*x2*f4*h0*h1^2*h3*y3-y3^2*x3^2*f3*h3^3*h1-2*y3^2*x3^2*h1^2*h2*f6*h3-8*h0*h3*x4*x1*y3^2*f4-8*h0*h3*x3*x4*f2*y1^2+2*x1*x4*y1^2*h0^2*f3-y3*x1*x2*y1*f1*h0*h2^2*h3-4*y3*x1*x2*y1*f0*f6*h0*h2-x3*x2*y3*y1*f5*h0*h1^2*h3-4*y3^2*x3*x2*f6*h0*h1*h2*h3-4*y3*x1*y2*x3*f0*f6*h1*h3-4*x3*x2*y3*y1*f0*f6*h1*h3+x3^2*y1^2*f3*h0*h1*h2*h3-4*x1*x2*y1^2*f0*h0*h1*h2*h3+4*y3*x3^2*y1*f6*h0^2*h2*h3-4*y2*x1*x3*y1*f0*f6*h0*h2-y2*x1*x3*y1*f6*h0^3*h2-y3*x1*x2*y1*f6*h0^3*h2-x3*x2*y3*y1*f0*h1*h3^3+4*y3*x1^2*y1*f0*h0*h1*h3^2-2*y3*x1^2*y1*f3*h0^2*h1*h3+y3*x2^2*y1*f4*h0^2*h2*h3+y3*x2^2*y1*h0*h1*h3^2*f2+x1^2*y3^2*f3*h0*h1*h2*h3-y3*x1*y2*x3*f0*h1*h3^3-8*h0*h3*f1*x1^2*y3*y2*f4-8*h0*h3*y2*f2*f5*x3^2*y1-8*h0*h3*y2^2*f2*f6*x3^2-8*h0*h3*x3*y2^2*f6*x2*f1-4*h0*h3*x1*x3*f3*y3^2*f5-8*h0*h3*f1*f4*x3*x2*y1^2-8*h0*h3*y3^2*f2*f5*x2*x1-8*h0*h3*x1^2*f2*y3^2*f4-8*h0*h3*y2*f1*x3^2*f6*y1-8*h0*h3*x1^2*f0*y2^2*f4-8*h0*h3*y2^2*f0*f5*x1*x2-8*h0*h3*x1^2*f0*y3^2*f6-8*h0*h3*f0*f5*x3*x2*y1^2+2*h1*h3*f0*f3*x2^2*y1^2+h1*h3*y4*x2^2*f1*y1-8*h0*h3*x2^2*y3^2*f6*f2-8*h0*h3*y3*x2^2*y2*f6*f1+2*h1*h3*y3*y4*x1^2*f1+2*h1*h3*x1^2*f1*y3^2*f4+2*h1*h3*y2*y4*f0*x1^2+2*h1*h3*y3^2*f0*f5*x1^2+2*h1*h3*f4*x3^2*f1*y1^2+2*h1*h3*f0*f5*x3^2*y1^2-8*h0*h3*y4*f4*x3^2*y1-8*h0*h3*x1^2*f0*y2*f3*y1-8*h0*h3*y3*y4*x1^2*f2-8*h0*h3*y2*f0*f5*x2^2*y1-4*h0*h3*x1*f3*x3*f1*y1^2+2*h1*h3*y2^2*f0*x1^2*f3-8*h0*h3*f0*f3*x1*x2*y1^2-8*h0*h3*x1^2*f0*y2*y3*f5-8*h0*h3*f6*x3^2*f0*y1^2-8*h0*h3*y3^2*x3*f6*x2*f3+2*h0*h3*x3^2*f3^2*y1^2+2*h0*h3*y3^2*x1^2*f3^2-8*h0*h3*f0*f4*x2^2*y1^2-8*h0*h3*y3^2*f1*x1*f6*x2-4*h0*h3*y3*x1^2*f3*f1*y1-8*h0*h3*y3*x3^2*y2*f6*f3-8*h0*h3*f4*x3^2*f2*y1^2-4*h0*h3*y3*x3^2*f5*f3*y1-2*h0^3*h3*y2*x2^2*y1*f5-4*h0*h3^2*y2*x2^2*y1*f0*h2-2*h0^2*h3^2*y2^2*x1*f3*x3-2*h0^3*h3*x1^2*y2*y1*f3-4*h0*h3*x1^2*y2*y1*f0*h1*h2-2*h0*h3^3*x3^2*y1^2*f0-4*h0*h3*y3*x3^2*y2*f6*h1*h2+4*h1*h3*f0*f4*x2*x3*y1^2-2*h0*h3^3*x3^2*y2*y1*f1+h0*h2*y3^2*x1*x2*f6*h1^2-2*h0^3*h3*x1*x2*y1^2*f3-4*h0*h3^2*y2^2*x1*x2*f0*h2-2*h0^3*h3*x2^2*y1^2*f4-2*h0^2*h3^2*y3*x1^2*y1*f1-2*h0^3*h3*x1^2*y3*y2*f5-2*h0*h3^3*y3*x3^2*y2*f3-2*h0^3*h3*x3^2*y1^2*f6-2*h0^3*h3*x3*x2*y1^2*f5-2*h0*h3^3*x3*y2^2*x2*f1-2*h0^3*h3*y2^2*x1*x2*f5-2*h0*h3^2*x1*x3*y3^2*f3*h2-2*h0*h3^3*y3^2*x1*x2*f1-4*h0^2*h3*x3*y2^2*x2*f6*h1+4*h1*h3*f0*x1^2*y3*y2*f4-2*h0*h3^3*y3^2*x3*x2
     *f3-2*h0*h3^3*x1^2*y3^2*f0-2*h0^2*h3^2*x1*x3*y3^2*f5-2*h0*h3^3*y3^2*x2^2*f2-2*h0*h3^3*x3^2*y2^2*f2-2*h0^2*h3^2*y3*x2^2*f3*y1+4*h0^2*h3*y3^2*x3*f6*h2*x1-4*h1*h3*y3*x3*y2*f6*x2*f1-2*h0^3*h3*x1^2*y3^2*f6-2*h0^2*h3^2*x1*x3*y1^2*f1+4*h0*h3^2*f0*x1*y1^2*h1*x3-2*h0^2*h3*x1*x3*y1^2*f3*h1+4*h0*h2*y2*f2*x3^2*f6*y1+2*h0^2*h3^2*f1*x2^2*y1^2-2*h0^3*h3*y2^2*x1^2*f4-2*h0*h3^3*y3*x2^2*y2*f1+h1*h3^2*y2^2*x3*x1*f2*h0+2*h0^2*h3^2*x1^2*y3^2*f3+2*h0^2*h3^2*y3^2*f5*x2^2-3*h0*h3^2*x3^2*y2*y1*f2*h2-h1*h3*y2*x1*x2*y1*h0^2*f3+h1*h3*x3*x2*y1^2*f0*h2^2+2*h0^2*h3^2*y2^2*f5*x3^2+h1^2*h3*x2^2*y1^2*f0*h2+2*h0^2*h3^2*y2^2*f1*x1^2-h1^2*h3*x3^2*y1^2*f4*h0+h1*h3^2*x3^2*y1^2*f0*h2-h1^2*h3*x1^2*y3^2*f4*h0-3*h0*h3^2*y3^2*x1*x2*f2*h2-h0*h3*x3^2*y1^2*h2^2*f2-h0*h3*x1^2*y3^2*h2^2*f2-3*h1*h3*x3*x2*y1^2*f4*h0^2-h0*h3*y4*x3^2*y1*h2^2+2*h0*h2*x3^2*y2^2*f6*f3+2*h0*h2*y3^2*x1^2*f5*f2+h0*h2*y3*y4*f5*x2^2+2*h0*h2*y4*x3^2*f5*y1+2*h0*h2*x3^2*f5*f2*y1^2+2*h0*h2*f1*x3^2*f6*y1^2+2*h0*h2*y3^2*x2^2*f6*f3+2*h0*h2*y3^2*f1*x1^2*f6+4*h0*h2*y3^2*f6*x2*x1*f2+2*h0*h2*y2*y4*x3^2*f6-4*h0*h2*y2*f0*f5*x1*x2*y1+h0^2*h2*y2^2*x1*f4*x3*h3-h0^3*h2*y2*x1*x2*y1*f5-h0*h2^2*y2*x1*x3*y1*f1*h3+h0*h2^2*x3^2*y2^2*f6*h1+h1*h3*x1^2*y3*y2*f0*h2^2+h0*h2^2*y3^2*x2^2*f6*h1+h1*h3^2*x1^2*y3^2*f0*h2-3*h1*h3*x1^2*y3*y2*f4*h0^2-h0*h2*y3*x3*x2*y2*f3*h3^2-h1^2*h3*y3*y4*x1^2*h0+h0^2*h2*x3^2*y1^2*f6*h1+h0^2*h2*x1^2*y3^2*f6*h1-h1^2*h3*y3*x1*y2*x3*f5*h0-h1*h3^3*y3*x3*x2*y2*f1+h0*h2*x3^2*y2*y1*f6*h1^2+h1*h3*x3*y2*y4*x1*h0*h2+h1^2*h3*y2^2*x1^2*f0*h2+2*h1*h3*x3*x4*f1*y1^2+2*h1*h3*f0*x4*x2*y1^2+h1*h3*x4*y2^2*x1*f1-h1^2*h3*x4*x3*y1^2*h0+4*y2^2*f0*f5*x1*x4-h1*h3*y3*y4*x4*x2-h1*h3*y2*y4*x3*x4-2*x2*f2*y1^2*h0*h2*x4-4*x1*x4*y1^2*f0*h0*h3+x4*x2*y2^2*h0*h1*f5-3*y3^2*x4*x2*h0*h3*f5+2*x1*x4*y3*y1*h0^2*h2*h3+x2*x4*y1^2*f3*h0*h1+x4*x2*y2^2*f1*h2*h3+2*x1*x4*y3*y2*f1*h2*h3+2*y4*x3*f3*x4*y1+2*y3*x4*x2*y1*f3*h0*h3+2*y3*x4*x2*y1*f4*h1^2+2*y3*x4*x2*y1*h2^2*f2-4*y3*x4*x3*y1*f6*h0*h1-7*y4*x4*x3*y1*h0*h3+2*y2*y4*x2*f3*x4+2*f1*f3*x2*x4*y1^2+2*y3*x4*x3*y2*h1^2*f6+x2*x4*y1^2*h1*h2*f1-x2*x4*y1^2*h0^2*h3*h1+8*f0*x4*x1*f3*y1^2-h0*h2*y4*x4*x2*y1-h0*h2*y2*y4*x1*x4+2*h0*h2*y3^2*x4*x2*f6+h0*h2*x4*x3*y2^2*f5+2*h0*h2*y3^2*x4*x1*f5+h0*h3*y2^2*x4^2+4*y3*x4*x3*y1*h2*h3*f2-x1*x4*y1^2*h0^3*h3-h0*h2^2*y3^2*x1*x4*h3+4*f1*y2^2*f6*x3*x4+2*x2*x4*y4^2+h0*h2*y3*x4*x2*y1*h1*h3+2*h0^2*h3^2*x3^2*y1^2*f3+2*y3*x4*x3*y2*h0*h2*f6+2*y3*x3*f3*x4*y2*f5-8*y3*y2*f0*f6*x1*x4-4*h0^2*h3*y3*x2^2*y2*f6*h1-2*h0^2*h3^2*y3*x3^2*y1*f5-2*h0*h3^2*y3*x3^2*y1*f3*h2+2*y2*y4*x4^2-3*x2*x4*y1^2*h0*h3*f1+4*x1*x4*y1^2*f0*h1*h2-2*x1*f1*y1^2*h0*h2*x4+2*x2*x4*y2^2*f5*f1+x4*x3*y2*y1*h3^2*h0^2-2*x4*x3*y2*y1*h3^2*f0-2*y2^2*x3*f4*h0*h3*x4+2*y2*x4*x2*y1*f4*h0*h1-x2*x4*h0^2*h3^2*y2^2+8*y2*f0*f4*x1*x4*y1+x4*x3*y2^2*h3^2*f1+y2^2*x1*x4*h0^2*f5+2*x4*x3*y2*y1*f1*h2*h3+2*x4*x3*y2*y1*h0*h1*f5+y2*x4*x2*y1*h2^2*f1+y2*x1*x4*y1*f3*h0*h1-x4*x3*y2^2*h3^2*h0*h1-2*y2^2*x1*f2*h0*h3*x4+2*y2^2*x1*x4*f0*h2*h3-y2^2*x1*x4*h0^2*h2*h3-y2^2*x2*f3*h0*h3*x4+y2*x4*x2*y1*h1*h3*f1+4*f1*y2*f5*x3*x4*y1-5*x3*f3*y1*h0*h3*y2*x4+2*y2*x1*x4*y1*f0*h2^2-2*y2*x1*f2*h0*h2*y1*x4+2*x4*y2*x1*f1*f3*y1-y2*x1*x4*y1*h0*h3*f1+y2*x1*x4*y1*h1*h2*f1+2*y2*x1*x4*y1*f0*h1*h3+2*y2*x1*x4*y1*h0^2*f4-2*x2*f2*y1*h0*h3*y2*x4+4*f1*y2*f4*x2*x4*y1-y2*x2*f3*h0*h2*y1*x4-8*y2*f0*f6*x3*x4*y1-x4*x3*y2*y1*h0*h1*h2*h3-2*x4*x3*y2*y1*f6*h0^2+4*y3*x4*y2*x1*f5*f1-x1*x4*y3*y2*h0*h1*h2*h3+4*y3*x2*f2*x4*y2*f5-y2*x2*f3*h1*h3*y3*x4+2*y3^2*x2*f3*x4*f5+8*y3*x4*x1*f4*f1*y1-2*y3*x4*x2*y1*h3^2*f0+2*y3*x4*x3*y1*h3^2*h0*h1+4*x1*x4*y3*y1*f4*h0*h1-8*y3*f0*f6*x2*x4*y1-y3^2*x4*x3*h3^3*h0+2*y3^2*x4*x3*h3^2*f3-2*y3^2*x2*f4*h1*h3*x4-2*x1*x4*y3*y2*f6*h0^2+y3*x4*x2*y1*h3^2*h0^2+2*x1*x4*y3*y2*h0*h1*f5-2*x1*x4*y3*y2*h3^2*f0+x1*x4*y3*y2*h3^2*h0^2-4*y3^2*x4*x3*f6*h0*h3+8*y3*x3*y2*f6*x4*f2+y3*x4*x3*y2*h1*h2*f5+8*y3^2*x3*f3*x4*f6+y3^2*x4*x2*f3*h2*h3-y3^2*x4*x2*h0*h2*h3^2+y3^2*x4*x2*h1*h2*f5-2*y3^2*x3*f5*h1*h3*x4+4*y3^2*x4*x3*f6*h1*h2-4*x1*x4*y3*y1*f0*h2*h3-2*x3*f3*y1*h1*h3*y3*x4-2*y3*x2*f3^2*x4*y1+8*y3*x2*f2*x4*f4*y1-2*y3*x4*x2*y1*f6*h0^2+8*y3*x3*f5*x4*f2*y1-8*y3*f1*f6*x3*x4*y1+2*x1*x4*y3*y1*h2^2*f1-8*y3*f0*f5*x1*x4*y1-2*x1*x4*y3*y1*h0^2*f5-2*y3*x1*f3*h0*h2*y1*x4-2*y3*x4*x2*y1*f3*h1*h2+2*y3*x4*x3*y1*f5*h1^2-2*y3*x4*x3*y1*h3^2*f1+2*y3*x4*x3*y2*f2*h3^2+2*y3*x4*x2*y2*h2*h3*f2+y3*x4*x3*y2*f3*h2*h3+y3*x4*x2*y2*f5*h0*h2+y3*x4*x2*y2*f5*h1^2-5*y3*x1*f3*h0*h3*y2*x4-2*y3*x2*f4*h0*h3*y2*x4-y3*x4*x3*y2*h0*h3*f5-2*y2*x3*f4*h1*h3*y3*x4-7*y3*y4*x1*x4*h0*h3+y4*x4*x2*y1*h1^2+y2*y4*x3*x4*h2^2+4*y4*x4*x1*f1*y1+4*y2*y4*x4*x1*f2+y3*y4*x1*x4*h1*h2+y4*x4*x3*y1*h1*h2+4*y4*x2*f2*x4*y1+2*y4*x1*x4*y1*h0*h1+y2*y4*x1*x4*h1^2+4*y2*y4*x3*x4*f4-3*y2*y4*x4*x2*h0*h3+y2*y4*x4*x2*h1*h2+4*y3*y4*x3*f5*x4+2*y3*y4*x4*x1*f3+y3*y4*x4*x2*h2^2+4*y3*y4*x2*x4*f4+2*y3*y4*x4*x3*h2*h3;

b33:=x3^2*y4^2-4*y3*y4*x1^2*f0-4*f0*x2^2*f2*y1^2-4*f0*f4*x3^2*y1^2-4*y2^2*x1^2*f2*f0-4*y2^2*f6*x3^2*f0-4*x1^2*f0*y3^2*f4-4*f0*x2^2*y3^2*f6-4*y4*f0*x2^2*y1+x2^2*f1^2*y1^2+x1^2*f1^2*y2^2+4*f0*x1*x3*y2*f3*y1-4*f0*f3*x2*x3*y1^2-4*x1*f0*x2*y3^2*f5+4*y3*f0*x3*f5*x2*y1+8*y3*f0*f4*x1*x3*y1+4*y3*y2*f0*f5*x1*x3-4*y3*y2*f0*f3*x1^2+8*y3*y2*f0*f6*x2*x3+4*x1*f0*x2*y3*f3*y1+8*y2*f0*x1*f2*x2*y1-2*x1*f1^2*y2*x2*y1-4*y2*f0*f5*x3^2*y1-2*y4*x2*f1*x3*y1+4*y4*f0*x1*x3*y1+4*x1*y2*y4*f0*x2+2*x1*y2*y4*x3*f1-x2^2*y1^2*h0^2*f2-x3^2*y1^2*f0*h2^2-y4*x2^2*y1*h0^2-y3^2*x2^2*f0*h3^2-x1^2*y3^2*f0*h2^2-y3^2*x2^2*f6*h0^2-x1^2*y3^2*f4*h0^2-y2^2*x1^2*f0*h1^2-y3*y4*x1^2*h0^2-x2^2*y1^2*f0*h1^2-y2^2*x1^2*h0^2*f2-x3^2*y2^2*f0*h3^2-x3^2*y1^2*f4*h0^2-x3^2*y2^2*f6*h0^2+2*y3*x3*x2*y2*f0*h3^2-x3^2*y2*y1*f5*h0^2+2*y3*x1*x3*y1*f0*h2^2+x3*y2*y4*x1*h0*h1+y3*x1*x2*y1*h0^2*f3-y3^2*x1*x2*f5*h0^2-2*x3^2*y2*y1*f0*h2*h3+y3*x1^2*f1*y2*h0*h2+y2*x1*x3*y1*h0^2*f3+x2^2*y1^2*f1*h0*h1-2*x3*x2*y1^2*f0*h1*h2-x3*x2*y1^2*h0^2*f3+y2^2*x1^2*f1*h0*h1+2*y2*x1*x2*y1*h0^2*f2-x1*y2^2*x3*f1*h0*h3+2*y2^2*x1*f0*h1*h3*x3+2*y2*x1*x2*y1*f0*h1^2-2*y2*x1*x2*y1*f1*h0*h1+2*y2*x1*x3*y1*f0*h1*h2-2*y2*f0*x2*y1*h1*h3*x3+x2*f1*x3*y1*h0*h3*y2-2*x1^2*y3*y2*f0*h1*h2-x1^2*y3*y2*h0^2*f3-2*y3^2*x1*x2*f0*h2*h3+2*y3*x1*x3*y1*f4*h0^2+x3*x2*y3*y1*f5*h0^2-y3*f1*x2^2*y1*h0*h3-y3*f1*x2*y1*h0*h2*x1+2*y3*x1*x2*y1*f0*h1*h2+2*x3*x2*y3*y1*f0*h2*h3+2*y3*x3*x2*y2*f6*h0^2+y3*x1*y2*x3*f5*h0^2+y3*x1*f1*y2*h0*h3*x2+2*y3*x1*y2*x3*f0*h2*h3+y2*y4*x1*x2*h0^2+y4*x1*x3*y1*h0^2-y4*x3*x2*y1*h0*h1-x3^2*y4*h0*h3*y2+y3*x3*y4*h0*h2*x1+y3*x3*y4*h0*h3*x2-x1*y2*x3*f1*h0*h2*y1-2*x1*y2*f0*x2*h1*h3*y3-x3^2*y4*h0*h2*y1+x2*f1*x3*y1^2*h0*h2+2*f0*x2^2*y1*h1*h3*y3+y3^2*x4^2+4*y2*f0*x4*x2*y1+y3*x3*h0*h2*y1*x4-4*f0*x4*x3*y1^2-x4*x3*y1^2*h0^2-4*y2^2*x4*x1*f0-y2^2*x1*x4*h0^2-2*y3*y4*x4*x3+y2*x4*x2*y1*h0^2-y3^2*x4*h0*h3*x2-x1*x4*y3*y2*h0*h1+y3*x3*h0*h3*y2*x4+y3*x4*x2*y1*h0*h1-y3^2*x4*h0*h2*x1+x1*x4*y3*y1*h0^2+4*y3*x4*x1*f0*y1+2*y3*f1*x2*x4*y1-2*y3*x1*f1*x4*y2;
b34:=-16*y2^2*x1^2*f6*f0^2-16*x1^2*f2^2*f0*y1^2+4*f1^2*x1^2*f2*y1^2-16*f4*x1^2*f0^2*y1^2-16*f0^2*f6*x2^2*y1^2+4*f1^2*x3^2*f6*y1^2+4*x2^2*f1^2*y2^2*f6+4*y2^2*f0*f5^2*x3^2+4*f0*f5^2*x2^2*y3^2+4*y3^2*f2*f5^2*x3^2-16*y3^2*f0*f6^2*x3^2+4*y3^2*x3^2*f3^2*f6+4*y4*f1^2*x1^2*y1+4*f1^2*x1^2*y3^2*f6-4*f0*f3^2*x3*x1*y1^2-8*f0*x3*f6*x2*f1*y1^2-16*f5*f0^2*x2*x1*y1^2-4*y3*x2*f1^2*x1*f5*y1+8*f0*f3*x1^2*f1*y1^2-16*y3*y2*f0*f6*x2^2*f3-8*y2^2*f2*f5*f0*x2*x1-8*y3*f0*f5^2*x3^2*y1+2*y3*y4*f5*x3^2*f3-4*y2*y4*f1*x3^2*f6-16*y3*y2*f1*x3^2*f6*f4-16*f2*f6*x3^2*f0*y1^2+4*f0*f3*f5*x3^2*y1^2-4*y2*y4*x3*f4*x1*f1-8*f0*f5*f1*x3*x1*y1^2+4*y3^2*x3*f5^2*x2*f1-8*y2^2*f1*f0*f6*x2*x1-8*y3*f1*f5*f0*x1^2*y1-16*y3*f0*f4^2*x3*x1*y1-4*y3*f6*x1*f1^2*y2*x2-8*y4*f0*x2*x1*f3*y1-4*f0*x1^2*f3^2*y3*y1+16*f0^2*f6*x3*x1*y1^2+2*x2^2*f1^2*y2*f5*y1-8*f0*x2*x1*f3*f2*y1^2+2*x2*f1^2*x1*f3*y1^2+16*y3*x1^2*f6*f0^2*y1-4*y2*x3*f6*x2*f1^2*y1-8*y3*y2*f1*f0*f6*x1^2-8*y2*f0*f5*f3*x3*x2*y1+2*x1*f1^2*y2^2*x2*f5-8*y2*f1*f5*f0*x2*x1*y1-16*y2*f0^2*f6*x2*x1*y1-8*y2*f0*f6*x2^2*f1*y1-8*y2*f0*f5*x2^2*f2*y1-8*y2*f0*f3*x1^2*f2*y1-16*y2^2*f0*f4*f6*x3^2-4*y2^2*f0*f5*x3*x1*f3+2*x1^2*f1^2*y2*f3*y1-8*f6*x3^2*f0*y2*f3*y1-8*f4*f0*x3*x1*y2*f3*y1-16*y2^2*f0*f6*x2^2*f2-4*y2^2*f6*x3*x1*f1^2-4*y2*f5*x3*x1*f1^2*y1+4*x2*f1^2*x1*y2*f4*y1-16*y2*f0*f4*f2*x2*x1*y1-16*y2^2*f0*f6*f3*x3*x2-16*y2*f5*x1^2*f0^2*y1-8*f0*x2*x1*f4*y3*f3*y1-4*f0*f5*x2^2*y3*f3*y1-16*x1^2*f2*f0*y3^2*f6+4*f0*x1^2*f3*y3^2*f5+8*y3*f0*f6*f3*x3*x2*y1-8*y3*f0*f4*f5*x3*x2*y1-8*y3*f6*x2*f1*x3*f2*y1-8*y3^2*f0*f5^2*x3*x1-8*y3^2*x3*f3*x1*f6*f1+16*y3^2*f0*f4*f6*x3*x1+4*y3*y2*f1*f5^2*x3^2-8*y3*y2*f0*f5*f6*x3^2-2*x3*f5*x2*f1*y3*f3*y1-16*y3^2*f2*f6*x3^2*f4-4*y3*f6*x2^2*f1^2*y1-8*y3*f1*x3^2*f6*f3*y1+16*y3*f0*f4*f6*x3^2*y1-8*f0*x2*x1*f3*y3^2*f6-16*f0*f6*x2^2*y3^2*f4-8*y3*x3*f2*x1*f5*f1*y1+8*y3*f6*x3*x1*f1^2*y1-16*y3^2*x3*f4*x2*f6*f1-8*y3^2*f0*f5*f6*x3*x2-2*y3*x3*y2*f3*x1*f5*f1-8*y3*y2*f0*f5*f4*x3*x1-8*y3*f6*x1*f1*y2*x3*f2+8*y3*y2*f0*f3*f6*x3*x1+16*y3*f0*f5*x3*x1*f3*y1-16*y3*f0*f2*f6*x3*x1*y1+4*f0*x3*f5^2*x2*y2*y3-8*y3*y2*f0*f5*f3*x2*x1-32*y3*y2*f0*f4*f6*x3*x2-8*y3*f6*x2*f1*x3*y2*f3-2*y4*x1*f3*x3*f1*y1-16*y4*x1^2*f2*f0*y1-8*y3*y4*f2*f6*x3^2-4*y4*f0*x3*f5*x2*y1-2*y2*y4*x3*f5*x2*f1-8*y4*f6*x3^2*f0*y1-8*y3*y4*f0*f5*x2*x1+8*y3*y4*f0*f6*x3*x1-8*y4*f4*f0*x3*x1*y1-4*y3*y4*x1*f1*x3*f5-4*y2*y4*f0*x1^2*f3-8*y2*y4*f0*x2*x1*f4-4*y2*y4*f0*f5*x2^2-8*y2*y4*f0*f6*x3*x2-16*y3*y4*f0*f6*x2^2-12*y3*y4*x2*f1*x3*f6-x3^2*y1^2*f2*h0^2*h3^2-x1*x3*y1^2*f3^2*h0^2-x3^2*y1^2*f6*h0^3*h2-x3^2*y1^2*f0*h1^2*h3^2-2*x1*x3*y1^2*f5*h0^2*f1-x1*x3*y1^2*f3*h0^3*h3-2*x1*f1^2*y1^2*h1*h3*x3-x3^2*y1^2*f0*h1*h2^2*h3+2*x3^2*y1^2*f0*f5*h1*h2+2*x3^2*y1^2*f0*f3*h2*h3-4*x3^2*y1^2*f0*f6*h1^2-4*x3^2*y1^2*f2*f6*h0^2-4*x3^2*y1^2*f0*f6*h0*h2-2*x3*x2*y1^2*f1*f6*h0^2+4*y2^2*f0*x1^2*f3*h0*h3-y2^2*x1*x3*f3*f5*h0^2-x3*x2*y1^2*f1*h0^2*h3^2+2*x1*y1^2*f0*h1^3*h3*x3-x1*x3*y1^2*f0*h1^2*h2^2-2*x1^2*y1^2*h1*h3*f0*h0^2+4*x1^2*y1^2*f0*f3*h0*h1+x1^2*y1^2*f1*h0*h1^3-8*x1^2*y1^2*f4*f0*h0^2+x1^2*y1^2*h0^3*f3*h1+x1^2*y1^2*h0^3*h3*f1+4*x1^2*y1^2*f0*h0*h3*f1+4*x1^2*y1^2*f0*h1*h2*f1-8*x1*x2*y1^2*h2*h3*f0^2+4*x3^2*y1^2*f1*f6*h0*h1-x1*x2*y1^2*h0*h3*f1^2-8*x2^2*y1^2*f0*f6*h0^2+4*x1^2*y1^2*f1*h0*h1*f2-2*x1^2*y1^2*f1*h0^2*h1*h2-x1^2*y1^2*f2*h1^2*h0^2-2*x1*x2*y1^2*h0^2*f3*f2+8*x1*x3*y1^2*f0*f6*h0^2+4*x3^2*y1^2*f0*f5*h0*h3+x1*x3*y1^2*f0*h0^2*h3^2+4*f0*f3*x2^2*y1^2*h0*h3+x2^2*y1^2*h0^3*f3*h3-2*x1*x2*y1^2*f0*f3*h1^2-y2^2*x1*x2*f6*h0^3*h1+y2^2*x1*x2*f1*h0*h1*h2*h3+x3^2*y2^2*f5*h0^2*h2*h3-4*x3^2*y2^2*f4*f6*h0^2-2*y2^2*x1*x2*f0*f5*h1^2+y2^2*x1*x2*f4*h0^3*h3-2*y2^2*x1*x2*f2*f5*h0^2+2*x3*y2^2*f6*h0^3*h2*x1-x3^2*y2^2*f6*h0^2*h2^2-x3^2*y2^2*f4*h0^2*h3^2-4*x3^2*y2^2*f0*f6*h2^2-y2^2*x1*x3*f1^2*h3^2-4*x3*y2^2*x2*f3*f6*h0^2+y2^2*x2^2*f1*h0*h1*h3^2+4*x3^2*y2^2*f0*f5*h2*h3-2*y2*x2^2*y1*f1*f6*h0^2-y2^2*x1*x3*f6*h0^2*h1^2-x3*y2^2*x2*f3*h0^2*h3^2+x3*y2^2*x2*f6*h0^3*h3+4*y2^2*f1*x3^2*f6*h0*h3-4*y2*x1*x2*y1*f0*h2*h3*f1-2*y2^2*x1*x2*f0*f1*h3^2+y2*x2^2*y1*f1*h0*h1*h2*h3-2*y2*x2^2*y1*f2*f5*h0^2+4*y2*f0*f3*x1*y1*h0*h3*x2-4*y2*x1*x2*y1*f0^2*h3^2+2*y2*x1*x2*y1*f2*h0^2*h1*h3-4*y2^2*x2^2*f0*f6*h1^2-4*y2^2*x2^2*f0*f6*h0*h2-y2^2*x1^2*f1*h0^2*h3*h2+4*y2^2*x2^2*f1*f6*h0*h1-y2^2*x2^2*f0*h1^2*h3^2-y2^2*x2^2*f2*h0^2*h3^2-4*y2^2*x2^2*f2*f6*h0^2-y2^2*x2^2*f6*h0^3*h2-2*y2*x1*x2*y1*f1*h0*h1^2*h3-4*y2*x1*x2*y1*f0*f5*h0*h1+y2^2*x1^2*h0^3*f3*h3+4*y2^2*f0*f5*x2^2*h0*h3+y2^2*x1*x2*f1^2*h2*h3-2*y3^2*x3*x2*f5*f6*h0^2-4*y3^2*x3^2*f4*f6*h1^2-4*y3*x2^2*y2*f3*f6*h0^2-8*x1^2*y1^2*h1*h3*f0^2-2*y2^2*x1*x2*f1*f6*h0^2-x1^2*y3*y2*f1*h0^2*h3^2-y3*x3*x2*y2*f6*h0*h1^2*h2+4*y3*x3^2*y1*f0*f4*h3^2+2*x3*x2*y3*y1*f1*f6*h0*h2-y3*x2^2*y1*f1^2*h3^2-x1^2*y3*y2*f6*h0^3*h1+2*x3*x2*y3*y1*f6*h0^2*h1*h2-y3^2*x3^2*f6*h0*h2^3-x1^2*y2*y1*h0*h3*f1^2-x1^2*y2*y1*f5*h0^4+x1*x2*y1^2*h1*h2*f1^2+y2*x2^2*y1*f1^2*h2*h3-4*y3*x1*x3*y1*h0^2*f4^2-y2^2*x1^2*f0*h0^2*h3^2-x2^2*y1^2*f0*h0^2*h3^2-y3*x1*x2*y2*f1^2*h3^2+2*x1^2*y1^2*h0^2*f3*f1-y2*x3*x2*y1*f1^2*h3^2+4*y3*x3^2*y1*f4*f6*h0^2-2*y4*x3^2*y1*f0*h3^2+x1*x3*y1^2*f6*h0^4+x3*y2^2*x2*f0*h0*h3^3-2*y2*x2^2*y1*f0*f1*h3^2+4*x1*x3*y1^2*f0^2*h3^2-y3*x1*y2*x3*f1*f5*h1*h2-x1^2*y1^2*h1^4*f0+2*x1*f1*y3*f3*y1*h1*h3*x3-y3*x1*y2*x3*f1*f3*h2*h3-4*y3*x1*x2*y2*f0*f5*h1*h2-y4*x3*x2*y1*f5*h0^2+x1*x2*y1^2*h0^3*f3*h2+x2^2*y2^2*f5*h0^3*h3+6*x1*y3*y1*f0*h2^2*h1*h3*x3-4*y2^2*x2^2*f0*f2*h3^2-y3*x1*y2*x3*h0*h1*h3^2*f2-2*x1^2*y2*y1*h0^2*f3*f2-2*y4*x1*x3*y1*f0*h2^2+2*y3*x1*x3*y1*f1^2*h3^2+x3^2*y1^2*f1*h0*h1*h3^2+4*y3*x1^2*y1*f0^2*h3^2-2*x1*x3*y3^2*f5^2*h0^2+2*y3*x1*x3*y1*f3*h0^2*h2*h3-y3^2*x3^2*f4*h0*h2*h3^2-4*y3^2*x3^2*f2*f4*h3^2+8*y3*x1^2*y1*f0*f6*h0^2-x1*x2*y1^2*f0*h1^3*h2-x3*x2*y1^2*f6*h0^3*h1+x1^2*y3^2*f3*f5*h0^2-8*x1*x2*y1^2*f5*f0*h0^2-x1*x2*y1^2*f5*h0^4+y2^2*x3^2*f1*h3^3*h0-2*x1*x3*y3^2*f1*f3*h3^2+y3*y4*x3^2*f3*h2*h3-4*x3^2*y2^2*f0*f4*h3^2-8*x1^2*y1^2*f2*h1^2*f0-x1*x3*y1^2*f5*h0^3*h1-2*y4*x1*x2*y1*h0^2*f3+x3^2*y1^2*f3*f5*h0^2+4*y3*x1*y2*x3*f0*f6*h1*h2+4*x1^2*y3^2*f1*f6*h0*h1-2*y2*y4*x1*x2*f4*h0^2+4*x1^2*y3^2*f0*f5*h0*h3-2*x3^2*f3*y3^2*f5*h1*h3-x1*x3*y3^2*f1*h0*h3^3-4*x3*y2^2*x2*f0*f3*h3^2+y2*x1*x3*y1*f0*h0*
    h2^2*h3-y2*x3*x2*y1*f0*h1*h2^2*h3+x1^2*y3^2*f1*h0*h1*h3^2-y3*x3^2*y1*f1*h0*h3^3+x3^2*y1^2*f5*h0^3*h3+4*y4*x1^2*y1*f1*h0*h1-y3*x2^2*y1*f6*h0^2*h1^2+2*x1*x3*y3^2*f0*h1*h3^3-4*y2*x3*x2*y1*f0*f5*h1*h2-4*x3^2*y1^2*f0*f2*h3^2-y2^2*x1*x3*f5*h0^3*h3+x1*x2*y1^2*h0^3*h3*f2-y2^2*x1*x2*f1*h0^2*h3^2-8*x1^2*y2*y1*h2*h3*f0^2+y3^2*x3^2*f5^2*h0*h2-2*y3*x1^2*y1*f0*h0*h1*h2*h3-x1^2*y3^2*f2*h0^2*h3^2-y3^2*x3*x2*f0*h2*h3^3+2*x1^2*y3^2*f0*f3*h2*h3-x3*x2*y3*y1*f1*f5*h0*h3-x1^2*y1^2*h0^2*h2^2*f0-2*x3*x2*y1^2*f0*f1*h3^2-2*x1^2*y2*y1*f0*f3*h1^2-8*y2^2*x1^2*f0*f6*h0^2-4*y3*x1*x2*y2*f1*f6*h0*h1+8*y2*x1*x2*y1*f0*f2*h1*h3+y2*x1*x2*y1*h2^2*f1*h0*h1-y2*x2^2*y1*f1*h0^2*h3^2+y2*x1*x2*y1*f1^2*h2^2-y2*x3*x2*y1*f3*h0^2*h2*h3-y2*x2^2*y1*f6*h0^3*h1+y2*x3*x2*y1*f1*h0*h1*h3^2-4*y2*x1*x3*y1*f1*f5*h0*h1-y2*x1*x2*y1*f6*h0^4+x1^2*y2*y1*h0^3*h3*f2+y2*x2^2*y1*f4*h0^3*h3-2*y2*x1*x2*y1*f1*h0^2*h2*h3+x1^2*y2*y1*h1*h2*f1^2+4*y2*x1*x2*y1*f1*f4*h0*h1-x1^2*y2*y1*f0*h1^3*h2-8*x1^2*y2*y1*f5*f0*h0^2-2*y2*x2^2*y1*f0*f5*h1^2+y3^2*x3^2*f5^2*h1^2-y3^2*x3^2*f0*h3^4-4*y3^2*x3^2*f6^2*h0^2+y3^2*x3^2*f3^2*h3^2-y2^2*x1^2*f6*h0^4-4*y2^2*x1^2*f0^2*h3^2-x2^2*y1^2*f6*h0^4-4*x2^2*y1^2*f0^2*h3^2+x3^2*y1^2*f1^2*h3^2+y2^2*x2^2*f1^2*h3^2-4*x1^2*y1^2*h2^2*f0^2-x1^2*y1^2*f4*h0^4+x3^2*y2^2*f5^2*h0^2+x1^2*y3^2*f1^2*h3^2+y3^2*x2^2*f5^2*h0^2+h1*h3*x3^2*y4^2+x1^2*y1^2*f1^2*h1^2-4*x1^2*y1^2*f2^2*h0^2+4*y3*x2*f1*f4*y1*h0*h2*x1+2*y3*x1*x2*y1*f3*h0^2*h1*h3-4*y3*x1*x2*y1*f1*f5*h0*h1+y3*x3^2*y1*f4*h0^2*h3^2-y3*x1*x3*y1*f0*h2^4-2*y3*x3^2*y1*f5^2*h0^2-12*y3*x1*x3*y1*f0*f6*h0*h2-y3*x2^2*y1*f3*f5*h0^2-4*x3*x2*y3*y1*f2*f6*h0*h1-4*y3*x1*x3*y1*f2*f5*h0*h1+4*y3*x3^2*y1*f0*f6*h2^2-4*x3*x2*y3*y1*f0*f4*h2*h3+y3^2*x3*x2*f5*h0*h1*h2*h3+x1^2*y3*y1*f0*h2^3*h0+x1^2*y3*y1*f4*h0^3*h2+y3*x1^2*y1*f6*h0^4-2*y3*x1^2*y1*f5*h0^2*f1-y3*x1^2*y1*f3*h0^3*h3-y3*x1^2*y1*f0*h1^2*h2^2-y3*x1^2*y1*f3^2*h0^2-4*y3*x1*x2*y2*f0*f3*h2*h3-2*x1^2*y3*y2*f1*f6*h0^2-y3*x3^2*y2*f5*h0^2*h3^2-4*y3*x1*y2*x3*f2*f6*h0*h1-y3*x2^2*y2*f3*h0^2*h3^2+y3*x2^2*y2*f6*h0^3*h3-4*y3*x3^2*y2*f1*f6*h2^2+4*x3*x2*y3*y1*f0*f6*h1*h2-y3*x1*y2*x3*f1*f5*h0*h3-2*y3*x3^2*y2*f5*f6*h0^2+y3*x3*x2*y2*f5^2*h0^2+y3*x2^2*y2*f0*h0*h3^3+2*y3*x2*f1*y2*f5*h0*h2*x1+4*y3*x1*x2*y2*f0*f5*h0*h3+y3*x2*y2*f1*h2^2*h3*h0*x1-2*x1^2*y3*y2*f0*f1*h3^2-y3*x3^2*y2*f0*h2*h3^3+4*y3*x1*x3*y1*f0*f5*h0*h3+8*y3*x1*x3*y1*f0*f5*h1*h2-4*y3*x1*x3*y1*f2*h2*h3*f1+x1*y3*y1*f3*h0*h1^2*h3*x3+2*y3*x2*f1*f4*y1*h1*h3*x3+2*y3*x3*y1*f5*h0^2*h1*h2*x1+8*y3*x1*x3*y1*f0*f4*h1*h3-x3*x2*y3*y1*f1*f3*h2*h3-x3*x2*y3*y1*f1*f5*h1*h2+8*y3*x1*x3*y1*f0*f3*h2*h3-y3^2*x1*x2*f3*h0^2*h3^2-y3*x1*y2*x3*f3*f5*h0*h1+2*x1^2*y3^2*f0*f5*h1*h2-y3*x3^2*y1*f0*h2^2*h3^2+6*y3*x1*y2*x3*f0*f5*h1*h3-x3*x2*y3*y1*f3*f5*h0*h1-y3^2*x3*x2*f5*h0^2*h3^2-4*x1^2*y3^2*f0*f6*h1^2+4*y2*f0*f4*x2*y1*h1*h3*x3-y3*x1^2*y1*f5*h0^3*h1-4*y3*x1*x2*y1*f0*f4*h1*h2-4*y3^2*x2^2*f4*f6*h0^2+4*y3^2*x3^2*f3*f6*h1*h2+6*x3*x2*y3*y1*f0*f5*h1*h3-4*y3*x2^2*y2*f0*f3*h3^2-4*y3^2*x3^2*f2*f6*h2^2+2*y3*x3^2*y1*f6*h0^2*h2^2-4*y3^2*x3*x2*f1*f4*h3^2-y3*x2^2*y1*f5*h0^3*h3-4*x1^2*y3^2*f0*f6*h0*h2+2*y3*x1*y2*x3*f6*h0^2*h1*h2+y3*x2*y1*f4*h0*h1^2*h3*x3-x3*x2*y3*y1*h0*h1*h3^2*f2+4*y3^2*x2^2*f0*f5*h2*h3-2*x3^2*y2*y1*f0*f3*h3^2-2*x3^2*y2*y1*f3*f6*h0^2-x3^2*y2*y1*f3*h0^2*h3^2+2*y2*x3*x2*y1*f0*h0*h2*h3^2-4*y2*x3*x2*y1*f1*f6*h0*h1+y2*x2*y1*f4*h0^2*h1*h3*x3+4*y2*f0*f5*x3*y1*h0*h2*x1-4*y2*x3*x2*y1*f0*f3*h2*h3+4*y2*x3*x2*y1*f0*f5*h0*h3-2*y2*x1*x3*y1*f0*h0*h1*h3^2-4*y2*x1*x3*y1*f0*f4*h1*h2+2*y2*x1*x3*y1*f3*h0^2*h1*h3+4*x1*x3*y3^2*f4*f6*h0^2-2*y3^2*x1*x2*f0*f3*h3^2+y3^2*x3*f2*h3^3*h0*x2-8*y3^2*x3^2*f0*f6*h3^2+2*x1*x3*y3^2*f6*h0^2*h2^2+4*x1*x3*y3^2*f0*f6*h2^2-4*y3^2*x2^2*f0*f6*h2^2-y3^2*x2^2*f6*h0^2*h2^2-x1^2*y3^2*f0*h1^2*h3^2+y3^2*x2^2*f5*h0^2*h2*h3-2*y3^2*x1*x2*f3*f6*h0^2-4*y3^2*x2^2*f0*f4*h3^2-y3^2*x2^2*f4*h0^2*h3^2+y3^2*x3^2*f3*h0*h3^3-4*y3^2*x3^2*f4*f6*h0*h2-y3^2*x3^2*f6*h0^2*h3^2+4*y3^2*x3^2*f3*f6*h0*h3-4*y3^2*x3*x2*f1*f6*h2^2-y3^2*x3^2*f5*h0*h3^2*h1-2*y3^2*x3*x2*f0*f5*h3^2+4*x1*x3*y3^2*f0*f4*h3^2+2*y3*x1*x2*y2*f0*h0*h2*h3^2+2*y3*x1*y2*x3*f1*f6*h0*h2+2*y3*x3^2*y1*f0*h1*h3^3+y3^2*x2^2*f1*h3^3*h0-4*y3*x3*x2*y2*f3*f6*h0*h1+4*y3^2*x3^2*f2*f5*h2*h3+x1*x3*y3^2*f4*h0^2*h3^2-2*y3*x3^2*y1*f1*f3*h3^2+y3^2*x3^2*f5*h0*h2^2*h3+3*y3*x1*x3*y1*f1*h0*h1*h3^2+8*y3*x3*x2*y2*f0*f6*h1*h3+x1^2*y3^2*f5*h0^3*h3+2*y3^2*x3*x2*f5^2*h0*h1-x1^2*y3^2*f0*h1*h2^2*h3-x1^2*y3^2*f6*h0^3*h2-4*x1^2*y3^2*f0*f2*h3^2-4*x1^2*y3^2*f2*f6*h0^2+y3*x1^2*y1*f0*h0^2*h3^2-2*y3*x3^2*y2*f0*f5*h3^2-x1*x3*y3^2*f0*h2^2*h3^2+8*y3*x1*x3*y1*f1*f6*h0*h1+4*y3^2*x2^2*f1*f6*h0*h3+y2*x1*x2*h0^2*f4*h1*h3*y3+2*y3*x2^2*f6*h0^3*h2*y1-2*f1^2*x1^2*y1*h1*h3*y3+4*y2*f0*x2*x1*f4*h1*h3*y3+y3*x1*x2*y1*f0*h2^2*h3*h0-f1*x2*y1^2*h0^2*h2^2*x1+x1*x3*y1^2*h0^3*f4*h2+x1*x3*y1^2*f0*h2^3*h0-y2*x1^2*f1*h0^2*h2^2*y1-f1*x2^2*y1^2*h0^2*h2*h3+4*y2*x3*f4*x1*f1*h0*h2*y1+3*x1^2*y1^2*h1^2*h2*h0*f0-3*x1^2*y1^2*f1^2*h0*h2+2*f1*x2*y1^2*h0*h2*h1*h3*x3-2*x1*x3*y1^2*f0*h0*h1*h2*h3+2*y2*x3*f5*x2*f1*h0*h2*y1+2*y2*x3*f4*x1*f1*h1*h3*y3+x3*y2*x1*f4*h0*h1^2*h3*y3-2*y3*x1*x2*y1*h3^2*f0*h0*h1+4*y3*f0*f5*x2*x1*h0*h2*y1+x3*y2*x2*f1*h2^2*h3*h0*y1+x1^2*y2*y1*h0^3*f3*h2-y2*y4*x2^2*f5*h0^2+y2*x1^2*f1*y4*h0*h2-4*y3*y4*x2^2*f6*h0^2-2*y2*y4*x1*x2*f0*h2^2-4*y3*y4*x2^2*f0*h3^2+4*y3*x3*x2*y2*f6*h0^2*h1*h3-y3*x3*x2*y2*f3*h0*h1*h3^2-x2^2*y1*h0^2*h1*y4*h3+2*y3*y4*x1*x3*f0*h3^2-2*y3*y4*x1*x2*f5*h0^2-2*y3*y4*x3^2*f6*h1^2-2*y3*y4*x3^2*f2*h3^2-2*x3*y2*y4*x2*f0*h3^2-2*y2*y4*x3^2*f6*h0*h1-2*x3*y2*y4*x2*f6*h0^2+4*y3*x3*x2*y2*f0*f5*h2*h3+2*y3*x3^2*y2*f5^2*h0*h1+y3*x3^2*f2*h3^3*h0*y2+y3*x3^2*y2*f5*h0*h1*h2*h3-4*y3*x3^2*y2*f1*f4*h3^2-y3*x1*x2*y2*f3*h0^2*h2*h3-y3*x1*x2*y2*f0*h1*h2^2*h3+y3*x1*x2*y2*f1*h0*h1*h3^2+4*y3*x3*x2*y2*f1*f6*h0*h3+2*y3*x2*f1*y2*f5*h1*h3*x3+y3*x2*y2*f5*h0*h1^2*h3*x3-4*y3*x3*x2*y2*f1*f6*h1*h2-4*y3*x1*y2*x3*f0*f4*h2*h3-2*y3*y4*x3^2*f6*h0*h2+y3*y4*x3^2*f5*h1*h2+2*y3*y4*x1*x3*f6*h0^2-2*y3*x3^2*f4*y4*h1*h3+y3*y4*x3^2*f5*h0*h3-3*y3*y4*x3*x2*f1*h3^2-y2*y4*x3^2*h0*h1*h3^2+2*x1^2*y1*f0*h1^3*h3*y3+2*y2*x1^2*f1*h1*h3*y3*h0*h2-2*y4*x3^2*y1*f6*h0^2-4*y4*x1^2*y1*h0^2*f2-4*y4*x1^2*y1*f0*h1^2+2*f1*x2^2*y1*y4*h0*h3-y2*y4*x3^2*f1*h3^2-
    2*y2*y4*x1^2*f0*h1*h2-2*y2*y4*x2^2*f0*h2*h3-2*y4*x1*x3*y1*f4*h0^2-x3*y2*y4*x1*h2^2*f1-y2*y4*x1^2*h0^2*f3-x3*x2*y3*y1*f6*h0*h1^3+y3^2*x3*x2*f6*h0^2*h2*h3-2*y2*x1*x3*y1*f4*h0^2*f3-6*f0*f3*x2*y1^2*h1*h3*x3+y3^2*x2*f1*h3^2*h0*h2*x1+2*y2^2*f0*f5*x2*h1*h3*x3-4*y3*x2^2*y1*f1*f6*h0*h1+4*y3*f2*f6*x3^2*h0*h3*y2-4*x3*x2*y1^2*f0*f6*h0*h1-y2*x2^2*y1*f0*h1^2*h2*h3+y3*x1*x3*y1*f6*h0^2*h1^2+y3*x2^2*y1*h2^2*f1*h0*h3+x1*x2*y1^2*f0*h0*h3*h1^2+4*y3^2*x3*x2*f1*f5*h2*h3-8*y3*x3^2*y2*f4*f6*h0*h1+2*x2^2*y1^2*f0*h1*h2*h0*h3+2*x1*x2*y1^2*f3*f1*h0*h1-x1*x2*y1^2*h0^2*h3*f1*h1+x1*x2*y1^2*h1^2*h2*f1*h0+4*x1*x2*y1^2*f0*f3*h0*h2+4*x1*x2*y1^2*f0*h0*h3*f2-2*x1*x2*y1^2*h2*h3*f0*h0^2-4*x1*x2*y1^2*f0*h1*h2*f2+2*x1*x2*y1^2*f0*h1*h2^2*h0-x1*x2*y1^2*h0^2*h1*h2*f2+2*x1*y1^2*h0^2*f2*h1*h3*x3+8*f0*f2*x1*y1^2*h1*h3*x3-4*x1*x3*y1^2*f0*f3*h0*h3-4*x1*x3*y1^2*f0*f3*h1*h2-4*x1*x3*y1^2*f0*f5*h0*h1-4*x1*x3*y1^2*f0*h2*h3*f1-2*x1*y1^2*f1*h0*h1^2*h3*x3-x2*y1^2*h0^2*f3*h1*h3*x3-3*x2*y1^2*f0*h1^2*h2*h3*x3-x3*y2^2*x2*f0*h1*h2*h3^2+2*y2^2*x3*f4*x1*f1*h0*h3-2*y2*x1*x3*y1*f1^2*h2*h3+2*y2^2*x1^2*f0*h1*h2*h0*h3-4*y2^2*x1*x2*f0*f2*h2*h3-y2^2*x1*x2*f0*h1^2*h2*h3-y2^2*x1*x2*f2*h0^2*h2*h3+2*y2^2*x1*x2*f1*f5*h0*h1-4*y2^2*x1*x2*f0*f6*h0*h1+y2^2*x1*x2*f0*h0*h1*h3^2+4*y2^2*f0*x2*x1*f4*h0*h3-8*x3*y2^2*x2*f0*f6*h1*h2+8*y2^2*f0*f6*x3*h0*h2*x1+x3*y2^2*x1*f4*h0^2*h1*h3-4*y2^2*x1*x3*f0*f5*h0*h3-2*y2^2*x1*x3*f0*f5*h1*h2-2*y2^2*x1*x3*f0*f3*h2*h3-y2^2*x1*x3*f0*h1*h2^2*h3-y2^2*x1*x3*f3*h0^2*h2*h3-4*y2^2*x1*x3*f1*f6*h0*h1-3*y2^2*x1*x3*f1*h0*h1*h3^2+x3*y2^2*x1*h2^2*f1*h0*h3+x3*y2^2*x2*f5*h0^2*h1*h3+x3*y2^2*x2*f1*h2*h3^2*h0+4*x3*y2^2*x2*f0*f6*h0*h3-x3*y2^2*x2*f6*h0^2*h1*h2+y2^2*x3*f5*x2*f1*h0*h3+4*x1^2*y2*y1*f0*h0*h3*f2+2*x1^2*y2*y1*f3*f1*h0*h1-x1^2*y2*y1*h0^2*h3*f1*h1+x1^2*y2*y1*h1^2*h2*f1*h0-2*x1^2*y2*y1*h2*h3*f0*h0^2+x1^2*y2*y1*f0*h0*h3*h1^2-4*x1^2*y2*y1*f0*h1*h2*f2-x1^2*y2*y1*h0^2*h1*h2*f2+2*y2*x2^2*y1*f1*f5*h0*h1-4*y2*x2^2*y1*f0*f2*h2*h3-y2*x2^2*y1*f2*h0^2*h2*h3-4*y2*x2^2*y1*f0*f6*h0*h1+y2*x2^2*y1*f0*h0*h1*h3^2+4*y2*f0*f4*x2^2*y1*h0*h3-2*y2*x1*x2*y1*f1^2*h1*h3-4*y2*x1*x2*y1*f0*f4*h1^2+2*y2*x1*x2*y1*f0*h1^3*h3-4*y2*x1*x2*y1*f0*f2*h2^2-y2*x1*x2*y1*f0*h1^2*h2^2-4*y2*x1*x2*y1*f2*f4*h0^2-y2*x1*x2*y1*h0^2*h2^2*f2-2*y2*x1*x2*y1*f5*h0^2*f1-y2*x1*x2*y1*f5*h0^3*h1-8*y2*x1*x2*y1*f0*f6*h0^2-y2*x1*x2*y1*f0*h0^2*h3^2+y2*x1*y1*h0^3*f3*h3*x2-4*x3^2*y2*y1*f0*f6*h1*h2-3*x3^2*y2*y1*f0*h1*h2*h3^2-y2*x1*x3*y1*h0^2*h2^2*f3-4*y2*f0*f5*x3^2*y1*h1*h3-2*y2*x1*x3*y1*f0*h2^2*f3-y2*x1*x3*y1*f0*h2^3*h1-y2*x1*x3*y1*f5*h0^2*h1^2-3*y2*x1*x3*y1*f1*h0*h1*h2*h3+x1*x3*y1*f1*h0^2*h3^2*y2+x3*y2*y1*f5*h0^3*h2*x1-2*y2*x2*y1*f0*h1^2*h3^2*x3-2*y2*x3*x2*y1*f3*f5*h0^2+y2*x3*x2*y1*f5*h0^3*h3-y2*x3*x2*y1*f6*h0^2*h1^2-8*y3*x3^2*y1*f0*f5*h2*h3-2*y3*x3*x2*y2*f1*f3*h3^2+4*y3*x3^2*y2*f1*f5*h2*h3-4*x1*x3*y3^2*f3*f6*h0*h1-2*y3*x1*x2*y1*f4*h0^2*f3-y3*x1*x2*y2*f6*h0^2*h1^2-4*y3*x3^2*y2*f0*f6*h2*h3+2*y3*x1*y2*x3*f0*f3*h3^2-4*y3^2*x1*x2*f0*f6*h1*h2-3*y3^2*x1*x2*f0*h1*h2*h3^2-2*x1*x3*y3^2*f5*h0^2*h2*h3+y3^2*x3*f2*h3^2*h0*h2*x1-8*x1*x3*y3^2*f0*f5*h2*h3-4*x1*x3*y3^2*f1*f6*h0*h3-4*x1*x3*y3^2*f1*f6*h1*h2-x1*x3*y3^2*f6*h0*h1^2*h2-x1*x3*y3^2*f3*h0*h1*h3^2+8*x1*x3*y3^2*f0*f6*h1*h3+4*x3*y3^2*f6*f2*h0*h2*x1+4*x3*y3^2*f6*f2*h0*h3*x2-x3*f3*y3^2*f5*h0*h3*x2-8*y3^2*x3*x2*f4*f6*h0*h1+y3^2*x3*x2*f6*h0*h1^2*h3-y3^2*x3*x2*f6*h0*h1*h2^2-y3^2*x3*x2*f4*h0*h1*h3^2-4*y3^2*x3*x2*f0*f6*h2*h3+x1^2*y3*y1*f1*h1*h2^2*h0-4*y3*x1^2*y1*f0*f3*h0*h3-4*y3*x1^2*y1*f0*f3*h1*h2-4*y3*x1^2*y1*f0*f5*h0*h1-4*y3*x1^2*y1*f0*h2*h3*f1+4*y3*f0*f4*x1^2*y1*h0*h2+2*x1^2*f1*y3*f3*y1*h0*h2+y3*x2^2*y1*f4*h0^2*h1*h3-4*y3*x2^2*y1*f0*f5*h0*h3-2*y3*x2^2*y1*f0*f5*h1*h2-2*y3*x2^2*y1*f0*f3*h2*h3-y3*x2^2*y1*f0*h1*h2^2*h3-y3*x2^2*y1*f3*h0^2*h2*h3+2*y3*x2^2*f1*f4*y1*h0*h3+x1*y3*y1*f1*h0^2*h3^2*x2-2*y3*x1*x2*y1*f0*h2^2*f3-y3*x1*x2*y1*f0*h2^3*h1-y3*x1*x2*y1*h0^2*h2^2*f3-y3*x1*x2*y1*f5*h0^2*h1^2-2*y3*x1*x2*y1*f1^2*h2*h3-3*y3*x1*x2*y1*f1*h0*h1*h2*h3+y3*x2*y1*h2^3*f1*h0*x1+y3*x3^2*y1*f5*h0*h1^2*h3-2*y3*x3^2*y1*f5*h0^2*h2*h3-4*y3*x3^2*y1*f1*f6*h0*h3-4*y3*x3^2*y1*f1*f6*h1*h2-4*y3*x3^2*y1*f3*f6*h0*h1-y3*x3^2*y1*f6*h0*h1^2*h2-y3*x3^2*y1*f3*h0*h1*h3^2+8*y3*x3^2*y1*f0*f6*h1*h3+2*x3^2*y3*f5*f1*y1*h1*h3-2*x3*x2*y3*y1*f1*f6*h1^2-8*y3*x1*x3*y1*f0*f4*h2^2-4*y3*x1*x3*y1*f0*h1^2*h3^2-y3*x1*x3*y1*h0^2*f4*h2^2-2*y3*x1*x3*y1*f5*h1^2*f1-y3*x1*x3*y1*f5*h1^3*h0-2*y3*x1*x3*y1*f2*h0*h1*h2*h3+4*y3*x1*x3*y1*f3*f5*h0^2+y3*x1*x3*y1*f5*h0^3*h3-4*y3*x1*x3*y1*f0*f6*h1^2-4*y3*x1*x3*y1*f2*f6*h0^2-3*y3*x1*x3*y1*f6*h0^3*h2-4*y3*x1*x3*y1*f0*f2*h3^2-y3*x1*x3*y1*f2*h0^2*h3^2-x3*x2*y3*y1*f3*h0*h1*h2*h3-2*x3*x2*y3*y1*f0*f5*h2^2-x3*x2*y3*y1*f0*h2^3*h3-2*x3*x2*y3*y1*f4*f5*h0^2-2*x3*x2*y3*y1*f1*f2*h3^2+2*x3*x2*y3*y1*f3*f6*h0^2+2*x3*x2*y3*y1*f0*f3*h3^2+x3*x2*y3*y1*f3*h0^2*h3^2+x1^2*y3*y2*f0*h2^2*h3*h0-4*x1^2*y3*y2*f0*f6*h0*h1+y3*x2^2*y2*f1*h2*h3^2*h0+y3*x2^2*y2*f5*h0^2*h1*h3+4*y3*x2^2*y2*f0*f6*h0*h3-8*y3*x2^2*y2*f0*f6*h1*h2-y3*x2^2*y2*f6*h0^2*h1*h2-y3*x2^2*y2*f0*h1*h2*h3^2+y3*x2^2*f1*y2*f5*h0*h3-2*y3*x1*x2*y2*f3*f5*h0^2+y3*x1*x2*y2*f5*h0^3*h3-y3*f5*x3^2*f3*h0*h3*y2+y3*x1*y2*x3*f3*h0^2*h3^2-y3*x3^2*y2*f6*h0*h1*h2^2-y3*x3^2*y2*f4*h0*h1*h3^2+y3*x3^2*y2*f6*h0^2*h2*h3-y3*x1*y2*x3*f3*h0*h1*h2*h3-2*y3*x1*y2*x3*f0*f5*h2^2-y3*x1*y2*x3*f0*h2^3*h3-2*y3*x1*y2*x3*f4*f5*h0^2-2*y3*x1*y2*x3*f1*f6*h1^2-2*y3*x1*y2*x3*f1*f2*h3^2-y3*x1*y2*x3*f6*h0*h1^3+2*y3*x1*y2*x3*f3*f6*h0^2-y3*x3*x2*y2*f0*h2^2*h3^2+y3*x3*x2*y2*f1*h0*h3^3-8*y3*x3*x2*y2*f4*f6*h0^2-8*y3*x3*x2*y2*f0*f6*h2^2-8*y3*x3*x2*y2*f0*f4*h3^2-y3*x3*x2*y2*f4*h0^2*h3^2+2*y3*x3*x2*y2*f0*h1*h3^3-3*f1*x2*y1*y4*h1*h3*x3-2*y3*y4*x1*x3*f5*h0*h1-4*y4*x1*x2*y1*f0*h1*h2+2*f1*x2*y1*y4*h0*h2*x1-y4*x1*x3*y1*f3*h0*h1-3*y4*x1*x3*y1*f1*h0*h3-y4*x1*x3*y1*f1*h1*h2+10*y4*x1*x3*y1*f0*h1*h3-2*y4*x3*x2*y1*f0*h2*h3-x2*y1*h0*h1^2*y4*h3*x3+y2*y4*x1*x2*h0^2*h1*h3+4*y2*y4*x1*x2*f0*h1*h3-2*x3*y2*y4*x1*f4*h0*h1+3*x3*y2*y4*x1*h1*h3*f1+x3*y2*y4*x1*h0*h1^2*h3-x3*y2*y4*x2*f5*h0*h1-x3*y2*y4*x2*f1*h2*h3-4*y3*y4*x1*x2*f0*h2*h3-6*y3*y4*x3*x2*f6*h0*h1-2*y3*y4*x1*x3*f1*h2*h3-2*y3*x3*f4*y4*h0*h3*x2+y3*y4*x3*x2*h0*h1*h3^2-3*y2*x1^2*f0*h1^2*h2*h3*y3+2*x1^2*y1*h0^2*f2*h1
    *h3*y3-3*y3*x2^2*y1*h3^2*f1*h0*h1-h1*h3*x3^2*y4*h0*h2*y1+2*x1*f3*x3*f1*y1^2*h0*h2+2*y2*x1*x2*y1*f0*h0*h1*h2*h3+y3*x3^2*y2*f6*h1^2*h0*h3-6*y2*f0*x1^2*f3*h1*h3*y3+x3*y2*x1*h2^3*f1*h0*y1+x3*x2*y1^2*f0*h2^2*h3*h0+y3^2*x1*x3*h0*h1^2*f5*h3-2*x1^2*y1*f1*h0*h1^2*h3*y3+2*y3^2*x1*f1*x3*f5*h1*h3+2*y3^2*x3^2*h0*h1*h2*h3*f6+4*x1^2*y2*y1*f0*f3*h0*h2+2*x1^2*y2*y1*f0*h1*h2^2*h0+8*y3*f0*f6*x2^2*h0*h2*y1-4*y3^2*f0*f5*x2*x1*h1*h3+y2*x3^2*f1*h3^2*h0*h2*y1+y3*x1*x2*h0^3*f5*h2*y1+x1*x3*y1^2*h1*h2^2*f1*h0+4*f4*f0*x3*x1*y1^2*h0*h2+4*y3*f2*f6*x3^2*h0*h2*y1-2*y2*x1*x2*f0*h1^2*h3^2*y3-y2*x1^2*h0^2*f3*h1*h3*y3+2*y2*f0*f5*x2^2*h1*h3*y3+8*x1^2*f2*f0*y1*h1*h3*y3+y3*x3^2*h3^2*f2*h0*h2*y1+4*h1^2*h3*y2*x1*x3*y1*f0*h2-8*y3^2*x2^2*f0*f6*h1*h3-y3*x1*x3*y1*f0*h0*h2*h3^2+4*y2*x1*x2*y1*f0*f4*h0*h2+4*x1^2*y1^2*f2*h0*h2*f0+x1^2*y1^2*f2*h0^3*h2+x3^2*y1^2*f0*h0*h2*h3^2+y2*x1*x3*y1*f4*h0^2*h1*h2+y2*x2^2*y1*f0*h0*h2^2*h3+y2*x1*x2*y1*f0*h2^3*h0+y2*x1*x2*y1*f4*h0^3*h2-x3^2*y2*y1*f6*h0^2*h1*h2-2*y3^2*x2^2*f0*h1*h3^3-y3*x1*x3*y1*f1*h0*h2^2*h3-x3*x2*y3*y1*f4*h0^2*h2*h3+8*y3*x1*x2*y1*f0*h1*h3*f3+4*y3*x1*x2*y1*f0*h1^2*h2*h3+x3*x2*y3*y1*f5*h0^2*h1*h3+4*x3*x2*y3*y1*f0*h1*h2*h3^2+x1^2*y3*y2*f0*h0*h1*h3^2+y3*y4*x1*x3*h0*h1*h2*h3+h0*h2*y3*x2^2*f5*f1*y1+2*h0*h2*y3^2*x3*f6*x2*f3+2*h0*h2*y3*x3^2*y2*f6*f3+2*h0*h2*x3*y2^2*f6*x2*f1+h0*h2*y2*y4*x1*f3*x3+h0*h2*x1*x3*y2^2*f5*f1-h0*h2*x1*x3*y3*f3^2*y1+2*h0*h2*y4*f2*x1*x3*y1+h0*h2*y3*y4*x3*f5*x2+2*h0*h2*y3*x2^2*y2*f6*f1+h0*h2^2*x3*x2*y3*y1*f2*h3-h0*h2^2*y3*x1*x3*y1*f3*h1+h0*h2^2*y2^2*x1*x2*f0*h3+h0*h2^2*y3*x1*y2*x3*f2*h3-h0^2*h2*y3*x1*f4*x3*h3*y2+h0*h2^3*y3*x1*x3*y1*f2-2*h1^3*h3*x2^2*y1^2*f0-8*h1*h3*x1^2*f0*y3^2*f4-h0^2*h2^2*y3*x1^2*f2*y1+2*h1*h3*x1^2*f1^2*y2^2+h0*h2*y3*x1*x3*y1*f4*h1^2-h0^2*h2*y3^2*x1*x2*f6*h1+h0*h2*y3*x3*x2*y2*f2*h3^2-8*h1*h3*y2^2*x1^2*f2*f0-8*h1*h3*y2^2*f6*x3^2*f0-h0^2*h2^2*x3*f2*y1^2*x1-8*h1*h3*f0*f4*x3^2*y1^2+h0^2*h2*y3*x1*x2*y1*f4*h1+2*h1*h3*x2^2*f1^2*y1^2-8*h1*h3*f0*x2^2*f2*y1^2+8*h1*h3*f0*x1*x3*y2*f3*y1-h1*h3*y3*y4*x1^2*h0^2-8*h1*h3*y4*f0*x2^2*y1-8*h1*h3*y3*y4*x1^2*f0-h1*h3*x1^2*y3^2*f4*h0^2+4*h0*h2*x1*x3*y3*f4*f2*y1+2*h0*h2*x1*x3*y3*y2*f5*f2-h0*h2*x3^2*f5*f1*y1^2-2*h1*h3*x2^2*y1^2*h0^2*f2-h1*h3*x3^2*y1^2*f4*h0^2-2*h1*h3*y2^2*x1^2*h0^2*f2+4*h1^2*h3^2*y2^2*x1*f0*x3+2*h1^2*h3*x2^2*y1^2*f1*h0+2*h0*h3*f4*x3^2*f1*y1^2+h1*h3*y3*x1*y2*x3*f5*h0^2+h1*h3*y4*x1*x3*y1*h0^2+h0*h3*y3*x1^2*y2*f3*f1+h0*h3*y4*f3*x3^2*y1+4*h1^2*h3^2*f0*x2^2*y1*y3+2*h0*h3*y3*y4*x1^2*f1-4*h0*h3*y3*y2*f0*f6*x1*x3+2*h0*h3*y3^2*f1*f5*x2*x1+4*h0*h3*y3^2*f0*f6*x2*x1+4*h0*h3*f0*f4*x2*x3*y1^2-h0*h3*y3*y4*x3*f3*x1+h0*h3*x3*f3*x2*f1*y1^2-4*h0*h3*y3*x3*f4*x1*f1*y1+h0^3*h3*x3*x2*y1^2*f4+h0^3*h3*x1^2*y3*y2*f4-4*h0*h3*y3*f0*x2*f6*x3*y1-4*h0*h3*y3*f0*f4*x2*x1*y1-4*h0*h3*y2*f0*f4*x1*x3*y1+h0^3*h3*x3^2*y2*y1*f6+h0^2*h3^2*y2^2*x3*x1*f2+4*h0*h3*f0*x1^2*y3*y2*f4+2*h0*h3*y4*f2*x2*x3*y1+h0*h3^3*x3^2*y2*y1*f0+2*h0*h3*y2*f1*f5*x3^2*y1+4*h0*h3*y2*f6*x3^2*f0*y1-2*h0*h3*y2*y4*x3*x1*f2+h0*h3^3*y3^2*x1*x2*f0-h0*h3^3*y3*x1*y2*x3*f0-h0^3*h3*x3*x2*y3*y1*f6-h0^2*h3^2*f2*x2*x3*y1*y2+h0*h3^2*x3*x2*y1^2*f0*h1+h0*h3^2*x1^2*y3^2*f0*h2+h0^3*h3*y3^2*x1*x2*f6-h0^2*h3*y3*x1^2*y2*f2*h2-h0*h3^3*x3*x2*y3*y1*f0-h0^3*h3*y3*x1*x2*y1*f4-h0^3*h3*y3*x1*y2*x3*f6-h0^2*h3^2*y3*x1*y2*f2*x2+h0^2*h3^2*y3*x2^2*f2*y1-2*h1^3*h3*y2^2*x1^2*f0-2*h1*h3^3*x3^2*y2^2*f0-h0^3*h3*y2*x1*x3*y1*f4-h0^2*h3*f2*x2*x3*y1^2*h2+2*h0*h2*y3*x2*f5*x3*f2*y1+h0*h2*y2^2*x2^2*f0*h3^2-h0*h2*y3^2*f1*x1^2*f5+4*h0*h2*y3*x2*y2*f6*x3*f2+2*h0*h3*x1^2*f1*y3^2*f4+2*h1^2*h3*y2^2*x1^2*f1*h0-12*y4*x4*x1*f0*y1-2*x4*x2*y2^2*f0*h2*h3-2*h0*h3*y3*x2*f2*x4*y1-16*f0*f2*x1*x4*y1^2+2*h0*h3*x3*x4*f1*y1^2-8*y3*f0*f4*x1*x4*y1-3*x1*x4*y3*y1*h0*h3*f1+2*h0*h3*y3*x4*x1*y2*f2+h0*h3*y3^2*f3*x1*x4-h0*h3*x3*x4*y3*f3*y1-4*x1*x4*y1^2*f0*h1^2+f1*x2*y1^2*h0*h2*x4+2*x3*x4*f3*y3^2*f5+4*y2*x4*x2*y1*f0*h1*h3-2*y3^2*x4*x2*f6*h0*h1-2*y3^2*x4*x3*h1^2*f6-16*y2^2*f0*f6*x3*x4-2*y3^2*x4*x3*f2*h3^2-2*y3^2*x4*x3*h0*h2*f6-y3*x4*x2*y1*h2^2*f1+4*h1*h3^2*y3*x1*y2*x3*f0*h2-2*x1*f1*x4*y3*f3*y1+2*y3*x4*x3*y1*f6*h0^2+h1*h3*x1*x4*y3*y1*h0^2-h1*h3*x4*x3*y1^2*h0^2-8*h1*h3*y2^2*x4*x1*f0+h1*h3*y3*x3*h0*h2*y1*x4-8*h1*h3*f0*x4*x3*y1^2+2*y3*y4*x4^2+h0*h2*y3*x4*x2*f3*y1-h0*h2*y2*y4*x4*x2+2*h0*h2*y3*x1*f2*x4*y1+h0*h2*y3*x3*f5*x4*y2+2*x3*x4*y4^2+4*x1*f1^2*x4*y1^2-4*f0*f3*x2*x4*y1^2+4*x1*x4*y1^2*f1*h0*h1-4*x1*x4*y1^2*h0^2*f2-x2*x4*y1^2*h0^2*f3-2*x2*x4*y1^2*f0*h1*h2-4*x4*x3*y2*y1*f0*h2*h3+y2*x4*x2*y1*h0^2*h3*h1-y2^2*x1*h0^2*h1*h3*x4-2*y2*x4*x2*y1*f0*h2^2-2*y2*x4*x2*y1*h0^2*f4-2*x4*x3*y2*y1*h0^2*f5-4*y2*x1*x4*y1*f0*h1*h2-2*y2*x1*x4*y1*h0^2*f3-4*x4*x3*y2^2*h3^2*f0+2*y2*x1*f1*h0*h2*y1*x4-4*x4*x3*y2^2*f6*h0^2-4*y2^2*f0*f5*x2*x4-x4*x2*y2^2*h0^2*f5+h1*h3*y3^2*x4^2+2*y2^2*x1*f1*h0*h3*x4-8*y2*f0*f5*x3*x4*y1-8*y2*f0*f3*x1*x4*y1-8*y2*f0*f4*x2*x4*y1-2*y3*x4*x3*y1*f1*h2*h3+y3^2*x4*x3*h0*h3*f5-4*x3*x4*y3*f5*f1*y1-2*y3^2*x1*x4*h3^2*f0-4*y3*x2*f1*x4*f4*y1-8*x3*x4*y3^2*f6*f2+10*x1*x4*y3*y1*f0*h1*h3-y2*x1*h0*h1^2*h3*y3*x4-8*y3*y2*f0*f6*x2*x4-2*y3*x4*x2*y2*h3^2*f0-4*y3^2*x2*f1*x4*f6-2*y3*x2*f1*x4*y2*f5+y3^2*x4*x3*h1*h2*f5-2*y3^2*x1*x4*f6*h0^2-8*y3^2*f0*f6*x1*x4-h1*h3*y3^2*x4*h0*h2*x1-y3^2*x4*x2*h3^2*f1-y3^2*x4*x2*h3^2*h0*h1-2*y3^2*x3*f4*h1*h3*x4+y3^2*x4*x3*f3*h2*h3-x1*x4*y3*y1*h1*h2*f1-x1*x4*y3*y1*f3*h0*h1-2*x1*x4*y3*y1*f0*h2^2+8*x3*x4*y3*f6*f0*y1-2*x1*x4*y3*y1*h0^2*f4+3*y3*x4*x2*y1*h1*h3*f1+y3*x4*x2*y1*h1^2*h3*h0-2*y3*x4*x2*y1*f4*h0*h1+2*y3*x4*x3*y1*h3^2*f0-2*y3*x4*x3*y1*h0*h1*f5-3*y2*x1*f1*h1*h3*y3*x4-2*x1*x4*y3*y2*f0*h2*h3-y3*x4*x2*y2*f1*h2*h3-x1*x4*y3*y2*h0^2*f5-2*y3*x4*x2*y2*f6*h0^2-4*y3*y2*f0*f5*x1*x4-3*y3*x4*x3*y2*h3^2*f1-y3*x4*x2*y2*h0*h1*f5-12*x3*x4*y3*y2*f6*f1-2*y3*x3*f4*h0*h3*y2*x4-6*y3*x4*x3*y2*f6*h0*h1+y3*x4*x3*y2*h3^2*h0*h1-3*y3*y4*x4*h0*h3*x2+y3*y4*x4*x3*h2^2-2*y2*y4*x1*f1*x4-3*x3*x4*y4*h0*h3*y2-3*y4*x1*x4*y1*h0^2-x3*x4*y4*h0*h2*y1-2*y4*f1*x2*x4*y1-y4*x4*x2*y1*h0*h1-y2*y4*x1*x4*h0*h1-6*y3*y4*x4*x3*h1*h3+4*y3*y4*x3*f4*x4-y3*y4*x4*h0*h2*x1;
b44:=16*y2^2*f2*f0*f6*x1*x4+4*y3*x4*y2*f3*x2*f6*f1+4*h0*h1*h3^2*y2*f0*f4*x1*x3*y1-2*f5*x1^2*f1^3*y1^2+x1^2*f1^2*f3^2*y1^2+16*y3^2*f0^2*f6^2*x1^2+16*y3^2*f2^2*x3^2*f6^2+x2^2*y2^2*f5^2*f1^2+16*f0^2*f6^2*x3^2*y1^2+y3^2*x3^2*f3^2*f5^2+2*f1^2*x3^2*f5^2*y1^2+16*f4^2*f0^2*x1^2*y1^2+16*y2^2*f0^2*f6^2*x2^2+2*x1^2*f5^2*f1^2*y3^2-2*y3^2*f1*f5^3*x3^2-2*y2*y4*x1^2*f5*f1^2+16*y2^2*f2*f0*f6*x2*x1*f3-4*f5^2*x2*f1*x3*y3^2*f4-2*f1*x3^2*f5^2*y3*f3*y1+16*f0*f6*f4^2*x2^2*y3^2-8*f2*f5^2*x3^2*f0*y1^2+16*y3^2*x3*f6^2*x1*f1^2-4*f3^2*f0*x1^2*y3^2*f6+16*f5*f0^2*f6*x3*x2*y1^2-16*y3*y2*f0*f3*f6^2*x3^2-8*f1^2*x3^2*f6*f4*y1^2+16*y3*y4*x2*f6*f1*x3*f4-8*x1^2*f6*f1^2*y3^2*f4-4*y4*x2^2*f6*f1^2*y1-4*y4*f4*x1^2*f1^2*y1-4*y3*y4*f5^2*x2*f1*x3+8*y3*f2*x3*f6*f3*x1*f1*y1+16*y2^2*f2*f0*f6^2*x3^2+8*y3*f1*f5*f0*f6*x2^2*y1-2*f5^2*x3*f3*x1*f1*y3^2+16*y3*f1^2*x3^2*f6^2*y1-2*f5*x3*f3*x1*f1^2*y1^2+16*f2^2*f0*x1^2*f4*y1^2-4*y2^2*f2*f5^2*f0*x2^2+8*y2^2*f0*f6*x3*f3^2*x1-16*y3*f0*f5*f2*f6*x3*x2*y1+8*y3*y2*f1*f5*f0*f6*x2*x1+32*y2*f0^2*f6^2*x3*x2*y1-16*y2*f1*f0*f6*x3*x1*f4*y1+16*y4*f4*f0*f6*x3^2*y1+16*f2*f0*f6^2*x2^2*y3^2-4*y3*y4*x1^2*f6*f1^2-4*y3*y4*f0*f5^2*x2^2+16*y2*f5^2*f0^2*x2*x1*y1+16*y3*y4*f2*x3^2*f6*f4+16*y3*y2*f2*f1*x3^2*f6^2+32*y3*y2*f0^2*f6^2*x2*x1+32*f2*x3^2*f6*f4*f0*y1^2+16*f4^2*f0*f6*x3^2*y2^2+16*f2^2*f0*x2*f5*x1*y1^2+8*f0*f5*x1^2*f1*f2*y1^2-16*f5*f0^2*x1^2*f3*y1^2+16*y2^2*f0^2*f6*x2*f5*x1-4*y3^2*f0*f5^3*x3*x2-4*y3*y4*f2*f5^2*x3^2-4*y4*f0*f5^2*x3^2*y1-8*y2^2*f0*f5*f3*f6*x3^2-4*x3^2*f6*f3^2*y3^2*f4-4*f4*x1^2*f1^2*f2*y1^2-4*x1^2*f6*f1^2*f0*y1^2+16*y3*y4*f0*f6*x2*x1*f3+16*f0*f6*x3*f4*x2*y3*f3*y1-16*y3^2*f1*x3^2*f6^2*f3-8*y3^2*f2*x3^2*f6*f3*f5+16*y2^2*f0^2*f6*x1^2*f4-4*f0*f5^2*x3^2*y2^2*f4+16*f5^2*f0^2*x3*x1*y1^2+16*f0*f6*x2*f1*x1*f2*y1^2-4*f5*x2*f1^2*x1*f2*y1^2-4*y2*y4*f0*x2*f5^2*x3-4*y2^2*f0*f5^2*f3*x3*x2-8*y2*f1*f5*f0*x1^2*f3*y1+16*x2*f6*f1*x3*f4^2*y3^2+16*y2*f0^2*f6*x3*f5*x1*y1-8*y3*y2*f1*f5*f3*f6*x3^2-4*f1*x3^2*f5^2*y3*y2*f4+16*y3*f5^2*f0^2*x1^2*y1-4*x2^2*f6*f1^2*f2*y1^2-4*y3*y2*f0*f5^3*x3^2+16*f0^2*f6*f4*x2^2*y1^2-8*f0*f5^2*x1^2*f2*y3^2-4*y2*f6*x1^2*f1^3*y1-4*x3^2*f6*f3^2*f0*y1^2-4*x2^2*f6*f1^2*y2^2*f4+16*y3*y2*f1*f0*f6^2*x2^2+8*y2*f1*f5^2*f0*x3*x1*y1-2*y2*y4*f1*x3^2*f5^2+16*y3*y2*f0^2*f6*f5*x1^2+4*y2*y4*x2*f6*f1*x3*f3-4*x2*f6*f1^3*x1*y1^2-4*f0*f5^2*x1*f3*x2*y3^2+16*f0*f6*x2*x1*f3*y3^2*f4-4*y3*x1^2*f1^2*f3*y2*f6-4*y4*f3^2*f0*x1^2*y1-4*y3*y4*x3^2*f6*f3^2-8*f0*f6*x2^2*f3*f1*y1^2+16*f2^2*f0*f6*x2^2*y1^2+8*f3*f0*x3*f5*x1*f2*y1^2-4*f3^2*f0*x1^2*f2*y1^2-8*f0*f4*f1*x1^2*f3*y1^2+16*f0^2*f6*x1^2*f2*y1^2-16*f0^2*f6*x2*x1*f3*y1^2+16*f4*f0^2*x2*f5*x1*y1^2-8*f0*f5*f1*x2*x1*f3*y1^2-32*f0^2*f6*x3*x1*f4*y1^2+8*f0*f6*x3*f3*x1*f1*y1^2+16*f3*f0*f6*x3*x2*f2*y1^2-4*x2*f6*f1^2*x3*f3*y1^2-4*f0*f5^2*x3^2*y2*f3*y1+16*f2*f0*f6*x2^2*y2^2*f4-8*y2*f1*f0*f6*x2*x1*f3*y1+16*y2*f5*f0^2*f6*x2^2*y1+16*y2^2*f1*f0*f6^2*x3*x2+16*f3*f0*f6*x3*x2*y2^2*f4-4*x1*f1^2*f3*x2*y2^2*f6-8*y2^2*f1*f0*f6*x1^2*f3-4*y2^2*f2*f6*x1^2*f1^2+16*y2^2*f0*f6*x1^2*f2^2+8*y2^2*f1*f0*f6*x3*f5*x1-4*x2^2*f6*f1^2*y2*f3*y1+16*y2*f1*f0*f6^2*x3^2*y1+16*y2*f5*f0^2*x1^2*f4*y1-16*y2*f0^2*f6*x1^2*f3*y1+16*y2*f0*f5*x1^2*f2^2*y1-4*f5*x1^2*f1^2*y2*f2*y1+16*y2*f0*f6*x1^2*f1*f2*y1+16*f2*f0*f6*x2^2*y2*f3*y1-2*x1*f1^2*f3*x2*y2*f5*y1+32*y2*f0*f6*x2*f2^2*x1*y1+8*y2*f0*f5*f2*x2*x1*f3*y1-8*y2*f2*x2*f6*f1^2*x1*y1+16*f4*f0*f6*x3^2*y2*f3*y1+4*y2*f0*f5*x3*f3^2*x1*y1+16*y2*f0*f6*x3*f3*x1*f2*y1+16*f3^2*f0*f6*x3*x2*y2*y1+8*y2*f1*f5*f0*f6*x3*x2*y1+16*y3^2*f1*f0*f6^2*x2*x1+32*f0*f6*x1^2*f2*y3^2*f4-32*y3*f2*f0*f6^2*x3^2*y1+16*f1*x3^2*f6*f4^2*y3*y2+8*y3*f0*f5*f3*x3*x1*f4*y1-8*f0*f6*x2^2*f3*y3^2*f5+16*y3*y2*f1^2*f6^2*x3*x2+16*f0*x1*f6*f3*x3*y3*y2*f4-32*y3*f0^2*f6*x1^2*f4*y1+8*y3*f1*f0*f6*x1^2*f3*y1-8*y3^2*x2*f5*f1*x3*f6*f3-4*f0*f5^2*x2^2*y3^2*f4+8*y3^2*f1*x3^2*f6*f4*f5+16*f4*f0*f6^2*x3^2*y3^2-4*f0*f5^2*x3^2*y3^2*f6-4*f2*f5^2*x3^2*y3^2*f4+16*f2*x3^2*f6*f4^2*y3^2-16*y3^2*f0*x3*f6^2*f3*x2+16*y3^2*f2*x2*f6^2*f1*x3+8*f6*x3*f3*x1*f1*y3^2*f4-32*y3^2*f0*f2*f6^2*x3*x1+8*y3^2*f0*f5*x1*f6*f3*x3+16*y3^2*f0*f5*f4*f6*x3*x2+16*f0*x1*f6*f2*x2*y3*f3*y1+8*f0*f6*x2^2*f3^2*y3*y1-2*x1^2*f5*f1^2*y3*f3*y1+8*f0*f5*x1^2*f2*y3*f3*y1-16*y3*f0*f4*f1*f6*x2*x1*y1+16*y3*f0^2*f6*x2*f5*x1*y1+4*f0*f5*x1*f3^2*x2*y3*y1+8*y3*f1*f5^2*f0*x2*x1*y1+8*f1*x3^2*f6*f4*y3*f3*y1+8*y3*f0*f5*f3*f6*x3^2*y1+32*y3*f0*f4*f2*f6*x3*x1*y1-16*y3*f0*f5^2*f2*x3*x1*y1-16*y3*x3*f6*f4*x1*f1^2*y1+32*y3*f0^2*f6^2*x3*x1*y1-8*y3*f0*f6*x3*f3^2*x1*y1+8*y3*f5^2*x3*x1*f1^2*y1+16*y3*f1*f0*f6^2*x3*x2*y1+8*y3*x2*f6*f1^2*x3*f5*y1+4*x2*f6*f1*x3*f3^2*y3*y1-16*y3*y2*f2*f5*f0*f6*x3*x1+16*y3*y2*f2*f0*f6*x1^2*f3-4*y3*y2*f0*f5^2*f3*x2^2+16*f0*f6*x2^2*f3*y3*y2*f4+16*y3*y2*f0*f3^2*f6*x2*x1+16*y3*y2*f0*f5*f4*f6*x3^2-2*y3*x2*f5^2*f1*x3*y2*f3+4*y3*x1*f1*f3^2*x3*y2*f6+16*y3*y2*f1*f0*f6^2*x3*x1+8*y3*y2*x3*f6*f5*x1*f1^2-8*f0*x2*f5^2*x3*y3*y2*f4-8*y3*y2*f0*f5*f3*f6*x3*x2+8*x2*f6*f1*x3*f3*y3*y2*f4+32*f0*f6*x3*f4^2*x2*y3*y2-4*y4*f5*x2*f1^2*x1*y1+16*y4*f2*f0*x1^2*f4*y1+16*y4*f2*f0*f6*x2^2*y1+16*y4*f2*f0*x2*f5*x1*y1+8*y4*f3*f0*x3*f5*x1*y1+16*y4*f3*f0*f6*x3*x2*y1+8*y2*y4*f0*f6*x2^2*f3-4*y2*y4*x2*x1*f6*f1^2+8*y2*y4*f0*f5*x1^2*f2+4*y2*y4*f0*f5*x1*f3*x2+16*y2*y4*f0*x1*f6*f2*x2+8*y2*y4*f1*x3^2*f6*f4+16*y2*y4*f0*f6*x3*f4*x2+8*y2*y4*f0*x1*f6*f3*x3+2*y2*y4*f5*x3*f3*x1*f1+16*y3*y4*f0*f6*x1^2*f2+16*y3*y4*f0*f6*f4*x2^2+8*y3*y4*f6*x3*f3*x1*f1-2*h0*h2^2*x1^2*y3*y2*f0*f6*h1-2*f0*x2*f5*y1*h1*h3*y3*x4+h0*h2^2*y3^2*x3*x2*f3*f5*h3-2*h0*h2*x1*x4*y3*f5*f1*y1-4*h0*h2*y3*x4*x3*y2*f6*f3+2*h1^2*h3*y3*x1*y2*x3*f2*f6*h0+3*h1*h3*x1^2*y3*y2*f1*f6*h0^2+y3^2*x3^2*f2^2*h3^4+x1^2*y1^2*f4^2*h0^4+x1^2*y3^2*h0^4*f6^2+x3^2*y1^2*f0^2*h3^4+x1^2*y3^2*f0^2*h3^4+y3^2*x3^2*h1^4*f6^2+x1^2*y1^2*h2^4*f0^2+y2^2*x2^2*f0^2*h3^4+x3^2*y1^2*h0^4*f6^2+y2^2*x2^2*h0^4*f6^2+2*h1*h3^2*y2^2*f0*f5*x2^2*h0-2*y4*x1*x4*y1*f0*h1*h3+8*y3*x3*x2*y2*f0*f4^2*h3^2-8*y3*x3^2*y2*f0*f6^2*h1*h2-y3*x3^2*y2*f0*h3^4*f3+5*y3*x3*x2*y2*f1*f5^2*h0*h3-2*y3*x2^2*y2*f0*f5*h2^2*h3*h1-2*y3*x3*x2*y2*f5*h0^2*h2*h3*f4+2*y3*x3*x2*y2*h0^2*f4*h2^2*f6+16*y3*x3*x2*y2*f1*h0*h1*f6^2+8*y3*x3*x2*y2*f1^2*f6*h3^2-4*y3*x1*y2*x3*f2*f5*h0^2*f6-2*y3*
    x3*y2*f1*f6*h2^3*h0*x1+4*y3*x1*y2*x3*f1^2*f6*h2*h3-2*x3*x2*y3*y1*f0*f2*h2*h3^3-8*x3*x2*y3*y1*f0*f2*h2*h3*f6-2*x1^2*y3*y2*h1^2*h2*f1*h0*f6-2*x3*x2*y3*y1*f5*h0^3*h2*f6-4*y3*x3*x2*y2*f0*f5*h1*h2*f6-2*y3*x2*y2*f4*f6*h0^3*h2*x1+2*y3*x3*x2*y2*f0*h2^2*h3^2*f4-2*y3*x2*y2*f0*f6*h2^3*h0*x1+4*y3*x1*y2*x3*f0*f6*h2^2*f3+4*y3*x2^2*y2*f0*f5^2*h0*h3+y3*x1*x2*y2*f6*h0^3*h1*f5+3*y3*x2^2*y2*f0*f5*h2*h3^2*h0-4*y3*x2^2*y2*f0*f5*h2*h3*f3+y3*x3*x2*y2*f0*f5*h2*h3^2*h1+4*y3*x1*x2*y2*f0*h0^2*f6*h3^2+2*y3*x1*x2*y2*f0*f1*h3^2*f5+2*y3*x2^2*y2*f0*f6*h2^3*h1-2*y3*x2^2*y2*f4*f6*h0^3*h3-y3*x2^2*y2*f5*h0^2*h2*h3*f3+2*y3*f2*f5^2*x3^2*h0*h3*y2-2*y3*x3*x2*y2*f5^2*h0^2*f4+2*y2*y4*x3^2*f1*f6*h2^2-2*x1^2*y3*y2*h1*h2*f1^2*f6-4*y3*x3^2*y2*f6^2*h0^2*f3+4*y3*x3*x2*y2*f3*f6*h0*h1*f4+4*y3*y4*x3^2*f2*f6*h2^2+2*x1^2*y3*y2*f0*f6*h0^2*h2*h3+8*x1^2*y3*y2*f0*f2*f6*h1*h2+x1^2*y3*y2*f0*f5*h3^2*h0^2+2*y3*x1*x2*y2*f0^2*h3^4+8*x1^2*y3*y2*f0^2*f6*h2*h3+4*x1^2*y3*y2*f2*f6*h0^2*f3+4*x1^2*y3*y2*f0*f6*h1^2*f3+x1^2*y3*y2*f0*h1^2*h3^2*f3+4*x1^2*y3*y2*f0*f2*h3^2*f3-3*y3*x1*x3*y1*f6*h0*h1^2*h3*f1-2*y3*x1*x3*y1*f6*h0*h1*h2^2*f1-4*y3*x1*x3*y1*f1^2*h3^2*f4-4*y3*x1*x3*y1*f1^2*f6*h2^2-y3*x1*x3*y1*f2*f3*h3^2*h0*h1+4*y3*x1*x3*y1*f2*f6*h1*h2*f1+4*y3*x1*x3*y1*f2*f6*h0*h3*f1+8*y3*x1*x3*y1*f4*f6*h1^2*f0+2*y3*x1*x3*y1*f6*h0*h2^3*f0+2*y3*x1*x3*y1*f2*h1*h3^3*f0+2*y3*x1*x3*y1*f6*h1^3*h3*f0-2*y3*x1*x3*y1*f1*h0*h1*h3^2*f4-y3*x1*x3*y1*f1^2*h3^3*h1-2*y3*x1*x3*y1*f6*h0^2*f3^2-8*y3*x1*x3*y1*f0*f6*h0*h1*h2*h3+y3*x1*x3*y1*h3^2*h0^2*f3^2-4*y3*x1*x3*y1*f5^2*h0^2*f2-16*y3*x1*x3*y1*f0*f5*h2*h3*f2+16*y3*x1*x3*y1*f0^2*f6*h3^2-2*y3*x1*x3*y1*f5*h0^2*h2*h3*f2+y3*x1*x3*y1*f2*h0*h3^3*f1-2*y3*x1*x3*y1*f2*f6*h1^2*h2*h0+4*y3*x1*x3*y1*f2*f3*f6*h0*h1-y3*x1*x3*y1*f2*h3^2*h1*h2*f1+y3*x1*x3*y1*f6*h1^3*h2*f1+2*y3*x1*x3*y1*f3*f6*h1^2*f1+2*x3*x2*y3*y1*f0*f6*h2^3*h1+x3*x2*y3*y1*h0*h1*h3^2*f3^2+x3*x2*y3*y1*f0*h2^2*h3^2*f3+2*x3*x2*y3*y1*f1^2*h3^2*f5+2*y3*x1*x2*y2*h0^4*f6^2-8*x3*x2*y3*y1*f0*f5*h0*h2*f6+2*x3*x2*y3*y1*f1*h0*h1*h3^2*f5+4*x3*x2*y3*y1*f0*f6*h2^2*f3+8*x3*x2*y3*y1*f0*f4*f6*h1*h2+x3*x2*y3*y1*f1*f0*h3^4-2*y3*x2*f5*f1*f3*y1*h1*h3*x3+x3*x2*y3*y1*f1*h0^2*f6*h3^2+4*x3*x2*y3*y1*f1*h0^2*f6^2+8*y3*x1*x3*y1*f4*f6*h0*h2*f0-y3*x2*y1*f3*f5*h0*h1^2*h3*x3-y3*x2*y1*f1*f5*h1^2*h2*h3*x3+x3*x2*y3*y1*f1*h3^2*f3^2-4*x3*x2*y3*y1*f6*h0^2*h1*f3*h3+2*x3*x2*y3*y1*h0*h1*f0*f6*h3^2+8*x3*x2*y3*y1*h0*h1*f0*f6^2+4*x3*x2*y3*y1*f1*f6*f3*h1*h2+y3*x1*y2*x3*f6*h0*h1^2*f3*h2+2*y3*x1*y2*x3*f6*h0*h1*f3^2+y3*x1*y2*x3*f1*f6*h1^2*h2^2+2*y3*x1*y2*x3*h0^3*h1*f6^2+y3*x1*y2*x3*f1*h3^2*f3^2+2*y2*y4*x2^2*f3*f6*h0^2+y3*x1*y2*x3*f4*h0^2*h3^2*f3-2*y3*x1*y2*x3*f0*f6*h1^2*h3*h2-2*y3*x1*y2*x3*f4*f6*h0^2*h1*h2+4*y3*x1*y2*x3*f0*f4*h3^2*f3+y3*x3^2*y2*f0*f5*h1*h3^3+4*y4*x2^2*y1*f0*f6*h1^2-y3*x3^2*y2*f1*f3*h2*h3^3+2*y3*x3^2*y2*f0*f4*h2*h3^3+4*y3*x3^2*y2*f0*f5*h2^2*f6-2*y3*x3^2*y2*f1*f3*f5*h3^2-4*y3*x3^2*y2*f1*f3*h2*h3*f6-4*y3*x3^2*y2*f1*f5*h1*h2*f6+4*y3*x1*y2*x3*f1*h0^2*f6^2+4*y3*y4*x1^2*f2*f6*h0^2-8*y3*y2*f1*x3*f6*f4*h0*h2*x1+2*y3*x1*y2*x3*h0*h1*f0*f6*h3^2+8*y3*x1*y2*x3*h0*h1*f0*f6^2+y3*x3^2*y2*f5*h0^2*h2^2*f6+2*y3*x3^2*y2*f0*h2^3*h3*f6+y3*x3*x2*y2*f3*h0*h1*h3^2*f4+3*y3*x3*x2*y2*f5^2*h0^2*h1*h3-y3*x3*x2*y2*f1*f5^2*h1*h2-12*y3*x3*x2*y2*f1*f6*h0*h3*f4+y3*x3*x2*y2*f3*f6*h0*h1*h2^2+4*y3*x3*x2*y2*f1*f6*h1*h2*f4-8*y3*x3*x2*y2*f0*f5*h2*h3*f4-2*y3*x3*x2*y2*f0*f5^2*h2^2+4*y3*x3*x2*y2*f1*f5*h2*h3^2*h0-2*y3*x3*x2*y2*f1*f5*h2*h3*f3-y3*x3*x2*y2*f5*h0*h1*h2*h3*f3-y3*x3*x2*y2*f1*f5*h2^2*h3*h1+2*y3*x1*y2*x3*f0*f5*h2*h3^2*h0-8*y3*x1*y2*x3*f0*f5*h0*h2*f6-2*y3*x1*y2*x3*f0*f2*h2*h3^3-8*y3*x1*y2*x3*f0*f2*h2*h3*f6+2*y3*x1*y2*x3*f1^2*h3^2*f5+8*y3*x1*y2*x3*f1*f6*h0*h1*f5+2*y3*x1*y2*x3*f1*h0*h1*h3^2*f5+y3*x1*y2*x3*f1^2*h3^3*h2+4*y4*x3^2*y1*f0*f6*h2^2-3*y3*x3*x2*y2*f1*h0*h3^3*f4+2*y3*x3*x2*y2*f1*f3*f6*h2^2-5*y3*x3*x2*y2*f1*f6*h0*h3*h2^2+4*y3*x3*x2*y2*f1*f6*h0*h3^2*h1+y3*x3*y2*f1*f5*h2^2*h3*h0*x1-2*y3*x1*y2*x3*f5*h0^3*h2*f6+y3*x3*x2*y2*f1*h1*h2*h3^2*f4+4*y3*x1*x2*y2*f6*h0^2*f3^2-8*y3*x1*x2*y2*f0*f6*h0*h1*h2*h3+y3*x1*x2*y2*f6*h0^2*f3*h1*h2+16*y3*x1*x2*y2*f0*h0^2*f6^2+16*y3*x1*x2*y2*f0*f6*f3*h1*h2-y3*x2*y2*f1*f3*h3^2*h0*h2*x1+5*y3*x1*x2*y2*f0*f5*h0*h3^2*h1+5*y3*x1*x2*y2*f6*h0^2*h2*h3*f1+y3*x2*y2*f0*f5*h2^2*h3*h0*x1+y3*x1*x2*y2*h3^2*h0^2*f3^2+4*y3*x1*x2*y2*f0*f1*f6*h2*h3+4*y3*x2^2*y2*f0*f4*h3^2*f3+y3*x2^2*y2*f6*h0^2*h2^2*f3+2*y3*x2^2*y2*f0*f4*h3^2*h1*h2+y3*x2^2*y2*f4*h0^2*h3^2*f3-2*y3*x2^2*y2*f0*f4*h3^3*h0+4*y3*x2^2*y2*f0*f6*h2^2*f3+4*y3*x2^2*y2*f4*f6*h0^2*f3+16*y3*x1*x2*y2*f0^2*f6*h3^2-3*y3*x2*y2*f1*f6*h1*h2^2*h0*x1-8*f0*f6*x2*y3*y2*f4*h0*h2*x1-6*y3*y2*f3*x2*f6*f1*h0*h2*x1+2*y3*x3^2*y2*f5^2*h0*h1^2*h3+4*y3*x3^2*f6*f3^2*h0*h3*y2-y3*x3^2*y2*f1*f5*h2^3*h3-2*y3*x3^2*y2*f0*f5*h2^2*h3^2-6*y3*x3^2*y2*f0*f5^2*h2*h3-y3*x3^2*y2*h0^2*f5^2*h2*h3-2*y3*x3^2*y2*f6^2*h0^2*h1*h2-8*y3*x3^2*y2*f0*f6*h3^2*f3-2*y3*x3^2*y2*f5*h0*h1*h2*h3*f4+8*y3*x3^2*y2*f2*h0*h1*f6^2+8*y3*x3^2*y2*f2*f1*f6*h3^2-2*y3*x3^2*f2*f6*h2^2*h0*h3*y2+2*y3*x3^2*y2*f2*h0*h1*f6*h3^2+y3*x1*y2*x3*h0*h1*h3^2*f3^2-y3*x3*x2*y2*f5^2*h0*h1*f3+2*y3*x3^2*y2*h0*h1*h3^2*f4^2+8*y3*x3^2*y2*f6*h0*h1*f4^2+8*y3*x3^2*y2*f1*f6*f4*h2^2+y3*x3^2*y2*f1*h3^2*f4*h2^2+y3*x3^2*y2*f1*f6*h1^2*h3^2+x3*x2*y3*y1*f1^2*h3^3*h2-2*y3*x3^2*y1*h0^3*h2*f6^2+2*y3*x1*x3*y1*f3*f5*h0^2*f4+y3*x3^2*y1*f3*h0^2*h2*h3*f6+y3*x2^2*y1*f0*f1*h3^3*h2-8*y3*x3^2*y1*h0^2*f2*f6^2-3*y3*x3^2*y1*f1*f6*h0*h3*h2^2+8*y3*x3*x2*y2*h0^2*f4^2*f6-y2*y4*x1*x2*f1^2*h3^2+2*y3*x3*x2*y2*h0^2*f4^2*h3^2-y3*x1*x3*y1*f5^2*h0^3*h2+4*y3*x1*x3*y1*f2*f6*h0^2*h3*h1+4*y4*x1^2*y1*f0*f4*h1^2+y3*x3*x2*y2*f0*f5*h0*h3^3+4*y3*x1*x2*y1*f0*f5*f3*h1*h2+y3*x1^2*y1*f0*f3*h2*h3*h1^2+8*x3*x2*y3*y1*f1*f0*f6*h3^2+y3*x3*x2*y2*f5*h0^3*h3*f6-4*x3*x2*y3*y1*f0*f5*h1^2*f6-3*y3*x3*x2*y2*f5*h0^2*h1*h2*f6-y3*x1^2*y1*f0*f1*h3^2*h1*h2+y3*x1^2*y1*f0*h0*h1*h3^2*f3+4*y3*x1^2*y1*f5*h2*h3*f0*h0^2-2*y3*x3*x2*y2*f3*f5*h0^2*f6+4*y3*x1*x2*y1*f5^2*h0*h1*f0-2*y3*x3*x2*y2*f0*h0*h2*f6*h3^2-16*y3*x1*x3*y1*f1*f6*h0*h1*f4+2*y3*x1*x3*y1*f2*f3*h3^2*f1+4*y3*x2^2*y1*f0*f1*f6*h2*h3-4*y3*x1*x2*y1*f0*f1*f6*h2^2-4*y3*x1*x3*y1*f0*f5^2*h0*h2-y3*x1^2*y1*f5*h1*h2*f1^2+2*y3*x1^2*y1*f5*h0^2*h3*f1*
    h1+2*y3*x1^2*y1*f3*f5*h0^2*f2+2*y3*x1^2*y1*f0*f3*f5*h1^2+3*y3*x1^2*y1*f5*h0*h3*f1^2-2*y3*x1^2*y1*f3*f5*f1*h0*h1+4*y3*x1^2*y1*f0*f1*f6*h1*h2+y3*x1^2*y1*f5*h0^2*h1*h2*f2+y3*x1^2*y1*f1*f6*h0^3*h3+2*y3*x1^2*y1*f1*f6*h0^2*f3-4*y3*x1^2*y1*f0*f5*h0*h3*f2+4*y3*x1^2*y1*f0*f3*h2*h3*f2+4*y3*x1^2*y1*f0*f5*h1*h2*f2+4*y3*x3^2*y1*f0*f5*h1*h2*f6-12*y3*x1*x3*y1*f0*f6*f3*h0*h3+4*y3*x1^2*y1*f0*f6*h0*h1*f3+y3*x3^2*y1*f0*f3*h2*h3^3+8*y3*x1^2*y1*f5^2*f0*h0^2+y3*x1*x2*y1*f5^2*h0^3*h1+16*y3*x1^2*y1*f5*h2*h3*f0^2+y3*x2^2*y1*f6*h0^2*h2*h3*f1+8*y3*x1*x3*y1*f5*h2*h3*f1^2+2*y3*x3*x2*y2*f0*h2^4*f6-x3*y2*y4*x2*f5^2*h0^2-2*y3*x3^2*y1*h0^2*f2*f6*h3^2+x1*x3*y3^2*f3*h0^2*h2*h3*f6+x1*x3*y3^2*f5*h0^3*h3*f6-x1*x3*y3^2*f0*f5*h2*h3^2*h1+4*x1*x3*y3^2*f0*f5*h1*h2*f6+x1*x3*y3^2*f0*f3*h2*h3^3+y3^2*x3*x2*f1*f6*h1^2*h3^2+8*y3^2*x3*x2*f1*f6*f4*h2^2+8*y3^2*x3*x2*f6*h0*h1*f4^2-y3^2*x3*x2*f1*h3^3*f4*h1-2*y3^2*x3*f2*f6*h2^2*h0*h3*x2-2*f0*f5^2*x1*y3^2*h1*h3*x3+4*y3^2*f3^2*x3*f6*h0*h3*x2-2*y3^2*x3*f2*f4*h3^3*h0*x2-8*x1*x3*y3^2*f0*h0*h2*f6^2+x1*x3*y3^2*f1*f6*h1*h2^3+16*x1*x3*y3^2*f1*h0*h1*f6^2-16*x1*x3*y3^2*f0*f2*f6*h3^2+2*x1*x3*y3^2*f0*f3*f5*h3^2+x1*x3*y3^2*f3*h0*h1*h3^2*f4+x1*x3*y3^2*f0*f5*h0*h3^3+4*x1*x3*y3^2*f0*f5*h0*h3*f6-x1*x3*y3^2*f1*h0*h3^3*f4+2*x1*x3*y3^2*f1*f3*h3^2*f4+4*x1*x3*y3^2*f1*f6*h1*h2*f4-4*x1*x3*y3^2*f1*f6*h0*h3*f4+y3^2*x3*x2*f0*f5*h1*h3^3+4*y3^2*x3*x2*f0*f5*h1*h3*f6+2*y3^2*x3*x2*f0*f4*h2*h3^3+4*y3^2*x3*x2*f0*f5*h2^2*f6-4*y3^2*x3*x2*f3*f5*h0*h1*f6-2*y3^2*x3*x2*f5*h0*h1^2*h2*f6-3*y3^2*x3*x2*f3*f5*h0*h1*h3^2-8*y3*x1^2*y1*f0^2*h3^2*f4-8*y3*x1^2*y1*f0^2*f6*h2^2+4*y3^2*x3*x2*f4*f5*h0^2*f6+8*y3*x3^2*y1*f1^2*f6*h3^2+2*y3^2*x3*x2*f0*h2^3*h3*f6+2*y3*x1*x3*y1*f0^2*h3^4+y3^2*x3*x2*f5*h0^2*h2^2*f6-2*y3*x1^2*y1*f6*h0^4*f4+y3^2*x3*x2*f4*f5*h0^2*h3^2-y3^2*x3*x2*f1*f5*h2^3*h3-6*y3^2*x3*x2*f0*f5^2*h2*h3+2*y3^2*x3*x2*h0*h1*h3^2*f4^2-2*y3^2*x3*x2*f5^2*h0*h1*f4+3*y3^2*x3*x2*f1*f5^2*h1*h3-8*y3^2*x3*x2*f0*f6*h3^2*f3-2*y3^2*x3*x2*f0*f5*h2^2*h3^2-8*y3^2*x3*x2*f0*f6^2*h1*h2-2*y3*x3^2*y1*f0*h0*h2*f6*h3^2-8*y3*x3^2*y1*f0*h0*h2*f6^2-y3*x3^2*y1*f5*h0*h1*h2*h3*f3-16*y3*x3^2*y1*f0*f2*f6*h3^2+y3*x3^2*y1*f3*f6*h0*h1*h2^2+2*y3*x3^2*y1*f1*f3*h3^2*f4+4*y3*x3^2*y1*f1*f6*h1*h2*f4-4*y3*x3^2*y1*f1*f6*h0*h3*f4+2*y3*x3^2*y1*f1*f3*f6*h2^2+y3*x3^2*y1*f1*h1*h2*h3^2*f4+y3*x3^2*y1*f1*f6*h1*h2^3+2*y3*x1*x3*y1*f0*f3*f5*h2^2+8*y3*x1*x3*y1*f2*f4*f6*h0^2-4*x3*x2*y3*y1*f2*f5*h0^2*f6+8*y3*x1*x3*y1*f2*f4*h3^2*f0-y3*x2*y1*f1*f3*h2^2*h3*h0*x1+2*y3*x1*x2*y1*f0^2*h3^3*h2-4*x3*x2*y3*y1*f0*f2*f5*h3^2+x3*x2*y3*y1*f1*f6*h1^2*h2^2+2*x3*x2*y3*y1*f0*f5*h2*h3^2*h0+2*y3*x3^2*y1*f1*f5*h2*h3^2*h0-y3*x3^2*y1*f1*f5^2*h1*h2-3*y3*x1*x3*y1*f0*h3^3*f3*h0+2*x3*x2*y3*y1*f6*h0*h1*f3^2-3*y3*x1*x3*y1*f6*h0^3*f3*h3+4*y3*x1*x3*y1*f0*f5*h0*h3*f4+4*y3*x1*x3*y1*f0*f3*h2*h3*f4+4*y3*x1*x3*y1*f0*f5*h1*h2*f4-3*y3*x1*x3*y1*f0*f5*h0*h3*h2^2+y3*x1*x3*y1*f5*h0^3*h3*f4-2*y3*x1*x3*y1*f0*f5*h1^2*h2*h3-2*y3*x3*x2*y2*f0*h1*h2^2*h3*f6+y3*x1*x3*y1*h2^2*h3^2*f1^2+4*y3*x1*x3*y1*f5*h2*h3*f1*h0*h1-4*y3*x1*x3*y1*f0*f5^2*h1^2-2*y3*x1*x3*y1*f0*h1*h2^2*h3*f4+4*y3*x1*x3*y1*f0*h0*h2*h3^2*f4+y3*x1*x3*y1*f5^2*h0^2*h1^2-y3*x1*x3*y1*f5*h0^2*h1*h2*f4+2*y3*x3^2*y1*f3*f5*h0^2*f6+y3*x3^2*y1*f5*h0^3*h3*f6+y3*x3^2*y1*f3*h0*h1*h3^2*f4+4*y3*x3^2*y1*f3*f6*h0*h1*f4+y3*x3^2*y1*f0*f5*h0*h3^3+2*y3*x3^2*y1*f0*f3*f5*h3^2+y3*x1*x3*y1*f0*f3*h2^3*h3+y3*x1*x3*y1*f0*f5*h1*h2^3+2*y3*x2^2*y1*f0*f6*h1^2*h2^2-y3*x2^2*y1*f6*h0^3*f3*h3+y3*x1*x2*y1*f1*h2^2*h3^2*f0+8*y3*x2^2*y1*f0*f6*f3*h1*h2-4*y3*x2^2*y1*f0*f6*f3*h0*h3-y3*x2^2*y1*f1*f3*h2*h3^2*h0-2*y3*x2*f5*f1*f3*y1*h0*h2*x1-y3*x2*y1*f1*f5*h1*h2^2*h0*x1+y3*x2^2*y1*f6*h0^3*h1*f5+2*y3*x2^2*y1*f0*f1*h3^2*f5+y3*x1^2*y1*f6*h0^3*h1*f3+y3*x1^2*y1*f0*f1*h3^3*h0+2*y3*x1^2*y1*f0*f1*h3^2*f3-2*y3*x1^2*y1*f0*f6*h0^2*h1*h3+y3*x1*x2*y1*f0*h2^2*h3*f3*h1+8*y3*x1*x2*y1*f0*f6*h0^2*f5+y3*x1*x2*y1*f0*f5*h3^2*h0^2-2*y3*x1^2*y1*f0*f6*h0^2*h2^2-2*y3*x1^2*y1*f0*h0^2*h3^2*f4-4*y3*x1*x2*y1*f0*f6*h1^2*h0*h3+2*y3*x1*x2*y1*h0^2*h3*f1*h1*f6-4*y3*x1*x2*y1*f1*f6*h0^2*f4+2*y3*x1*x2*y1*f0*h1^2*h3^2*f3+4*y3*x1*x2*y1*f0*f2*h3^2*f3+8*y3*x1*x2*y1*f0*f2*f6*h1*h2+y3*x1*x2*y1*f2*h0^2*h3^2*f3+8*y3*x1*x2*y1*f0^2*f6*h2*h3-2*y3*x1*x2*y1*f6*h0^3*h1*f4+4*y3*x1*x2*y1*f0^2*h3^2*f5+y3*x1*x2*y1*f6*h0^4*f5-2*y3*x1*x2*y1*f0*f1*h3^3*h1-4*y3*x1*x2*y1*f0*f1*h3^2*f4-8*y3*x1*x2*y1*f0*f6*h0*h1*f4-4*y3*x1*x2*y1*f0*h2*h3^2*f3*h0+y3*x1*x2*y1*f5*h0^2*f3^2+8*y3*x1*x2*y1*f1*f5*h2*h3*f0+2*y3*x1*x2*y1*f1*f5^2*h0^2+2*y3*x1*x2*y1*f1*f5*h2*h3*h0^2+4*y3*x1*x2*y1*f2*f6*h0^2*f3+y3*x1*x2*y1*h0^2*h2*h3*f3^2-2*h0*h2*y3*x3*x2*y2*f2*f4*h3^2-h0^2*h3^2*y2^2*x3*f5*x2*f2+h1*h3*y3*x3^2*y2*f5*f6*h0^2-8*y3*x2*f6*f1*x3*f4*h0*h2*y1+y3*x3*x2*f5*h2^2*h3*f1*h0*y1-y3*f5*x3*f3*h0^2*h2*y1*h3*x2-8*y3*f0*f6*f4*x2^2*h0*h2*y1-2*y3*x1^2*f6*f1^2*h0*h2*y1-2*y3*x2^2*f6*h2^3*f0*h0*y1-2*y3*x2^2*f6*f4*h0^3*h2*y1+y3*x2^2*f0*f5*h2^2*h3*h0*y1-x3*y2*x2*f1*h3^2*f3*h0*h2*y1-3*y3*x1*x3*y1*h3^2*h0*h2*f3*f1-2*y3*x3^2*h3^2*f2*f4*h0*h2*y1-2*y3*x3^2*f6*f2*h2^3*h0*y1-8*y3*f2*x3^2*f6*f4*h0*h2*y1+4*y3*x1*x3*y1*h0^2*h2*h3*f6*f1+4*y3*x1*x3*y1*f6*h0*h2*f3*f1+2*y3*f2*f5^2*x3^2*h0*h2*y1-2*y3*x1*x2*y1*f6*f0*h0*h1*h2^2+2*y3*x3^2*f5*h2^2*h3*f2*h0*y1+4*y3*f2*f6*x3^2*h0*h2*y1*h1*h3-4*y3*y4*x1^2*f1*f6*h0*h1+4*y3*y4*x1^2*f0*f2*h3^2+4*x3*y2*y4*x2*f0*f6*h2^2+x3*y2*y4*x2*f1*f3*h3^2+4*y3*y4*x3^2*f4*f6*h1^2+4*y3*y4*x1^2*f0*f6*h1^2+4*y3*y4*x1*x3*f1*f6*h1*h2+2*y3*y4*x1*x3*f1*f3*h3^2+4*y3*y4*x1*x3*f3*f6*h0*h1-8*y3*f2*f6*x3*y4*h0*h2*x1-2*y3*y4*x3*x2*f5^2*h0*h1-4*y3*y4*x3^2*f2*f5*h2*h3+4*y3*y4*x1*x2*f3*f6*h0^2-4*y3*x2*f1*f6*y4*h0*h2*x1-4*y3*y4*x3^2*f3*f6*h1*h2+4*y3*y4*x3^2*f2*f4*h3^2+4*y3*y4*x3*x2*f1*f4*h3^2+2*y3*f5*x3^2*f3*y4*h1*h3+4*x3*y2*y4*x2*f0*f4*h3^2+2*y2*y4*x1^2*f2*f5*h0^2+4*y2*y4*x1^2*f0*f2*h2*h3-2*y2*y4*x1^2*f1*f5*h0*h1-y2*y4*x1^2*f1^2*h2*h3+4*y4*x3^2*y1*f0*f4*h3^2+2*y4*x1*x3*y1*f3*f5*h0^2+4*y4*x1*x3*y1*f0*f3*h2*h3+x3*y2*y4*x1*f1*f5*h0*h3+x3*y2*y4*x1*f3*f5*h0*h1+x3*y2*y4*x1*f1*f5*h1*h2-2*y2*f0*f5*x1*y4*h1*h3*x3-2*y2*y4*x3^2*f1*f5*h2*h3+2*x3*y2*y4*x1*f3*f6*h0^2+2*x3*y2*y4*x2*f1*f6*h1*h2+2*x3*y2*y4*x1*f0*f3*h3^2+x3*y2*y4*x1*f1*f3*h2*h3+2*y2*y4*x1*x2*f0*f5*h1*h2+4*y2*y4*x1*x2*f0*
    f6*h1^2+2*y2*y4*x1*x2*f0*f3*h2*h3+4*y2*y4*x1*x2*f0*f2*h3^2+y2*y4*x1*x2*f3*f5*h0^2-3*y3*x1*x3*y1*h0^2*f5*f3*h1*h3+4*y3*x1*x3*y1*f0*f5*h0*h3^2*h1+2*x1^2*y1*f4*f1*h0*h1^2*h3*y3+4*x1^2*y1*f0*f4*h0*h2*h1*h3*y3-8*f2*f0*x2*f5*x1*y1*h1*h3*y3+x1*x2*y1*f1*h0*h1^2*f5*h3*y3+4*y3*x1*x3*y1*f0*f5*f3*h1*h3-2*f0*f5^2*x3^2*y1*h1*h3*y3+3*y3*x3^2*y2*f5^2*f1*h1*h3-3*y2*x1*x2*f0*f5*h1^2*h2*h3*y3-6*y3*x3*x2*y2*h0^2*f4*h1*h3*f6-3*y3*x3^2*y2*f1*f6*h1*h2^2*h3+y2*x1*x2*f6*f1*h0*h1^2*h3*y3-8*y2*f0*x1*f6*f2*x2*h1*h3*y3-y2*x1*x2*h0^2*f5*f3*h1*h3*y3-2*y2*x1*x2*h3^3*f0*f2*h1*y3-4*y3^2*x3^2*f6*f2*h1*h2^2*h3+2*y3^2*x3*x2*f5^2*h0*h1^2*h3-2*y2*x1*x2*f6*f0*h1^3*h3*y3+y3^2*x3^2*f5^2*h1^3*h3+y2*x1^2*f5*f1^2*h1*h3*y3+y3^2*x2^2*f5^2*h0^2*h3*h1-2*x2^2*y1*h3^3*f0*f2*h1*y3-8*f2*f0*f6*x2^2*y1*h1*h3*y3-f3*x1*f1*y1*h1*h3^2*y3*h0*x2-2*x2^2*y1*f6*f0*h1^3*h3*y3-2*x1*x2*y1*f0*f5*h1^3*h3*y3+2*y3^2*x3*x2*f2*h0*h1*f6*h3^2-2*x3*x2*y3*y1*f6*h1^2*h3*f0*h2-2*x1^2*y1*h0^2*f4*f2*h1*h3*y3-4*y2*f1*x3^2*f6*f4*h0*h2*y1-y2*x3^2*f1*h3^2*f4*h0*h2*y1-4*y2*x1*x3*y1*f0*h2*h3^2*f3*h0-x3*y2*x1*f1*h2^2*h3*f3*h0*y1+3*x1^2*y2*y1*f1^2*f5*h0*h2-3*x1^2*y2*y1*h1^2*h2*h0*f0*f5+y2*f1*x3^2*f5^2*h0*h2*y1-6*y2*x1*x2*y1*f0*h2*h3^2*f2*h0-2*x3*y2*x2*f6*h2^3*f0*h0*y1-8*y2*f0*f6*x3*f4*x2*h0*h2*y1-3*x3*y2*x2*f1*f6*h1*h2^2*h0*y1+x3*y2*x2*f0*f5*h2^2*h3*h0*y1-2*y2*f5*x3*f3*x1*f1*h0*h2*y1-x3*y2*x1*f1*f5*h1*h2^2*h0*y1-6*y2*x2*f6*f1*x3*f3*h0*h2*y1-2*x3*y2*x2*f6*f4*h0^3*h2*y1-y2*x1^2*f0*f5*h1^3*h3*y3+4*x1^2*y1^2*f4*f1^2*h0*h2+y2*x1^2*f1*h0*h1^2*f5*h3*y3-4*y2*f0*f5*x1^2*f2*h1*h3*y3+x1^2*y1^2*h2^3*f1^2*h0-y2*x1^2*h0^2*f5*f2*h1*h3*y3+x1^2*y1^2*h0^3*f3^2*h2-2*y2*f5*x3*f3*x1*f1*h1*h3*y3-4*y3*x1*y2*x3*h0^2*h1*f6*h3*f3-x3*y2*x1*h0*h1^2*f5*f3*h3*y3-x3*y2*x1*f1*f5*h1^2*h2*h3*y3+2*x1*x2*y1^2*f1^2*h2^2*h3*h0-y2*x3^2*f1*f6*h2^3*h0*y1+2*x1*x2*y1^2*f4*f0*h0^2*h2*h3-4*x1^2*y1^2*f0*f4*h0*h1^2*h2+x2^2*y1^2*h3^2*h0*h2*f1^2+8*y3*y4*x3*x2*f4*f6*h0*h1+4*y3*y4*x3*x2*f1*f6*h2^2+2*y3*f5*x3*f3*y4*h0*h3*x2+4*y3^2*x3^2*f5^2*f2*h1*h3-2*y3*x3*x2*f1*f6*h2^3*h0*y1-8*f2*f0*x1^2*f4*y1*h1*h3*y3-6*y2*f0*f5*x1*f3*x2*h1*h3*y3-2*x1^2*y1*f0*f4*h1^3*h3*y3+4*y3^2*x3^2*f3^2*f6*h1*h3+x2^2*y1*f6*f1*h0*h1^2*h3*y3+y3^2*x3^2*f3^2*h3^3*h1+y2*x3^2*f5*h2^2*h3*f1*h0*y1+2*f4*x1^2*f1^2*y1*h1*h3*y3+4*x1^2*y1^2*f0*f3^2*h0*h2+4*y3*x3^2*y2*f4*f5*h0^2*f6+y3*x1*x2*y2*f0*f1*h3^3*h2+4*y3*x3^2*y1*f1*f6*h0*h3^2*h1+4*x1^2*y1^2*f2^2*f0*h2^2-4*x1^2*y2*y1*f0*f5*f1*h1*h2-y3^2*x3*x2*h0^2*f5^3+y3^2*x3^2*f0*h2^2*f6*h3^2+4*x1*x3*y1^2*f0*f1*f6*h0*h3-2*x3^2*y1^2*f5^2*h0^2*f2+8*y2^2*x1*x2*f0^2*f6*h2*h3+8*x1^2*y2*y1*f0*f5*f2*h1^2-2*y3*x2^2*y2*f0*f6*h1^2*h3*h2-x3^2*y2^2*f5^2*h0^2*f4-4*y3^2*x3^2*f2*f5*h2*h3*f4+x1^2*y1^2*f2^2*h0^2*h2^2+4*y3*x3^2*y2*f0*f4*f5*h3^2+4*y4*x2^2*y1*f0*f2*h3^2+8*y2*x2^2*y1*f0*f6*h0^2*f5+8*y3*x2^2*y2*f0*f4*f6*h1*h2+8*x1^2*y3^2*f0^2*f6*h3^2+2*y2^2*x1*x2*f0*f6*h1^3*h2+x1^2*y2*y1*f0*f5*h1^4+4*y2^2*x1^2*f0^2*f6*h2^2+y3*x2^2*y2*f5^2*h0^3*h3-y2*x1*x2*y1*f3*h2*h3*f1*h0*h1-2*x1^2*y1^2*f4*h0^2*f1*f3-4*x1^2*y1^2*f0*f4*f1*h1*h2-3*y3*x1*x2*y1*f1*h0^2*h3^2*f4-4*x1^2*y1^2*f0*f3*h1*h2*f2+8*y2^2*x1*x2*f0*f6*h0^2*f5-4*y3^2*x3*x2*f1*f5*h2*h3*f4-2*y3*x3*x2*y2*f0*f5*h2^3*h3+4*y3^2*x2^2*f0*h1^2*f6^2-4*y3*y4*x2^2*f0*f5*h2*h3-3*x1*x2*y1^2*f1*h0^2*h2*h3*f3+x3^2*y2*y1*f6*h0^2*h2^2*f3+8*y3^2*x3^2*f2*h1^2*f6^2+x2*y1^2*f1*f5*h0*h1^2*h3*x3-2*x3^2*y1^2*f1^2*h3^2*f4-x1^2*y2*y1*f5*h0^3*h1*f3-x1^2*y1^2*f0*f3*h1^3*h2+x2^2*y1^2*f0*h0*h1*h3^2*f3-y3*x3^2*y1*f1*h0*h3^3*f4-4*y3*x1*y2*x3*f0*f6*h2^2*h0*h3+4*y4*x3*x2*y1*f0*f3*h3^2+8*x3*y2^2*x2*f1*f0*f6*h3^2+4*y3^2*x3^2*f0*h2^2*f6^2+4*y2*x3*x2*y1*f0*h0^2*f6*h3^2+8*y3*x1*y2*x3*f0*f4*f6*h1*h2+4*x1^2*y2*y1*f0*f1*f6*h0*h2-y3*f5*x3*f3*h0^2*h3*y2*h2*x1+x1^2*y3^2*f2*f4*h3^2*h0^2+y3*x1*y2*x3*f1*f0*h3^4+4*y3*x1*y2*x3*f1*f6*f3*h1*h2+2*x3*y2*y4*x2*f3*f6*h0*h1+y2^2*x3^2*f1*f5*h2*h3^2*h0+y3^2*x3*x2*f2*f1*h3^4-y2^2*x1^2*f0*f1*h3^2*h1*h2+4*y3*x1*x2*y2*f0*h3^2*f3^2+y3*x3^2*y2*f1*f6*h2^4-3*y3^2*x3^2*f1*f5^2*h2*h3+y2*x2^2*y1*f6*h0^4*f5+3*x1*x2*y1^2*f1^2*f5*h0*h2+2*y2*x3*x2*y1*f0^2*h3^4-4*y3^2*x3^2*f2*f3*f6*h2*h3-2*y3^2*x3*x2*f1*f3*f5*h3^2+4*y2^2*x1^2*f0*h3^2*f2^2+x1^2*y1^2*f6*h0^2*h1^2*f0-2*y2*x1*x2*y1*f6*h1^2*f1^2-x2^2*y1^2*f2*f5*h0^3*h3+8*y3*y4*x1*x2*f0*f6*h1*h2+4*x3*x2*y1^2*f0*f2*h3^2*f3+y3^2*x2^2*f0*h2^2*h3^2*f4-2*x3*y2^2*x2*f0*f4*h3^3*h0-2*x3^2*y1^2*f1^2*f6*h2^2-2*x1*x3*y3^2*f0*h1^2*f6*h3^2-8*y3*f2*x3^2*f6*f4*h0*h3*y2+2*x1^2*y1*f1*f4*h0^2*h1*h3*y2-2*x1*x2*y1^2*f0*h2^2*h3*f1*h1-x3*y2^2*x2*f5*h0^2*h2*h3*f3+4*y3*x2^2*y2*f1*h0^2*f6^2-2*y3^2*x3*f2*f6*h2^3*h0*x1+4*y2*x3*x2*y1*f0*h3^2*f3^2+y3*x2^2*y1*f0*f5*h0*h3^2*h1+2*y3*x2^2*y1*f6*h0^2*f3^2+4*y3^2*x3*x2*f1*h3^2*f4^2-y3*x3*x2*y2*f0*f3*h2*h3^3+y3*x1*x2*y2*f0*f3*h2*h3^2*h1+4*x1^2*y1^2*f2^2*h0^2*f4-4*y3*x3^2*y2*f1*f6*f4*h1*h3+2*y3*x1*x2*y1*f0*h2*h3*f3^2+8*y2^2*x2^2*f0^2*f6*h3^2+y3^2*x3^2*f4*h0*h1*h3^2*f5+y2^2*x1*x3*f0*f5*h0*h3^2*h1+2*x3*x2*y3*y1*h0^3*h1*f6^2-y3*x2^2*y1*f3*f5*h0^2*h1*h3-4*x1^2*y3*y2*f3*f1*h0*h1*f6-y3*y4*x2^2*f5^2*h0^2-4*y3^2*x2^2*f0*f5*h1*h2*f6-2*x1^2*y3^2*f0*f5^2*h1^2+x2^2*y1^2*f0*f6*h0^2*h2^2-4*y3^2*x3^2*f2*f6*h1*h2*f5+x3^2*y2^2*h0^2*h1^2*f6^2-2*x1^2*y2*y1*f6*f1*h0^2*h1^2+8*y3*x2^2*y2*h0*h1*f0*f6^2-3*y3*x1^2*y1*f0*f5*h0*h3*h1^2-y3^2*x2^2*f0*f3*h2*h3^3+16*y3*x3^2*y1*f1*h0*h1*f6^2-2*y3*x3^2*y1*f0*f2*h3^4+y3*x3*x2*y2*f1*f6*h1*h2^3-y3^2*x2^2*f0*f5^2*h2^2+4*y3*x3*x2*y2*h0^2*h1^2*f6^2-x1^2*y1^2*f0*h1*h3^2*f1*h0+y3^2*x1*x2*f1*h0^2*f6*h3^2+2*y3*x1*y2*x3*f0*f6*h2^3*h1+y3*x1*y2*x3*f0*h2^2*h3^2*f3-y4*x1^2*y1*f1^2*h2^2+x1*x3*y3^2*f3*f6*h0*h1*h2^2-y3*y4*x3^2*f3^2*h3^2-4*x1^2*y2*y1*f0^2*h3^2*f3+x1^2*y1^2*h1^2*h3^2*f0^2+4*y3*y4*x2^2*f0*f4*h3^2+2*x1^2*y2*y1*f6*h0^3*h1*f2+2*x1^2*y2*y1*h2^3*f0^2*h3+4*y2*x3*x2*y1*f6*h0^2*f3^2-y2^2*f5*x3*f3*x1*f1*h0*h3+4*x3^2*y2^2*h0^2*f2*f6^2+y2^2*x1*x3*h3^2*h0^2*f3^2-2*y3*x1*x2*y2*f1*h0^2*h3^2*f5-2*y3^2*x3^2*f1*f6*h3^2*h1*h2-2*x3*y2^2*x2*f0*f5^2*h1*h2+8*y3^2*x2^2*f0*f4*h2^2*f6-2*y3^2*x3*x2*f6^2*h0^2*h1*h2+y3*x1^2*y1*f0*f5*h1^3*h2-y3*y4*x3^2*f5^2*h1^2+y3*x2^2*y1*h3^2*h0^2*f3^2-2*x3*x2*y1^2*h1*h2*f1^2*f6-4*y3*y4*x3*x2*f1*f5*h2*h3-2*y3*x1*x2*y1*f0*f2*h3^2*h1*h2+2*f4*x1*f1^2*y1^2*h0*h3*x2+x1^2*y3*y2*f2*
    h0^2*h3^2*f3-x2^2*y1^2*f6*h0^3*h1*f3+y3*x3^2*y2*f4*f5*h0^2*h3^2+y2^2*x1^2*h3^2*h0*h2*f1^2+y3*x2^2*y1*f0*f3*h2*h3^2*h1-x3^2*y2^2*f0*f5^2*h2^2-y3*x2^2*y1*f0*h3^3*f3*h0-4*y3^2*x3*x2*f6^2*h0^2*f3+x3*x2*y1^2*f6*h0^4*f5+x3^2*y2*y1*f4*h0^2*h3^2*f3-4*y2*x1*x3*y1*f0*f1*f6*h2^2-2*x3*y2^2*x2*f4*f6*h0^3*h3-y3^2*x3^2*f2*f3*h3^3*h2-x2^2*y1^2*f6*h1^2*f1^2+4*x1^2*y1^2*f0^2*f6*h1^2-2*y3*x1*x3*y1*f6*h0^2*h1^2*f4+y3^2*x2^2*f1*f5*h2*h3^2*h0-4*y3*x3*x2*y2*f0*f3*h2*h3*f6-2*y3*x3*x2*y2*f0*f3*f5*h3^2-y2^2*x2^2*f5^2*h0^2*f2-4*x3*x2*y1^2*f3*f1*h0*h1*f6+2*x1*x3*y1^2*h2^2*h3^2*f0^2-2*y3*x1*x3*y1*f0*h3^2*f3^2+8*x3^2*y1^2*f4*f6*h1^2*f0+y2^2*x2^2*f2*f4*h3^2*h0^2+2*y2*y4*x3^2*f1*f4*h3^2+y2^2*x1^2*f0*f6*h0^2*h2^2+y2^2*x1^2*f6*h0^4*f4+y2*x1*x2*y1*f0*f5*h1^3*h2-2*x1^2*y3^2*f5^2*h0^2*f2+8*y4*x3*x2*y1*f0*f6*h1*h2-y4*x3^2*y1*f5^2*h0^2+x1^2*y2*y1*f4*h0^4*f5+8*x1^2*y1^2*f4*h2^2*f0^2-y3*x2^2*y2*f5^2*h0^2*f3+4*x1^2*y3*y2*f0^2*h3^2*f5+4*y2*y4*x3^2*f4*f6*h0*h1+4*y3*y4*x2^2*f4*f6*h0^2+x1*x3*y1^2*f1*f6*h0^3*h3-y3^2*x3^2*f3^2*f6*h2^2-8*y3*x1*x3*y1*f0*f6*f3*h1*h2-x1^2*y3^2*f0*h3^2*f3^2+3*y3*x3*x2*y2*f3*h0^2*h2*h3*f6-y3^2*x3^2*f3^2*h3^2*f4-x1^2*y3^2*f6*h0^2*f3^2+8*x1^2*y1^2*f4*h1*h3*f0^2+8*y3^2*x3*x2*f2*f1*f6*h3^2-8*y2*x2^2*y1*f0*f2*f6*h0*h3+y2^2*x1^2*f0*f6*h1^4-2*x1*x3*y1^2*f6*h0^4*f4+2*x1^2*y1^2*f4*h2^2*f0*h0^2+y3^2*x3^2*f1*h1*h3^3*f5+8*y2*x1*x2*y1*f6*h0^2*f2^2-x3*y2^2*x1*f3*f5*h0^2*h1*h3+4*y3^2*x3^2*f2*h3^2*f4^2-8*f0*f4*f2*x1*y1^2*h1*h3*x3+2*y3*x2^2*y1*f0*h3^2*f3^2+y3*x2^2*y2*f1*h0^2*f6*h3^2-y3*x1^2*y1*f3*h2*h3*f1*h0*h1+4*y2*x2^2*y1*f0^2*h3^2*f5+8*x1^2*y2*y1*f0*f6*h0*h1*f2-8*y3*x2^2*y2*f0*f4*f6*h0*h3-8*y3^2*x3^2*f1*f6^2*h1*h2-2*y3^2*x3^2*f6*h0*h1*h3^2*f3+2*y3^2*x3*x2*h1^3*h0*f6^2+2*y3^2*x3^2*f2*h1^2*f6*h3^2-4*y2^2*f0*f6*x2^2*f3*h0*h3+8*y4*x1*x2*y1*f0*f2*h2*h3-4*y3^2*x3*x2*f1*f3*h2*h3*f6+8*x1^2*y1^2*f0*f6*h0^2*f2+y3*x1^2*y1*f3*h0^2*h2*h3*f2+2*y3^2*x1*x2*h0^3*h1*f6^2+x1*y1^2*f3^2*h0^3*h3*x2+4*y3^2*x3^2*f1*f4*f6*h2*h3+2*y3^2*x1*x2*f0*f4*h3^2*h1*h2+2*y2*y4*x2^2*f0*f3*h3^2+2*y3^2*x3^2*f1*f4*h3^2*f5-4*y2^2*x2^2*f0*f5*h2*h3*f2+8*y3*x1*y2*x3*f1*f0*f6*h3^2-y4*x2^2*y1*f1^2*h3^2+y3^2*x3^2*f2*f6*h2^4+4*y4*x1*x3*y1*f0*f5*h1*h2-2*x1^2*y3^2*f1^2*h3^2*f4+4*y4*x2^2*y1*f2*f6*h0^2-2*x1^2*y1*f2*f4*h0^3*h3*y2+8*y3*x2^2*y2*f1*f0*f6*h3^2+y3*x2^2*y2*f1*f0*h3^4-y3*x2^2*y2*f0*h1*h3^3*f3+y3*x2^2*y1*f6*h0^2*f3*h1*h2+y2^2*x1^2*f0*h0*h1*h3^2*f3-4*y3*x3^2*y2*f3*f5*h0*h1*f6+2*y3^2*x3*x2*f6*h0*h1*f4*h2^2+4*y2^2*x1^2*f0^2*h3^2*f4-2*x3^2*y1^2*f0*f5^2*h1^2-x1^2*y2*y1*f6*h0^4*f3+4*y3*x3^2*y2*h1^2*f1*f6^2+y2*x1*x3*y1*f5*h0^2*f3^2+x1^2*y3*y2*f6*h0^4*f5+x1*x2*y1^2*f1*f6*h0^3*h2+4*y3*x3^2*y1*f0*f5*h0*h3*f6+8*x2^2*y1^2*f0*f6*f2*h1^2-2*y3*x3^2*y2*f5^2*h0*h1*f4-x3*x2*y1^2*f3*f1*h0*h1*h3^2-y3*x3^2*y1*f5*h0^2*h1*h2*f6+x1*x3*y1^2*f0*f3*h2*h3*h1^2-y3*x3^2*y2*f1*f5^2*h2^2+3*y3*x3^2*y1*f1*f5^2*h0*h3+8*y3*x3^2*y2*f0*f4*h2*h3*f6+y3^2*x3^2*h1^2*h3^2*f4^2-x1^2*y3*y2*f3*f1^2*h3^2-4*x1^2*y2*y1*f0*f5*h0*h1*f3-x1^2*y1^2*f3^2*h0^2*f2+y2^2*x1*x2*f0*h1^2*h3^2*f3-4*y3^2*x3*x2*f1*f5*h1*h2*f6+y2^2*x1*x2*f2*h0^2*h3^2*f3+8*y3^2*x3^2*f2^2*f6*h3^2+3*x1*x3*y3^2*f1*f5^2*h0*h3+2*x1*x3*y3^2*h0^2*h1^2*f6^2+4*x1^2*y2*y1*h2^2*f0^2*f5-2*x3*y2^2*f4*f6*h0^3*h2*x1+x1^2*y1^2*f6*h0^4*f2+4*y3^2*x2^2*h0^2*f4^2*f6+y3^2*x2^2*f5^2*f1*h0*h3+x2^2*y1^2*f0*f6*h1^4-2*y3*x3^2*y2*f5*h0*h1^2*h2*f6+x1^2*y1^2*f0*h1^2*h2^2*f2+y2*x2^2*y1*f0*f5*h3^2*h0^2+8*x1^2*y3^2*f0*h0^2*f6^2-y3^2*x3^2*f2*f5^2*h2^2+y3^2*x2^2*f0*f2*h3^4+2*y2^2*x1*x3*f1*f6*h0^2*f5+x2^2*y1^2*h2^2*h3^2*f0^2-y2^2*x2^2*f6*h0*h1*h2^2*f1-y3*x1^2*y1*f5*h1^2*h2*f1*h0-4*y3*x1*x3*y1*f1^2*f6*h1*h3+2*x3^2*y1^2*f5*h2*h3*f1^2-y2^2*x2^2*f1*h0*h1*h3^2*f4+2*x1^2*y2*y1*f4*f0*h0^2*h2*h3-x1^2*y1^2*f1*f4*h0*h1^3-y2^2*x2^2*f0*f5*h1^2*h2*h3+2*y3*x1^2*y1*h2^2*h3^2*f0^2-2*y2^2*x1*x2*f0*f2*h3^3*h0+y3*x3^2*f3^2*h3^3*h0*y2-x1^2*y3*y2*f3*f1*h0*h1*h3^2+x3*x2*y3*y1*f6*h0^2*h1^2*f5+2*y2^2*x1*x3*f6*h0^2*f3^2+4*x1*x3*y3^2*f0*f3*h2*h3*f6+4*y3*y4*x1*x2*f0*f3*h3^2+4*y2*x2^2*y1*f0*f2*h3^2*f3-6*f0*x2*f5*y2*f3*y1*h1*h3*x3+4*y4*x1^2*y1*f0*f2*h2^2+y3^2*x3^2*h0^2*h2^2*f6^2-4*y3*x3^2*y2*f1*f5*h2*h3*f4+2*y3^2*f2*f5^2*x3*h0*h3*x2-y3^2*x2^2*f1*f4*h3^3*h0-y3*x3^2*y1*f1*f5*h2^2*h3*h1-2*x1^2*y3^2*f1^2*f6*h2^2+2*y2*y4*x1^2*f0*f5*h1^2+8*y3^2*x1*x2*f0*f4*f6*h1*h2+8*x1^2*y1^2*f4^2*f0*h0^2-4*y3*x2^2*y2*f0*f6*h2^2*h0*h3-4*y2^2*f0*f5*x1^2*f2*h0*h3+y3^2*x2^2*h0^2*f4^2*h3^2-x3*y2^2*x2*f5^2*h0^2*f3+4*y4*x3*x2*y1*f3*f6*h0^2-x1^2*y2*y1*h3^2*f1^3+y3*x3^2*y1*f1^2*h3^4-2*y3^2*x3*x2*f5*h0*h1*h2*h3*f4-y3^2*x3*x2*f1*f5^2*h2^2+2*x1*x3*y3^2*f1*f3*f6*h2^2+4*x1^2*y1^2*f0^2*h3^2*f2-y4*x1^2*y1*f3^2*h0^2-4*y3^2*x3^2*f0*f5*h2*h3*f6+4*y4*x3^2*y1*f4*f6*h0^2+2*x1^2*y3*y2*f0^2*h3^3*h2+4*y3*x1*x2*y1*f0*f6*h1^2*f3-x1^2*y3^2*f0*h3^3*f3*h0+2*y3*x1*x3*y1*f4*f6*h0^3*h2-y3^2*x3^2*f5^2*h0^2*f6+8*y3*x1*x3*y1*f5^2*f1*h0*h1-x1^2*y1^2*f0*h2^3*f1*h1-y2^2*x1^2*f0*f5*h1^2*h0*h3-4*y2^2*x2^2*f1*f6*h0*h1*f4+2*y3*x1*x2*y1*f0*f6*h0^2*h2*h3-2*x3^2*y2^2*f0*f3*f5*h3^2-4*y3*x1*y2*x3*f0*f2*f5*h3^2+4*f3^2*f0*x1^2*y1*h0*h3*y2-4*x1*x2*y1^2*f0^2*h3^2*f3+y2^2*x1^2*f5*f1^2*h0*h3-2*f1^2*f6*x3*y1^2*h0*h2*x1+4*x1*x2*y1^2*f5*h0^2*f2^2-16*y3*x1^2*y1*f0*f6*h0^2*f4+2*y2*x3*x2*y1*f1*f6*h0^2*f5-y2*y4*x3^2*f5^2*h0*h1+y2^2*x1^2*f6*h0^2*h2*f1*h1-y3*x1^2*y1*f6*h0^2*h2*f1*h1-2*x1*x3*y1^2*f0^2*h3^3*h1-4*y2^2*x1^2*f2*f6*f1*h0*h1+8*x3^2*y1^2*f2*f4*f6*h0^2+y2^2*x1^2*f1*f5*h0^2*h1*h3-8*x1^2*y1^2*f5*f0^2*h1*h2-2*y2*x2*y1*f0*f2*h3^3*h1*x3-x1^2*y1^2*f1*f6*h0^3*h1-4*y2^2*x1^2*f0*f6*h0*h1*f3-x1^2*y1^2*f1^2*h3^2*f0+2*y2*x2^2*y1*f0^2*h3^3*h2-4*y2^2*x1^2*f0*f1*f6*h1*h2+y3^2*x2^2*f0*h2^4*f6+4*y3*x1*y2*x3*f4*f6*h0^2*f3-8*f0*f4*f2*x1*y1^2*h0*h3*x2+y3^2*x2^2*f0*h1^2*f6*h3^2-y2^2*x1^2*f2*h3^2*f1*h0*h1-2*x3*x2*y3*y1*f4*f6*h0^2*h1*h2+4*y3*x1^2*y1*f0*f1*f6*h0*h3+2*y3*x1*x2*y2*f1*f6*h0^2*f5+2*y2*x1*x2*y1*f3*f5*h0^2*f2+4*y3*x3^2*y1*f0*f3*h2*h3*f6+16*y3*x1*x3*y1*f0*h0^2*f6^2+x1*x2*y1^2*f4*h0^4*f5+4*y2^2*x1^2*f6*h0^2*f2^2-8*y3*x1^2*y1*f0^2*f6*h1*h3+y2^2*x1^2*h2^2*h3^2*f0^2+2*x3^2*y2*y1*h0*h1*f0*f6*h3^2-y3*y4*x1^2*f1^2*h3^2-4*x1^2*y2*y1*f0*h2*h3*f1*f3-2*y3*x1^2*y1*f0^2*h3^3*h1-y2^2*x2^2*f5*h0^2*h2*h3*f2+4*x2^2*y1^2*f6*h0^2*f2^2+x1^2*y1^2*f1^2*f3*h1
    *h2-y3*x1^2*y1*f5*h0^3*h3*f2+2*y3*x3^2*y1*h0^2*h1^2*f6^2+4*y3*y4*x2^2*f0*f6*h2^2+8*y2*x2^2*y1*f0^2*f6*h2*h3+y3^2*x3*f3^2*h3^3*h0*x2+4*x3^2*y2^2*f0*h1^2*f6^2-4*y2*x2^2*y1*f3*f1*h0*h1*f6-y3^2*x2^2*f5^2*h0^2*f4-3*y3*x3^2*y2*f3*f5*h0*h1*h3^2-8*f2*f0*x1^2*f4*y1*h0*h3*y2+x1^2*y1^2*h1^4*f0*f4+y2^2*x2^2*f5*h2*h3*f1*h0*h1-4*x1*x2*y1^2*f0*h2*h3*f1*f3-4*x1*x2*y1^2*f0*f5*h0*h1*f3+2*x3^2*y2*y1*h0^3*h1*f6^2-2*x1*x2*y1^2*f5*h0^2*f1*f3-y3^2*x3^2*f6*h1^3*h2*f5-2*x1*x2*y1^2*f1^2*h2*h3*f2-2*x1*x2*y1^2*f1*h0*h1*h2*h3*f2-6*x1*x2*y1^2*f6*f1^2*h0*h1+y2*x1*x2*y1*f5^2*h0^4-x1*x2*y1^2*h3^2*f1^2*h0*h1+y2*x2^2*y1*h0*h3^3*f1^2+8*x1*x2*y1^2*f4*f0^2*h2*h3+2*y2*x3*x2*y1*h0^4*f6^2-x1*x2*y1^2*f5*h0^3*h1*f3+x3^2*y2*y1*f1*f0*h3^4-x1^2*y2*y1*f1^2*f5*h1^2+8*x1*x2*y1^2*f4*f0*h0^2*f5+x1^2*y1*f3^2*h0^3*h3*y2+x1*x2*y1^2*f0*f5*h0^2*h2^2-y3^2*x3^2*f2*f5*h2^3*h3+2*x1*x2*y1^2*f0*h2*h3*f2*h1^2-4*x1*x2*y1^2*f0*f5*f2*h0*h2+8*x1*x2*y1^2*f0*f5*f2*h1^2-4*x1*x2*y1^2*f1*f5*h0*h1*f2-x1*x2*y1^2*f1*f5*h0*h1^3-y3^2*x3^2*f0*f5*h2*h3^3-x1*x2*y1^2*f5*h0^3*f2*h2+2*x1*x2*y1^2*h0^2*h2*h3*f2^2+4*y3*x3^2*y2*f1*h3^2*f4^2+x1*x2*y1^2*f5*h0^2*f2*h1^2-2*x1*x3*y1^2*f3*f5*f1*h0*h1+2*x1*x3*y1^2*f5*h0^2*h3*f1*h1-x3^2*y2^2*f0*f3*h2*h3^3+x3^2*y2^2*h0^2*f4*h2^2*f6+2*x3^2*y1^2*f0*h0^2*f6*h3^2+8*x3^2*y2^2*f0*f4*h2^2*f6-4*x1*x3*y1^2*f0*f5*h0*h3*f2+2*x1*x2*y1^2*f6*h0^3*h1*f2+x1*x2*y1^2*f1*h0^2*h3^2*f2+4*x1*x2*y1^2*f1*f6*h0^2*f2+4*x1*x2*y1^2*f0*f1*f6*h1^2+x1*x2*y1^2*f0*f1*h3^2*h1^2+4*x1*x2*y1^2*f0*f1*h3^2*f2-x3^2*y2^2*f3*f5*h0^2*h3^2+8*x3*x2*y1^2*f0*f2*f6*h1*h2-2*x3^2*y2^2*f3*f5*h0^2*f6+2*y2^2*x1*x3*f0*h3^2*f3^2+4*x2^2*y1^2*f0^2*f6*h2^2-2*x2^2*y1^2*f0*f1*h3^2*f3-x2^2*y1^2*f0*f1*h3^2*h1*h2-x2^2*y1^2*f1*h0^2*h3^2*f3-4*x2^2*y1^2*f0*f6*h0*h1*f3+x3*y2^2*x2*f1*f0*h3^4+x3*x2*y1^2*f0*f5*h3^2*h0^2-y2^2*x1^2*f2*f5*h0^3*h3+f5*x2*f1^2*y1^2*h1*h3*x3+8*x2^2*y1^2*f0*f6*h0^2*f4-4*x2^2*y1^2*f2*f6*f1*h0*h1+4*y2^2*x1*x2*f0^2*h3^2*f5+x2^2*y1^2*f6*h0^2*h2*f1*h1+x2^2*y1^2*f0*h3^2*f2*h1^2-4*x2^2*y1^2*f0*f1*f6*h1*h2+y2^2*x1*x2*f6*h0^4*f5-2*x2^2*y1^2*f1*f6*h0^2*f3-x2^2*y1^2*f6*h1^3*f1*h0-x2^2*y1^2*f2*h3^2*f1*h0*h1-y3^2*x3*x2*f0*h3^4*f3-2*x1*y1^2*f0*f4*h1^2*h0*h3*x2+4*f0*f3^2*x1*y1^2*h0*h3*x2+8*x3*x2*y1^2*f0^2*f6*h2*h3-y2^2*x1*x2*f3*f1^2*h3^2+8*x3*x2*y1^2*f0*f6*h0^2*f5-y2*x2^2*y1*f3*f1^2*h3^2-2*x1*y1^2*f2*f4*h0^3*h3*x2-8*x1*x2*y1^2*f0*f6*h0^2*f3+y3*x3^2*y2*f2*f1*h3^4-8*x1*x2*y1^2*f0^2*f6*h1*h2-8*x1*x3*y3^2*f0*h1^2*f6^2-2*x1*x2*y1^2*f0^2*h3^2*h1*h2+4*x1*x2*y1^2*f0*f1*f6*h0*h2+2*y3^2*x3^2*f1*f6*h2^2*f5+y3^2*x3^2*f6*h1^2*f4*h2^2+y3^2*x1*x2*f1*f0*h3^4+2*f4*x1*f1^2*y1^2*h1*h3*x3+2*x3*y2^2*x2*h0^3*h1*f6^2+4*x1*y1^2*f0*f4*h0*h2*h1*h3*x3-2*x1*y1^2*f0*f4*h1^3*h3*x3+4*x3*y2^2*x2*f1*h0^2*f6^2+4*y2^2*x2^2*f2*f4*h3^2*f0-2*x1*y1^2*f2*f4*h0^2*h1*h3*x3-x1*x3*y1^2*f3*h2*h3*f1^2+4*y2^2*x2^2*f4*f6*h1^2*f0+y2^2*x2^2*f4*h1^2*h3^2*f0-y2^2*x3^2*f1*f4*h3^3*h0+8*x3^2*y2^2*f0*f2*f6*h3^2+2*x1*y1^2*f1*f4*h0*h1^2*h3*x3-x1*x3*y1^2*f6*h0^2*h2*f1*h1+4*x1*x3*y1^2*f0*f1*f6*h1*h2+x1*x3*y1^2*f0*f1*h3^3*h0+y2^2*x2^2*f5^2*f1*h0*h1+2*x1*x3*y1^2*f0*f1*h3^2*f3-y2^2*x2^2*f3*f6*h0^3*h3-y2^2*x1^2*f6*h1^3*f1*h0-2*y2^2*x1^2*f1*f6*h0^2*f3-16*x1*x3*y1^2*f0*f6*h0^2*f4+y2^2*x1^2*f0*h3^2*f2*h1^2+x1*x3*y1^2*f6*h0^3*h1*f3-y2^2*x1^2*f1*h0^2*h3^2*f3-2*y2^2*x1^2*f0*f1*h3^2*f3+x1*x3*y1^2*f0*f5*h1^3*h2+3*x1*x3*y1^2*f5*h0*h3*f1^2-x1*x3*y1^2*f3*h2*h3*f1*h0*h1-x1*x3*y1^2*f5*h1*h2*f1^2+y2^2*x2^2*f2*f6*h2^2*h0^2+x1*x3*y1^2*f5*h0^2*h1*h2*f2+4*x1*x3*y1^2*f0*f3*h2*h3*f2+x1*x3*y1^2*f3*h0^2*h2*h3*f2+2*x1*x3*y1^2*f3*f5*h0^2*f2+y2^2*x2^2*f5*h2*h3*f1^2+2*y2^2*x2^2*f0*h0^2*f6*h3^2+4*x1*x3*y1^2*f0*f5*h1*h2*f2-x1*x3*y1^2*f5*h0^3*h3*f2-y2^2*x2^2*f0*f3*h3^3*h0-4*x3^2*y1^2*f0*f6*f3*h1*h2+x3^2*y1^2*f0*f6*h1^2*h2^2-4*x3^2*y1^2*f0*f6*f3*h0*h3-x3^2*y1^2*f6*h0^3*f3*h3-2*x3*x2*y1^2*h1^2*h2*f1*h0*f6-x3^2*y1^2*f6*h0^2*f3^2+4*x1*x3*y1^2*f5*h2*h3*f0*h0^2-x3^2*y1^2*f0*h3^2*f3^2-x3^2*y1^2*f0*h3^3*f3*h0+x3^2*y1^2*f5*h2*h3*f1*h0*h1+x3*x2*y1^2*f0*h1^2*h3^2*f3+8*y2^2*x1^2*f0*f6*h0^2*f4+4*x3*x2*y1^2*f0*f6*h1^2*f3+2*x3^2*y1^2*f5^2*f1*h0*h1+x3*x2*y1^2*f2*h0^2*h3^2*f3+8*y2^2*x1^2*f0*f6*f2*h1^2+2*x3*x2*y1^2*f0*f6*h1^3*h2-x3^2*y1^2*f5*h0^2*h2*h3*f2+8*x3^2*y1^2*f2*f4*h3^2*f0-2*x1*x3*y1^2*f0*f6*h0^2*h1*h3+x1*x3*y1^2*f5^2*h0^4+x3^2*y1^2*f4*h1^2*h3^2*f0-8*x3^2*y1^2*f0*f5*h2*h3*f2+4*x3^2*y2*y1*f1*h0^2*f6^2-x3^2*y1^2*f0*f5*h1^2*h2*h3+x3^2*y1^2*f2*f6*h2^2*h0^2+x3^2*y2^2*h0^2*f2*f6*h3^2-2*x1*x3*y1^2*f0*h0^2*h3^2*f4-2*x1*x3*y1^2*f0*f6*h0^2*h2^2+y2^2*x1^2*f6*h0^2*f2*h1^2-8*x3^2*y1^2*f1*f6*h0*h1*f4+x3^2*y1^2*f2*f4*h3^2*h0^2-x3^2*y1^2*f6*h0*h1*h2^2*f1-4*f0*f5*x2*f2*y1^2*h1*h3*x3+4*x3*x2*y1^2*f2*f6*h0^2*f3+8*x3^2*y1^2*f2*f6*h2^2*f0+2*x3*x2*y1^2*f0*f6*h0^2*h2*h3-x3^2*y1^2*f1*h0*h1*h3^2*f4-x2*y1^2*f0*f5*h1^3*h3*x3+4*y2^2*x2^2*f2*f4*f6*h0^2+8*y2^2*x2^2*f0*h0^2*f6^2-3*x1*x3*y1^2*f0*f5*h0*h3*h1^2-4*y2^2*x1*x2*f0*f6*h0*h2*f3-y2^2*x1^2*f2*h3^2*f1^2-x1^2*y1^2*f5*h0^4*f3-y2^2*x2^2*f1^2*f6*h2^2+2*x3*x2*y1^2*f2*f6*h0^2*h1*h2+y2^2*x1^2*h3^2*h0^2*f2^2-4*x1^2*y1^2*f0*f4*f1*h0*h3+x2^2*y1^2*f0*h0^2*h3^2*f4+2*x3*x2*y1^2*f0^2*h3^3*h2+4*x1*x2*y1^2*h2^2*f0^2*f5+2*x1*x3*y1^2*f1*f6*h0^2*f3-x1^2*y1^2*f1^2*f4*h1^2-y2^2*x1^2*f6*h1^2*f1^2+2*x1*y1^2*f1*f4*h0^2*h1*h3*x2-3*x1^2*y1^2*f5*f1^2*h0*h1+4*x3*x2*y1^2*f0^2*h3^2*f5-y2*x1*x2*y1*f5*h1*h2*f1^2+x1*x2*y1^2*f0*f5*h1^4+y3*x1^2*y1*f5^2*h0^4+2*y2*x1*x3*y1*f0*f6*h1^3*h2+4*y3^2*x3^2*f4*h0^2*f6^2-4*x3*y2^2*x2*f0*f6*h2^2*h0*h3-y3^2*x3^2*f5^2*h1^2*f4+8*x3^2*y1^2*f0*h0^2*f6^2-x1*x2*y1^2*h3^2*f1^3+2*y2*x2^2*y1*f2*f6*h0^2*h1*h2+y3^2*x3^2*f0*f4*h3^4-x3*x2*y1^2*f3*f1^2*h3^2-y3^2*x3^2*h0*h1*f5^3+x1*x3*y1^2*f0*h0*h1*h3^2*f3-4*x3*y2^2*x2*f0*f5*h2*h3*f3-2*x1^2*y1^2*f0*f3*h0^2*h3*h2+2*y2*x1*x2*y1*f0*f3*f5*h1^2+4*x3^2*y2^2*h0^2*f4^2*f6+8*x3^2*y2*y1*f0*f4*f6*h1*h2+x3^2*y2^2*f0*h2^4*f6+2*x1*x3*y1^2*f0*f3*f5*h1^2-x1*x3*y1^2*f5*h1^2*h2*f1*h0-y2^2*x2^2*f1^2*h3^2*f4-x2*y1^2*f2*f5*h0^2*h1*h3*x3+2*x1^2*y2*y1*f0*h2*h3*f2*h1^2-x1*x2*y1^2*f6*h0^4*f3+x3^2*y2^2*h0^2*f4^2*h3^2-2*y2*x2^2*y1*h1^2*h2*f1*h0*f6-x1^2*y1^2*f1^2*h2^2*f2+8*x1*x2*y1^2*f0*f6*h0*h1*f2-8*x1^2*y1^2*f5*f0*h0^2*f3+8*x1*x2*y1^2*f0*h2*h3*f2^2-x2^2*y1^2*f0*f5*h1^2*h0*h3-x1*x3*y1^2*f0*
    f1*h3^2*h1*h2-x1^2*y1^2*f4*h0^3*h1*f3+x2^2*y1^2*f1*f5*h0^2*h1*h3+2*x1*x2*y1^2*f0*f6*h0*h1^3-x1*x2*y1^2*f1^2*f5*h1^2+x1^2*y1^2*f5*h0^3*h1*f2-4*f0*f5*x2^2*f2*y1^2*h0*h3+2*x1^2*y1^2*f5*h0^2*f1*f2+16*x1*x3*y1^2*f5*h2*h3*f0^2+8*x1*x3*y1^2*f5^2*f0*h0^2-8*x1*x3*y1^2*f0^2*h3^2*f4-x1^2*y1^2*f1^2*f6*h0^2+4*x1*x3*y1^2*f0*f6*h0*h1*f3-y2^2*x2^2*f0*f5^2*h1^2+4*y2^2*x2^2*f2*f6*h2^2*f0+3*x1^2*y1^2*f0*h1*h2^2*h0*f3+x1^2*y1^2*f1*h0*h1*f3^2+x1^2*y1^2*f1*h0*h1^2*f3*h2-8*x1*x3*y1^2*f0^2*f6*h2^2-3*x1*x2*y1^2*f0*f5*h1^2*h2*h0+f5*x2^2*f1^2*y1^2*h0*h3-x1^2*y1^2*h2^2*f1*h0*h1*f2+x1^2*y1^2*f5*h0^3*f1*h2+x1^2*y1^2*f1*h0^2*h2*h3*f2-4*x1*x2*y1^2*f0*f5*f1*h1*h2+y2^2*x1*x2*h0*h3^3*f1^2+2*x1^2*y1^2*f0*f5*f1*h1^2+4*x1^2*y1^2*f0*f5*h0*h1*f2+4*x1^2*y1^2*f0*f5*f1*h0*h2-2*x1^2*y1^2*f0*f5*h0^2*h1*h2+4*y2*x3*x2*y1*f0*f1*f6*h2*h3+8*x1^2*y1^2*f2*h1^2*f0*f4-4*x1^2*y1^2*f1*f6*h0*h1*f0-8*x1^2*y1^2*h2*h3*f0^2*f3+2*y2^2*x1*x2*f0^2*h3^3*h2+x1^2*y1^2*f0*f5*h0*h1^3+4*x1^2*y1^2*f0*h2*h3*f1*f2-x3^2*y2^2*f0*f5*h2^3*h3+4*x2^2*y1^2*f0*h3^2*f2^2-x3^2*y2*y1*f5^2*h0^2*f3+y2^2*x1^2*f0*h0^2*h3^2*f4+x3*y2^2*x2*f5^2*h0^3*h3+y2^2*x2^2*f0*f6*h1^2*h2^2-y2^2*x1^2*f6*h0^3*h1*f3+x2^2*y1^2*f6*h0^2*f2*h1^2+x3^2*y2^2*f5^2*h0^2*h1*h3+y2^2*f1*x3^2*f5^2*h0*h3+4*x2^2*y1^2*f0^2*h3^2*f4+x3^2*y2^2*f0*h1^2*f6*h3^2+x2^2*y1^2*h3^2*h0^2*f2^2+2*x1*x2*y1^2*h2^3*f0^2*h3+x2^2*y1^2*f6*h0^4*f4-x2^2*y1^2*f2*h3^2*f1^2-4*y2^2*x1*x3*f0*f6*f3*h0*h3+4*y3^2*x2^2*h0^2*f2*f6^2-x1^2*y1^2*f0*f3^2*h1^2+y2*x2*y1*f1*f6*h0*h1^2*h3*x3+y2*x1*x3*y1*f3*h0^2*h1^2*f6+x1^2*y1^2*f4*h0^2*h1^2*f2+4*y3^2*x2^2*f0*f4^2*h3^2+3*x1^2*y1^2*f1*f4*h0^2*h1*h2-x1^2*y1^2*h2*h3*f1^3+y3^2*x2^2*h0^2*h1^2*f6^2-4*x1^2*y1^2*f1*f4*h0*h1*f2+y2*x1*x3*y1*f0*f5*h3^2*h0^2-y3*x3^2*y2*h0^2*f5^3-x3^2*y2^2*f5*h0^2*h2*h3*f4+8*x1^2*y2*y1*f4*f0*h0^2*f5-2*x3*y2^2*x2*f0*f6*h1^2*h3*h2-y3^2*x3^2*f0*f5^2*h3^2-x1^2*y1^2*f5*f1*h0^2*h1^2+2*y2*x1*x2*y1*f0*h3^2*f2*h1^2-x3*y2^2*x1*f1*f3*h2*h3^2*h0-8*y2^2*f0*f4*f6*x3*h0*h2*x1+x3*y2^2*f0*f5*h2^2*h3*h0*x1-2*y2*x2*y1*f0*f6*h1^3*h3*x3+8*y2*x1*x3*y1*f1*f5*h2*h3*f0+8*y2^2*x1*x3*f0*f6*f3*h1*h2+2*y2*x1*x3*y1*f1*f5*h2*h3*h0^2+x1^2*y1^2*f0*h0^2*h3^2*f2-x1^2*y1^2*h0^2*f3*h1*h2*f2-x1^2*y1^2*f4*h0^3*f1*h3-2*x1^2*y1^2*h0^2*h2^2*f1*f3+2*x1^2*y1^2*f0*f4*h0^2*h1*h3-4*x1^2*y1^2*f0*f4*h0*h1*f3+y2^2*x1*x3*f0*f3*h2*h3^2*h1+4*y3^2*x3^2*f6*h1^2*f4^2-3*y2*x1*x2*y1*f5*h0^3*h3*f2+4*y2^2*x1*x3*f0*f6*h0*h1*f5+x1^2*y1^2*f0*h1^2*h3*f1*h2-2*x1^2*y1^2*f0*h2^2*f1*f3+x1^2*y1^2*f0*h2^2*f1*h0*h3+8*x3*y2^2*x2*f0*f4*f6*h1*h2+x1*x3*y3^2*f1^2*h3^4+4*x3^2*y2^2*f0*f4^2*h3^2+y2*x3*x2*y1*h3^2*h0^2*f3^2-2*x1*x2*y1^2*f6*f1*h0^2*h1^2+4*x3*y2*y4*x2*f4*f6*h0^2+8*x3^2*y1^2*f0^2*f6*h3^2-2*y3*x3^2*y1*f1*f5*h2*h3*f3+4*x1^2*y2*y1*f5*h0^2*f2^2-2*x3*y2^2*x2*f0*f5*h2^2*h3*h1-8*x1*x3*y1^2*f0^2*f6*h1*h3+y3^2*x3^2*f6*h0*h1*h2^2*f5+y3^2*x3^2*f1*f4*h3^3*h2-2*y3*x3^2*f2*f4*h3^3*h0*y2+2*y3*x3^2*y2*h1^3*h0*f6^2+y3*x1*x3*y1*f3*f6*h1^3*h0+4*y4*x1^2*y1*f2*f4*h0^2+x3*x2*y3*y1*f4*h0^2*h3^2*f3-y3^2*x3^2*f1*h3^4*f3-3*y3^2*x3*x2*f1*f6*h1*h2^2*h3+x3^2*y2^2*f0*h2^2*h3^2*f4+x3^2*y2^2*f0*f2*h3^4+4*x1*x3*y3^2*f3*f6*h0*h1*f4-2*x1*x3*y3^2*h0^3*h2*f6^2+4*x3*x2*y3*y1*f0*f4*h3^2*f3+16*y2*x3*x2*y1*f0*f6*f3*h1*h2+8*y3*x1*x3*y1*f2*f6*h2^2*f0-2*x1^2*y2*y1*f0*h2^2*h3*f1*h1-2*y2*x1*x3*y1*f0*f1*h3^3*h1+y2*x3*x2*y1*f6*h0^3*h1*f5+y2*x1*x2*y1*f5*h0^2*h1*h2*f2-4*x3*y2^2*x2*f0*f6*h1*h3*f3+2*y2*x1*x2*y1*f6*h0^2*f2*h1^2-4*y2*x1*x3*y1*f1*f6*h0^2*f4+3*y2^2*x1*x2*h0^2*h3*f1*h1*f6+2*y2*x1*x3*y1*f0*h2*h3*f3^2-2*y2*x1*x2*y1*f2*h3^2*f1*h0*h1+8*y2*x1*x3*y1*f0^2*f6*h2*h3-2*y2^2*x1*x2*f0*f6*h0*h2^2*h1+8*y2^2*x1*x2*f0*f2*f6*h1*h2-4*y2^2*x1*x2*f0*f6*h1^2*h0*h3-2*y2^2*x1*x2*h1^2*h2*f1*h0*f6-y2^2*x1*x2*f3*f1*h0*h1*h3^2-4*y2^2*x1*x2*f3*f1*h0*h1*f6+4*y2^2*x1*x2*h0*h3*f1^2*f6-2*y2^2*x1*x2*h1*h2*f1^2*f6-8*y2^2*x1*x2*f0*f2*f6*h0*h3-2*y2^2*x1*x2*f2*f6*h0^3*h3+4*y2^2*x1*x2*f0*f6*h1^2*f3+4*y2^2*x1*x2*f2*f6*h0^2*f3-y2^2*x1*x2*f6*h0^3*h2*f3+4*y2^2*x1*x2*f0*f2*h3^2*f3+2*y2^2*x1*x2*f2*f6*h0^2*h1*h2+y2^2*x1*x2*f0*f5*h3^2*h0^2+y2^2*x1*f1*f6*h0*h1^2*h3*x3-8*x3*y2^2*x2*f0*f4*f6*h0*h3-y2^2*x3^2*f1*f6*h2^2*h0*h3+4*x3*y2^2*x2*f0*f5^2*h0*h3-4*x3^2*y2^2*f0*f5*h2*h3*f4+x3^2*y2^2*f0*f5*h2*h3^2*h1+4*x3*y2^2*x2*f0*f6*h2^2*f3-4*x3^2*y2^2*f0*f5*h1*h2*f6-4*x3^2*y2^2*f0*f3*h2*h3*f6-x3^2*y2^2*f5*h0^2*h1*h2*f6+x3^2*y2^2*f3*h0^2*h2*h3*f6-2*y2^2*x1*f0*f6*h1^3*h3*x3-4*y2^2*f1*x3^2*f6*f4*h0*h3-2*y2^2*x1*f0*f2*h3^3*h1*x3+2*y2^2*x1*x3*f0*f6*h1^2*h2^2-y2^2*x1*x3*f6*h0^3*f3*h3+y2^2*x1*x3*f6*h0^2*f3*h1*h2-y2^2*x1*x3*f0*h3^3*f3*h0-2*x3*y2^2*f0*f6*h2^3*h0*x1+4*y2^2*x1*x3*f0*f1*f6*h2*h3+y2^2*x1*x3*f6*h0^2*h2*h3*f1+2*y2^2*x1*x3*f0*f1*h3^2*f5+y2^2*x1*x3*f0*f1*h3^3*h2+y2^2*x1*x3*f6*h0^3*h1*f5-8*y2^2*f2*f0*f6*x1*h1*h3*x3+3*x3*y2^2*x2*f0*f5*h2*h3^2*h0+x3*y2^2*x2*f1*h0^2*f6*h3^2+8*x3*y2^2*x2*h0*h1*f0*f6^2+2*x3*y2^2*x2*f0*f6*h2^3*h1+4*x3*y2^2*x2*f4*f6*h0^2*f3+x3*y2^2*x2*f6*h0^2*h2^2*f3+4*x3*y2^2*x2*f0*f4*h3^2*f3+x3*y2^2*x2*f4*h0^2*h3^2*f3-x3*y2^2*x2*f0*h1*h3^3*f3+2*x3*y2^2*x2*f0*f4*h3^2*h1*h2+3*y2*x2^2*y1*h0^2*h3*f1*h1*f6-4*y2*x2^2*y1*f0*f6*h1^2*h0*h3-4*x1^2*y2*y1*f1*f5*h0*h1*f2+16*y2*x1*x2*y1*f5*h2*h3*f0^2-2*y2*x1*x3*y1*f6*h0^3*h1*f4+4*y2*x1*x3*y1*f0*f2*h3^2*f3-4*y2*x2^2*y1*f0*f6*h0*h2*f3+8*y2*x2^2*y1*f0*f2*f6*h1*h2-y2*x1*x2*y1*f6*h0^3*h1*f3-2*y2*x2^2*y1*f0*f6*h0*h2^2*h1+y2*x1*x3*y1*f0*f5*h1^2*h2^2+4*y2*x1*x3*y1*f5^2*h0*h1*f0-2*x1^2*y2*y1*f0^2*h3^2*h1*h2-2*x1^2*y1*f0*f4*h1^2*h0*h3*y2-8*y2*f0*f5*f2*x1*y1*h1*h3*x3-y2*x1*x2*y1*f5*h1^2*h2*f1*h0+2*x3^2*y2*y1*f0*f4*h3^2*h1*h2-y2*x2*y1*f3*f5*h0^2*h1*h3*x3+8*x3^2*y2*y1*h0*h1*f0*f6^2+2*y2*x1*x3*y1*f0^2*h3^3*h2-4*x1^2*y2*y1*f0*f5*f2*h0*h2+x1^2*y2*y1*f0*f5*h0^2*h2^2+8*x1^2*y2*y1*f0*h2*h3*f2^2-x1^2*y2*y1*f5*h0^3*f2*h2+x1^2*y2*y1*f5*h0^2*f2*h1^2+2*x1^2*y2*y1*h0^2*h2*h3*f2^2-x1^2*y2*y1*f1*f5*h0*h1^3-2*x1^2*y2*y1*f1^2*h2*h3*f2+2*x1^2*y2*y1*f1^2*h2^2*h3*h0-2*x1^2*y2*y1*f1*h0*h1*h2*h3*f2-2*x1^2*y2*y1*f5*h0^2*f1*f3-3*x1^2*y2*y1*f1*h0^2*h2*h3*f3+8*x1^2*y2*y1*f4*f0^2*h2*h3-6*x1^2*y2*y1*f6*f1^2*h0*h1-x1^2*y2*y1*h3^2*f1^2*h0*h1+4*x1^2*y2*y1*f0*f1*f6*h1^2+4*x1^2*y2*y1*f1*f6*h0^2*f2+x1^2*y2*y1*f1*f6*h0^3*h2+4*x1^2*y2*y1*f0*f1*h3^2*f2+x1^2*y2*y1*f0*f1*h3^2*
    h1^2+x1^2*y2*y1*f1*h0^2*h3^2*f2+2*x1^2*y2*y1*f0*f6*h0*h1^3-8*x1^2*y2*y1*f0^2*f6*h1*h2-8*x1^2*y2*y1*f0*f6*h0^2*f3+2*f4*x1^2*f1^2*y1*h0*h3*y2+16*y2*x1*x2*y1*f0*f6*f2*h1^2-y2*x1*x2*y1*f3*h2*h3*f1^2-12*y2*x1*x2*y1*f0*f5*h0*h3*f2+5*y2*x1*x2*y1*f5*h0*h3*f1^2+3*y2*x1*x2*y1*h3^2*h0*h2*f1^2-y2*x2^2*y1*f3*f1*h0*h1*h3^2+4*y2*x2^2*y1*h0*h3*f1^2*f6-2*y2*x2^2*y1*h1*h2*f1^2*f6+2*y2*x2^2*y1*f0*f6*h1^3*h2-2*y2*x2^2*y1*f2*f6*h0^3*h3-2*y2*x2^2*y1*f0*f2*h3^3*h0+4*y2*x2^2*y1*f0*f6*h1^2*f3+4*y2*x2^2*y1*f2*f6*h0^2*f3-y2*x2^2*y1*f6*h0^3*h2*f3+y2*x2^2*y1*f0*h1^2*h3^2*f3+y2*x2^2*y1*f2*h0^2*h3^2*f3+8*y2*x1*x2*y1*f5^2*f0*h0^2+4*y2*x1*x2*y1*f5*h2*h3*f0*h0^2+4*y2*x1*x2*y1*h2^2*h3^2*f0^2-2*y2*x1*x2*y1*f3*f5*f1*h0*h1+4*y2*x1*x2*y1*f5*h0^2*h3*f1*h1-5*y2*x1*x2*y1*f0*f5*h0*h3*h1^2+y2*x1*x2*y1*f0*f3*h2*h3*h1^2+4*y2*x1*x2*y1*f0*f5*h1*h2*f2+4*y2*x1*x2*y1*f0*f3*h2*h3*f2+y2*x1*x2*y1*f3*h0^2*h2*h3*f2-2*y2*x1*x2*y1*f0*f6*h1^2*h2*h0+2*y2*x1*x2*y1*f0*f6*h1^4+8*y2*x1*x2*y1*f0*h3^2*f2^2+2*y2*x1*x2*y1*h3^2*h0^2*f2^2-8*y2*x1*x2*y1*f2*f6*f1*h0*h1+y2*x1*x2*y1*f6*h0^2*h2*f1*h1-2*y2*x1*x2*y1*f6*h1^3*f1*h0-2*y2*x1*x2*y1*f2*h3^2*f1^2+4*y2*x1*x2*y1*f0*f1*f6*h0*h3-4*y2*x1*x2*y1*f0*f1*f6*h1*h2-2*y2*x1*x2*y1*f1*f6*h0^2*f3+y2*x1*x2*y1*f1*f6*h0^3*h3-2*y2*x1*x2*y1*f0*f1*h3^2*f3+y2*x1*x2*y1*f0*f1*h3^3*h0-3*y2*x1*x2*y1*f0*f1*h3^2*h1*h2-2*y2*x1*x2*y1*f1*h0^2*h3^2*f3-4*y2*x1*x2*y1*f0*f6*h0*h1*f3-2*y2*x1*x2*y1*f0*f6*h0^2*h1*h3+3*y2*x1*x2*y1*f0*h0*h1*h3^2*f3+y2*x1*x3*y1*f2*h0^2*h3^2*f3+4*y2*x3*x2*y1*f0*f6*h1^2*h2^2+2*y2*x1*x3*y1*f0*h1^2*h3^2*f3+y2*x3*x2*y1*f0*f1*h3^3*h2-2*x3^2*y2*y1*f0*f5^2*h1*h2-4*x3^2*y2*y1*f0*f5*h2*h3*f3-2*x3^2*y2*y1*f0*f5*h2^2*h3*h1-x3^2*y2*y1*f5*h0^2*h2*h3*f3+8*x3^2*y2*y1*f1*f0*f6*h3^2+x3^2*y2*y1*f1*h0^2*f6*h3^2+2*x3^2*y2*y1*f0*f6*h2^3*h1+4*x3^2*y2*y1*f4*f6*h0^2*f3+4*x3^2*y2*y1*f0*f6*h2^2*f3+4*x3^2*y2*y1*f0*f4*h3^2*f3+y2*x1*x3*y1*f1*h2^2*h3^2*f0-f3*x1*f1*y1*h0*h3^2*y2*h1*x3+2*y2*x1*x3*y1*f1*f5^2*h0^2+y2*x1*x3*y1*f5^2*h0^3*h1+4*y2*x1*x3*y1*f0*f5*f3*h1*h2+y2*x1*x3*y1*f0*h2^2*h3*f3*h1+y2*x1*x3*y1*h0^2*h2*h3*f3^2+y2*x1*y1*f1*f5*h0*h1^2*h3*x3+4*y2*x1*x3*y1*f0*f6*h1^2*f3+4*y2*x1*x3*y1*f2*f6*h0^2*f3+8*y2*x1*x3*y1*f0*f2*f6*h1*h2+2*y2*x1*x3*y1*f0*f6*h0^2*h2*h3-2*y2*x1*x3*y1*f0*f6*h0*h2^2*h1-4*y2*x1*x3*y1*f0*f6*h1^2*h0*h3-2*y2*x1*x3*y1*f0*f2*h3^2*h1*h2-8*y2*x1*x3*y1*f0*f1*f6*h1*h3+2*y2*x1*x3*y1*h0^2*h3*f1*h1*f6-4*y2*x1*x3*y1*f0*f1*h3^2*f4-3*y2*x1*x3*y1*f1*h0^2*h3^2*f4-8*y2*x1*x3*y1*f0*f6*h0*h1*f4+8*y2*x1*x3*y1*f0*f6*h0^2*f5+y2*x1*x3*y1*f6*h0^4*f5+4*y2*x1*x3*y1*f0^2*h3^2*f5-2*y2*x1*y1*f0*f5*h1^3*h3*x3-3*y2*x2*y1*f0*f5*h1^2*h2*h3*x3+16*y2*x3*x2*y1*f0^2*f6*h3^2+16*y2*x3*x2*y1*f0*h0^2*f6^2-8*y2*x3*x2*y1*f0*f6*h0*h1*h2*h3+y2*x3*x2*y1*f6*h0^2*f3*h1*h2+y2*x3*x2*y1*f0*f3*h2*h3^2*h1-8*y2*f0*f6*x2*f2*y1*h1*h3*x3+5*y2*x3*x2*y1*f6*h0^2*h2*h3*f1+2*y2*x3*x2*y1*f0*f1*h3^2*f5-2*y2*x3*x2*y1*f1*h0^2*h3^2*f5+4*y2*x3*x2*y1*f0*f6*h0*h1*f5+5*y2*x3*x2*y1*f0*f5*h0*h3^2*h1+3*y3^2*x3^2*f2*f5*h2*h3^2*h1+y3*x1*x2*y1*f0*f5*h1^2*h2^2+y3*x1*y2*x3*f1*h0^2*f6*h3^2+2*x3*x2*y3*y1*f6*h0^2*h2^2*f3-y3*x2^2*f5*f1*f3*y1*h0*h3+16*y3*x3*x2*y2*f0*f4*h2^2*f6+2*y3*x1*x3*y1*f4*h1^2*h3^2*f0+2*y3*x3^2*f2*f5*h2*h3^2*h0*y2+y3*x1*x2*y1*f3*h0^2*h1^2*f6+8*y3*x1*x3*y1*f2*f6*h1*h3*f0-8*y3^2*f2*f6*x3*f4*h0*h3*x2+2*y3*x1*x3*y1*f2*f6*h2^2*h0^2+4*y3*x1*x2*y2*f0*f6*h1^2*h2^2-x1*x3*y3^2*f5*h0^2*h1*h2*f6+x1*x3*y3^2*f1*h1*h2*h3^2*f4-2*x1*x3*y3^2*f0*h0*h2*f6*h3^2+8*x3*x2*y3*y1*f1*f6*h0*h1*f5-y3*x3^2*y2*f1*h3^3*f4*h1-2*y3*x3*x2*y2*f3*f5*h0^2*h3^2-4*y3^2*x3*x2*f1*f6*f4*h1*h3+y3*x1*y2*x3*f6*h0^2*h1^2*f5+2*x1^2*y3*y2*f2*f6*h0^2*h1*h2-2*y3^2*x3*f2*f4*h3^2*h0*h2*x1-3*x1*x3*y3^2*f1*f6*h0*h3*h2^2-2*y3*x2^2*y2*f0*f5^2*h1*h2-y3*x1^2*y1*f3*h2*h3*f1^2+x3*x2*y3*y1*f6*h0*h1^2*f3*h2+8*x1^2*y3*y2*f0*f6*h0^2*f5+8*y3^2*x3*x2*f0*f4*h2*h3*f6+4*y3^2*x3*x2*h1^2*f1*f6^2-2*x1*x3*y3^2*f0*f2*h3^4-y3*x3^2*y1*f0*f5*h2*h3^2*h1+4*y3^2*x1*x2*f1*h0^2*f6^2+2*y3*x2^2*y1*f1*f6*h0^2*f5+4*x3*x2*y3*y1*f1^2*f6*h2*h3+8*x1*x3*y3^2*f1^2*f6*h3^2+4*y3*x3^2*y2*f0*f5*h1*h3*f6-2*x1*x3*y3^2*f1*f5*h2*h3*f3+y3^2*x2*f1*f5*h2^2*h3*h0*x1-4*y3^2*x3^2*f2*f6*h0*h3*f5+y3^2*x3^2*f1*f6*h2^3*h3-8*y3*x3^2*y1*f0*h1^2*f6^2-2*y3*x3^2*y1*f0*h1^2*f6*h3^2-4*x3*x2*y3*y1*f0*f6*h2^2*h0*h3-8*x1*x3*y3^2*h0^2*f2*f6^2-2*x1*x3*y3^2*h0^2*f2*f6*h3^2+y3^2*x3*x2*f1*f6*h2^4-y3*x1*x3*y1*f3*h0^2*h2*h3*f4-3*x3*x2*y3*y1*f2*f5*h0^2*h3^2-y3*x3^2*y1*f5^2*h0*h1*f3+y3^2*x3^2*f3^2*f5*h2*h3+2*y3*x3*x2*y2*f1*f3*h3^2*f4+2*y3*x1*x3*y1*h0^4*f6^2-3*y3*x1*y2*x3*f2*f5*h0^2*h3^2-y3^2*x3*x2*f1*f3*h2*h3^3-4*y3*x1*y2*x3*f0*f5*h1^2*f6+y3^2*x3^2*f3*h1*h2^2*f5*h3-4*y3*x2^2*y2*f0*f6*h1*h3*f3-y3^2*x3^2*f3*h1*h2*h3^2*f4-y3^2*x3^2*f3*f6*h1*h2^3+2*y3*x2^2*y2*h0^3*h1*f6^2-x1^2*y3^2*f6*h0^3*f3*h3+4*y3*x1*x3*y1*f0*h0^2*f6*h3^2+4*y3*x1*x2*y2*f0*f6*h0*h1*f5+2*y3*x1*x2*y1*f0*f6*h1^3*h2+4*y3*x2^2*y1*f0*f6*h0*h1*f5-2*y3*x1*x3*y1*f0*h2^2*h3^2*f2+4*y3*x3*x2*y2*f0*f5*h0*h3*f6+2*x1*x3*y3^2*f3*f5*h0^2*f6+2*y3*x1*y2*x3*f6*h0^2*h2^2*f3+2*y3*x3^2*y2*f6*h0*h1*f4*h2^2+2*x1^2*y3*y2*f0*f6*h1^3*h2+4*x3*x2*y3*y1*f4*f6*h0^2*f3+y3*x3*x2*y2*f1^2*h3^4-8*y3*x1*x2*y1*f0*f1*f6*h1*h3-y3^2*x3^2*f1*f5*h2^2*h3^2+2*x1^2*y3^2*f5^2*f1*h0*h1+2*x1^2*y3^2*f5*h2*h3*f1^2+x1^2*y3^2*f5*h2*h3*f1*h0*h1+2*x1^2*y3^2*f0*h0^2*f6*h3^2-8*x1^2*y3^2*f0*f5*h2*h3*f2-x1^2*y3^2*f0*f5*h1^2*h2*h3-x1^2*y3^2*f5*h0^2*h2*h3*f2-4*x1^2*y3^2*f0*f6*f3*h0*h3-4*x1^2*y3^2*f0*f6*f3*h1*h2+x1^2*y3^2*f0*f6*h1^2*h2^2-8*x1^2*y3^2*f1*f6*h0*h1*f4-x1^2*y3^2*f6*h0*h1*h2^2*f1-x1^2*y3^2*f1*h0*h1*h3^2*f4+8*x1^2*y3^2*f2*f4*f6*h0^2+x1^2*y3^2*f2*f6*h2^2*h0^2+8*x1^2*y3^2*f2*f6*h2^2*f0+8*x1^2*y3^2*f4*f6*h1^2*f0+8*x1^2*y3^2*f2*f4*h3^2*f0+x1^2*y3^2*f4*h1^2*h3^2*f0-y3^2*x2^2*f1*f6*h2^2*h0*h3+8*y3^2*x1*x2*h0*h1*f0*f6^2-4*y3^2*x2^2*f0*f5*h2*h3*f4+y3^2*x2^2*f0*f5*h2*h3^2*h1-y3^2*x2^2*f0*f5*h2^3*h3-y3^2*x2^2*f5*h0^2*h2*h3*f4+8*y3^2*x2^2*f0*f2*f6*h3^2+y3^2*x2^2*h0^2*f2*f6*h3^2-4*y3^2*x2^2*f6*f1*f4*h0*h3+y3^2*x2^2*h0^2*f4*h2^2*f6-2*y3^2*x2^2*f0*f3*f5*h3^2-4*y3^2*x2^2*f0*f3*h2*h3*f6-2*y3^2*x2^2*f3*f5*h0^2*f6-y3^2*x2^2*f3*f5*h0^2*h3^2-y3^2*x2^2*f5*h0^2*h1*h2*f6+y3^2*x2^2*f3*h0^2*h2*h3*f6-y3^2*x2*f1*f6*h2^3*h0*x1-y3^2*x2*f1*f4*h3^2*h0*h2*x1+y3^2
    *x2*f5^2*f1*h0*h2*x1-2*y3^2*x1*x2*f0*f5^2*h1*h2-4*y3^2*x1*x2*f0*f5*h2*h3*f3-2*y3^2*x1*x2*f0*f5*h2^2*h3*h1-y3^2*x1*x2*f5^2*h0^2*f3-y3^2*x1*x2*f5*h0^2*h2*h3*f3-4*y3^2*x2*f6*f1*f4*h0*h2*x1+8*y3^2*x1*x2*f1*f0*f6*h3^2+2*y3^2*x1*x2*h0*h1*f0*f6*h3^2+2*y3^2*x1*x2*f0*f6*h2^3*h1+4*y3^2*x1*x2*f4*f6*h0^2*f3+4*y3^2*x1*x2*f0*f6*h2^2*f3+y3^2*x1*x2*f6*h0^2*h2^2*f3+4*y3^2*x1*x2*f0*f4*h3^2*f3+y3^2*x1*x2*f4*h0^2*h3^2*f3-y3^2*x3*x2*h0^2*f5^2*h2*h3+2*y3^2*x3*f2*f5*h2*h3^2*h0*x2+2*y3^2*x3*f2*f5*h2^2*h3*h0*x1+4*y3^2*x3*x2*f0*f4*f5*h3^2-8*y3^2*f2*f6*x3*f4*h0*h2*x1+y3^2*x3^2*f3*h1*h2*f5^2+8*y3^2*x3^2*f2*h0*h2*f6^2+2*y3^2*x3^2*f2*h0*h2*f6*h3^2+y3^2*x3^2*h2^2*h3^2*f2*f4-y3^2*x3^2*f5*h1^2*h2*h3*f4-8*y3^2*x3^2*f6^2*h0*h1*f3-8*y3^2*x3^2*f1*f6*h3^2*f3+8*y3^2*x3^2*f0*f4*f6*h3^2+y3^2*x3^2*f4*h0^2*f6*h3^2+8*y3^2*x3^2*f2*f6*f4*h2^2+y3^2*x3*x2*f1*h3^2*f4*h2^2+3*y3^2*x3^2*f3*f6*h1^2*h2*h3-4*y3^2*x3^2*f3*f6*h1*h2*f4-y3^2*x3^2*f5*h0^2*h2*h3*f6-2*y3^2*x3^2*f3*f6*h1^2*f5-2*y3^2*x3^2*f2*f3*h3^2*f5-y3^2*x3^2*f2*h0*h3^3*f5-2*y3^2*x3^2*f3*h1^2*h3^2*f5+y3^2*x3^2*f6*h0*h1^2*h3*f5+2*y3^2*f2*f5^2*x3*h0*h2*x1+4*y3^2*x3^2*f1*f6*h1*h3*f5+4*y3^2*x3^2*f4*f6*h0*h1*f5+4*x1*x3*y3^2*f1*f6*h0*h3^2*h1+8*y3^2*x3*x2*f2*h0*h1*f6^2+4*y3^2*x3*f2*f6*h1*h3*h0*h2*x1-x1*x3*y3^2*f1*f5^2*h1*h2-x1*x3*y3^2*f5^2*h0*h1*f3+2*x1*x3*y3^2*f1*f5*h2*h3^2*h0-x1*x3*y3^2*f1*f5*h2^2*h3*h1-x1*x3*y3^2*f5*h0*h1*h2*h3*f3+2*f3*x1^2*f1*y1*y4*h0*h2-4*y4*x1^2*y1*f0*f3*h1*h2+4*y2*y4*x1*x2*f2*f6*h0^2-4*x3*y2*y4*x2*f0*f5*h2*h3+4*x3*y2*y4*x1*f0*f6*h1*h2-4*y2*y4*x1*x2*f1*f6*h0*h1-4*f0*x2*f5*y1*y4*h1*h3*x3-2*y2*f1*f6*x3*y4*h0*h2*x1+4*y2*y4*x2^2*f0*f6*h1*h2-8*f4*f0*x1*y1*y4*h1*h3*x3-4*y4*x1^2*y1*f1*f4*h0*h1+2*f3*x1*f1*y1*y4*h0*h3*x2-4*y4*x1*x2*y1*f1*f5*h0*h1-4*y4*x2^2*y1*f1*f6*h0*h1-2*y4*x1*x2*y1*f1^2*h2*h3+4*y4*x1*x2*y1*f0*f5*h1^2+4*y4*x1*x2*y1*f2*f5*h0^2-4*y4*x3^2*y1*f0*f5*h2*h3-h1*h3^3*x1^2*y3*y2*f0*f1+2*h0^2*h2*y3*x2^2*y2*f6*f2*h3-2*h0*h2^3*y3*x3*x2*y2*f2*f6-h0*h2*y3*x2^2*y2*f1*f4*h3^2-2*h0*h3^3*x3^2*y2*y1*f0*f4-h0*h2*x1^2*y3*y2*f0*f3*h3^2+h0*h2^2*y3*x2^2*y2*f1*f5*h3-h1*h3*y3*x2^2*y2*f3*f6*h0^2-h0^3*h2*x1^2*y3*y2*f3*f6+16*y3*y2*f1*x3*f6*f4*x4+2*h0*h1*h3^2*f0*x1^2*y3*y2*f4+h1^2*h3^2*y3*x2*f1*f4*y1*x3+h1*h3*y3^2*x3*x2*f5*f6*h0^2-2*h1^3*h3*y3^2*x3^2*f4*f6-2*h1*h3*y3^2*x2^2*f4*f6*h0^2+4*y2*y4*f0*f5*x4*x1-2*h1^2*h3*y3*x1*x2*y1*f0*f4*h2+4*y3^2*x4*x3*f2*h3^2*f4+4*h0*h1*h3^2*y3*f0*f4*x2*x1*y1-2*h0^3*h3*x1^2*y3*y2*f2*f6+4*x4*x3*y2^2*f6*h2^2*f0+4*y4*f0*x2*f5*x4*y1-2*y4*f3*x1*f1*x4*y1+4*y3^2*x1*x4*f6*f4*h0^2+2*h1^2*h3^2*y2*f0*f4*x2*y1*x3-h0^3*h2*x3*y2^2*x2*f5*f6-h0^2*h3^2*y3*x2^2*f2*y2*f5-12*h0*h3*y2*f0*f6*x2*x3*f3*y1+4*h0*h3*y2*f0*f5*x2*x3*f4*y1-h0*h2*y3^2*x3*x2*f3*f4*h3^2-h0*h2^2*y2*x1*x2*y1*f0*f3*h3-2*h0*h2^3*x1^2*y1^2*f0*f2+4*h0*h3*y3*y4*x3*f5*x1*f2+h0*h3*y2*x3*f3*x2*f5*f1*y1-2*h1^2*h3*y2*x1*x3*y1*f0*f4*h2-2*h0*h3^2*y3*x2*f2*y2*f5*h1*x3+h0^3*h3*x3^2*y2*y1*f5^2-y2^2*x1*x4*f1^2*h3^2+2*y3*x4*x2*y2*f6*h0*h1*f3+y4*x1*x4*y1*h0*h3*f1+4*x1*x4*y3*y2*h3^2*f0*f3-h1*h3*x3^2*y2*y1*f3*f6*h0^2-h1*h3^3*x3^2*y2*y1*f0*f3-2*h0^2*h3^2*y2^2*x3*f4*x1*f2+4*h0*h3*y3*f0*f4*x2^2*f5*y1-2*h1*h3*x1*x3*y3^2*f4*f6*h0^2-h1*h3^3*y3^2*x1*x2*f0*f3-h0^3*h2*y3*x2^2*y2*f5*f6-y3^2*x4*x2*f5^2*h0*h1+16*y3^2*f2*f6*x3*f4*x4+2*h1*h3*x1*x3*y3^2*f0*f6*h2^2-2*h0*h2*y3*x1^2*y1*f0*f2*h3^2-4*h0*h2*x1^2*y3^2*f0*f6*h1*h3-2*h0^3*h3*y3^2*x1*x2*f4*f6-2*x2*x4*y1^2*f5*f1*h0*h1-h0^3*h2*x1*x3*y1^2*f3*f5-2*h0*h2^2*x3*x2*y1^2*f0*f6*h1+2*h0^2*h2*x2^2*y2^2*f6*f1*h3-h0*h2^3*y3^2*x3*x2*f3*f6-h0*h2*y3*x1*x2*y1*f1*f6*h1^2-4*y3^2*x4*x3*f3*h1*h2*f6-2*h0*h3^3*x3*x2*y1^2*f0*f2-2*h0*h2*y3*x4*x2*f5*f2*y1+4*h0*h3*y4*x3*f4*x1*f1*y1+2*h0*h3*y4*x3*f5*x2*f1*y1+4*h0*h3*y2*f0*f5^2*x3^2*y1-4*y2*f5*x1*f1^2*x4*y1+2*y2*x4*x2*y1*f0*f5*h1*h2+h0*h2*y3*x1^2*y1*f1^2*h3^2-4*x1*x4*y1^2*f4*f1*h0*h1+2*h0*h2*y2^2*f6*x1^2*f1^2+2*h0*h2*y3*x1^2*y1*f0*f6*h1^2-2*h1*h3*y3^2*x2^2*f0*f6*h2^2-4*h0*h2*x3^2*y1^2*f0*f6*h1*h3+2*y3*x4*x2*y1*h3^2*f0*f3+2*h0*h2*x2^2*f6*f1^2*y1^2-h1*h3*y3^2*x1*x2*f3*f6*h0^2+2*h0*h1*h3^2*f0*f4*x2*x3*y1^2-4*h0*h2^2*x1*x2*y1^2*f0*f2*h3+h0*h3^3*x1*x3*y3^2*f2*f3-h0*h2*x3*x2*y1^2*f0*f3*h3^2-4*h0*h2^2*x1^2*y2*y1*f0*f2*h3-h1*h3*y2*y4*x1*f1*x4+2*h0^2*h2*x1^2*y2*y1*f1*f5*h1+h0^3*h3*y3*x1*y2*x3*f5^2+h0^3*h3*y3^2*x1*x2*f5^2-2*h0*h2^2*y2*x1*x2*y1*f0*f5*h1+4*y3*x4*x2*y2*f6*f4*h0^2+4*h0*h3*f0*f5^2*x3*x1*y2*y3+4*h0*h3*f1*x3*f6*x2*y2*f2*y1-4*h0*h2*x3*f6*x2*f3*y3^2*f4-2*h0*h2*y2*y4*x3^2*f6*f3-4*h0*h2*y3*f1*x3^2*f6*f5*y1-x2*x4*y1^2*h2*h3*f1^2+8*h0*h3*y2*f0*f4^2*x3*x1*y1+4*h0*h3*y2*f6*x3*x1*f1^2*y1+4*h0*h3*f0*f4*x2*x1*y2*f3*y1-4*h0*h2*y3*y4*x3*f6*x2*f3-8*h0*h2*x3*f6*x2*f2*y3*y2*f4-4*h0*h2*y2*y4*x3*f6*x2*f2+h0*h2*x3*y2^2*f5^2*x2*f1-4*h0*h2*y3*x3*y2*f5*x2*f6*f1-h1*h3^3*y3*x3^2*y1*f1*f3-4*x1*x4*y1^2*f0*f3*h1*h2-4*h0*h2*x3*f6*x2*f1*y2^2*f4+16*f0*x4*f6*x2*y3*y2*f4-4*h0*h2*y2*f0*f5*f4*x1*x3*y1-4*h0*h2*f1*x3*f6*x1*y2*f2*y1+2*h1*h3*y3*x1*x3*y1*h0^2*f4^2-h1^2*h3*y3*x3*x2*y2*f3*f6*h0+2*h1^2*h3^2*y2*f0*x2*x1*f4*y3-4*h0*h2*y3*x4*x2*y2*f6*f2-h1*h3*y4*f1*x2*x4*y1-4*y3*x4*x2*y2*f0*f5*h2*h3-y3*x4*x2*y2*h0^2*f5^2+2*h1*h3*y2*x3*f4*x1*f1*h0*h2*y1-4*y2*f0*f5*x1*h1*h3*y3*x4+4*x4*x3*y2*y1*h3^2*f0*f3-4*h0*h2*x1*x4*y3*y2*f6*f1-h0*h2*y2*y4*x4*x3*f5-2*h0*h2*y2^2*x1^2*f0*f2*h3^2+2*f3*x1*f1*y1*h0*h3*y2*x4-4*f1^2*f6*x3*x4*y1^2-4*y2*f1*f6*x3*h0*h2*y1*x4-4*y2^2*f0*f5^2*x3*x4+h1^2*h3^2*y2*x3*f4*x1*f1*y3-2*h0*h3^3*y3^2*x1*x2*f0*f4+4*y3^2*x4*x2*f6*h0*h1*f4-2*h0*h3^3*y3*x1*y2*x3*f1*f3+2*y3*x4*x3*y1*h3^2*f1*f3+h1^2*h3^2*y3*x2*f1*y2*f5*x3-2*h1^2*h3*y3*x3*x2*y2*f1*f6*h2-8*h0*h3*y3*y2*f2*f0*f6*x1^2+4*h0*h3*y3*y2*f0*f5*f4*x2*x1+4*h0*h3*y3*x2*f2*x1*y2*f6*f1+2*y3*x4*x2*y1*f6*h0^2*f3-h0*h3*y3*x1*x3*y1*f3*f4*h1^2-h0*h3*y3*x1*x3*y1*f3*h2^2*f2+16*y2^2*f0*f4*f6*x3*x4-2*y3^2*x2*f5^2*f1*x4-h0*h2^3*y3*x2^2*y2*f1*f6-2*h0^2*h3*f1*y2*f4*x2*y1*h2*x1+4*y3^2*x1*x4*f6*h2^2*f0+2*y3^2*f5*x3*f3*h1*h3*x4+h0^3*h3*x3*x2*y3*y1*f5^2+4*y2*x4*x2*y1*f6*f0*h1^2+2*h0*h2*y4*x1*f2*x4*y1+h0*h2*y3*x2^2*y2*f5^2*f1+2*h0*h2*y3^2*x1^2*f3*f6*f1-x4*x3*y2^2*h0^2*f5^2+h1^2*h3^2*y2^2*f0*f5*x2*x3+4*x4*x3*y2^2*h3^2*f4*f0+4*y2*x1*x4*y1*h0^2*f5*f2-h1*h3*y2*x1*x3*y1*f4*h0^2*f3+2*x4*x2*y2^2*h3^2*f0*f3+2*x1
    *x4*y3*y1*h0^2*f5*f3+y3*x4*x2*y1*f1*f5*h0*h3-x1*x4*y1^2*h0^2*f3^2+2*h1*h3*y3*y4*x3*f4*x4-4*h0*h2*y3*f0*f4*x1*x2*f5*y1+4*y3^2*x4*x3*h1^2*f6*f4-8*h0*h2*y3*f2^2*x3*f6*x1*y1-4*h0*h2*y2*f0*f5*f6*x3^2*y1+h0*h3*y3*x2*y2*f3*x1*f5*f1+8*h0*h3*y3*x3*f4^2*x1*f1*y1-2*h1*h3*y3*x3^2*y1*f4*f6*h0^2+2*h0*h3*f1*y2*f4*x2*x4*y1+8*y4*f4*f0*x1*x4*y1-2*y3*x4*x3*y2*f5^2*h0*h1+4*y2*x4*x2*y1*h3^2*f0*f2-4*h0*h2*y3*x1*f2*x2*f1*f6*y1-4*h0*h2*y3*x1*f2*x3*y2*f6*f3-4*h1^2*h3*x3*x2*y1^2*f0*f6*h0+h0^3*h3*x1*x3*y1^2*f4*f3+h0^3*h3*y3*x1^2*y1*f4*f3-y3^2*x1*x4*h0^2*f5^2-y3^2*x4*x3*f5^2*h1^2+h1^2*h3^2*y3^2*x1*f1*x3*f5+4*h1*h3*x1*x2*y1^2*f0*f3*h0*h2+h1^2*h3*x1*x2*y1^2*f3*f1*h0+2*h1*h3^2*y3^2*x3*x2*f1*f5*h2-4*h1^2*h3*y3*x3^2*y2*f4*f6*h0+8*h0*h3*y3*f2^2*f5*x3*x1*y1+2*y2*y4*x3*x4*f6*h0*h1+4*x1*x4*y3*y1*f0*f5*h1*h2-4*y3^2*x4*f3^2*x3*f6+h1*h3^2*y2^2*x3*f4*x1*f1*h0-8*h0*h3*y2*f0*f6*x3^2*f4*y1-8*h0*h3*y3*f0*f5*f3*x2*x1*y1+16*y3*y2*f0*x4*f6*x1*f3-h0*h2*y3*y4*x2*f5*x4+4*y2*x4*x2*y1*f6*h0^2*f2+y3*x4*x2*y1*f1*f5*h1*h2-4*h0*h2*y3*y2*f0*x1^2*f6*f3+h1^2*h3*y2*x2^2*y1*f1*f5*h0+h1^2*h3*x1^2*y2*y1*f3*f1*h0+2*h1*h3^2*x3*y2^2*x2*f0*f6*h0+8*y2*y4*f0*x4*f6*x2+2*h0*h3*y3*x4*y2*x1*f5*f1-h1^2*h3*y2^2*x1*x3*f0*f5*h2+h0*h3^3*x3*x2*y1^2*f1^2+2*h1*h3^2*y2^2*f0*x2*x1*f4*h0-h1*h3^3*y2*x2^2*y1*f0*f1+h1^2*h3*y2^2*x1*x2*f1*f5*h0+h1^2*h3^2*x1*f1*y3*f3*y1*x3+8*f0*f5*x2*f2*x4*y1^2+2*h1*h3^2*y2*f0*f4*x2^2*y1*h0+8*y2*x1*x4*y1*f0*h2*h3*f2+h1^2*h3^2*y3^2*f0*f5*x2*x1+4*x4*x3*y2*y1*f6*h0^2*f3+4*h1*h3*x1^2*y2*y1*f0*f3*h0*h2-2*h1^2*h3*x3^2*y2*y1*f0*f6*h2-2*h1*h3*y2*x1*x2*y1*f2*f4*h0^2-4*h0*h2*y3^2*x3*f5*x1*f6*f1-2*h1^3*h3*y2*x1*x2*y1*f0*f4-4*h1^2*h3*y3^2*x3*x2*f4*f6*h0-2*h1^2*h3*x1*x3*y3^2*f1*f6*h2+2*y3*y4*x1*x4*h3^2*f0+4*y3*y4*x4*x2*f1*f6+4*h0*h3*y3*f2*x3^2*f6*f3*y1+4*h0*h3*y2^2*f0*f5*x3*x1*f4-2*h1*h3^2*y3*x3^2*y2*f0*f6*h2-2*h1^2*h3*y3^2*x1*x2*f0*f6*h2+16*f2*f6*x3*x4*f0*y1^2-h1^2*h3*x1*x3*y3^2*f3*f6*h0-h1*h3*y3*x1*x2*y1*f4*h0^2*f3+4*x4*x2*y2^2*f6*f0*h1*h2+2*x4*x2*y2^2*f6*h0^2*f3-2*h0^3*h3*x3*x2*y1^2*f2*f6-h1*h3^3*y3*x3*x2*y2*f1*f3+2*h1*h3^2*y3*x3^2*y2*f1*f5*h2+2*h0*h3^3*y3*x1*y2*x3*f2^2+4*y3*x4*x2*y2*f6*h2^2*f0+4*y3*x4*x2*y2*h3^2*f4*f0+h1^2*h3^2*y2*f0*f5*x3^2*y1+h0^3*h3*y3*x1*x2*y2*f4*f5-2*h1*h3^2*y3^2*x3*x2*f0*f6*h2-2*h0*h2^2*x1*x3*y1^2*f0*f5*h1-h0*h2^2*x1*x3*y1^2*f0*f3*h3+h0*h3^3*y3*x1*x2*y2*f1*f2+4*f0*x2*f5*x4*y2*f3*y1+16*y2*f0*f3*f6*x3*x4*y1-4*y2*x1*x4*y1*f5*f1*h0*h1-2*y2*x1*x4*y1*h2*h3*f1^2-h0*h2*x3*x2*y3*y1*f2*f3*h3^2+4*h0^2*h2*h3*y3*x1*f2*x3*y2*f6+4*h0^2*h2*h3*y3*x3*f6*x2*f2*y1+2*h0^2*h2*h3*y3^2*f6*x2*x1*f2-2*h0*h3^2*y3*x2*f2*f4*y1*h1*x3+2*h0^2*h2^2*y3*x2*y2*f6*f2*x1-2*h1*h3^3*y3^2*x3^2*f2*f4-h0^2*h3*y2*x3*f5*x2*f2*h2*y1-2*h0*h3^2*y3^2*x3*f5*x1*f2*h1+16*f0*f4*f2*x1*x4*y1^2-h1*h3*x1^2*y2*y1*h0^2*f3*f2+8*x1*x4*y3*y2*f6*f0*h1*h2+2*y2*x4*x2*y1*f0*h2*h3*f3+2*h0^2*h2*x1*x2*y1^2*f1*f5*h1+4*y3*x4*x3*y2*f6*f1*h2^2+4*y3*x4*x3*y2*h3^2*f1*f4-8*h0*h2*y3*y2*f0*f6^2*x3*x2-h1^2*h3*y3*x2^2*y1*f0*f5*h2-4*y2^2*f6*x1*f1^2*x4+2*h0*h3*y3*x2*f2*x4*y2*f5+h0*h3*y3^2*x2*f3*x4*f5+8*h0*h3*y3*f0*f4^2*x2*x1*y1+4*h0*h3*f1*y2^2*f6*x3*x1*f2+h0^2*h2^2*y2*x2^2*f6*f1*y1-2*h0*h2^2*x3*x2*y3*y1*f2*f6*h1+2*h1*h3*y2^2*f0*f5^2*x3^2+2*h1*h3*f0*f5^2*x2^2*y3^2-4*h0*h2*f0*f3*f5*x1*x3*y1^2-8*f4*f0*x1*y1*h1*h3*y3*x4-4*f0*f5^2*x4*x1*y3^2-4*x4*x3*y1^2*f1*h0*h1*f6+h1^2*h3^2*y2*f0*f5*x2^2*y3-4*h0*h2*y2^2*f0*f6*x3*x2*f5-4*h0*h2*x3*f6*x2*f2*y3*f3*y1-4*h0*h2*y2*f0*f5*f3*x1*x2*y1+8*y3*x4*x3*y2*f6*h0*h1*f4+8*y3*f1*x3*f6*f3*x4*y1-h0*h2*x1^2*y1^2*f1^2*h1*h3+2*h0*h3*f1*y2*f5*x3*x4*y1+4*h0*h3*y3*x4*x1*f4*f1*y1-8*h0*h3*y3^2*f0*f4*f6*x2*x1+2*h0^2*h2*h3*y2*f2*x3^2*f6*y1+2*y4*x4*x3*y1*f6*h0^2+h1*h3*x1*x3*y3^2*f5^2*h0^2-4*h1*h3*f0*x3*f6*x2*f1*y1^2+h1*h3^2*y3*x2^2*f1*f4*y1*h0-x4*x3*y1^2*f1^2*h3^2-2*h0*h2*y2*y4*x2^2*f6*f1+2*h1*h3*f0*f3*f5*x3^2*y1^2-2*h1*h3*y2*y4*x3*f4*x1*f1-4*h1*h3*f0*f5*f1*x3*x1*y1^2-4*h1*h3*y2^2*f2*f5*f0*x2*x1+h0^2*h2^2*x3*f5*y3*f3*y1*x1-4*h1*h3*f0*x2*x1*f3*f2*y1^2+h1*h3*x2*f1^2*x1*f3*y1^2-y4*x1*x4*y1*f3*h0*h1-4*h1*h3*y4*f0*x2*x1*f3*y1+h1*h3*x2^2*f1^2*y2*f5*y1-8*h1*h3*y3*f0*f4^2*x3*x1*y1-4*h1*h3*y2^2*f1*f0*f6*x2*x1-4*h1*h3*y3*f1*f5*f0*x1^2*y1+8*h0*h3*y3*f2^2*x3*f6*x2*y1+2*y4*x4*x3*y1*h3^2*f0+4*h0*h3*y3*x3*f3*x2*y2*f6*f2-8*h0*h3*y3*x3*f3*x1*y2*f6*f1+h0*h3^3*y3*x2^2*y1*f1*f2-4*f0*x2*f5^2*x4*y2*y3-4*h1*h3*y2*f0*f5*x2^2*f2*y1-4*h1*h3*y2*f0*f3*x1^2*f2*y1-2*f5*x2*f1^2*x4*y1^2-8*h1*h3*y2*f0^2*f6*x2*x1*y1-4*h1*h3*y2*f0*f6*x2^2*f1*y1+h1*h3*x1^2*f1^2*y2*f3*y1+h1*h3*x1*f1^2*y2^2*x2*f5-4*h1*h3*y2*f1*f5*f0*x2*x1*y1+h0*h3^3*y3*x3^2*y1*f2*f3-h1^3*h3*y3*x1*x3*y1*f5*f1+h0^3*h3*y3*x2^2*y1*f4*f5-y2*x4*x2*y1*f1^2*h3^2+8*y2^2*f0*f6*x2*f3*x4+h1^2*h3^2*x3^2*y3*f5*f1*y1-h1^3*h3*x3*x2*y3*y1*f1*f6-h1*h3^3*x1*x3*y3^2*f1*f3-h0*h2*y3*x1*y2*x3*f2*f3*h3^2+h0*h3^3*y2^2*x1*x3*f1*f2-4*h1*h3*y3*y2*f1*f0*f6*x1^2+2*h0*h2*y3*x2*f5*f2*y1*h1*h3*x3-2*h0^3*h2*y3*x3*x2*y2*f6^2-8*h0*h3*f0*f6*x3*x2*f2*y1^2+4*h0*h3*y3*x3*y2*f4*x1*f5*f1+4*h0*h3*y3*y2*x1^2*f6*f1^2+2*y3^2*x4*x2*h3^2*f1*f4-2*h1^2*h3*y3*x3^2*y1*f1*f6*h2-h1^2*h3*y3*x3^2*y1*f3*f6*h0-8*h1*h3*y2*f0*f4*f2*x2*x1*y1-2*h1*h3*f0*f5*x2^2*y3*f3*y1-4*x4*x3*y2^2*f0*f5*h2*h3+2*h1*h3*x2*f1^2*x1*y2*f4*y1-2*h0^2*h3*y3*x1^2*f4*f1*y1*h2-2*h0*h2*y2*y4*x1*f2*x3*f5-12*h0*h3*y3*y2*f0*f3*f6*x2*x1-2*h1*h3*y2^2*f0*f5*x3*x1*f3-4*h1*h3*f6*x3^2*f0*y2*f3*y1-4*h1*h3*f4*f0*x3*x1*y2*f3*y1+4*y2^2*x1*x4*f6*f0*h1^2-y3^2*x4*x3*f3^2*h3^2+4*h0*h3*y3*x2*f2*x1*f5*f1*y1+8*h0*h3*y3*f2^2*x3*f6*x1*y2+4*y2^2*x1*x4*f6*h0^2*f2+4*h0*h2*h1*h3*y3*x3^2*y2*f6*f3+2*h0*h2*h1*h3*y3*x2*y2*f5*x1*f1+2*h1*h3*f0*x1^2*f3*y3^2*f5-4*h1*h3*y3*f0*f4*f5*x3*x2*y1+y2*y4*x1*x4*h0^2*f5-h0*h3*y3*x2*f3^2*x4*y1+4*h0*h3*y3*x2*f2*x4*f4*y1+4*h0*h3*y3*x3*f5*x4*f2*y1+4*y3*x4*x3*y1*f6*f1*h1*h2+4*y3*x4*x3*y1*f6*h0*h1*f3-h0*h2*h1*h3*y3^2*x3^2*f5^2+2*h0*h2*h1*h3*x1*x3*y3*y2*f5*f2-4*h1*h3*f0*x2*x1*f4*y3*f3*y1+2*h0*h2^2*y3*x3*x2*y2*f2*f5*h3-2*h0*h2*x1*x3*y1^2*f0*f2*h3^2+3*h0*h2*y3^2*x1*x2*f0*f5*h3^2+16*f0*f6*x1*x4*y3^2*f4+4*h0*h3*y3^2*x3*f3*x1*f6*f2-h0^3*h2*y2*x1*x2*y1*f3*f5-4*h1*h3*y3^2*x3*f3*x1*f6*f1+2*h1*h3^2*x1^2*y3^2*f0*f5*h0-4*h1*h3*y3*f6*x2*f1*x3*f2*y1+h0*h2^2*y3*x3^2*y2*f3*f5*h3+4*x1*x4*y3*y2*f6*h0^2*f3+
    2*h0^3*h3*y3*x1*x2*y1*f4^2+h0*h3^3*y3*x1*x2*y1*f1^2+h0*h3*y2*y4*x3^2*f5*f3+2*h0*h3*y2*y4*x3*f5*x2*f2-4*y3*x4*x3*y2*f5*h2*h3*f1+4*y2^2*x1*x4*h3^2*f0*f2-2*h0*h3^3*x3*x2*y3*y1*f1*f3+h0^2*h2^2*y2*x1*f2*x3*f5*y1-2*h0*h2*y2^2*x1^2*f0*f6*h1^2-4*h1*h3*f0*x2*x1*f3*y3^2*f6-4*h1*h3*y3*x3*f2*x1*f5*f1*y1-h0*h3*y2*y4*x3*f3^2*x1+h0*h3*y2*y4*x1^2*f3*f1-h0*h3*x1^2*f3*f1*y3^2*f5-4*h1*h3*y3*f1*x3^2*f6*f3*y1+8*x4*x3*y2*y1*f6*f0*h1*h2+2*y3^2*x4*x2*f6*f1*h2^2-8*h1*h3*y3^2*f2*f6*x3^2*f4-h0*h3^2*y2*x2*f4*x1*f1*h1*y3-h0*h2*y2*x2^2*y1*f0*f3*h3^2-2*h0^2*h3*y3*x2*f2*f4*y1*h2*x1+2*h1*h3*f0*x3*f5^2*x2*y2*y3+2*h0*h3*y2*y4*x2*f4*x1*f1+2*h0*h3*y3*y4*x2*f5*x1*f1+8*f0*x4*f6*x2*y3*f3*y1+2*h0^2*h2*y2*x2^2*y1*f0*f6*h3+4*y3^2*x1*x4*h3^2*f4*f0-h0*h2^2*y3*x2^2*y1*f1*f6*h1+y3*x4*x2*y2*h3^2*f1*f3+4*x1*x4*y3*y1*f0*h2*h3*f3-4*y3^2*f2*f5^2*x3*x4-2*h0^2*h3^2*y3*x2^2*f2*f4*y1+4*y3*x4*x2*y1*f6*f0*h1*h2-4*h1*h3*y3*y2*f0*f5*f4*x3*x1-4*h1*h3*y3*f6*x1*f1*y2*x3*f2+h0*h3*y2*y4*x2^2*f5*f1-2*h0*h2*x2^2*y1^2*f0*f2*h3^2-4*h0*h2*y2^2*x2^2*f0*f6*h1*h3-4*h0*h2*y3^2*f0*f5*x1*f6*x2-h0*h2*y2*y4*f1*x1*x2*f5-4*h1*h3*y2*y4*f0*x2*x1*f4-2*h1*h3*y3*y4*x1*f1*x3*f5-2*h1*h3*y2*y4*f0*x1^2*f3-4*h1*h3*y3*y4*f0*f5*x2*x1-2*h1*h3*y2*y4*f0*f5*x2^2+2*y3*y4*x4*x3*h1^2*f6+2*h0*h3^3*x3*x2*y3*y1*f2^2-4*h1*h3*y3*f6*x2*f1*x3*y2*f3-h1*h3*y2*y4*x3*f5*x2*f1+4*h0*h3*y2*y4*x3*f4*x1*f2+4*h0*h3*y3*f0*f5^2*x3*x2*y1-2*h0^3*h3*y3*x1*x2*y1*f3*f5-8*y3*f2*f6*x3*h0*h2*y1*x4+2*h0^2*h2^2*y2*x3*f6*x2*f2*y1-4*h1^2*h3*x1^2*y3*y2*f0*f6*h0-h1*h3^3*x3*x2*y3*y1*f1*f2+h1*h3*x3*x2*y3*y1*f4*f5*h0^2-h1*h3*x3*x2*y3*y1*f0*f5*h2^2-2*h0^3*h3*x3^2*y2*y1*f4*f6-h0*h2*y2^2*x1*x2*f0*f3*h3^2-2*h0*h3^2*y2*x3*f4*x1*f2*h1*y3-h0^2*h3^2*y2^2*x2^2*f5*f1+y2*x4*x2*y1*h0^2*f5*f3-2*h0^2*h3*y2*x3*f4*x1*f2*h2*y1+2*y3*y4*x4*x3*f2*h3^2+2*h0*h3*y2*y4*x3*x4*f4+h0*h3*y3*y4*x4*x1*f3+2*h0*h3*y4*x2*f2*x4*y1+2*h0*h3*y2*y4*x4*x1*f2+h0*h3*y3*x3*f3^3*x1*y1-8*h0*h3*y3*x3*f3*x1*f5*f1*y1-2*h1*h3*f0*f3*x2*x4*y1^2+h0*h3^3*y2*x1*x3*y1*f1^2+h0^2*h2^2*x3*x1*f5*f1*y1^2-8*h0*h3*y3*x3*f3*x2*f1*f6*y1+4*h0*h3*y3^2*f0*f5^2*x2*x1-4*y3^2*x4*x3*f5*h2*h3*f2-y3*y4*x4*x3*f3*h2*h3-4*h0*h2*y4*x3*f6*x2*f1*y1+y3*y4*x4*x2*h3^2*f1-2*h0^2*h3*x3*f4*x1*f1*y1^2*h2+2*y3*y4*x1*x4*f6*h0^2-8*h0*h2*f0*f4*x1^2*f2*y1^2-2*h0*h2*y3^2*x3^2*f6^2*h1^2-4*h0*h2*x3*f6*x2*f3*f0*y1^2-4*h0*h2*y3*y2*f0*f5*f6*x2^2+y2*y4*x3*x4*h3^2*f1+4*y2*y4*f1*f6*x3*x4-4*f0*f3^2*x1*x4*y1^2+h0*h2*y3^2*x2*f5^2*x3*f3-h0^3*h2*y2*x1*x3*y1*f4*f5+2*h1*h3^2*y3*x2^2*y2*f0*f6*h0+2*h0*h2^2*y2*x1*x3*y1*f0*f4*h3-2*h0^3*h3*y2*x1*x3*y1*f3*f5+h0^3*h3*y2*x1*x2*y1*f4*f3+2*h0*h2*x1*x3*y1^2*f0*f6*h1^2-h0*h2^3*y2*x1*x3*y1*f0*f5+2*y2*y4*x4*x2*f6*h0^2+h0^2*h2^2*y2*x2*f5*f1*y1*x1+16*y2*f0*f6*x2*f2*x4*y1-2*h0*h2*x2^2*f6*f1*y3*f3*y1+2*h0*h2*y3*x3*f5^2*x2*y2*f2-4*h0*h2*x2^2*f6*f1*y3*y2*f4+3*h0*h2*x3^2*y2*y1*f0*f5*h3^2-h0*h2^3*x3*y2^2*x2*f1*f6-2*h0^2*h2*x1^2*y2*y1*f0*f6*h1+2*y3*x2*f5*f1*x4*f3*y1-4*y2*x4*x2*y1*f1*h0*h1*f6+8*y3^2*x2*f6*f1*x4*f4-2*h0*h2*y4*x3*x1*f5*f1*y1-4*h0*h2*y3*x3*f5*x1*f4*f1*y1+3*h1*h3*x3*x2*y1^2*f1*f6*h0^2+2*y2*y4*x1*x4*f0*h2*h3+8*y3*y4*f0*f6*x1*x4-4*y2*f6*x2*f1^2*x4*y1-4*h0*h2^2*x3^2*y2*y1*f0*f6*h3-h0^3*h2*x3^2*y2*y1*f5*f6-h0*h2^3*y3*x1*x3*y1*f1*f5-8*h0*h3*y2*f0*f5*x3*x1*f3*y1+4*h0*h3*y3*f6*x2*x1*f1^2*y1-4*h0*h3*y3*x3*f3*x1*f4*f2*y1+4*h0*h3*f1*f5*x3*x1*y2*f2*y1-2*h0*h2*x3*y2^2*f6*x1*f1*f3+4*x2*x4*y1^2*f0*h2*h3*f2+2*x2*x4*y1^2*f0*f5*h1^2+2*h0*h3*y3*y4*x2*x4*f4+2*h0^2*h2*y2^2*x3*f6*x2*f2*h3+4*x1*x4*y1^2*f0*f4*h1^2+2*y3*y4*x4*x2*f6*h0*h1+4*h0*h3*y3*f0*f4*x1^2*f3*y1+4*h0*h3*x3*f6*x2*f1^2*y1^2+4*h0*h3*f0*f4*x3*x1*f3*y1^2+h0*h2*x1*x2*y1^2*f0*f1*h3^2+4*h0*h1*h2*h3*y3*x2*y2*f6*x3*f2+4*y3^2*x4*x3*f2*f6*h2^2-3*h0*h3^3*y3*x1*x2*y2*f0*f3+h0*h2*x1*x3*y1^2*f1^2*h3^2-2*h0^2*h2*x1*x2*y1^2*f0*f6*h1-2*h0*h3^2*y3*x3^2*f5*f2*y1*h1-h0^2*h3^2*x3^2*f5*f1*y1^2+2*x2*x4*y1^2*h0^2*f5*f2+8*y3*f0*f5*x4*x1*f3*y1+2*h0*h2*y2*f6*x1*x2*f1^2*y1-4*h0*h2*y3*f0*f5*x1^2*f3*y1+4*h0*h1*h2*h3*y2*f0*x1*x2*f4*y1+2*y4*x1*x4*y1*h0^2*f4-2*y3*x2*f1*f6*h0*h2*y1*x4+x4^2*y4^2-h0*h2*x3*y2^2*x2*f1*f4*h3^2-4*y3^2*x1*x4*f0*f5*h2*h3+2*h0^2*h2*x3^2*y1^2*f1*f6*h3-h1*h3^3*x3*x2*y1^2*f0*f1-h1^3*h3*x1^2*y2*y1*f0*f3+2*h0^3*h3*y2*x1*x3*y1*f4^2-4*h0*h2^2*y3^2*x1*x2*f0*f6*h3+2*f3*x1*f1*y1^2*h0*h2*x4+h0*h2*x1^2*y2*y1*f0*f1*h3^2+2*h0*h2*y2*x2*f5*f1*y1*h1*h3*x3-h0*h3*x3^2*f5*f3*f1*y1^2+4*h0*h3*y3*x2^2*f2*f1*f6*y1+4*h0*h3*y3*x3*f4*x2*f5*f1*y1+h0*h2*y3*x3^2*f5^2*y2*f3+h0^3*h3*y2*x3*x2*y1*f4*f5+h0*h3^3*y2*x3*x2*y1*f1*f2-h0^2*h3^2*f1*y2*f4*x2^2*y1-h0^2*h3^2*y3^2*f1*x1^2*f5-4*y2^2*x1*x4*f1*h0*h1*f6+h0^2*h2*y2^2*x1*f2*x3*f5*h3+2*h0*h2*x3^2*f6*f3*f1*y1^2+h0*h1*h2*h3*x1*x3*y3*f3^2*y1-h0^3*h2*y3^2*x1*x2*f5*f6+4*y2*x1*x4*y1*f0*f5*h1^2+16*y2*f0*f5*f2*x1*x4*y1-2*h1*h3*y2^2*f0*f5*x2*x4-2*y3^2*x4*x2*f5*h2*h3*f1-h1^3*h3*y3*x1*y2*x3*f1*f6-h1*h3^3*y3*x1*y2*x3*f1*f2-4*f4*x1*f1^2*x4*y1^2-x1*x4*y1^2*h2^2*f1^2-h1*h3*y3*x1*y2*x3*f0*f5*h2^2+h1*h3*y3*x1*y2*x3*f4*f5*h0^2-4*h0*h2*x3^2*f6*f3*y3*y2*f4-4*h1*h3*y2*f0*f5*x3*x4*y1-4*h1*h3*y2*f0*f3*x1*x4*y1-3*h0^3*h3*y2*x3*x2*y1*f3*f6+h0^2*h2^2*y3*x2*f5*f2*y1*x1+y3*y4*x4*x3*h0*h3*f5-h0^2*h3^2*y3*x3^2*y2*f6*f3+y3*x4*x2*y1*f1*h2*h3*f3-h0*h2^2*y3*x1^2*y1*f0*f3*h3-2*h0^3*h2*x1^2*y1^2*f2*f4-h1*h3*x1*x2*y1^2*h0^2*f3*f2+2*h1*h3^2*x3^2*y1^2*f0*f5*h0-2*h0*h2^2*y3*x1^2*y1*f0*f5*h1+h0*h3^3*x1^2*y3*y2*f1^2+2*h0*h2^2*y3*x1*x3*y1*f1*f4*h3+2*h1^2*h3*y2*x1*x2*y1*f1*f4*h0-h0^2*h3^2*y3^2*x3*f6*x2*f3-h0^2*h3^2*x1^2*f0*y2*f3*y1+2*y2*y4*x4*x2*h3^2*f0-3*h0*h3^3*y2*x3*x2*y1*f0*f3-h0*h3^2*f1*y2*f4*x2*y1*h1*x3-2*h1*h3*x3^2*y2^2*f4*f6*h0^2-h1^3*h3*y2^2*x1*x2*f0*f5+y3*x4*x2*y1*h0*h1*f5*f3-h0^2*h3*y3*x2*f2*y2*f5*h2*x1-4*h1*h3*y2*f0*f4*x2*x4*y1-h0^3*h2*y3*x1^2*y1*f3*f5-3*h0^3*h3*y3*x1*x2*y2*f3*f6-h1^3*h3*x1*x2*y1^2*f0*f3-y4*x1*x4*y1*h1*h2*f1+8*y3*y4*f2*f6*x3*x4-2*y3*y4*f5*x3*f3*x4+8*y4*f0*f6*x3*x4*y1+4*x4*x3*y1^2*h3^2*f0*f2+4*x4*x3*y1^2*f6*f0*h1^2+h0^2*h2*y3*x2^2*f5*f2*y1*h3-2*h0*h2*y3^2*x4*x2*f6*f3-h1*h3*y2^2*x1*x2*f2*f5*h0^2+4*x4*x3*y1^2*f6*h0^2*f2-h0^2*h3^2*f0*f3*x1*x2*y1^2-2*h1*h3*x3^2*y2^2*f0*f6*h2^2-h1^3*h3*y2*x2^2*y1*f0*f5+4*h0*h2*y3^2*x3*x2*f3*f6*h1*h3-2*h0*h2*x2^2*y1^2*f0*f6*h1^2-h0^3*h2*x3*x2*y1^2*f3*f6-h0*h2
    ^3*y3*x1*x2*y1*f0*f5-h1*h3*x3*y2^2*x2*f3*f6*h0^2-h0*h2*y2*x1*x3*y1*f1*f6*h1^2+h0*h2*y2*x1*x3*y1*f1*f2*h3^2+2*h0*h2*y3*x1*x3*y1*f2^2*h3^2+h0^2*h2^2*x3*f6*x2*f1*y1^2-2*h1*h3*y3*x2*f1*x4*f4*y1-h0*h2^3*y3*x3^2*y2*f3*f6-2*h0*h3^3*x1^2*y3*y2*f0*f2+2*h0*h2^2*y3*x1*x2*y1*f0*f4*h3-h0^3*h2*y3*x1*x2*y1*f4*f5+y4*x4*x2*y1*h0^2*f5+2*y4*x1*x4*y1*f0*h2^2-2*h1*h3*x3*x4*y3*f5*f1*y1+h0^2*h2^2*x1^2*y3*f5*f1*y1-h0*h2*y3*x3^2*y2*f3*f4*h3^2+h0*h3^3*y3*x3*x2*y2*f2*f3+h0^2*h2^2*x1^2*y3*y2*f6*f1+h0*h3*y4*x3*f3*x4*y1+h0^2*h2^2*x2*y2^2*f6*f1*x1+2*h0^2*h2*y2^2*x1*x2*f0*f6*h3-2*h1*h3*x1^2*y1^2*h2^2*f0^2+h0*h3*y2*y4*x2*f3*x4+2*h1*h3*y3*x2*f1*f4*y1*h0*h2*x1-h0^2*h3^2*f1*f4*x3*x2*y1^2-h1*h3*y3*x2*f1*x4*y2*f5+h1*h3*y3*x3^2*y1*f5^2*h0^2+h0*h3*f1*f3*x2*x4*y1^2-2*y3*y4*x4*x3*h0*h2*f6+4*x1*x4*y1^2*h0^2*f4*f2+2*h0^2*h2*x1^2*y3^2*f1*f6*h3+h0^3*h3*y2^2*x1*x3*f4*f5-4*y3*y2*f1*f5^2*x3*x4-h1*h3^3*y2^2*x1*x2*f0*f1-2*h1*h3^3*y2*x1*x2*y1*f0^2-2*h0^2*h3^2*y3*f1*f5*x1*x3*y1+2*h1^2*h3*y3*x1*x3*y1*f2*f5*h0+2*h1*h3*y3*x3^2*y1*f0*f6*h2^2-h0*h2*y2*x4*x2*f5*f1*y1+h0*h2*y3*x1*x2*y1*f1*f2*h3^2-h0^2*h3^2*y3^2*f2*f5*x2*x1-h0^2*h3^2*y2*f2*f5*x3^2*y1-h0*h2^2*y2^2*x1*x3*f1*f6*h1+h0*h2^2*x3*y2^2*x2*f1*f5*h3+4*x1*x4*y1^2*f0*h2^2*f2-2*h0*h2*x4*x2*y2^2*f6*f1-2*h0*h2^2*y3*x1*y2*x3*f2*f6*h1+2*h1^2*h3*x3*x2*y3*y1*f2*f6*h0+2*y3*f5*x3*f3*h0*h3*y2*x4+2*y3*x4*x2*y2*f6*f1*h1*h2-h0^2*h3^2*f1*x1^2*y3*y2*f4+4*x4*x3*y2^2*f6*f4*h0^2-h0^2*h3^2*y2^2*x2*f4*x1*f1-h1*h3*y2*x2^2*y1*f2*f5*h0^2-y3*y4*x4*x3*h1*h2*f5+2*y4*x4*x2*y1*f0*h2*h3+h0*h3*x2*x4*y2^2*f5*f1;
 
 B:=[[b11, b12, b13,b14]
   ,[b12, b22, b23, b24]
   ,[b13, b23, b33, b34]
   ,[b14, b24, b34, b44]];
 return B;
end function;

//The functions called BM compute the matrix B of forms biquadratic in Kummer coordinates x=(x1,x2,x3,x4) 
//of P and y=(y1,y2,y3,y4) of Q such that there are Kummer coordinates w=(w1,w2,w3,w4) of P+Q and 
//z=(z1,z2,z3,z4) of P-Q satisfying 
//B_{ij}=bij=wi*zj+wj*zi for i\ne j aand B_{ii}=Bii=wi*zi, where P and Q are points on the Jacobian J of a genus 2 curve C.

//Here assume P and Q are points on a genus 2 Jacobian
function BMJ(P,Q)
  return BMdata(Eltseq(kappa(P)),Eltseq(kappa(Q)),Parent(P));
end function;

//Now assume KP and KQ are points on the Kummer surface of a genus 2 Jacobian J.
function BM(KP,KQ,J)
 return BMdata(Eltseq(KP),Eltseq(KQ),J);
end function;





//The function delta computes the duplication map delta applied to a point KP on
//the Kummer surface of a genus 2 Jacobian. So if KP comes from a point P
//on J, then delta(KP) is the image of 2P on the Kummer surface. First we find the
//duplication map associated to a genus 2 Jacobian in the function deltadata



function deltadata(J)
 K:=BaseRing(J);
 P<x1,x2,x3,x4>:=PolynomialRing(K,4);
 f,h:=HyperellipticPolynomials(Curve(J));
 f0:=Coefficient(f,0);
 f1:=Coefficient(f,1);
 f2:=Coefficient(f,2);
 f3:=Coefficient(f,3);
 f4:=Coefficient(f,4);  
 f5:=Coefficient(f,5);
 f6:=Coefficient(f,6);
 h0:=Coefficient(h,0);
 h1:=Coefficient(h,1);
 h2:=Coefficient(h,2);
 h3:=Coefficient(h,3);
 delta1:=(-16*f0^2*f6 - 4*f0^2*h3^2 - 16*f0*f2*f4 - 8*f0*f2*h1*h3 - 4*f0*f2*h2^2 +
    4*f0*f3^2 + 4*f0*f3*h0*h3 + 4*f0*f3*h1*h2 - 4*f0*f4*h1^2 - 8*f0*f6*h0^2 - 
    f0*h0^2*h3^2 + 2*f0*h0*h1*h2*h3 - 2*f0*h1^3*h3 + 4*f1^2*f4 + 2*f1^2*h1*h3 + 
    f1^2*h2^2 - 2*f1*f3*h0*h2 + 4*f1*f4*h0*h1 - f1*h0^2*h2*h3 + 2*f1*h0*h1^2*h3 
    - 4*f2*f4*h0^2 - 2*f2*h0^2*h1*h3 + f3^2*h0^2 + f3*h0^3*h3 - f6*h0^4)*x1^4 + 
    (-16*f0*f1*f6 - 4*f0*f1*h3^2 - 32*f0*f2*f5 - 16*f0*f2*h2*h3 + 8*f0*f4*h0*h3 
    - 8*f0*f5*h1^2 - 8*f0*f6*h0*h1 + 2*f0*h0*h1*h3^2 + 2*f0*h0*h2^2*h3 - 
    4*f0*h1^2*h2*h3 + 8*f1^2*f5 + 4*f1^2*h2*h3 - 2*f1*f3*h0*h3 + 8*f1*f5*h0*h1 -
    4*f1*f6*h0^2 - 2*f1*h0^2*h3^2 + 3*f1*h0*h1*h2*h3 - 8*f2*f5*h0^2 - 
    2*f2*h0^2*h2*h3 - f3*h0^2*h1*h3 + 2*f4*h0^3*h3 - 2*f6*h0^3*h1)*x1^3*x2 + 
    (32*f0*f2*f6 + 8*f0*f2*h3^2 - 16*f0*f3*f5 - 8*f0*f3*h2*h3 + 8*f0*f4*h1*h3 - 
    8*f0*f5*h0*h3 - 8*f0*f5*h1*h2 + 16*f0*f6*h0*h2 + 8*f0*f6*h1^2 + 
    6*f0*h1^2*h3^2 - 2*f0*h1*h2^2*h3 - 16*f1^2*f6 - 4*f1^2*h3^2 - 2*f1*f3*h1*h3 
    + 4*f1*f5*h0*h2 - 16*f1*f6*h0*h1 - 5*f1*h0*h1*h3^2 + 2*f1*h0*h2^2*h3 - 
    f1*h1^2*h2*h3 + 8*f2*f6*h0^2 + 2*f2*h0^2*h3^2 + 2*f2*h0*h1*h2*h3 - 
    4*f3*f5*h0^2 - 2*f3*h0^2*h2*h3 - f3*h0*h1^2*h3 + 2*f4*h0^2*h1*h3 - 
    2*f5*h0^3*h3 + 4*f6*h0^3*h2 - 2*f6*h0^2*h1^2)*x1^3*x3 + (-16*f0*f4 - 
    8*f0*h1*h3 - 4*f0*h2^2 + 4*f1*f3 + 2*f1*h0*h3 + 2*f1*h1*h2 - 4*f2*h0*h2 + 
    2*f3*h0*h1 - 4*f4*h0^2 - h0^2*h1*h3)*x1^3*x4 + (-64*f0*f2*f6 - 16*f0*f2*h3^2
    - 8*f0*f3*f5 - 4*f0*f3*h2*h3 + 12*f0*f5*h0*h3 - 4*f0*f5*h1*h2 - 
    8*f0*f6*h0*h2 - 16*f0*f6*h1^2 + 4*f0*h0*h2*h3^2 - 4*f0*h1^2*h3^2 - 
    2*f0*h1*h2^2*h3 + 12*f1^2*f6 + 3*f1^2*h3^2 + 2*f1*f5*h0*h2 + 12*f1*f6*h0*h1 
    + 3*f1*h0*h1*h3^2 + f1*h0*h2^2*h3 - 16*f2*f6*h0^2 - 3*f2*h0^2*h3^2 - 
    2*f3*f5*h0^2 - f3*h0^2*h2*h3 + 3*f5*h0^3*h3 - 2*f6*h0^3*h2 - 
    f6*h0^2*h1^2)*x1^2*x2^2 + (-16*f0*f4*f5 - 8*f0*f4*h2*h3 + 8*f0*f5*h1*h3 - 
    4*f0*f5*h2^2 + 4*f0*h1*h2*h3^2 - 2*f0*h2^3*h3 - 16*f1*f2*f6 - 4*f1*f2*h3^2 -
    4*f1*f3*f5 - 2*f1*f3*h2*h3 + 2*f1*f5*h0*h3 - 2*f1*f5*h1*h2 + 4*f1*f6*h0*h2 -
    4*f1*f6*h1^2 + 2*f1*h0*h2*h3^2 - f1*h1^2*h3^2 - f1*h1*h2^2*h3 + 
    4*f2*f5*h0*h2 - 8*f2*f6*h0*h1 + 2*f2*h0*h2^2*h3 - 2*f3*f5*h0*h1 - 
    f3*h0*h1*h2*h3 - 4*f4*f5*h0^2 - 2*f4*h0^2*h2*h3 + 3*f5*h0^2*h1*h3 + 
    2*f6*h0^2*h1*h2 - 2*f6*h0*h1^3)*x1^2*x2*x3 + (-32*f0*f5 - 16*f0*h2*h3 - 
    4*f2*h0*h3 - 8*f5*h0^2 - h0*h1^2*h3)*x1^2*x2*x4 + (-48*f0*f4*f6 - 
    12*f0*f4*h3^2 + 16*f0*f5^2 + 16*f0*f5*h2*h3 - 24*f0*f6*h1*h3 - 12*f0*f6*h2^2
    - 6*f0*h1*h3^3 + f0*h2^2*h3^2 + 24*f1*f3*f6 + 6*f1*f3*h3^2 - 8*f1*f4*f5 - 
    4*f1*f4*h2*h3 - 2*f1*f5*h2^2 + 12*f1*f6*h0*h3 + 12*f1*f6*h1*h2 + 
    3*f1*h0*h3^3 + 3*f1*h1*h2*h3^2 - f1*h2^3*h3 - 16*f2^2*f6 - 4*f2^2*h3^2 - 
    8*f2*f6*h0*h2 - 8*f2*f6*h1^2 - 2*f2*h0*h2*h3^2 - f2*h1^2*h3^2 + 
    2*f3*f5*h0*h2 + 12*f3*f6*h0*h1 + 3*f3*h0*h1*h3^2 + f3*h0*h2^2*h3 - 
    4*f4*f5*h0*h1 - 12*f4*f6*h0^2 - 3*f4*h0^2*h3^2 - 2*f4*h0*h1*h2*h3 + 
    4*f5^2*h0^2 + 5*f5*h0^2*h2*h3 - 6*f6*h0^2*h2^2 + 4*f6*h0*h1^2*h2 - 
    f6*h1^4)*x1^2*x3^2 + (-8*f1*f5 - 4*f1*h2*h3 - 4*f2*h1*h3 - 4*f5*h0*h1 + 
    2*h0*h1*h2*h3 - h1^3*h3)*x1^2*x3*x4 + (4*f2 - 4*h0*h2 + h1^2)*x1^2*x4^2 + 
    (-32*f0*f3*f6 - 8*f0*f3*h3^2 + 8*f0*f6*h0*h3 - 16*f0*f6*h1*h2 + 2*f0*h0*h3^3
    - 4*f0*h1*h2*h3^2 + 2*f1*f5*h0*h3 + 4*f1*f6*h0*h2 + 2*f1*h0*h2*h3^2 - 
    8*f3*f6*h0^2 - 2*f3*h0^2*h3^2 + f5*h0^2*h1*h3 + 2*f6*h0^3*h3 - 
    2*f6*h0^2*h1*h2)*x1*x2^3 + (-16*f0*f5^2 - 16*f0*f5*h2*h3 + 24*f0*f6*h1*h3 + 
    6*f0*h1*h3^3 - 4*f0*h2^2*h3^2 - 24*f1*f3*f6 - 6*f1*f3*h3^2 + 2*f1*f5*h1*h3 -
    12*f1*f6*h1*h2 - 2*f1*h1*h2*h3^2 + 4*f2*f5*h0*h3 + 8*f2*f6*h0*h2 + 
    4*f2*h0*h2*h3^2 - 12*f3*f6*h0*h1 - 3*f3*h0*h1*h3^2 - 4*f5^2*h0^2 - 
    4*f5*h0^2*h2*h3 + 2*f5*h0*h1^2*h3 + 6*f6*h0^2*h1*h3 + 4*f6*h0^2*h2^2 - 
    4*f6*h0*h1^2*h2)*x1*x2^2*x3 + (-48*f0*f6 - 12*f0*h3^2 - 4*f1*f5 - 2*f1*h2*h3
    - 2*f5*h0*h1 - 12*f6*h0^2 - h0*h1*h2*h3)*x1*x2^2*x4 + (-16*f0*f5*f6 - 
    4*f0*f5*h3^2 - 8*f0*f6*h2*h3 - 2*f0*h2*h3^3 - 8*f1*f5^2 - 8*f1*f5*h2*h3 + 
    12*f1*f6*h1*h3 + 3*f1*h1*h3^3 - 2*f1*h2^2*h3^2 - 16*f2*f3*f6 - 4*f2*f3*h3^2 
    + 4*f2*f5*h1*h3 - 8*f2*f6*h1*h2 + 2*f3*f5*h0*h3 + 4*f3*f6*h0*h2 - 
    4*f3*f6*h1^2 + 2*f3*h0*h2*h3^2 - f3*h1^2*h3^2 - 4*f5^2*h0*h1 - 4*f5*f6*h0^2 
    - 3*f5*h0*h1*h2*h3 + f5*h1^3*h3 - 2*f6*h0^2*h2*h3 + 6*f6*h0*h1^2*h3 + 
    2*f6*h0*h1*h2^2 - 2*f6*h1^3*h2)*x1*x2*x3^2 + (-24*f1*f6 - 6*f1*h3^2 - 
    8*f2*f5 - 4*f2*h2*h3 - 2*f5*h1^2 - 12*f6*h0*h1 + 3*h0*h1*h3^2 - 
    h1^2*h2*h3)*x1*x2*x3*x4 - 6*h0*h3*x1*x2*x4^2 + (32*f0*f6^2 + 16*f0*f6*h3^2 +
    2*f0*h3^4 - 16*f1*f5*f6 - 4*f1*f5*h3^2 - 8*f1*f6*h2*h3 - 2*f1*h2*h3^3 + 
    8*f2*f6*h1*h3 + 2*f2*h1*h3^3 - 8*f3^2*f6 - 2*f3^2*h3^2 + 2*f3*f5*h1*h3 - 
    8*f3*f6*h0*h3 - 8*f3*f6*h1*h2 - 2*f3*h0*h3^3 - f3*h1*h2*h3^2 + 
    16*f4*f6*h0*h2 + 4*f4*h0*h2*h3^2 - 4*f5^2*h0*h2 - 8*f5*f6*h0*h1 - 
    f5*h0*h1*h3^2 - 4*f5*h0*h2^2*h3 + f5*h1^2*h2*h3 + 8*f6^2*h0^2 + 
    2*f6*h0^2*h3^2 - 2*f6*h0*h1*h2*h3 + 4*f6*h0*h2^3 + 2*f6*h1^3*h3 - 
    2*f6*h1^2*h2^2)*x1*x3^3 + (-16*f2*f6 - 4*f2*h3^2 - 4*f3*f5 - 2*f3*h2*h3 - 
    2*f5*h0*h3 - 2*f5*h1*h2 + 4*f6*h0*h2 - 4*f6*h1^2 + 2*h1^2*h3^2 - 
    h1*h2^2*h3)*x1*x3^2*x4 - 6*h1*h3*x1*x3*x4^2 + 4*x1*x4^3 + (-16*f0*f4*f6 - 
    4*f0*f4*h3^2 + 4*f0*f5^2 + 4*f0*f5*h2*h3 - 8*f0*f6*h1*h3 - 4*f0*f6*h2^2 - 
    2*f0*h1*h3^3 + 4*f1*f6*h0*h3 + f1*h0*h3^3 - 4*f4*f6*h0^2 - f4*h0^2*h3^2 + 
    f5^2*h0^2 + f5*h0^2*h2*h3 - f6*h0^2*h2^2)*x2^4 + (-16*f0*f5*f6 - 
    4*f0*f5*h3^2 - 8*f0*f6*h2*h3 - 2*f0*h2*h3^3 - 16*f1*f4*f6 - 4*f1*f4*h3^2 + 
    4*f1*f5^2 + 4*f1*f5*h2*h3 - 4*f1*f6*h1*h3 - 4*f1*f6*h2^2 - f1*h1*h3^3 + 
    8*f2*f6*h0*h3 + 2*f2*h0*h3^3 - 8*f4*f6*h0*h1 - 2*f4*h0*h1*h3^2 + 
    2*f5^2*h0*h1 - 4*f5*f6*h0^2 - 2*f5*h0^2*h3^2 + 2*f5*h0*h1*h2*h3 + 
    2*f6*h0^2*h2*h3 - 2*f6*h0*h1*h2^2)*x2^3*x3 + (-8*f1*f6 - 2*f1*h3^2 - 
    4*f6*h0*h1 - h0*h1*h3^2)*x2^3*x4 + (-48*f0*f6^2 - 24*f0*f6*h3^2 - 3*f0*h3^4 
    - 8*f1*f5*f6 - 2*f1*f5*h3^2 - 4*f1*f6*h2*h3 - f1*h2*h3^3 - 16*f2*f4*f6 - 
    4*f2*f4*h3^2 + 4*f2*f5^2 + 4*f2*f5*h2*h3 - 4*f2*f6*h2^2 + 12*f3*f6*h0*h3 + 
    3*f3*h0*h3^3 - 8*f4*f6*h0*h2 - 4*f4*f6*h1^2 - 2*f4*h0*h2*h3^2 - f4*h1^2*h3^2
    + 2*f5^2*h0*h2 + f5^2*h1^2 - 4*f5*f6*h0*h1 - 3*f5*h0*h1*h3^2 + 
    2*f5*h0*h2^2*h3 + f5*h1^2*h2*h3 - 12*f6^2*h0^2 - 3*f6*h0^2*h3^2 + 
    4*f6*h0*h1*h2*h3 - 2*f6*h0*h2^3 - f6*h1^2*h2^2)*x2^2*x3^2 + (-16*f2*f6 - 
    4*f2*h3^2 + 4*f5*h0*h3 - 8*f6*h0*h2 - 4*f6*h1^2 - h1^2*h3^2)*x2^2*x3*x4 + 
    (-32*f1*f6^2 - 16*f1*f6*h3^2 - 2*f1*h3^4 - 16*f3*f4*f6 - 4*f3*f4*h3^2 + 
    4*f3*f5^2 + 4*f3*f5*h2*h3 + 4*f3*f6*h1*h3 - 4*f3*f6*h2^2 + f3*h1*h3^3 + 
    8*f4*f6*h0*h3 - 8*f4*f6*h1*h2 + 2*f4*h0*h3^3 - 2*f4*h1*h2*h3^2 - 
    2*f5^2*h0*h3 + 2*f5^2*h1*h2 - 2*f5*h0*h2*h3^2 - f5*h1^2*h3^2 + 
    2*f5*h1*h2^2*h3 - 16*f6^2*h0*h1 - 4*f6*h0*h1*h3^2 + 2*f6*h0*h2^2*h3 + 
    2*f6*h1^2*h2*h3 - 2*f6*h1*h2^3)*x2*x3^3 + (-24*f3*f6 - 6*f3*h3^2 + 
    4*f5*h1*h3 - 12*f6*h1*h2 - h1*h2*h3^2)*x2*x3^2*x4 + (-4*f5 - 
    2*h2*h3)*x2*x3*x4^2 + (-16*f2*f6^2 - 8*f2*f6*h3^2 - f2*h3^4 + 8*f3*f5*f6 + 
    2*f3*f5*h3^2 + 4*f3*f6*h2*h3 + f3*h2*h3^3 - 16*f4^2*f6 - 4*f4^2*h3^2 + 
    4*f4*f5^2 + 4*f4*f5*h2*h3 - 8*f4*f6*h2^2 - f4*h2^2*h3^2 - 2*f5^2*h1*h3 + 
    f5^2*h2^2 + 4*f5*f6*h0*h3 + 4*f5*f6*h1*h2 + f5*h0*h3^3 - f5*h1*h2*h3^2 + 
    f5*h2^3*h3 - 8*f6^2*h0*h2 - 4*f6^2*h1^2 - 2*f6*h0*h2*h3^2 - f6*h1^2*h3^2 + 
    2*f6*h1*h2^2*h3 - f6*h2^4)*x3^4 + (-32*f4*f6 - 8*f4*h3^2 + 8*f5^2 + 
    8*f5*h2*h3 - 4*f6*h1*h3 - 8*f6*h2^2 - h1*h3^3)*x3^3*x4 + (-12*f6 - 
    3*h3^2)*x3^2*x4^2;
    
 delta2:=(16*f0^2*f5 + 8*f0^2*h2*h3 - 4*f0*f2*f3 - 4*f0*f3*h0*h2 - f0*f3*h1^2 + 
    8*f0*f5*h0^2 + 2*f0*h0^2*h2*h3 - 2*f0*h0*h1*h2^2 + f1^2*f3 + f1*f3*h0*h1 + 
    f1*h0^2*h2^2 - f2*f3*h0^2 - f3*h0^3*h2 + f5*h0^4)*x1^4 + (32*f0^2*f6 + 
    8*f0^2*h3^2 + 16*f0*f1*f5 + 8*f0*f1*h2*h3 - 4*f0*f3^2 - 4*f0*f3*h0*h3 - 
    2*f0*f3*h1*h2 - 8*f0*f4*h0*h2 + 8*f0*f5*h0*h1 + 16*f0*f6*h0^2 + 
    2*f0*h0^2*h3^2 - 2*f0*h0*h1*h2*h3 - 2*f0*h0*h2^3 - f1*f3*h0*h2 + 
    4*f1*f5*h0^2 + 3*f1*h0^2*h2*h3 - f1*h0*h1*h2^2 + 2*f2*h0^2*h2^2 - f3^2*h0^2 
    - f3*h0^3*h3 - f3*h0^2*h1*h2 - 2*f4*h0^3*h2 + 2*f5*h0^3*h1 + 
    2*f6*h0^4)*x1^3*x2 + (-32*f0*f2*f5 - 16*f0*f2*h2*h3 + 16*f0*f3*f4 + 
    6*f0*f3*h1*h3 + 4*f0*f3*h2^2 + 8*f0*f4*h0*h3 + 8*f0*f4*h1*h2 - 8*f0*f5*h0*h2
    - 8*f0*f5*h1^2 + 2*f0*h0*h1*h3^2 - 2*f0*h0*h2^2*h3 - 2*f0*h1^2*h2*h3 + 
    2*f0*h1*h2^3 + 16*f1^2*f5 + 8*f1^2*h2*h3 - 6*f1*f3^2 - 5*f1*f3*h0*h3 - 
    5*f1*f3*h1*h2 - 8*f1*f4*h0*h2 + 16*f1*f5*h0*h1 - f1*h0^2*h3^2 + 
    4*f1*h0*h1*h2*h3 - 2*f1*h0*h2^3 - f1*h1^2*h2^2 + 6*f2*f3*h0*h2 - 
    8*f2*f5*h0^2 - 2*f2*h0^2*h2*h3 + 2*f2*h0*h1*h2^2 - 3*f3^2*h0*h1 + 
    4*f3*f4*h0^2 - f3*h0^2*h1*h3 + 2*f3*h0^2*h2^2 - f3*h0*h1^2*h2 + 2*f4*h0^3*h3
    - 2*f4*h0^2*h1*h2 - 2*f5*h0^3*h2 + 2*f5*h0^2*h1^2)*x1^3*x3 + (4*f0*f3 + 
    4*f0*h0*h3 + 4*f0*h1*h2 - 4*f1*h0*h2 + f3*h0^2 + h0^3*h3 - 
    h0^2*h1*h2)*x1^3*x4 + (32*f0*f1*f6 + 8*f0*f1*h3^2 - 4*f0*f3*f4 - 
    2*f0*f3*h1*h3 - f0*f3*h2^2 - 8*f0*f4*h0*h3 - 4*f0*f5*h0*h2 + 16*f0*f6*h0*h1 
    - 4*f0*h0*h2^2*h3 + 4*f1^2*f5 + 2*f1^2*h2*h3 - f1*f3*h0*h3 - 4*f1*f4*h0*h2 +
    4*f1*f5*h0*h1 + 8*f1*f6*h0^2 + 2*f1*h0^2*h3^2 - f1*h0*h1*h2*h3 - f1*h0*h2^3 
    + 4*f2*h0^2*h2*h3 - f3*f4*h0^2 - f3*h0^2*h1*h3 + f3*h0^2*h2^2 - 2*f4*h0^3*h3
    - 2*f4*h0^2*h1*h2 - f5*h0^3*h2 + f5*h0^2*h1^2 + 4*f6*h0^3*h1)*x1^2*x2^2 + 
    (-64*f0*f2*f6 - 16*f0*f2*h3^2 - 20*f0*f3*f5 - 10*f0*f3*h2*h3 + 32*f0*f4^2 + 
    24*f0*f4*h1*h3 + 16*f0*f4*h2^2 - 4*f0*f5*h0*h3 - 12*f0*f5*h1*h2 - 
    8*f0*f6*h0*h2 - 16*f0*f6*h1^2 - 4*f0*h0*h2*h3^2 + 2*f0*h2^4 + 32*f1^2*f6 + 
    8*f1^2*h3^2 + 16*f1*f2*f5 + 8*f1*f2*h2*h3 - 12*f1*f3*f4 - 7*f1*f3*h1*h3 - 
    3*f1*f3*h2^2 - 12*f1*f4*h0*h3 - 4*f1*f4*h1*h2 + 4*f1*f5*h1^2 + 
    32*f1*f6*h0*h1 + 3*f1*h0*h1*h3^2 - 3*f1*h0*h2^2*h3 - f1*h1^2*h2*h3 - 
    f1*h1*h2^3 + 6*f2*f3*h0*h3 - 8*f2*f4*h0*h2 + 8*f2*f5*h0*h1 - 16*f2*f6*h0^2 -
    2*f2*h0^2*h3^2 + 6*f2*h0*h1*h2*h3 - 2*f2*h0*h2^3 + 5*f3^2*h0*h2 - 
    6*f3*f4*h0*h1 - 5*f3*f5*h0^2 + f3*h0^2*h2*h3 - 2*f3*h0*h1^2*h3 + 
    3*f3*h0*h1*h2^2 + 8*f4^2*h0^2 + 2*f4*h0^2*h2^2 - 4*f4*h0*h1^2*h2 - 
    f5*h0^3*h3 - 3*f5*h0^2*h1*h2 + 2*f5*h0*h1^3 - 2*f6*h0^3*h2 + 
    4*f6*h0^2*h1^2)*x1^2*x2*x3 + (16*f0*f4 + 8*f0*h1*h3 + 4*f0*h2^2 + 2*f1*f3 - 
    2*f1*h0*h3 + 2*f1*h1*h2 - 8*f2*h0*h2 + f3*h0*h1 + 4*f4*h0^2 + h0^2*h1*h3 - 
    h0*h1^2*h2)*x1^2*x2*x4 + (-20*f0*f3*f6 - 5*f0*f3*h3^2 + 8*f0*f5*h1*h3 - 
    8*f0*f6*h0*h3 - 8*f0*f6*h1*h2 - 2*f0*h0*h3^3 + 2*f0*h1*h2*h3^2 - 14*f1*f3*f5
    - 7*f1*f3*h2*h3 + 16*f1*f4^2 + 8*f1*f4*h1*h3 + 8*f1*f4*h2^2 - 8*f1*f5*h0*h3 
    - 8*f1*f5*h1*h2 + 8*f1*f6*h0*h2 - 2*f1*h0*h2*h3^2 + f1*h1^2*h3^2 - 
    2*f1*h1*h2^2*h3 + f1*h2^4 + 16*f2^2*f5 + 8*f2^2*h2*h3 - 20*f2*f3*f4 - 
    4*f2*f3*h1*h3 - 5*f2*f3*h2^2 - 8*f2*f4*h0*h3 - 8*f2*f4*h1*h2 + 8*f2*f5*h0*h2
    + 8*f2*f5*h1^2 - 2*f2*h0*h1*h3^2 + 2*f2*h0*h2^2*h3 + 2*f2*h1^2*h2*h3 - 
    2*f2*h1*h2^3 + 5*f3^3 + 7*f3^2*h0*h3 + 7*f3^2*h1*h2 - 4*f3*f4*h0*h2 - 
    5*f3*f4*h1^2 - 7*f3*f5*h0*h1 - 5*f3*f6*h0^2 + 2*f3*h0^2*h3^2 - f3*h0*h2^3 - 
    f3*h1^3*h3 + 2*f3*h1^2*h2^2 + 8*f4^2*h0*h1 - 2*f4*h0^2*h2*h3 + 
    2*f4*h0*h1^2*h3 + 2*f4*h0*h1*h2^2 - 2*f4*h1^3*h2 - 2*f5*h0^2*h1*h3 + 
    f5*h0^2*h2^2 - 2*f5*h0*h1^2*h2 + f5*h1^4 - 2*f6*h0^3*h3 + 
    2*f6*h0^2*h1*h2)*x1^2*x3^2 + (-16*f0*f5 - 8*f0*h2*h3 + 16*f1*f4 + 4*f1*h1*h3
    + 4*f1*h2^2 - 12*f2*f3 - 4*f2*h0*h3 - 4*f2*h1*h2 + 2*f3*h0*h2 - 3*f3*h1^2 + 
    8*f4*h0*h1 - 4*f5*h0^2 - 2*h0^2*h2*h3 + h0*h1^2*h3 + 2*h0*h1*h2^2 - 
    h1^3*h2)*x1^2*x3*x4 + (4*f1 + 2*h0*h1)*x1^2*x4^2 + (-4*f0*f3*f5 - 
    2*f0*f3*h2*h3 - 4*f0*f5*h0*h3 - 2*f0*h0*h2*h3^2 + 8*f1^2*f6 + 2*f1^2*h3^2 - 
    4*f1*f4*h0*h3 - 2*f1*f5*h0*h2 + 8*f1*f6*h0*h1 - 2*f1*h0*h2^2*h3 + 
    2*f2*h0^2*h3^2 - f3*f5*h0^2 + 2*f3*h0^2*h2*h3 - 2*f4*h0^2*h1*h3 - f5*h0^3*h3
    - f5*h0^2*h1*h2 + 2*f6*h0^2*h1^2)*x1*x2^3 + (-56*f0*f3*f6 - 14*f0*f3*h3^2 + 
    32*f0*f4*f5 + 16*f0*f4*h2*h3 + 12*f0*f5*h1*h3 + 8*f0*f5*h2^2 - 8*f0*f6*h0*h3
    - 32*f0*f6*h1*h2 - 2*f0*h0*h3^3 - 2*f0*h1*h2*h3^2 + 4*f0*h2^3*h3 + 
    32*f1*f2*f6 + 8*f1*f2*h3^2 - 8*f1*f3*f5 - 4*f1*f3*h2*h3 - 4*f1*f4*h1*h3 - 
    10*f1*f5*h0*h3 - 2*f1*f5*h1*h2 + 12*f1*f6*h0*h2 + 8*f1*f6*h1^2 - 
    2*f1*h0*h2*h3^2 - 2*f1*h1*h2^2*h3 - 8*f2*f4*h0*h3 - 4*f2*f5*h0*h2 + 
    16*f2*f6*h0*h1 + 4*f2*h0*h1*h3^2 - 4*f2*h0*h2^2*h3 + 5*f3^2*h0*h3 - 
    4*f3*f5*h0*h1 - 14*f3*f6*h0^2 - f3*h0^2*h3^2 + 5*f3*h0*h1*h2*h3 + 
    8*f4*f5*h0^2 + 4*f4*h0^2*h2*h3 - 4*f4*h0*h1^2*h3 - 2*f5*h0^2*h1*h3 - 
    2*f5*h0*h1^2*h2 - 2*f6*h0^3*h3 - 2*f6*h0^2*h1*h2 + 4*f6*h0*h1^3)*x1*x2^2*x3 
    + (8*f0*f5 + 4*f0*h2*h3 + 8*f1*f4 + 4*f1*h1*h3 + 2*f1*h2^2 - 8*f2*h0*h3 - 
    5*f3*h0*h2 + 4*f4*h0*h1 + 2*f5*h0^2 + h0^2*h2*h3 - h0*h1*h2^2)*x1*x2^2*x4 + 
    (-64*f0*f4*f6 - 16*f0*f4*h3^2 + 32*f0*f5^2 + 32*f0*f5*h2*h3 - 8*f0*f6*h1*h3 
    - 16*f0*f6*h2^2 - 2*f0*h1*h3^3 + 4*f0*h2^2*h3^2 - 20*f1*f3*f6 - 5*f1*f3*h3^2
    + 16*f1*f4*f5 + 8*f1*f4*h2*h3 + 4*f1*f5*h2^2 - 4*f1*f6*h0*h3 - 
    12*f1*f6*h1*h2 - f1*h0*h3^3 - 3*f1*h1*h2*h3^2 + 2*f1*h2^3*h3 + 32*f2^2*f6 + 
    8*f2^2*h3^2 - 12*f2*f3*f5 - 6*f2*f3*h2*h3 - 8*f2*f4*h1*h3 - 12*f2*f5*h0*h3 -
    4*f2*f5*h1*h2 + 24*f2*f6*h0*h2 + 16*f2*f6*h1^2 + 2*f2*h1^2*h3^2 - 
    4*f2*h1*h2^2*h3 + 5*f3^2*h1*h3 + 6*f3*f4*h0*h3 - 7*f3*f5*h0*h2 - 
    3*f3*f5*h1^2 - 10*f3*f6*h0*h1 + f3*h0*h1*h3^2 - 2*f3*h0*h2^2*h3 + 
    3*f3*h1^2*h2*h3 + 8*f4*f5*h0*h1 - 16*f4*f6*h0^2 - 2*f4*h0^2*h3^2 + 
    6*f4*h0*h1*h2*h3 - 2*f4*h1^3*h3 + 8*f5^2*h0^2 + 3*f5*h0^2*h2*h3 - 
    3*f5*h0*h1^2*h3 - f5*h0*h1*h2^2 - f5*h1^3*h2 - 4*f6*h0^2*h1*h3 + 
    2*f6*h1^4)*x1*x2*x3^2 + (-48*f0*f6 - 12*f0*h3^2 + 16*f1*f5 + 8*f1*h2*h3 + 
    16*f2*f4 + 4*f2*h2^2 - 10*f3^2 - f3*h0*h3 - 9*f3*h1*h2 + 4*f4*h1^2 + 
    8*f5*h0*h1 - 12*f6*h0^2 - 3*h0^2*h3^2 + 4*h0*h1*h2*h3 - 
    h1^2*h2^2)*x1*x2*x3*x4 + (8*f2 - 2*h0*h2 + 2*h1^2)*x1*x2*x4^2 + 
    (-32*f1*f4*f6 - 8*f1*f4*h3^2 + 16*f1*f5^2 + 16*f1*f5*h2*h3 - 8*f1*f6*h1*h3 -
    8*f1*f6*h2^2 - 2*f1*h1*h3^3 + 2*f1*h2^2*h3^2 + 16*f2*f3*f6 + 4*f2*f3*h3^2 - 
    8*f2*f5*h1*h3 + 8*f2*f6*h0*h3 + 8*f2*f6*h1*h2 + 2*f2*h0*h3^3 - 
    2*f2*h1*h2*h3^2 - 6*f3^2*f5 - 3*f3^2*h2*h3 + 6*f3*f4*h1*h3 - 5*f3*f5*h0*h3 -
    5*f3*f5*h1*h2 + 6*f3*f6*h0*h2 + 4*f3*f6*h1^2 - f3*h0*h2*h3^2 + 
    2*f3*h1^2*h3^2 - f3*h1*h2^2*h3 - 16*f4*f6*h0*h1 - 2*f4*h0*h1*h3^2 + 
    2*f4*h1^2*h2*h3 + 8*f5^2*h0*h1 - f5*h0^2*h3^2 + 4*f5*h0*h1*h2*h3 - 
    2*f5*h1^3*h3 - f5*h1^2*h2^2 + 2*f6*h0^2*h2*h3 - 2*f6*h0*h1^2*h3 - 
    2*f6*h0*h1*h2^2 + 2*f6*h1^3*h2)*x1*x3^3 + (-16*f1*f6 - 4*f1*h3^2 + 16*f2*f5 
    + 8*f2*h2*h3 - 12*f3*f4 + 2*f3*h1*h3 - 3*f3*h2^2 - 4*f4*h0*h3 - 4*f4*h1*h2 +
    4*f5*h0*h2 + 4*f5*h1^2 - 8*f6*h0*h1 - 2*h0*h1*h3^2 + h0*h2^2*h3 + 
    2*h1^2*h2*h3 - h1*h2^3)*x1*x3^2*x4 + (-8*f3 - 2*h0*h3 - 2*h1*h2)*x1*x3*x4^2 
    + (-4*f0*f3*f6 - f0*f3*h3^2 - 2*f1*f5*h0*h3 - f1*h0*h2*h3^2 - f3*f6*h0^2 + 
    f3*h0^2*h3^2 - f5*h0^2*h1*h3)*x2^4 + (8*f0*f5^2 + 8*f0*f5*h2*h3 + 
    2*f0*h2^2*h3^2 - 4*f1*f3*f6 - f1*f3*h3^2 - 2*f1*f5*h1*h3 - 4*f1*f6*h0*h3 - 
    f1*h0*h3^3 - f1*h1*h2*h3^2 - 4*f2*f5*h0*h3 - 2*f2*h0*h2*h3^2 - 2*f3*f6*h0*h1
    + 2*f3*h0*h1*h3^2 + 2*f4*h0^2*h3^2 + 2*f5^2*h0^2 - 2*f5*h0*h1^2*h3 - 
    2*f6*h0^2*h1*h3)*x2^3*x3 + (4*f1*f5 + 2*f1*h2*h3 - 5*f3*h0*h3 + 2*f5*h0*h1 +
    h0^2*h3^2 - h0*h1*h2*h3)*x2^3*x4 + (32*f0*f5*f6 + 8*f0*f5*h3^2 + 
    16*f0*f6*h2*h3 + 4*f0*h2*h3^3 + 4*f1*f5^2 + 4*f1*f5*h2*h3 - 4*f1*f6*h1*h3 - 
    f1*h1*h3^3 + f1*h2^2*h3^2 - 4*f2*f3*f6 - f2*f3*h3^2 - 4*f2*f5*h1*h3 - 
    8*f2*f6*h0*h3 - 2*f2*h0*h3^3 - 2*f2*h1*h2*h3^2 - f3*f5*h0*h3 - 2*f3*f6*h0*h2
    - f3*f6*h1^2 - f3*h0*h2*h3^2 + f3*h1^2*h3^2 + 4*f4*h0*h1*h3^2 + 2*f5^2*h0*h1
    + 8*f5*f6*h0^2 + 2*f5*h0^2*h3^2 - f5*h0*h1*h2*h3 - f5*h1^3*h3 - 
    4*f6*h0*h1^2*h3)*x2^2*x3^2 + (8*f1*f6 + 2*f1*h3^2 + 8*f2*f5 + 4*f2*h2*h3 - 
    5*f3*h1*h3 - 8*f4*h0*h3 + 4*f5*h0*h2 + 2*f5*h1^2 + 4*f6*h0*h1 + h0*h1*h3^2 -
    h1^2*h2*h3)*x2^2*x3*x4 + (5*f3 - 4*h0*h3 + 2*h1*h2)*x2^2*x4^2 + (32*f0*f6^2 
    + 16*f0*f6*h3^2 + 2*f0*h3^4 + 16*f1*f5*f6 + 4*f1*f5*h3^2 + 8*f1*f6*h2*h3 + 
    2*f1*h2*h3^3 - 8*f2*f6*h1*h3 - 2*f2*h1*h3^3 - 4*f3^2*f6 - f3^2*h3^2 - 
    f3*f5*h1*h3 - 4*f3*f6*h0*h3 - 2*f3*f6*h1*h2 - f3*h0*h3^3 - f3*h1*h2*h3^2 + 
    2*f4*h1^2*h3^2 + 8*f5*f6*h0*h1 + 3*f5*h0*h1*h3^2 - f5*h1^2*h2*h3 + 
    8*f6^2*h0^2 + 2*f6*h0^2*h3^2 - 2*f6*h0*h1*h2*h3 - 2*f6*h1^3*h3)*x2*x3^3 + 
    (16*f2*f6 + 4*f2*h3^2 + 2*f3*f5 + f3*h2*h3 - 8*f4*h1*h3 - 2*f5*h0*h3 + 
    2*f5*h1*h2 + 8*f6*h0*h2 + 4*f6*h1^2 + h0*h2*h3^2 - h1*h2^2*h3)*x2*x3^2*x4 + 
    (8*f4 - 2*h1*h3 + 2*h2^2)*x2*x3*x4^2 + 4*x2*x4^3 + (16*f1*f6^2 + 
    8*f1*f6*h3^2 + f1*h3^4 - 4*f3*f4*f6 - f3*f4*h3^2 + f3*f5^2 + f3*f5*h2*h3 - 
    4*f3*f6*h1*h3 - f3*f6*h2^2 - f3*h1*h3^3 + f5*h1^2*h3^2 + 8*f6^2*h0*h1 + 
    2*f6*h0*h1*h3^2 - 2*f6*h1^2*h2*h3)*x3^4 + (4*f3*f6 + f3*h3^2 - 4*f5*h1*h3 + 
    4*f6*h0*h3 + 4*f6*h1*h2 + h0*h3^3 - h1*h2*h3^2)*x3^3*x4 + (4*f5 + 
    2*h2*h3)*x3^2*x4^2;

 delta3:=(-16*f0^2*f4 - 8*f0^2*h1*h3 - 4*f0^2*h2^2 + 8*f0*f1*f3 + 4*f0*f1*h0*h3 + 
    4*f0*f1*h1*h2 - 16*f0*f2^2 - 8*f0*f2*h1^2 + 4*f0*f3*h0*h1 - 8*f0*f4*h0^2 - 
    2*f0*h0^2*h1*h3 - f0*h0^2*h2^2 + 2*f0*h0*h1^2*h2 - f0*h1^4 + 4*f1^2*f2 - 
    2*f1^2*h0*h2 + f1^2*h1^2 + 4*f1*f2*h0*h1 + 2*f1*f3*h0^2 + f1*h0^3*h3 - 
    f1*h0^2*h1*h2 + f1*h0*h1^3 - 4*f2^2*h0^2 - f2*h0^2*h1^2 + f3*h0^3*h1 - 
    f4*h0^4)*x1^4 + (-32*f0^2*f5 - 16*f0^2*h2*h3 - 16*f0*f2*f3 + 8*f0*f2*h0*h3 -
    8*f0*f2*h1*h2 + 4*f0*f3*h0*h2 - 4*f0*f3*h1^2 - 16*f0*f5*h0^2 - 
    4*f0*h0^2*h2*h3 + 2*f0*h0*h1^2*h3 + 2*f0*h0*h1*h2^2 - 2*f0*h1^3*h2 + 
    4*f1^2*f3 - 2*f1^2*h0*h3 + 2*f1^2*h1*h2 + 4*f1*f3*h0*h1 - 2*f1*h0^2*h1*h3 - 
    f1*h0^2*h2^2 + 2*f1*h0*h1^2*h2 - 4*f2*f3*h0^2 + 2*f2*h0^3*h3 - 
    2*f2*h0^2*h1*h2 + f3*h0^3*h2 - 2*f5*h0^4)*x1^3*x2 + (32*f0^2*f6 + 
    8*f0^2*h3^2 - 16*f0*f1*f5 - 8*f0*f1*h2*h3 + 16*f0*f2*h1*h3 - 8*f0*f3^2 - 
    8*f0*f3*h0*h3 - 8*f0*f3*h1*h2 + 8*f0*f4*h0*h2 - 8*f0*f5*h0*h1 + 
    16*f0*f6*h0^2 + 2*f0*h0^2*h3^2 - 2*f0*h0*h1*h2*h3 + 2*f0*h0*h2^3 + 
    4*f0*h1^3*h3 - 2*f0*h1^2*h2^2 - 4*f1^2*h1*h3 + 2*f1*f3*h0*h2 - 4*f1*f5*h0^2 
    - f1*h0^2*h2*h3 - 4*f1*h0*h1^2*h3 + f1*h0*h1*h2^2 + 4*f2*h0^2*h1*h3 - 
    2*f3^2*h0^2 - 2*f3*h0^3*h3 - f3*h0^2*h1*h2 + 2*f4*h0^3*h2 - 2*f5*h0^3*h1 + 
    2*f6*h0^4)*x1^3*x3 + (-32*f0*f2 - 4*f0*h0*h2 - 8*f0*h1^2 + 8*f1^2 + 
    8*f1*h0*h1 - 8*f2*h0^2 - h0^3*h2)*x1^3*x4 + (-48*f0^2*f6 - 12*f0^2*h3^2 - 
    8*f0*f1*f5 - 4*f0*f1*h2*h3 - 16*f0*f2*f4 - 8*f0*f2*h1*h3 - 4*f0*f2*h2^2 + 
    12*f0*f3*h0*h3 - 4*f0*f4*h1^2 - 4*f0*f5*h0*h1 - 24*f0*f6*h0^2 - 
    3*f0*h0^2*h3^2 + 4*f0*h0*h1*h2*h3 - 2*f0*h1^3*h3 - f0*h1^2*h2^2 + 4*f1^2*f4 
    + 2*f1^2*h1*h3 + f1^2*h2^2 + 4*f1*f4*h0*h1 - 2*f1*f5*h0^2 - 3*f1*h0^2*h2*h3 
    + 2*f1*h0*h1^2*h3 + f1*h0*h1*h2^2 - 4*f2*f4*h0^2 - 2*f2*h0^2*h1*h3 - 
    f2*h0^2*h2^2 + 3*f3*h0^3*h3 - f5*h0^3*h1 - 3*f6*h0^4)*x1^2*x2^2 + 
    (-16*f0*f1*f6 - 4*f0*f1*h3^2 - 16*f0*f3*f4 + 4*f0*f3*h1*h3 - 4*f0*f3*h2^2 - 
    8*f0*f4*h1*h2 + 12*f0*f5*h0*h2 - 8*f0*f6*h0*h1 - 2*f0*h0*h1*h3^2 + 
    6*f0*h0*h2^2*h3 + 2*f0*h1^2*h2*h3 - 2*f0*h1*h2^3 - 8*f1^2*f5 - 4*f1^2*h2*h3 
    + 2*f1*f3*h0*h3 + 4*f1*f4*h0*h2 - 8*f1*f5*h0*h1 - 4*f1*f6*h0^2 - 
    3*f1*h0*h1*h2*h3 + f1*h0*h2^3 - 4*f3*f4*h0^2 + 2*f3*h0^2*h1*h3 - 
    f3*h0^2*h2^2 + 3*f5*h0^3*h2 - 2*f5*h0^2*h1^2 - 2*f6*h0^3*h1)*x1^2*x2*x3 + 
    (-24*f0*f3 - 12*f0*h1*h2 + 4*f1*h0*h2 - 6*f3*h0^2 - h0^2*h1*h2)*x1^2*x2*x4 +
    (-48*f0*f2*f6 - 12*f0*f2*h3^2 + 24*f0*f3*f5 + 12*f0*f3*h2*h3 - 16*f0*f4^2 - 
    8*f0*f4*h1*h3 - 8*f0*f4*h2^2 + 12*f0*f5*h0*h3 + 12*f0*f5*h1*h2 - 
    24*f0*f6*h0*h2 - 12*f0*f6*h1^2 - 6*f0*h1^2*h3^2 + 4*f0*h1*h2^2*h3 - f0*h2^4 
    + 16*f1^2*f6 + 4*f1^2*h3^2 - 8*f1*f2*f5 - 4*f1*f2*h2*h3 + 2*f1*f3*h1*h3 - 
    2*f1*f5*h1^2 + 16*f1*f6*h0*h1 + 5*f1*h0*h1*h3^2 - 4*f2*f5*h0*h1 - 
    12*f2*f6*h0^2 - 3*f2*h0^2*h3^2 - 2*f2*h0*h1*h2*h3 + 6*f3*f5*h0^2 + 
    3*f3*h0^2*h2*h3 + f3*h0*h1^2*h3 - 4*f4^2*h0^2 - 2*f4*h0^2*h1*h3 - 
    f4*h0^2*h2^2 + 3*f5*h0^3*h3 + 3*f5*h0^2*h1*h2 - f5*h0*h1^3 - 6*f6*h0^3*h2 + 
    f6*h0^2*h1^2)*x1^2*x3^2 + (-16*f0*f4 + 4*f0*h1*h3 - 4*f0*h2^2 - 4*f1*f3 - 
    2*f1*h0*h3 - 2*f1*h1*h2 - 2*f3*h0*h1 - 4*f4*h0^2 + 2*h0^2*h2^2 - 
    h0*h1^2*h2)*x1^2*x3*x4 + (-12*f0 - 3*h0^2)*x1^2*x4^2 + (-16*f0*f1*f6 - 
    4*f0*f1*h3^2 - 16*f0*f2*f5 - 8*f0*f2*h2*h3 + 8*f0*f4*h0*h3 - 4*f0*f5*h0*h2 -
    4*f0*f5*h1^2 - 8*f0*f6*h0*h1 + 2*f0*h0*h1*h3^2 - 2*f0*h1^2*h2*h3 + 4*f1^2*f5
    + 2*f1^2*h2*h3 + 4*f1*f5*h0*h1 - 4*f1*f6*h0^2 - 2*f1*h0^2*h3^2 + 
    2*f1*h0*h1*h2*h3 - 4*f2*f5*h0^2 - 2*f2*h0^2*h2*h3 + 2*f4*h0^3*h3 - 
    f5*h0^3*h2 - 2*f6*h0^3*h1)*x1*x2^3 + (-24*f0*f3*f5 - 12*f0*f3*h2*h3 + 
    8*f0*f4*h1*h3 - 12*f0*f5*h1*h2 + 24*f0*f6*h0*h2 + 6*f0*h0*h2*h3^2 + 
    4*f0*h1^2*h3^2 - 4*f0*h1*h2^2*h3 - 16*f1^2*f6 - 4*f1^2*h3^2 + 4*f1*f4*h0*h3 
    + 2*f1*f5*h0*h2 - 16*f1*f6*h0*h1 - 4*f1*h0*h1*h3^2 + 2*f1*h0*h2^2*h3 - 
    6*f3*f5*h0^2 - 3*f3*h0^2*h2*h3 + 4*f4*h0^2*h1*h3 - 2*f5*h0^2*h1*h2 + 
    6*f6*h0^3*h2 - 4*f6*h0^2*h1^2)*x1*x2^2*x3 + (-16*f0*f4 - 8*f0*h1*h3 - 
    4*f0*h2^2 + 4*f1*h0*h3 - 4*f4*h0^2 - h0^2*h2^2)*x1*x2^2*x4 + (-16*f0*f4*f5 -
    8*f0*f4*h2*h3 + 4*f0*f5*h1*h3 - 4*f0*f5*h2^2 + 2*f0*h1*h2*h3^2 - 
    2*f0*h2^3*h3 - 16*f1*f2*f6 - 4*f1*f2*h3^2 - 4*f1*f3*f5 - 2*f1*f3*h2*h3 + 
    4*f1*f4*h1*h3 + 2*f1*f5*h0*h3 - 2*f1*f5*h1*h2 + 8*f1*f6*h0*h2 - 4*f1*f6*h1^2
    + 3*f1*h0*h2*h3^2 - 8*f2*f6*h0*h1 - 2*f2*h0*h1*h3^2 - 2*f3*f5*h0*h1 - 
    f3*h0*h1*h2*h3 - 4*f4*f5*h0^2 + 2*f4*h0*h1^2*h3 + 2*f5*h0^2*h1*h3 - 
    f5*h0^2*h2^2 - f5*h0*h1^2*h2 + 4*f6*h0^2*h1*h2 - 2*f6*h0*h1^3)*x1*x2*x3^2 + 
    (-24*f0*f5 - 12*f0*h2*h3 - 8*f1*f4 - 2*f1*h2^2 - 4*f4*h0*h1 - 6*f5*h0^2 + 
    3*h0^2*h2*h3 - h0*h1*h2^2)*x1*x2*x3*x4 + (-4*f1 - 2*h0*h1)*x1*x2*x4^2 + 
    (32*f0*f4*f6 + 8*f0*f4*h3^2 - 16*f0*f5^2 - 16*f0*f5*h2*h3 + 16*f0*f6*h1*h3 +
    8*f0*f6*h2^2 + 4*f0*h1*h3^3 - 2*f0*h2^2*h3^2 - 16*f1*f3*f6 - 4*f1*f3*h3^2 + 
    4*f1*f5*h1*h3 - 8*f1*f6*h0*h3 - 8*f1*f6*h1*h2 - 2*f1*h0*h3^3 + 8*f2*f6*h0*h2
    + 2*f2*h0*h2*h3^2 - 2*f3*f5*h0*h2 - 8*f3*f6*h0*h1 - 2*f3*h0*h1*h3^2 - 
    f3*h0*h2^2*h3 + 8*f4*f6*h0^2 + 2*f4*h0^2*h3^2 + 2*f4*h0*h1*h2*h3 - 
    4*f5^2*h0^2 - 5*f5*h0^2*h2*h3 + 2*f5*h0*h1^2*h3 - f5*h0*h1*h2^2 + 
    6*f6*h0^2*h2^2 - 2*f6*h0*h1^2*h2)*x1*x3^3 + (-8*f1*f5 - 4*f1*h2*h3 - 
    4*f4*h0*h2 - 4*f5*h0*h1 + 2*h0*h1*h2*h3 - h0*h2^3)*x1*x3^2*x4 - 
    6*h0*h2*x1*x3*x4^2 + (-16*f0*f2*f6 - 4*f0*f2*h3^2 + 4*f0*f5*h0*h3 - 
    8*f0*f6*h0*h2 - 4*f0*f6*h1^2 - f0*h1^2*h3^2 + 4*f1^2*f6 + f1^2*h3^2 + 
    4*f1*f6*h0*h1 + f1*h0*h1*h3^2 - 4*f2*f6*h0^2 - f2*h0^2*h3^2 + f5*h0^3*h3 - 
    2*f6*h0^3*h2)*x2^4 + (-32*f0*f3*f6 - 8*f0*f3*h3^2 + 4*f0*f5*h1*h3 + 
    8*f0*f6*h0*h3 - 16*f0*f6*h1*h2 + 2*f0*h0*h3^3 - 2*f0*h1*h2*h3^2 + 
    2*f1*f5*h0*h3 + f1*h0*h2*h3^2 - 8*f3*f6*h0^2 - 2*f3*h0^2*h3^2 + 
    2*f5*h0^2*h1*h3 + 2*f6*h0^3*h3 - 4*f6*h0^2*h1*h2)*x2^3*x3 + (-8*f0*f5 - 
    4*f0*h2*h3 - 2*f5*h0^2 - h0^2*h2*h3)*x2^3*x4 + (-64*f0*f4*f6 - 16*f0*f4*h3^2
    + 12*f0*f5^2 + 12*f0*f5*h2*h3 - 8*f0*f6*h1*h3 - 16*f0*f6*h2^2 - 2*f0*h1*h3^3
    - f0*h2^2*h3^2 - 8*f1*f3*f6 - 2*f1*f3*h3^2 + 2*f1*f5*h1*h3 + 12*f1*f6*h0*h3 
    - 4*f1*f6*h1*h2 + 3*f1*h0*h3^3 - 4*f3*f6*h0*h1 - f3*h0*h1*h3^2 - 
    16*f4*f6*h0^2 - 3*f4*h0^2*h3^2 + 3*f5^2*h0^2 + 3*f5*h0^2*h2*h3 + 
    f5*h0*h1^2*h3 + 4*f6*h0^2*h1*h3 - 4*f6*h0^2*h2^2 - 
    2*f6*h0*h1^2*h2)*x2^2*x3^2 + (-48*f0*f6 - 12*f0*h3^2 - 4*f1*f5 - 2*f1*h2*h3 
    - 2*f5*h0*h1 - 12*f6*h0^2 - h0*h1*h2*h3)*x2^2*x3*x4 + (-16*f0*f5*f6 - 
    4*f0*f5*h3^2 - 8*f0*f6*h2*h3 - 2*f0*h2*h3^3 - 32*f1*f4*f6 - 8*f1*f4*h3^2 + 
    8*f1*f5^2 + 8*f1*f5*h2*h3 - 8*f1*f6*h2^2 + 8*f2*f6*h0*h3 + 2*f2*h0*h3^3 - 
    2*f3*f5*h0*h3 - f3*h0*h2*h3^2 - 16*f4*f6*h0*h1 - 2*f4*h0*h1*h3^2 + 
    4*f5^2*h0*h1 - 4*f5*f6*h0^2 - 2*f5*h0^2*h3^2 + 3*f5*h0*h1*h2*h3 + 
    2*f6*h0^2*h2*h3 + 2*f6*h0*h1^2*h3 - 4*f6*h0*h1*h2^2)*x2*x3^3 + (-32*f1*f6 - 
    8*f1*h3^2 - 4*f4*h0*h3 - 16*f6*h0*h1 - h0*h2^2*h3)*x2*x3^2*x4 - 
    6*h0*h3*x2*x3*x4^2 + (-16*f0*f6^2 - 8*f0*f6*h3^2 - f0*h3^4 - 16*f2*f4*f6 - 
    4*f2*f4*h3^2 + 4*f2*f5^2 + 4*f2*f5*h2*h3 - 4*f2*f6*h2^2 + 4*f3^2*f6 + 
    f3^2*h3^2 - 2*f3*f5*h1*h3 + 4*f3*f6*h0*h3 + 4*f3*f6*h1*h2 + f3*h0*h3^3 - 
    8*f4*f6*h0*h2 - 4*f4*f6*h1^2 - 2*f4*h0*h2*h3^2 + 2*f5^2*h0*h2 + f5^2*h1^2 - 
    f5*h0*h1*h3^2 + 2*f5*h0*h2^2*h3 - 4*f6^2*h0^2 - f6*h0^2*h3^2 + 
    2*f6*h0*h1*h2*h3 - 2*f6*h0*h2^3)*x3^4 + (-16*f2*f6 - 4*f2*h3^2 + 4*f3*f5 + 
    2*f3*h2*h3 - 4*f4*h1*h3 + 2*f5*h0*h3 + 2*f5*h1*h2 - 8*f6*h0*h2 - 4*f6*h1^2 -
    h0*h2*h3^2)*x3^3*x4 + (4*f4 - 4*h1*h3 + h2^2)*x3^2*x4^2 + 4*x3*x4^3;    

 delta4:=(16*f0^2*f2*f6 + 4*f0^2*f2*h3^2 - 16*f0^2*f3*f5 - 8*f0^2*f3*h2*h3 + 16*f0^2*f4^2
    + 8*f0^2*f4*h1*h3 + 8*f0^2*f4*h2^2 - 8*f0^2*f5*h1*h2 + 4*f0^2*f6*h1^2 + 
    f0^2*h1^2*h3^2 - 2*f0^2*h1*h2^2*h3 + f0^2*h2^4 - 4*f0*f1^2*f6 - f0*f1^2*h3^2
    + 8*f0*f1*f2*f5 + 4*f0*f1*f2*h2*h3 - 8*f0*f1*f3*f4 - 2*f0*f1*f3*h2^2 - 
    4*f0*f1*f4*h0*h3 - 4*f0*f1*f4*h1*h2 + 4*f0*f1*f5*h0*h2 + 2*f0*f1*f5*h1^2 - 
    4*f0*f1*f6*h0*h1 - f0*f1*h0*h1*h3^2 + f0*f1*h0*h2^2*h3 + f0*f1*h1^2*h2*h3 - 
    f0*f1*h1*h2^3 + 16*f0*f2^2*f4 + 4*f0*f2^2*h2^2 - 4*f0*f2*f3^2 - 
    8*f0*f2*f3*h0*h3 - 4*f0*f2*f3*h1*h2 - 8*f0*f2*f4*h0*h2 + 8*f0*f2*f4*h1^2 + 
    4*f0*f2*f5*h0*h1 + 8*f0*f2*f6*h0^2 - 3*f0*f2*h0^2*h3^2 - 8*f0*f2*h0*h1*h2*h3
    - 2*f0*f2*h0*h2^3 + f0*f2*h1^2*h2^2 + 4*f0*f3^2*h0*h2 - f0*f3^2*h1^2 - 
    4*f0*f3*f4*h0*h1 - 8*f0*f3*f5*h0^2 - 2*f0*f3*h0^2*h2*h3 - 2*f0*f3*h0*h1^2*h3
    + 3*f0*f3*h0*h1*h2^2 - f0*f3*h1^3*h2 + 8*f0*f4^2*h0^2 + 2*f0*f4*h0^2*h1*h3 +
    2*f0*f4*h0^2*h2^2 - 4*f0*f4*h0*h1^2*h2 + f0*f4*h1^4 - 2*f0*f5*h0^2*h1*h2 + 
    f0*f5*h0*h1^3 + f0*f6*h0^2*h1^2 - f0*h0^2*h1^2*h3^2 - 2*f0*h0*h1^3*h2*h3 - 
    2*f1^3*f5 - f1^3*h2*h3 - 4*f1^2*f2*f4 - f1^2*f2*h2^2 + f1^2*f3^2 + 
    2*f1^2*f3*h0*h3 + f1^2*f3*h1*h2 + 4*f1^2*f4*h0*h2 - f1^2*f4*h1^2 - 
    3*f1^2*f5*h0*h1 - f1^2*f6*h0^2 + f1^2*h0^2*h3^2 + f1^2*h0*h1*h2*h3 + 
    f1^2*h0*h2^3 - 4*f1*f2*f4*h0*h1 + 2*f1*f2*f5*h0^2 + f1*f2*h0^2*h2*h3 - 
    f1*f2*h0*h1*h2^2 + f1*f3^2*h0*h1 - 2*f1*f3*f4*h0^2 + 2*f1*f3*h0^2*h1*h3 - 
    2*f1*f3*h0^2*h2^2 + f1*f3*h0*h1^2*h2 - f1*f4*h0^3*h3 + 3*f1*f4*h0^2*h1*h2 - 
    f1*f4*h0*h1^3 + f1*f5*h0^3*h2 - f1*f5*h0^2*h1^2 - f1*f6*h0^3*h1 + 
    f1*h0^3*h1*h3^2 + 2*f1*h0^2*h1^2*h2*h3 + 4*f2^2*f4*h0^2 + f2^2*h0^2*h2^2 - 
    f2*f3^2*h0^2 - 2*f2*f3*h0^3*h3 - f2*f3*h0^2*h1*h2 - 2*f2*f4*h0^3*h2 + 
    f2*f4*h0^2*h1^2 + f2*f5*h0^3*h1 + f2*f6*h0^4 - f2*h0^4*h3^2 - 
    2*f2*h0^3*h1*h2*h3 + f3^2*h0^3*h2 - f3*f4*h0^3*h1 - f3*f5*h0^4 + 
    f4^2*h0^4)*x1^4 + (-32*f0^2*f3*f6 - 8*f0^2*f3*h3^2 + 32*f0^2*f4*f5 + 
    16*f0^2*f4*h2*h3 + 8*f0^2*f5*h2^2 - 16*f0^2*f6*h1*h2 - 4*f0^2*h1*h2*h3^2 + 
    4*f0^2*h2^3*h3 + 32*f0*f1*f2*f6 + 8*f0*f1*f2*h3^2 - 16*f0*f1*f3*f5 - 
    8*f0*f1*f3*h2*h3 - 8*f0*f1*f5*h1*h2 + 8*f0*f1*f6*h0*h2 + 8*f0*f1*f6*h1^2 + 
    2*f0*f1*h0*h2*h3^2 + 2*f0*f1*h1^2*h3^2 - 4*f0*f1*h1*h2^2*h3 + 32*f0*f2^2*f5 
    + 16*f0*f2^2*h2*h3 - 8*f0*f2*f3*h1*h3 - 16*f0*f2*f4*h0*h3 - 8*f0*f2*f5*h0*h2
    + 16*f0*f2*f5*h1^2 + 16*f0*f2*f6*h0*h1 - 8*f0*f2*h0*h2^2*h3 + 
    4*f0*f2*h1^2*h2*h3 - 8*f0*f3*f5*h0*h1 - 16*f0*f3*f6*h0^2 - 6*f0*f3*h0^2*h3^2
    - 4*f0*f3*h0*h1*h2*h3 - 2*f0*f3*h1^3*h3 + 16*f0*f4*f5*h0^2 + 
    4*f0*f4*h0^2*h2*h3 - 4*f0*f4*h0*h1^2*h3 + 2*f0*f5*h0^2*h2^2 - 
    6*f0*f5*h0*h1^2*h2 + 2*f0*f5*h1^4 - 4*f0*f6*h0^2*h1*h2 + 4*f0*f6*h0*h1^3 - 
    2*f0*h0^2*h1*h2*h3^2 - 4*f0*h0*h1^2*h2^2*h3 - 8*f1^3*f6 - 2*f1^3*h3^2 - 
    8*f1^2*f2*f5 - 4*f1^2*f2*h2*h3 + 2*f1^2*f3*h1*h3 + 4*f1^2*f4*h0*h3 + 
    6*f1^2*f5*h0*h2 - 2*f1^2*f5*h1^2 - 12*f1^2*f6*h0*h1 - 2*f1^2*h0*h1*h3^2 + 
    4*f1^2*h0*h2^2*h3 - 8*f1*f2*f5*h0*h1 + 8*f1*f2*f6*h0^2 + 2*f1*f2*h0^2*h3^2 -
    4*f1*f2*h0*h1*h2*h3 - 4*f1*f3*f5*h0^2 - 4*f1*f3*h0^2*h2*h3 + 
    2*f1*f3*h0*h1^2*h3 + 4*f1*f4*h0^2*h1*h3 + 4*f1*f5*h0^2*h1*h2 - 
    2*f1*f5*h0*h1^3 + 2*f1*f6*h0^3*h2 - 4*f1*f6*h0^2*h1^2 + f1*h0^3*h2*h3^2 + 
    2*f1*h0^2*h1*h2^2*h3 + 8*f2^2*f5*h0^2 + 4*f2^2*h0^2*h2*h3 - 
    2*f2*f3*h0^2*h1*h3 - 4*f2*f4*h0^3*h3 - 2*f2*f5*h0^3*h2 + 2*f2*f5*h0^2*h1^2 +
    4*f2*f6*h0^3*h1 - 2*f3*f5*h0^3*h1 - 2*f3*f6*h0^4 - f3*h0^4*h3^2 - 
    2*f3*h0^3*h1*h2*h3 + 2*f4*f5*h0^4)*x1^3*x2 + (-64*f0^2*f4*f6 - 
    16*f0^2*f4*h3^2 + 32*f0^2*f5^2 + 32*f0^2*f5*h2*h3 - 16*f0^2*f6*h1*h3 - 
    16*f0^2*f6*h2^2 - 4*f0^2*h1*h3^3 + 4*f0^2*h2^2*h3^2 + 16*f0*f1*f3*f6 + 
    4*f0*f1*f3*h3^2 - 8*f0*f1*f5*h1*h3 + 8*f0*f1*f6*h0*h3 + 8*f0*f1*f6*h1*h2 + 
    2*f0*f1*h0*h3^3 - 2*f0*f1*h1*h2*h3^2 + 16*f0*f2*f3*f5 + 8*f0*f2*f3*h2*h3 - 
    16*f0*f2*f4*h1*h3 - 8*f0*f2*f5*h0*h3 + 8*f0*f2*f5*h1*h2 - 4*f0*f2*h0*h2*h3^2
    + 8*f0*f3*f4*h0*h3 - 8*f0*f3*f5*h0*h2 + 4*f0*f3*f5*h1^2 + 8*f0*f3*f6*h0*h1 +
    6*f0*f3*h0*h1*h3^2 - 2*f0*f3*h0*h2^2*h3 + 2*f0*f3*h1^2*h2*h3 - 
    32*f0*f4*f6*h0^2 - 4*f0*f4*h0^2*h3^2 + 8*f0*f4*h0*h1*h2*h3 - 4*f0*f4*h1^3*h3
    + 16*f0*f5^2*h0^2 + 8*f0*f5*h0^2*h2*h3 - 6*f0*f5*h0*h1^2*h3 - 
    4*f0*f5*h0*h1*h2^2 + 2*f0*f5*h1^3*h2 - 4*f0*f6*h0^2*h1*h3 - 
    4*f0*f6*h0^2*h2^2 + 4*f0*f6*h0*h1^2*h2 + 2*f0*h0^2*h1*h3^3 + 
    4*f0*h0*h1^2*h2*h3^2 - 4*f1^2*f3*f5 - 2*f1^2*f3*h2*h3 + 4*f1^2*f4*h1*h3 + 
    6*f1^2*f5*h0*h3 - 2*f1^2*f5*h1*h2 - 4*f1^2*f6*h0*h2 + 2*f1^2*h0*h2*h3^2 - 
    4*f1*f3^2*h0*h3 - 4*f1*f3*f5*h0*h1 + 4*f1*f3*f6*h0^2 - 4*f1*f3*h0^2*h3^2 - 
    8*f1*f3*h0*h1*h2*h3 - 4*f1*f4*h0^2*h2*h3 + 4*f1*f4*h0*h1^2*h3 + 
    4*f1*f5*h0^2*h1*h3 + 2*f1*f5*h0^2*h2^2 - 2*f1*f5*h0*h1^2*h2 + 
    2*f1*f6*h0^3*h3 - 2*f1*f6*h0^2*h1*h2 - f1*h0^3*h3^3 - 3*f1*h0^2*h1*h2*h3^2 -
    2*f1*h0*h1^2*h2^2*h3 + 4*f2*f3*f5*h0^2 + 6*f2*f3*h0^2*h2*h3 - 
    4*f2*f4*h0^2*h1*h3 - 2*f2*f5*h0^3*h3 + 2*f2*f5*h0^2*h1*h2 + 
    2*f2*h0^3*h2*h3^2 + 4*f2*h0^2*h1*h2^2*h3 - 2*f3^2*h0^2*h1*h3 + 
    2*f3*f4*h0^3*h3 - 2*f3*f5*h0^3*h2 + 2*f3*f6*h0^3*h1 - f3*h0^3*h1*h3^2 - 
    2*f3*h0^2*h1^2*h2*h3 - 4*f4*f6*h0^4 + 2*f5^2*h0^4)*x1^3*x3 + (32*f0*f2*f4 + 
    8*f0*f2*h2^2 - 8*f0*f3^2 - 8*f0*f3*h0*h3 - 8*f0*f3*h1*h2 + 8*f0*f4*h1^2 - 
    4*f0*h0^2*h3^2 - 8*f0*h0*h1*h2*h3 - 8*f1^2*f4 - 2*f1^2*h2^2 + 4*f1*f3*h0*h2 
    - 8*f1*f4*h0*h1 + 8*f2*f4*h0^2 - 2*f3^2*h0^2 - 2*f3*h0^3*h3 - h0^4*h3^2 - 
    2*h0^3*h1*h2*h3)*x1^3*x4 + (32*f0^2*f4*f6 + 8*f0^2*f4*h3^2 + 16*f0^2*f5^2 + 
    16*f0^2*f5*h2*h3 - 8*f0^2*f6*h1*h3 + 8*f0^2*f6*h2^2 - 2*f0^2*h1*h3^3 + 
    6*f0^2*h2^2*h3^2 - 24*f0*f1*f3*f6 - 6*f0*f1*f3*h3^2 - 4*f0*f1*f5*h1*h3 + 
    4*f0*f1*f6*h0*h3 - 12*f0*f1*f6*h1*h2 + f0*f1*h0*h3^3 - 5*f0*f1*h1*h2*h3^2 + 
    64*f0*f2^2*f6 + 16*f0*f2^2*h3^2 + 8*f0*f2*f3*f5 + 4*f0*f2*f3*h2*h3 - 
    8*f0*f2*f4*h1*h3 - 20*f0*f2*f5*h0*h3 + 4*f0*f2*f5*h1*h2 + 32*f0*f2*f6*h1^2 -
    10*f0*f2*h0*h2*h3^2 + 4*f0*f2*h1^2*h3^2 - 4*f0*f3*f4*h0*h3 - 
    4*f0*f3*f5*h0*h2 + 2*f0*f3*f5*h1^2 - 12*f0*f3*f6*h0*h1 + f0*f3*h0*h1*h3^2 - 
    3*f0*f3*h0*h2^2*h3 + f0*f3*h1^2*h2*h3 + 16*f0*f4*f6*h0^2 - 2*f0*f4*h0^2*h3^2
    - 4*f0*f4*h0*h1*h2*h3 - 2*f0*f4*h1^3*h3 + 8*f0*f5^2*h0^2 + 
    4*f0*f5*h0^2*h2*h3 - 7*f0*f5*h0*h1^2*h3 - 2*f0*f5*h0*h1*h2^2 + f0*f5*h1^3*h2
    - 2*f0*f6*h0^2*h1*h3 + 2*f0*f6*h0^2*h2^2 - 6*f0*f6*h0*h1^2*h2 + 4*f0*f6*h1^4
    - 2*f0*h0^2*h1*h3^3 - f0*h0^2*h2^2*h3^2 - 4*f0*h0*h1^2*h2*h3^2 - 
    2*f0*h0*h1*h2^3*h3 - 16*f1^2*f2*f6 - 4*f1^2*f2*h3^2 - 2*f1^2*f3*f5 - 
    f1^2*f3*h2*h3 + 2*f1^2*f4*h1*h3 + 7*f1^2*f5*h0*h3 - f1^2*f5*h1*h2 + 
    6*f1^2*f6*h0*h2 - 4*f1^2*f6*h1^2 + 5*f1^2*h0*h2*h3^2 - 16*f1*f2*f6*h0*h1 - 
    4*f1*f2*h0*h1*h3^2 - 2*f1*f3*f5*h0*h1 - 6*f1*f3*f6*h0^2 - 2*f1*f3*h0^2*h3^2 
    - f1*f3*h0*h1*h2*h3 - 2*f1*f4*h0^2*h2*h3 + 2*f1*f4*h0*h1^2*h3 + 
    6*f1*f5*h0^2*h1*h3 + f1*f5*h0^2*h2^2 - f1*f5*h0*h1^2*h2 + f1*f6*h0^3*h3 + 
    3*f1*f6*h0^2*h1*h2 - 4*f1*f6*h0*h1^3 + f1*h0^3*h3^3 + 2*f1*h0^2*h1*h2*h3^2 +
    16*f2^2*f6*h0^2 + 4*f2^2*h0^2*h3^2 + 2*f2*f3*f5*h0^2 + f2*f3*h0^2*h2*h3 - 
    2*f2*f4*h0^2*h1*h3 - 5*f2*f5*h0^3*h3 + f2*f5*h0^2*h1*h2 + 4*f2*f6*h0^2*h1^2 
    - f3*f4*h0^3*h3 - f3*f5*h0^3*h2 - 3*f3*f6*h0^3*h1 + 2*f4*f6*h0^4 - 
    f4*h0^4*h3^2 - 2*f4*h0^3*h1*h2*h3 + f5^2*h0^4)*x1^2*x2^2 + (64*f0^2*f5*f6 + 
    16*f0^2*f5*h3^2 + 32*f0^2*f6*h2*h3 + 8*f0^2*h2*h3^3 - 32*f0*f1*f4*f6 - 
    8*f0*f1*f4*h3^2 + 16*f0*f1*f5^2 + 16*f0*f1*f5*h2*h3 - 24*f0*f1*f6*h1*h3 - 
    8*f0*f1*f6*h2^2 - 6*f0*f1*h1*h3^3 + 2*f0*f1*h2^2*h3^2 + 64*f0*f2*f3*f6 + 
    16*f0*f2*f3*h3^2 - 24*f0*f2*f5*h1*h3 - 16*f0*f2*f6*h0*h3 + 32*f0*f2*f6*h1*h2
    - 4*f0*f2*h0*h3^3 - 4*f0*f2*h1*h2*h3^2 + 8*f0*f3^2*f5 + 4*f0*f3^2*h2*h3 - 
    8*f0*f3*f4*h1*h3 - 8*f0*f3*f5*h0*h3 + 8*f0*f3*f5*h1*h2 - 8*f0*f3*f6*h0*h2 + 
    16*f0*f3*f6*h1^2 - 6*f0*f3*h0*h2*h3^2 + 6*f0*f3*h1^2*h3^2 + 
    2*f0*f3*h1*h2^2*h3 + 16*f0*f4^2*h0*h3 - 8*f0*f4*f5*h0*h2 - 16*f0*f4*f6*h0*h1
    + 12*f0*f4*h0*h1*h3^2 + 4*f0*f4*h0*h2^2*h3 - 4*f0*f4*h1^2*h2*h3 + 
    8*f0*f5^2*h0*h1 + 32*f0*f5*f6*h0^2 + 8*f0*f5*h0^2*h3^2 + 8*f0*f5*h0*h1*h2*h3
    - 2*f0*f5*h0*h2^3 - 6*f0*f5*h1^3*h3 + 2*f0*f5*h1^2*h2^2 + 8*f0*f6*h0^2*h2*h3
    - 16*f0*f6*h0*h1^2*h3 - 8*f0*f6*h0*h1*h2^2 + 8*f0*f6*h1^3*h2 + 
    2*f0*h0^2*h2*h3^3 + 4*f0*h0*h1*h2^2*h3^2 - 8*f1^2*f3*f6 - 2*f1^2*f3*h3^2 + 
    2*f1^2*f5*h1*h3 + 16*f1^2*f6*h0*h3 - 4*f1^2*f6*h1*h2 + 4*f1^2*h0*h3^3 + 
    8*f1*f2*f5*h0*h3 - 8*f1*f2*f6*h0*h2 + 2*f1*f2*h0*h2*h3^2 - 8*f1*f3*f4*h0*h3 
    - 4*f1*f3*f5*h0*h2 - 8*f1*f3*f6*h0*h1 - 6*f1*f3*h0*h1*h3^2 - 
    4*f1*f3*h0*h2^2*h3 - 8*f1*f4*f6*h0^2 - 12*f1*f4*h0^2*h3^2 - 
    4*f1*f4*h0*h1*h2*h3 + 4*f1*f5^2*h0^2 + 4*f1*f5*h0^2*h2*h3 + 
    4*f1*f5*h0*h1^2*h3 - 2*f1*f5*h0*h1*h2^2 + 10*f1*f6*h0^2*h1*h3 + 
    2*f1*f6*h0^2*h2^2 - 6*f1*f6*h0*h1^2*h2 - f1*h0^2*h1*h3^3 - f1*h0^2*h2^2*h3^2
    - 2*f1*h0*h1^2*h2*h3^2 - 2*f1*h0*h1*h2^3*h3 + 16*f2*f3*f6*h0^2 + 
    8*f2*f3*h0^2*h3^2 - 4*f2*f4*h0^2*h2*h3 - 2*f2*f5*h0^2*h1*h3 + 
    2*f2*f5*h0^2*h2^2 - 4*f2*f6*h0^3*h3 + 4*f2*f6*h0^2*h1*h2 + 2*f2*h0^3*h3^3 + 
    4*f2*h0^2*h1*h2*h3^2 + 2*f3^2*f5*h0^2 + 4*f3^2*h0^2*h2*h3 - 
    6*f3*f4*h0^2*h1*h3 - 2*f3*f5*h0^3*h3 - 2*f3*f6*h0^3*h2 + 2*f3*f6*h0^2*h1^2 +
    f3*h0^3*h2*h3^2 + 2*f3*h0^2*h1*h2^2*h3 + 4*f4^2*h0^3*h3 - 2*f4*f5*h0^3*h2 - 
    4*f4*f6*h0^3*h1 - 2*f4*h0^3*h1*h3^2 - 4*f4*h0^2*h1^2*h2*h3 + 2*f5^2*h0^3*h1 
    + 4*f5*f6*h0^4 + f5*h0^4*h3^2 + 2*f5*h0^3*h1*h2*h3)*x1^2*x2*x3 + 
    (48*f0*f2*f5 + 24*f0*f2*h2*h3 - 12*f0*f3*h1*h3 + 12*f0*f5*h1^2 - 12*f1^2*f5 
    - 6*f1^2*h2*h3 + 2*f1*f3*h0*h3 - 12*f1*f5*h0*h1 - 2*f1*h0^2*h3^2 - 
    4*f1*h0*h1*h2*h3 + 12*f2*f5*h0^2 - 2*f3*h0^2*h1*h3 - h0^3*h1*h3^2 - 
    2*h0^2*h1^2*h2*h3)*x1^2*x2*x4 + (64*f0^2*f6^2 + 32*f0^2*f6*h3^2 + 
    4*f0^2*h3^4 + 96*f0*f2*f4*f6 + 24*f0*f2*f4*h3^2 - 32*f0*f2*f5^2 - 
    32*f0*f2*f5*h2*h3 + 8*f0*f2*f6*h1*h3 + 24*f0*f2*f6*h2^2 + 2*f0*f2*h1*h3^3 - 
    2*f0*f2*h2^2*h3^2 - 16*f0*f3^2*f6 - 4*f0*f3^2*h3^2 + 8*f0*f3*f4*f5 + 
    4*f0*f3*f4*h2*h3 + 8*f0*f3*f5*h1*h3 + 2*f0*f3*f5*h2^2 - 28*f0*f3*f6*h0*h3 - 
    16*f0*f3*f6*h1*h2 - 7*f0*f3*h0*h3^3 + f0*f3*h2^3*h3 - 8*f0*f4^2*h1*h3 + 
    4*f0*f4*f5*h0*h3 + 4*f0*f4*f5*h1*h2 + 8*f0*f4*f6*h0*h2 + 24*f0*f4*f6*h1^2 + 
    4*f0*f4*h0*h2*h3^2 + 4*f0*f4*h1^2*h3^2 - 2*f0*f4*h1*h2^2*h3 - 
    4*f0*f5^2*h0*h2 - 8*f0*f5^2*h1^2 + 8*f0*f5*h0*h1*h3^2 - 3*f0*f5*h0*h2^2*h3 -
    4*f0*f5*h1^2*h2*h3 + f0*f5*h1*h2^3 + 32*f0*f6^2*h0^2 + 4*f0*f6*h0^2*h3^2 - 
    24*f0*f6*h0*h1*h2*h3 + 2*f0*f6*h0*h2^3 + 2*f0*f6*h1^3*h3 + 2*f0*f6*h1^2*h2^2
    - f0*h0^2*h3^4 - 2*f0*h0*h1*h2*h3^3 - 32*f1^2*f4*f6 - 8*f1^2*f4*h3^2 + 
    12*f1^2*f5^2 + 12*f1^2*f5*h2*h3 - 4*f1^2*f6*h1*h3 - 8*f1^2*f6*h2^2 - 
    f1^2*h1*h3^3 + f1^2*h2^2*h3^2 + 8*f1*f2*f3*f6 + 2*f1*f2*f3*h3^2 - 
    4*f1*f2*f5*h1*h3 + 4*f1*f2*f6*h0*h3 + 4*f1*f2*f6*h1*h2 + f1*f2*h0*h3^3 - 
    f1*f2*h1*h2*h3^2 - 6*f1*f3*f5*h0*h3 + 8*f1*f3*f6*h0*h2 + 2*f1*f3*f6*h1^2 - 
    f1*f3*h0*h2*h3^2 + f1*f3*h1^2*h3^2 + 8*f1*f4^2*h0*h3 - 4*f1*f4*f5*h0*h2 - 
    32*f1*f4*f6*h0*h1 - 4*f1*f4*h0*h1*h3^2 + 2*f1*f4*h0*h2^2*h3 + 
    12*f1*f5^2*h0*h1 - 2*f1*f5*h0^2*h3^2 + 10*f1*f5*h0*h1*h2*h3 - f1*f5*h0*h2^3 
    - f1*f5*h1^3*h3 + 8*f1*f6*h0^2*h2*h3 - 3*f1*f6*h0*h1^2*h3 - 
    4*f1*f6*h0*h1*h2^2 + f1*f6*h1^3*h2 + f1*h0^2*h2*h3^3 + 2*f1*h0*h1*h2^2*h3^2 
    + 8*f2^2*f5*h0*h3 - 8*f2^2*f6*h0*h2 + 2*f2^2*h0*h2*h3^2 - 12*f2*f3*f4*h0*h3 
    + 4*f2*f3*f6*h0*h1 - f2*f3*h0*h1*h3^2 - 3*f2*f3*h0*h2^2*h3 + 
    24*f2*f4*f6*h0^2 - 2*f2*f4*h0^2*h3^2 - 8*f2*f4*h0*h1*h2*h3 - 8*f2*f5^2*h0^2 
    - 4*f2*f5*h0^2*h2*h3 + 2*f2*f5*h0*h1^2*h3 + 4*f2*f6*h0^2*h1*h3 + 
    4*f2*f6*h0^2*h2^2 - 2*f2*f6*h0*h1^2*h2 - f2*h0^2*h2^2*h3^2 - 
    2*f2*h0*h1*h2^3*h3 + 3*f3^3*h0*h3 - 4*f3^2*f6*h0^2 + 4*f3^2*h0^2*h3^2 + 
    5*f3^2*h0*h1*h2*h3 + 2*f3*f4*f5*h0^2 - f3*f4*h0^2*h2*h3 - 3*f3*f4*h0*h1^2*h3
    - f3*f5*h0^2*h1*h3 + f3*f5*h0^2*h2^2 - 7*f3*f6*h0^3*h3 + f3*f6*h0*h1^3 + 
    f3*h0^3*h3^3 + 3*f3*h0^2*h1*h2*h3^2 + 2*f3*h0*h1^2*h2^2*h3 + 
    2*f4^2*h0^2*h1*h3 + f4*f5*h0^3*h3 - f4*f5*h0^2*h1*h2 + 2*f4*f6*h0^3*h2 - 
    2*f4*f6*h0^2*h1^2 - f4*h0^2*h1^2*h3^2 - 2*f4*h0*h1^3*h2*h3 - f5^2*h0^3*h2 + 
    f5^2*h0^2*h1^2 + f5*h0^3*h1*h3^2 + 2*f5*h0^2*h1^2*h2*h3 + 4*f6^2*h0^4 - 
    f6*h0^4*h3^2 - 2*f6*h0^3*h1*h2*h3)*x1^2*x3^2 + (32*f0*f2*f6 + 8*f0*f2*h3^2 +
    16*f0*f3*f5 + 8*f0*f3*h2*h3 - 16*f0*f4*h1*h3 + 8*f0*f5*h1*h2 + 8*f0*f6*h1^2 
    - 8*f1^2*f6 - 2*f1^2*h3^2 + 8*f1*f4*h0*h3 - 4*f1*f5*h0*h2 - 8*f1*f6*h0*h1 - 
    8*f2*f3*h0*h3 + 8*f2*f6*h0^2 - 4*f2*h0^2*h3^2 - 8*f2*h0*h1*h2*h3 + 
    4*f3*f5*h0^2 + 4*f3*h0^2*h2*h3 - 2*f3*h0*h1^2*h3 + 2*h0^3*h2*h3^2 - 
    h0^2*h1^2*h3^2 + 4*h0^2*h1*h2^2*h3 - 2*h0*h1^3*h2*h3)*x1^2*x3*x4 + (8*f0*f4 
    - 2*f0*h1*h3 + 2*f0*h2^2 - 2*f1*f3 + f1*h0*h3 - f1*h1*h2 + 2*f2*h0*h2 - 
    f3*h0*h1 + 2*f4*h0^2)*x1^2*x4^2 + (32*f0^2*f5*f6 + 8*f0^2*f5*h3^2 + 
    16*f0^2*f6*h2*h3 + 4*f0^2*h2*h3^3 - 8*f0*f1*f6*h1*h3 - 2*f0*f1*h1*h3^3 + 
    32*f0*f2*f3*f6 + 8*f0*f2*f3*h3^2 - 8*f0*f2*f5*h1*h3 - 16*f0*f2*f6*h0*h3 + 
    16*f0*f2*f6*h1*h2 - 4*f0*f2*h0*h3^3 - 8*f0*f3*f5*h0*h3 - 8*f0*f3*f6*h0*h2 + 
    8*f0*f3*f6*h1^2 - 6*f0*f3*h0*h2*h3^2 + 2*f0*f3*h1^2*h3^2 + 
    4*f0*f4*h0*h1*h3^2 + 16*f0*f5*f6*h0^2 - 2*f0*f5*h0^2*h3^2 - 
    8*f0*f5*h0*h1*h2*h3 - 2*f0*f5*h1^3*h3 + 4*f0*f6*h0^2*h2*h3 - 
    8*f0*f6*h0*h1^2*h3 - 4*f0*f6*h0*h1*h2^2 + 4*f0*f6*h1^3*h2 - 
    2*f0*h0^2*h2*h3^3 - 4*f0*h0*h1*h2^2*h3^2 - 8*f1^2*f3*f6 - 2*f1^2*f3*h3^2 + 
    2*f1^2*f5*h1*h3 + 8*f1^2*f6*h0*h3 - 4*f1^2*f6*h1*h2 + 2*f1^2*h0*h3^3 - 
    8*f1*f3*f6*h0*h1 - 2*f1*f3*h0*h1*h3^2 - 2*f1*f4*h0^2*h3^2 + 
    2*f1*f5*h0*h1^2*h3 + 6*f1*f6*h0^2*h1*h3 + 2*f1*f6*h0^2*h2^2 - 
    4*f1*f6*h0*h1^2*h2 + 8*f2*f3*f6*h0^2 + 2*f2*f3*h0^2*h3^2 - 
    2*f2*f5*h0^2*h1*h3 - 4*f2*f6*h0^3*h3 + 4*f2*f6*h0^2*h1*h2 - 2*f3*f5*h0^3*h3 
    - 2*f3*f6*h0^3*h2 + 2*f5*f6*h0^4 - f5*h0^4*h3^2 - 
    2*f5*h0^3*h1*h2*h3)*x1*x2^3 + (64*f0^2*f6^2 + 32*f0^2*f6*h3^2 + 4*f0^2*h3^4 
    + 32*f0*f1*f5*f6 + 8*f0*f1*f5*h3^2 + 16*f0*f1*f6*h2*h3 + 4*f0*f1*h2*h3^3 - 
    32*f0*f2*f6*h1*h3 - 8*f0*f2*h1*h3^3 + 48*f0*f3^2*f6 + 12*f0*f3^2*h3^2 - 
    16*f0*f3*f5*h1*h3 - 16*f0*f3*f6*h0*h3 + 48*f0*f3*f6*h1*h2 - 4*f0*f3*h0*h3^3 
    + 4*f0*f3*h1*h2*h3^2 + 16*f0*f4*f5*h0*h3 - 32*f0*f4*f6*h0*h2 + 
    4*f0*f4*h1^2*h3^2 + 16*f0*f5*f6*h0*h1 + 12*f0*f5*h0*h1*h3^2 + 
    4*f0*f5*h0*h2^2*h3 - 8*f0*f5*h1^2*h2*h3 + 32*f0*f6^2*h0^2 + 
    16*f0*f6*h0^2*h3^2 - 8*f0*f6*h0*h2^3 - 8*f0*f6*h1^3*h3 + 12*f0*f6*h1^2*h2^2 
    + 2*f0*h0^2*h3^4 + 4*f0*h0*h1*h2*h3^3 + 16*f1*f2*f6*h0*h3 + 4*f1*f2*h0*h3^3 
    - 8*f1*f3*f5*h0*h3 - 16*f1*f3*f6*h0*h2 - 8*f1*f3*h0*h2*h3^2 + 
    8*f1*f5*f6*h0^2 - 8*f1*f5*h0^2*h3^2 - 4*f1*f5*h0*h1*h2*h3 + 
    12*f1*f6*h0^2*h2*h3 + 4*f1*f6*h0*h1^2*h3 - 8*f1*f6*h0*h1*h2^2 - 
    2*f1*h0^2*h2*h3^3 - 4*f1*h0*h1*h2^2*h3^2 - 4*f2*f4*h0^2*h3^2 + 
    4*f2*f6*h0^2*h2^2 + 12*f3^2*f6*h0^2 + 6*f3^2*h0^2*h3^2 - 8*f3*f5*h0^2*h1*h3 
    - 4*f3*f6*h0^3*h3 + 4*f3*f6*h0^2*h1*h2 + f3*h0^3*h3^3 + 2*f3*h0^2*h1*h2*h3^2
    + 4*f4*f5*h0^3*h3 - 8*f4*f6*h0^3*h2 + 4*f5*f6*h0^3*h1 - 2*f5*h0^3*h1*h3^2 - 
    4*f5*h0^2*h1^2*h2*h3 + 4*f6^2*h0^4 + 2*f6*h0^4*h3^2 + 
    4*f6*h0^3*h1*h2*h3)*x1*x2^2*x3 + (64*f0*f2*f6 + 16*f0*f2*h3^2 + 8*f0*f3*f5 +
    4*f0*f3*h2*h3 - 8*f0*f4*h1*h3 + 4*f0*f5*h1*h2 + 16*f0*f6*h1^2 - 16*f1^2*f6 -
    4*f1^2*h3^2 + 4*f1*f4*h0*h3 - 2*f1*f5*h0*h2 - 16*f1*f6*h0*h1 + 16*f2*f6*h0^2
    + 2*f3*f5*h0^2 - 2*f3*h0^2*h2*h3 - h0^3*h2*h3^2 - 
    2*h0^2*h1*h2^2*h3)*x1*x2^2*x4 + (64*f0*f1*f6^2 + 32*f0*f1*f6*h3^2 + 
    4*f0*f1*h3^4 - 32*f0*f2*f5*f6 - 8*f0*f2*f5*h3^2 - 16*f0*f2*f6*h2*h3 - 
    4*f0*f2*h2*h3^3 + 64*f0*f3*f4*f6 + 16*f0*f3*f4*h3^2 - 8*f0*f3*f5^2 - 
    8*f0*f3*f5*h2*h3 - 8*f0*f3*f6*h1*h3 + 16*f0*f3*f6*h2^2 - 2*f0*f3*h1*h3^3 + 
    2*f0*f3*h2^2*h3^2 - 8*f0*f4*f5*h1*h3 - 16*f0*f4*f6*h0*h3 + 32*f0*f4*f6*h1*h2
    - 4*f0*f4*h0*h3^3 + 4*f0*f4*h1*h2*h3^2 + 16*f0*f5^2*h0*h3 - 4*f0*f5^2*h1*h2 
    - 24*f0*f5*f6*h0*h2 - 8*f0*f5*f6*h1^2 + 10*f0*f5*h0*h2*h3^2 + 
    2*f0*f5*h1^2*h3^2 - 6*f0*f5*h1*h2^2*h3 + 32*f0*f6^2*h0*h1 + 
    8*f0*f6*h0*h1*h3^2 - 16*f0*f6*h0*h2^2*h3 - 8*f0*f6*h1^2*h2*h3 + 
    8*f0*f6*h1*h2^3 + 16*f1^2*f5*f6 + 4*f1^2*f5*h3^2 + 8*f1^2*f6*h2*h3 + 
    2*f1^2*h2*h3^3 - 8*f1*f2*f6*h1*h3 - 2*f1*f2*h1*h3^3 + 8*f1*f3^2*f6 + 
    2*f1*f3^2*h3^2 - 4*f1*f3*f5*h1*h3 - 8*f1*f3*f6*h0*h3 + 8*f1*f3*f6*h1*h2 - 
    2*f1*f3*h0*h3^3 + 8*f1*f4*f5*h0*h3 - 24*f1*f4*f6*h0*h2 - 2*f1*f4*h0*h2*h3^2 
    + 2*f1*f4*h1^2*h3^2 + 2*f1*f5^2*h0*h2 + 16*f1*f5*f6*h0*h1 + 
    4*f1*f5*h0*h1*h3^2 + 4*f1*f5*h0*h2^2*h3 - 2*f1*f5*h1^2*h2*h3 + 
    16*f1*f6^2*h0^2 + 8*f1*f6*h0^2*h3^2 + 8*f1*f6*h0*h1*h2*h3 - 6*f1*f6*h0*h2^3 
    - 2*f1*f6*h1^3*h3 + 2*f1*f6*h1^2*h2^2 + f1*h0^2*h3^4 + 2*f1*h0*h1*h2*h3^3 + 
    16*f2^2*f6*h0*h3 + 4*f2^2*h0*h3^3 - 8*f2*f3*f5*h0*h3 - 8*f2*f3*f6*h0*h2 - 
    6*f2*f3*h0*h2*h3^2 - 4*f2*f4*h0*h1*h3^2 - 8*f2*f5*f6*h0^2 - 
    12*f2*f5*h0^2*h3^2 - 4*f2*f5*h0*h1*h2*h3 + 12*f2*f6*h0^2*h2*h3 + 
    4*f2*f6*h0*h1^2*h3 - 4*f2*f6*h0*h1*h2^2 - 2*f2*h0^2*h2*h3^3 - 
    4*f2*h0*h1*h2^2*h3^2 + 4*f3^2*f6*h0*h1 + 4*f3^2*h0*h1*h3^2 + 
    16*f3*f4*f6*h0^2 + 8*f3*f4*h0^2*h3^2 - 2*f3*f5^2*h0^2 - 6*f3*f5*h0^2*h2*h3 -
    4*f3*f5*h0*h1^2*h3 - 6*f3*f6*h0^2*h1*h3 + 6*f3*f6*h0^2*h2^2 + 
    2*f3*f6*h0*h1^2*h2 + f3*h0^2*h1*h3^3 + 2*f3*h0*h1^2*h2*h3^2 + 
    2*f4*f5*h0^2*h1*h3 - 4*f4*f6*h0^3*h3 - 4*f4*f6*h0^2*h1*h2 + 2*f4*h0^3*h3^3 +
    4*f4*h0^2*h1*h2*h3^2 + 4*f5^2*h0^3*h3 - 6*f5*f6*h0^3*h2 + 2*f5*f6*h0^2*h1^2 
    - f5*h0^3*h2*h3^2 - f5*h0^2*h1^2*h3^2 - 2*f5*h0^2*h1*h2^2*h3 - 
    2*f5*h0*h1^3*h2*h3 + 8*f6^2*h0^3*h1 + 2*f6*h0^3*h1*h3^2 + 
    4*f6*h0^2*h1^2*h2*h3)*x1*x2*x3^2 + (80*f0*f3*f6 + 20*f0*f3*h3^2 - 
    20*f0*f5*h1*h3 + 40*f0*f6*h1*h2 + 4*f1*f3*f5 + 2*f1*f3*h2*h3 - 4*f1*f4*h1*h3
    + 10*f1*f5*h0*h3 + 2*f1*f5*h1*h2 - 20*f1*f6*h0*h2 + 8*f2*f4*h0*h3 - 
    4*f2*f5*h0*h2 - 6*f3^2*h0*h3 + 2*f3*f5*h0*h1 + 20*f3*f6*h0^2 + 
    4*f3*h0^2*h3^2 - 6*f3*h0*h1*h2*h3 + 3*h0^3*h3^3 + 5*h0^2*h1*h2*h3^2 - 
    2*h0*h1^2*h2^2*h3)*x1*x2*x3*x4 + (8*f0*f5 + 4*f0*h2*h3 - 2*f1*h1*h3 + 
    4*f2*h0*h3 + 2*f5*h0^2)*x1*x2*x4^2 + (-64*f0*f2*f6^2 - 32*f0*f2*f6*h3^2 - 
    4*f0*f2*h3^4 + 16*f0*f3*f5*f6 + 4*f0*f3*f5*h3^2 + 8*f0*f3*f6*h2*h3 + 
    2*f0*f3*h2*h3^3 - 4*f0*f5^2*h1*h3 + 8*f0*f5*f6*h0*h3 + 8*f0*f5*f6*h1*h2 + 
    2*f0*f5*h0*h3^3 - 2*f0*f5*h1*h2*h3^2 - 16*f0*f6^2*h0*h2 - 16*f0*f6^2*h1^2 - 
    4*f0*f6*h0*h2*h3^2 - 4*f0*f6*h1^2*h3^2 + 4*f0*f6*h1*h2^2*h3 + 32*f1^2*f6^2 +
    16*f1^2*f6*h3^2 + 2*f1^2*h3^4 + 16*f1*f3*f4*f6 + 4*f1*f3*f4*h3^2 - 
    4*f1*f3*f5^2 - 4*f1*f3*f5*h2*h3 - 8*f1*f3*f6*h1*h3 + 4*f1*f3*f6*h2^2 - 
    2*f1*f3*h1*h3^3 - 8*f1*f4*f6*h0*h3 + 8*f1*f4*f6*h1*h2 - 2*f1*f4*h0*h3^3 + 
    2*f1*f4*h1*h2*h3^2 + 6*f1*f5^2*h0*h3 - 2*f1*f5^2*h1*h2 - 8*f1*f5*f6*h0*h2 + 
    4*f1*f5*h0*h2*h3^2 + 2*f1*f5*h1^2*h3^2 - 2*f1*f5*h1*h2^2*h3 + 
    32*f1*f6^2*h0*h1 + 8*f1*f6*h0*h1*h3^2 - 6*f1*f6*h0*h2^2*h3 - 
    4*f1*f6*h1^2*h2*h3 + 2*f1*f6*h1*h2^3 + 8*f2*f3*f6*h0*h3 + 2*f2*f3*h0*h3^3 - 
    16*f2*f4*f6*h0*h2 - 4*f2*f4*h0*h2*h3^2 + 4*f2*f5^2*h0*h2 - 
    4*f2*f5*h0*h1*h3^2 + 4*f2*f5*h0*h2^2*h3 - 16*f2*f6^2*h0^2 - 
    4*f2*f6*h0^2*h3^2 + 8*f2*f6*h0*h1*h2*h3 - 4*f2*f6*h0*h2^3 - 4*f3^2*f5*h0*h3 
    - 2*f3^2*h0*h2*h3^2 + 8*f3*f4*f6*h0*h1 + 6*f3*f4*h0*h1*h3^2 - 
    2*f3*f5^2*h0*h1 + 4*f3*f5*f6*h0^2 - 4*f3*f5*h0^2*h3^2 - 8*f3*f5*h0*h1*h2*h3 
    + 6*f3*f6*h0^2*h2*h3 - 2*f3*f6*h0*h1^2*h3 + 2*f3*f6*h0*h1*h2^2 - 
    f3*h0^2*h2*h3^3 - 2*f3*h0*h1*h2^2*h3^2 - 4*f4*f6*h0^2*h1*h3 + 
    2*f4*h0^2*h1*h3^3 + 4*f4*h0*h1^2*h2*h3^2 + 2*f5^2*h0^2*h1*h3 + 
    2*f5*f6*h0^3*h3 - 2*f5*f6*h0^2*h1*h2 - f5*h0^3*h3^3 - 3*f5*h0^2*h1*h2*h3^2 -
    2*f5*h0*h1^2*h2^2*h3 - 4*f6^2*h0^3*h2 + 4*f6^2*h0^2*h1^2 + 2*f6*h0^3*h2*h3^2
    + 4*f6*h0^2*h1*h2^2*h3)*x1*x3^3 + (32*f0*f4*f6 + 8*f0*f4*h3^2 - 8*f0*f5^2 - 
    8*f0*f5*h2*h3 + 8*f0*f6*h2^2 + 16*f1*f3*f6 + 4*f1*f3*h3^2 - 4*f1*f5*h1*h3 + 
    8*f1*f6*h1*h2 + 8*f2*f5*h0*h3 - 16*f2*f6*h0*h2 - 8*f3*f4*h0*h3 + 
    8*f3*f6*h0*h1 + 4*f3*h0*h1*h3^2 - 2*f3*h0*h2^2*h3 + 8*f4*f6*h0^2 - 
    4*f4*h0^2*h3^2 - 8*f4*h0*h1*h2*h3 - 2*f5^2*h0^2 + 2*h0^2*h1*h3^3 - 
    h0^2*h2^2*h3^2 + 4*h0*h1^2*h2*h3^2 - 2*h0*h1*h2^3*h3)*x1*x3^2*x4 + (16*f0*f6
    + 4*f0*h3^2 - 6*f3*h0*h3 + 4*f6*h0^2 - 4*h0^2*h3^2 - 
    8*h0*h1*h2*h3)*x1*x3*x4^2 + (16*f0^2*f6^2 + 8*f0^2*f6*h3^2 + f0^2*h3^4 + 
    16*f0*f2*f4*f6 + 4*f0*f2*f4*h3^2 - 4*f0*f2*f5^2 - 4*f0*f2*f5*h2*h3 + 
    4*f0*f2*f6*h2^2 - 12*f0*f3*f6*h0*h3 - 3*f0*f3*h0*h3^3 + 4*f0*f4*f6*h1^2 + 
    f0*f4*h1^2*h3^2 - f0*f5^2*h1^2 + 2*f0*f5*h0*h1*h3^2 - f0*f5*h1^2*h2*h3 + 
    8*f0*f6^2*h0^2 - 2*f0*f6*h0^2*h3^2 - 12*f0*f6*h0*h1*h2*h3 + f0*f6*h1^2*h2^2 
    - f0*h0^2*h3^4 - 2*f0*h0*h1*h2*h3^3 - 4*f1^2*f4*f6 - f1^2*f4*h3^2 + 
    f1^2*f5^2 + f1^2*f5*h2*h3 - f1^2*f6*h2^2 - 4*f1*f4*f6*h0*h1 - 
    f1*f4*h0*h1*h3^2 + f1*f5^2*h0*h1 - f1*f5*h0^2*h3^2 + f1*f5*h0*h1*h2*h3 + 
    2*f1*f6*h0^2*h2*h3 - f1*f6*h0*h1*h2^2 + 4*f2*f4*f6*h0^2 + f2*f4*h0^2*h3^2 - 
    f2*f5^2*h0^2 - f2*f5*h0^2*h2*h3 + f2*f6*h0^2*h2^2 - 3*f3*f6*h0^3*h3 + 
    f6^2*h0^4 - f6*h0^4*h3^2 - 2*f6*h0^3*h1*h2*h3)*x2^4 + (32*f0*f1*f6^2 + 
    16*f0*f1*f6*h3^2 + 2*f0*f1*h3^4 + 32*f0*f3*f4*f6 + 8*f0*f3*f4*h3^2 - 
    8*f0*f3*f5^2 - 8*f0*f3*f5*h2*h3 - 8*f0*f3*f6*h1*h3 + 8*f0*f3*f6*h2^2 - 
    2*f0*f3*h1*h3^3 - 16*f0*f4*f6*h0*h3 + 16*f0*f4*f6*h1*h2 - 4*f0*f4*h0*h3^3 + 
    4*f0*f4*h1*h2*h3^2 + 8*f0*f5^2*h0*h3 - 4*f0*f5^2*h1*h2 - 8*f0*f5*f6*h0*h2 + 
    6*f0*f5*h0*h2*h3^2 + 2*f0*f5*h1^2*h3^2 - 4*f0*f5*h1*h2^2*h3 + 
    16*f0*f6^2*h0*h1 + 4*f0*f6*h0*h1*h3^2 - 8*f0*f6*h0*h2^2*h3 - 
    4*f0*f6*h1^2*h2*h3 + 4*f0*f6*h1*h2^3 - 8*f1*f3*f6*h0*h3 - 2*f1*f3*h0*h3^3 - 
    8*f1*f4*f6*h0*h2 - 2*f1*f4*h0*h2*h3^2 + 2*f1*f5^2*h0*h2 + 2*f1*f5*h0*h2^2*h3
    + 8*f1*f6^2*h0^2 - 2*f1*f6*h0^2*h3^2 - 8*f1*f6*h0*h1*h2*h3 - 2*f1*f6*h0*h2^3
    - f1*h0^2*h3^4 - 2*f1*h0*h1*h2*h3^3 - 2*f2*f5*h0^2*h3^2 + 4*f2*f6*h0^2*h2*h3
    + 8*f3*f4*f6*h0^2 + 2*f3*f4*h0^2*h3^2 - 2*f3*f5^2*h0^2 - 2*f3*f5*h0^2*h2*h3 
    - 6*f3*f6*h0^2*h1*h3 + 2*f3*f6*h0^2*h2^2 - 4*f4*f6*h0^3*h3 + 2*f5^2*h0^3*h3 
    - 2*f5*f6*h0^3*h2 + 4*f6^2*h0^3*h1 - 2*f6*h0^3*h1*h3^2 - 
    4*f6*h0^2*h1^2*h2*h3)*x2^3*x3 + (16*f0*f3*f6 + 4*f0*f3*h3^2 - 4*f0*f5*h1*h3 
    + 8*f0*f6*h1*h2 + 2*f1*f5*h0*h3 - 4*f1*f6*h0*h2 + 4*f3*f6*h0^2 - 
    2*f3*h0^2*h3^2 - h0^3*h3^3 - 2*h0^2*h1*h2*h3^2)*x2^3*x4 + (32*f0*f2*f6^2 + 
    16*f0*f2*f6*h3^2 + 2*f0*f2*h3^4 - 24*f0*f3*f5*f6 - 6*f0*f3*f5*h3^2 - 
    12*f0*f3*f6*h2*h3 - 3*f0*f3*h2*h3^3 + 64*f0*f4^2*f6 + 16*f0*f4^2*h3^2 - 
    16*f0*f4*f5^2 - 16*f0*f4*f5*h2*h3 + 32*f0*f4*f6*h2^2 + 4*f0*f4*h2^2*h3^2 + 
    6*f0*f5^2*h1*h3 - 4*f0*f5^2*h2^2 + 4*f0*f5*f6*h0*h3 - 12*f0*f5*f6*h1*h2 + 
    f0*f5*h0*h3^3 + 3*f0*f5*h1*h2*h3^2 - 4*f0*f5*h2^3*h3 - 8*f0*f6^2*h0*h2 + 
    8*f0*f6^2*h1^2 - 2*f0*f6*h0*h2*h3^2 + 2*f0*f6*h1^2*h3^2 - 6*f0*f6*h1*h2^2*h3
    + 4*f0*f6*h2^4 + 16*f1^2*f6^2 + 8*f1^2*f6*h3^2 + f1^2*h3^4 + 8*f1*f3*f4*f6 +
    2*f1*f3*f4*h3^2 - 2*f1*f3*f5^2 - 2*f1*f3*f5*h2*h3 - 4*f1*f3*f6*h1*h3 + 
    2*f1*f3*f6*h2^2 - f1*f3*h1*h3^3 - 20*f1*f4*f6*h0*h3 + 4*f1*f4*f6*h1*h2 - 
    5*f1*f4*h0*h3^3 + f1*f4*h1*h2*h3^2 + 7*f1*f5^2*h0*h3 - f1*f5^2*h1*h2 - 
    4*f1*f5*f6*h0*h2 + 6*f1*f5*h0*h2*h3^2 + f1*f5*h1^2*h3^2 - f1*f5*h1*h2^2*h3 +
    16*f1*f6^2*h0*h1 + 4*f1*f6*h0*h1*h3^2 - 7*f1*f6*h0*h2^2*h3 - 
    2*f1*f6*h1^2*h2*h3 + f1*f6*h1*h2^3 - 4*f2*f3*f6*h0*h3 - f2*f3*h0*h3^3 - 
    8*f2*f4*f6*h0*h2 - 2*f2*f4*h0*h2*h3^2 + 2*f2*f5^2*h0*h2 - 2*f2*f5*h0*h1*h3^2
    + 2*f2*f5*h0*h2^2*h3 + 8*f2*f6^2*h0^2 - 2*f2*f6*h0^2*h3^2 - 
    4*f2*f6*h0*h1*h2*h3 - 2*f2*f6*h0*h2^3 - f2*h0^2*h3^4 - 2*f2*h0*h1*h2*h3^3 + 
    4*f3*f4*f6*h0*h1 + f3*f4*h0*h1*h3^2 - f3*f5^2*h0*h1 - 6*f3*f5*f6*h0^2 - 
    2*f3*f5*h0^2*h3^2 - f3*f5*h0*h1*h2*h3 + f3*f6*h0^2*h2*h3 - 
    3*f3*f6*h0*h1^2*h3 + f3*f6*h0*h1*h2^2 + 16*f4^2*f6*h0^2 + 4*f4^2*h0^2*h3^2 -
    4*f4*f5^2*h0^2 - 4*f4*f5*h0^2*h2*h3 - 10*f4*f6*h0^2*h1*h3 + 
    4*f4*f6*h0^2*h2^2 + 5*f5^2*h0^2*h1*h3 + f5*f6*h0^3*h3 - 5*f5*f6*h0^2*h1*h2 +
    f5*h0^3*h3^3 + 2*f5*h0^2*h1*h2*h3^2 - 2*f6^2*h0^3*h2 + 6*f6^2*h0^2*h1^2 - 
    2*f6*h0^3*h2*h3^2 - f6*h0^2*h1^2*h3^2 - 4*f6*h0^2*h1*h2^2*h3 - 
    2*f6*h0*h1^3*h2*h3)*x2^2*x3^2 + (64*f0*f4*f6 + 16*f0*f4*h3^2 - 16*f0*f5^2 - 
    16*f0*f5*h2*h3 + 16*f0*f6*h2^2 + 8*f1*f3*f6 + 2*f1*f3*h3^2 - 2*f1*f5*h1*h3 +
    4*f1*f6*h1*h2 + 4*f2*f5*h0*h3 - 8*f2*f6*h0*h2 + 4*f3*f6*h0*h1 - 
    2*f3*h0*h1*h3^2 + 16*f4*f6*h0^2 - 4*f5^2*h0^2 - h0^2*h1*h3^3 - 
    2*h0*h1^2*h2*h3^2)*x2^2*x3*x4 + (8*f0*f6 + 2*f0*h3^2 + 3*f3*h0*h3 + 
    2*f6*h0^2 + h0^2*h3^2 + 2*h0*h1*h2*h3)*x2^2*x4^2 + (-32*f0*f3*f6^2 - 
    16*f0*f3*f6*h3^2 - 2*f0*f3*h3^4 + 32*f0*f4*f5*f6 + 8*f0*f4*f5*h3^2 + 
    16*f0*f4*f6*h2*h3 + 4*f0*f4*h2*h3^3 - 8*f0*f5^3 - 12*f0*f5^2*h2*h3 + 
    8*f0*f5*f6*h1*h3 + 8*f0*f5*f6*h2^2 + 2*f0*f5*h1*h3^3 - 4*f0*f5*h2^2*h3^2 - 
    16*f0*f6^2*h1*h2 - 4*f0*f6*h1*h2*h3^2 + 4*f0*f6*h2^3*h3 + 32*f1*f2*f6^2 + 
    16*f1*f2*f6*h3^2 + 2*f1*f2*h3^4 - 16*f1*f3*f5*f6 - 4*f1*f3*f5*h3^2 - 
    8*f1*f3*f6*h2*h3 - 2*f1*f3*h2*h3^3 + 32*f1*f4^2*f6 + 8*f1*f4^2*h3^2 - 
    8*f1*f4*f5^2 - 8*f1*f4*f5*h2*h3 - 8*f1*f4*f6*h1*h3 + 16*f1*f4*f6*h2^2 - 
    2*f1*f4*h1*h3^3 + 2*f1*f4*h2^2*h3^2 + 6*f1*f5^2*h1*h3 - 2*f1*f5^2*h2^2 - 
    8*f1*f5*f6*h1*h2 + 4*f1*f5*h1*h2*h3^2 - 2*f1*f5*h2^3*h3 + 8*f1*f6^2*h1^2 + 
    2*f1*f6*h1^2*h3^2 - 6*f1*f6*h1*h2^2*h3 + 2*f1*f6*h2^4 - 16*f2*f4*f6*h0*h3 - 
    4*f2*f4*h0*h3^3 + 4*f2*f5^2*h0*h3 + 4*f2*f5*h0*h2*h3^2 + 16*f2*f6^2*h0*h1 + 
    4*f2*f6*h0*h1*h3^2 - 4*f2*f6*h0*h2^2*h3 - 8*f3*f4*f6*h0*h2 - 
    2*f3*f4*h0*h2*h3^2 + 2*f3*f5^2*h0*h2 - 8*f3*f5*f6*h0*h1 - 4*f3*f5*h0*h1*h3^2
    + 2*f3*f5*h0*h2^2*h3 - 8*f3*f6^2*h0^2 - 6*f3*f6*h0^2*h3^2 - 
    4*f3*f6*h0*h1*h2*h3 - 2*f3*f6*h0*h2^3 - f3*h0^2*h3^4 - 2*f3*h0*h1*h2*h3^3 + 
    16*f4^2*f6*h0*h1 + 4*f4^2*h0*h1*h3^2 - 4*f4*f5^2*h0*h1 + 8*f4*f5*f6*h0^2 + 
    2*f4*f5*h0^2*h3^2 - 4*f4*f5*h0*h1*h2*h3 - 8*f4*f6*h0*h1^2*h3 + 
    4*f4*f6*h0*h1*h2^2 - 2*f5^3*h0^2 - 2*f5^2*h0^2*h2*h3 + 4*f5^2*h0*h1^2*h3 + 
    2*f5*f6*h0^2*h1*h3 + 2*f5*f6*h0^2*h2^2 - 4*f5*f6*h0*h1^2*h2 + 
    f5*h0^2*h1*h3^3 + 2*f5*h0*h1^2*h2*h3^2 - 4*f6^2*h0^2*h1*h2 + 4*f6^2*h0*h1^3 
    - 2*f6*h0^2*h1*h2*h3^2 - 4*f6*h0*h1^2*h2^2*h3)*x2*x3^3 + (48*f1*f4*f6 + 
    12*f1*f4*h3^2 - 12*f1*f5^2 - 12*f1*f5*h2*h3 + 12*f1*f6*h2^2 + 2*f3*f5*h0*h3 
    - 12*f3*f6*h0*h2 - 2*f3*h0*h2*h3^2 + 24*f4*f6*h0*h1 - 6*f5^2*h0*h1 - 
    2*f5*h0^2*h3^2 - 4*f5*h0*h1*h2*h3 - h0^2*h2*h3^3 - 
    2*h0*h1*h2^2*h3^2)*x2*x3^2*x4 + (8*f1*f6 + 2*f1*h3^2 + 4*f4*h0*h3 - 
    2*f5*h0*h2 + 4*f6*h0*h1)*x2*x3*x4^2 + (16*f0*f4*f6^2 + 8*f0*f4*f6*h3^2 + 
    f0*f4*h3^4 - 4*f0*f5^2*f6 - f0*f5^2*h3^2 - 4*f0*f5*f6*h2*h3 - f0*f5*h2*h3^3 
    + 4*f0*f6^2*h2^2 + f0*f6*h2^2*h3^2 - 16*f1*f3*f6^2 - 8*f1*f3*f6*h3^2 - 
    f1*f3*h3^4 + 8*f1*f4*f5*f6 + 2*f1*f4*f5*h3^2 + 4*f1*f4*f6*h2*h3 + 
    f1*f4*h2*h3^3 - 2*f1*f5^3 - 3*f1*f5^2*h2*h3 + 4*f1*f5*f6*h1*h3 + 
    2*f1*f5*f6*h2^2 + f1*f5*h1*h3^3 - f1*f5*h2^2*h3^2 - 8*f1*f6^2*h1*h2 - 
    2*f1*f6*h1*h2*h3^2 + f1*f6*h2^3*h3 + 16*f2^2*f6^2 + 8*f2^2*f6*h3^2 + 
    f2^2*h3^4 - 8*f2*f3*f5*f6 - 2*f2*f3*f5*h3^2 - 4*f2*f3*f6*h2*h3 - 
    f2*f3*h2*h3^3 + 16*f2*f4^2*f6 + 4*f2*f4^2*h3^2 - 4*f2*f4*f5^2 - 
    4*f2*f4*f5*h2*h3 - 8*f2*f4*f6*h1*h3 + 8*f2*f4*f6*h2^2 - 2*f2*f4*h1*h3^3 + 
    f2*f4*h2^2*h3^2 + 4*f2*f5^2*h1*h3 - f2*f5^2*h2^2 - 4*f2*f5*f6*h0*h3 - 
    4*f2*f5*f6*h1*h2 - f2*f5*h0*h3^3 + 3*f2*f5*h1*h2*h3^2 - f2*f5*h2^3*h3 + 
    8*f2*f6^2*h0*h2 + 8*f2*f6^2*h1^2 + 2*f2*f6*h0*h2*h3^2 + 2*f2*f6*h1^2*h3^2 - 
    4*f2*f6*h1*h2^2*h3 + f2*f6*h2^4 - 4*f3^2*f4*f6 - f3^2*f4*h3^2 + f3^2*f5^2 + 
    f3^2*f5*h2*h3 + 4*f3^2*f6*h1*h3 - f3^2*f6*h2^2 + f3^2*h1*h3^3 - 
    8*f3*f4*f6*h0*h3 - 4*f3*f4*f6*h1*h2 - 2*f3*f4*h0*h3^3 - f3*f4*h1*h2*h3^2 + 
    2*f3*f5^2*h0*h3 + f3*f5^2*h1*h2 - 2*f3*f5*f6*h1^2 + 2*f3*f5*h0*h2*h3^2 - 
    2*f3*f5*h1^2*h3^2 + f3*f5*h1*h2^2*h3 - 8*f3*f6^2*h0*h1 - 2*f3*f6*h0*h1*h3^2 
    - 2*f3*f6*h0*h2^2*h3 + 3*f3*f6*h1^2*h2*h3 - f3*f6*h1*h2^3 + 4*f4^2*f6*h1^2 +
    f4^2*h1^2*h3^2 - f4*f5^2*h1^2 + 4*f4*f5*f6*h0*h1 + f4*f5*h0*h1*h3^2 - 
    f4*f5*h1^2*h2*h3 + 4*f4*f6^2*h0^2 - 3*f4*f6*h0^2*h3^2 - 8*f4*f6*h0*h1*h2*h3 
    - 2*f4*f6*h1^3*h3 + f4*f6*h1^2*h2^2 - f4*h0^2*h3^4 - 2*f4*h0*h1*h2*h3^3 - 
    f5^3*h0*h1 - f5^2*f6*h0^2 + f5^2*h0^2*h3^2 + f5^2*h0*h1*h2*h3 + f5^2*h1^3*h3
    - f5*f6*h0^2*h2*h3 + f5*f6*h0*h1^2*h3 + f5*f6*h0*h1*h2^2 - f5*f6*h1^3*h2 + 
    f5*h0^2*h2*h3^3 + 2*f5*h0*h1*h2^2*h3^2 + f6^2*h0^2*h2^2 - 2*f6^2*h0*h1^2*h2 
    + f6^2*h1^4 - f6*h0^2*h2^2*h3^2 - 2*f6*h0*h1*h2^3*h3)*x3^4 + (32*f2*f4*f6 + 
    8*f2*f4*h3^2 - 8*f2*f5^2 - 8*f2*f5*h2*h3 + 8*f2*f6*h2^2 - 8*f3^2*f6 - 
    2*f3^2*h3^2 + 4*f3*f5*h1*h3 - 8*f3*f6*h0*h3 - 8*f3*f6*h1*h2 - 2*f3*h0*h3^3 +
    8*f4*f6*h1^2 - 2*f5^2*h1^2 - 4*f6*h0^2*h3^2 - 8*f6*h0*h1*h2*h3 - h0^2*h3^4 -
    2*h0*h1*h2*h3^3)*x3^3*x4 + (8*f2*f6 + 2*f2*h3^2 - 2*f3*f5 - f3*h2*h3 + 
    2*f4*h1*h3 + f5*h0*h3 - f5*h1*h2 - 2*f6*h0*h2 + 2*f6*h1^2)*x3^2*x4^2 + x4^4;
   return [delta1,delta2,delta3,delta4]; 
end function;

//Compute the Kummer coordinates of 2P, where P is a point on the Kummer surface of a genus 2 Jacobian.

function delta(P,J)
 return [Evaluate(deltadata(J)[i],Eltseq(P)):i in [1..4]];
end function;

//Compute 2P, where P is a point on the Kummer surface of a genus 2 Jacobian.
function Double(P,J)
 return Parent(P)!delta(P,J);
end function;



//The function WMdata computes the matrix W associated to a point P of order 2 on a genus 2
//Jacobian. We have to make a case distinction, distinguishing between char(k)=2 and otherwise.
//If char(k)=2, then t is the factor of the polynomial h that does not come from P, i.e.
//h=t*a, where a is the first polynomial appearing in the Mumford representation of P.
//Otherwise 4*f+h^2=s*t, where s is a polynomial homogeneous of degree 2 that is a constant 
//multiple of a.  

function WMdata(P,t)
 C:=Curve(Parent(P));
 K:=GeneralKummerSurface(Parent(P));
 k:=BaseRing(C);
 f,h:=HyperellipticPolynomials(C);
 f0:=Coefficient(f,0);
 f1:=Coefficient(f,1);
 f2:=Coefficient(f,2);
 f3:=Coefficient(f,3);
 f4:=Coefficient(f,4);  
 f5:=Coefficient(f,5);
 f6:=Coefficient(f,6);
 t0:=Coefficient(t,0);
 t1:=Coefficient(t,1);
if Characteristic(k) eq 2 then 
 kp:=kappa(P);
 k2:=kp[2];  //Now normalize ki=xi/x2.
 k1:=kp[1]/k2;
 k3:=kp[3]/k2;
 k4:=kp[4]/k2;
 b:=P[2];
 k2:=1;
 if IsZero(kp[1]) then  //P is not generic
  y1:=Coefficient(b, 0);
  _,r6:=IsSquare(f6);
  a0:=r6;
  a1:=r6*k3;
  a2:=r6*k3^2;
  a3:=r6*k3^3+y1;
  c:=y1*r6;
 else  //P is generic (i.e. can be written as the difference of two affine points on the curve).
  a0:=Coefficient(b, 1)*k1/k2;
  a1:=Coefficient(b, 0)*k1/k2;
  a2:=k2/k1*a1+k3/k1*a0;
  a3:=k2/k1*a2+k3/k1*a1;
  cc:=(f0*k1^5+k3*f6*k2^4+k3*k2^3*f5*k1+k3*k2^2*f4*k1^2+k3*k2*f3*k1^3+k3*f2*k1^4+k3^2*k1*k2^2*f6+k3^2*k1^3*f4+k3^3*f6*k1^2)/k1^5;
  c1:=a0*a1*(k2/k1)^3+cc;
  c:=c1*k1/k2;
 end if; 
 w11:=t1*a2+k4;
 w12:=t1*a1+f5*k3;
 w13:=t1*a0+f5*k2;
 w14:=k1;
 w21:=t1*a3+t0*a2+f3*k3;
 w22:=t1*a2+t0*a1+k4;
 w23:=t0*a0+t1*a1+f3*k1;
 w24:=k2;
 w31:=f1*k2+t0*a3;
 w32:=f1*k1+t0*a2;
 w33:=t0*a1+k4;
 w34:=k3;
 w41:=f3*f1*k1+t0*f3*a2+f1*t1*a1+t0^2*c+f1*t0*a0; 
 w42:=t0*t1*c+t1*a0*f1+f1*f5*k2+t0*f5*a3;
 w43:=t1*f3*a1+f3*f5*k3+t1*f5*a3+t0*f5*a2+t1^2*c;
 w44:=k4;
else  //char(k) is not equal to 2.
  s:=Parent(f)!((4*f+h^2)/t);
  s0:=Coefficient(s,0);
  s1:=Coefficient(s,1);
  s2:=Coefficient(s,2);
  h0:=Coefficient(h,0);
  h1:=Coefficient(h,1);
  h2:=Coefficient(h,2);
  h3:=Coefficient(h,3);
  t2:=Coefficient(t,2); //Now t is homogeneous of degree 4.
  t3:=Coefficient(t,3);
  t4:=Coefficient(t,4);    
  w11:=s2^2*t0+s0*s2*t2-s0^2*t4-2*h0*h2*s2;
  w12:=s0*s2*t3-s0*s1*t4-2*s2*h0*h3;
  w13:=s1*s2*t3-s1^2*t4+2*s0*s2*t4-2*s2*h1*h3;
  w14:=4*s2;
  w21:=-s0*s2*t1-s0*s1*t2+s0^2*t3+2*s1*h0*h2;
  w22:=s2^2*t0-s0*s2*t2+s0^2*t4+2*h0*h3*s1;
  w23:=s2^2*t1-s1*s2*t2-s0*s2*t3+2*s1*h1*h3;
  w24:=-4*s1;
  w31:=-s1^2*t0+2*s0*s2*t0+s0*s1*t1-2*s0*h0*h2;
  w32:=-s1*s2*t0+s0*s2*t1-2*s0*h0*h3;
  w33:=-s2^2*t0+s0*s2*t2+s0^2*t4-2*h1*h3*s0;
  w34:=4*s0;
  w41:=1/2*h0*h2*(s2^2*t0+s0*s2*t2-s0^2*t4)+1/2*h0*h3*(-s0*s2*t1-s0*s1*t2+s0^2*t3)+1/2*h1*h3*(-s1^2*t0+2*s0*s2*t0+s0*s1*t1)-1/4*s1*s2^2*t0*t1+1/4*s1^2*s2*t0*t2+1/4*s0*s2^2*t1^2-s0*s2^2*t0*t2-1/4*s0*s1*s2*t1*t2+1/4*s0*s1*s2*t0*t3-1/4*s0^2*s2*t1*t3-2*(1/2*h0*h2*s2-1/2*h0*h3*s1+1/2*h1*h3*s0-1/4*s2^2*t0-1/4*s0*s2*t2-1/4*s0^2*t4)*h0*h2;
  w42:=1/2*h0*h2*(s0*s2*t3-s0*s1*t4)+1/2*h0*h3*(s2^2*t0-s0*s2*t2+s0^2*t4)+1/2*h1*h3*(-s1*s2*t0+s0*s2*t1)+1/4*s1^2*s2*t0*t3-1/4*s1^3*t0*t4-1/2*s0*s2^2*t0*t3-1/4*s0*s1*s2*t1*t3+s0*s1*s2*t0*t4+1/4*s0*s1^2*t1*t4-1/2*s0^2*s2*t1*t4-2*(1/2*h0*h2*s2-1/2*h0*h3*s1+1/2*h1*h3*s0-1/4*s2^2*t0-1/4*s0*s2*t2-1/4*s0^2*t4)*h0*h3;
  w43:=1/2*h0*h2*(s1*s2*t3-s1^2*t4+2*s0*s2*t4)+1/2*h0*h3*(s2^2*t1-s1*s2*t2-s0*s2*t3)+1/2*h1*h3*(-s2^2*t0+s0*s2*t2+s0^2*t4)-1/4*s0*s2^2*t1*t3-1/4*s0*s1*s2*t2*t3+1/4*s0*s1*s2*t1*t4+1/4*s0*s1^2*t2*t4+1/4*s0^2*s2*t3^2-s0^2*s2*t2*t4-1/4*s0^2*s1*t3*t4-2*(1/2*h0*h2*s2-1/2*h0*h3*s1+1/2*h1*h3*s0-1/4*s2^2*t0-1/4*s0*s2*t2-1/4*s0^2*t4)*h1*h3;
  w44:=2*h0*h2*s2-2*h0*h3*s1+2*h1*h3*s0-s2^2*t0-s0*s2*t2-s0^2*t4;
end if;
 W:=[[w11, w12, w13,w14]
   ,[w12, w22, w23, w24]
   ,[w13, w23, w33, w34]
   ,[w14, w24, w34, w44]];
 return W;
end function;


//Apply the matrix W associated to a 2-torsion point P on a genus 2 Jacobian to the 
//Kummer coordinates of an arbitrary point on the same Jacobian (or on the Kummer surface).
//This is equal to kappa(P+Q).
function WM(P,Q,t)
 W:=WMdata(P,t);
 if #Eltseq(Q) eq 2 then
  //Q lies on the Jacobian
  KQ:=kappa(Q);
 else
  //Q lies on the Kummer surface
  KQ:=Q;
 end if;  
 W1:=W[1,1]*KQ[1]+W[1,2]*KQ[2]+W[1,3]*KQ[3]+W[1,4]*KQ[4];
 W2:=W[2,1]*KQ[1]+W[2,2]*KQ[2]+W[2,3]*KQ[3]+W[2,4]*KQ[4];
 W3:=W[3,1]*KQ[1]+W[3,2]*KQ[2]+W[3,3]*KQ[3]+W[3,4]*KQ[4];
 W4:=W[4,1]*KQ[1]+W[4,2]*KQ[2]+W[4,3]*KQ[3]+W[4,4]*KQ[4];
 return [W1,W2,W3,W4];  
end function;

//Apply the matrix W associated to a 2-torsion point P on a genus 2 Jacobian J to a point Q lying on the
//associated Kummer surface K and return the image on K. This is equal to kappa(K,P+Q).

function Translate_by_two_torsion_point(P,Q,t)
 return Parent(Q)!WM(P,Q,t);
end function;


//Let C and C1 be genus 2 curves that are related by a transformation tau = [t,e,u], 
//where t = [a,b,c,d] s.t. ad-bc \ne 0, e \ne 0 and u(x) is a polynomial of degree at most 3.
//Then the corresponding map Kummer_transformation between Kummer surfaces is given below.  

//kt is the map on Kummer coordinates induced  by tau. This is a linear map on k^4, where k is the ground field.
//Here k is a set of Kummer coordinates.on the Kummer surface associated to the Jacobian of the genus 2 curve
//given by f and h.


function ktgen(f,h,t,e,u,k)
 a,b,c,d := Explode(t);
 esq:=e*e;
 det:=a*d-b*c;
 f0:=Coefficient(f,0);
 f1:=Coefficient(f,1);
 f2:=Coefficient(f,2);
 f3:=Coefficient(f,3);
 f4:=Coefficient(f,4);
 f5:=Coefficient(f,5);
 f6:=Coefficient(f,6);
 
 h0:=Coefficient(h,0);
 h1:=Coefficient(h,1);
 h2:=Coefficient(h,2);
 h3:=Coefficient(h,3);
 
 u0:=Coefficient(u,0);
 u1:=Coefficient(u,1);
 u2:=Coefficient(u,2);
 u3:=Coefficient(u,3);

  
 l11:=-esq*(4*a^3*b*c*d^3*f2-2*f1*a^3*b*c^2*d^2-2*f1*a^2*b^2*c^3*d-3*f3*a^2*b^2*c*d^3-4*f5*a*b^3*d^4-f3*a^3*b*d^4-4*f5*b^4*c*d^3+2*f4*a^2*b^2*d^4+2*
f4*b^4*c^2*d^2-3*f3*a*b^3*c^2*d^2-f3*b^4*c^3*d-2*f1*a^4*c*d^3-2*f1*a*b^3*c^4+4*f4*a*b^3*c*d^3+4*a*b^3*c^3*d*f2+8*b^4*d^4*f6+6*a^4*c^2*d^2*f0+6*a^2*b^2*c^4*
f0-4*a^3*b*c^3*d*f0)/det^4;

 l12:=-e*(-b^4*c^3*d*u0*h3-4*b^4*c*d^3*u2*h3-4*a*b^3*d^4*u2*h3+6*a^2*b^2*c^4*u0*h0-2*a*b^3*c^4*u1*h0-3*a*b^3*c^2*d^2*u3*h0-4*a^3*b*c^3*d*u0*h0-2*a^3*b*c
^2*d^2*u1*h0-b^4*c^3*d*u3*h0+6*a^2*b^2*c^2*d^2*u2*h0+2*b^4*c^2*d^2*u1*h3-a^3*b*d^4*u0*h3-2*a^4*c*d^3*u1*h0-3*a*b^3*c^2*d^2*u0*h3-2*a^2*b^2*c^3*d*u1*h0+4*h1*
a*b^3*c^3*d*u1-3*h1*a*b^3*c^2*d^2*u2-2*h1*a^2*b^2*c^3*d*u0+4*h2*a*b^3*c*d^3*u2-3*h2*a^2*b^2*c*d^3*u1+6*h2*a^2*b^2*c^2*d^2*u0+4*h1*a*b^3*c*d^3*u3-3*h2*a*b^3*
c^2*d^2*u1+4*h1*a^3*b*c*d^3*u1+2*h2*b^4*c^2*d^2*u2-4*h2*b^4*c*d^3*u3-h2*a^3*b*d^4*u1+2*h2*a^2*b^2*d^4*u2+h2*b^4*c^4*u0-4*h2*a*b^3*d^4*u3-h2*b^4*c^3*d*u1+2*
h1*b^4*c^2*d^2*u3-2*h1*a*b^3*c^4*u0-h1*b^4*c^3*d*u2-3*h1*a^2*b^2*c*d^3*u2-2*h1*a^3*b*c^2*d^2*u0-2*h1*a^4*c*d^3*u0-h1*a^3*b*d^4*u2+2*h1*a^2*b^2*d^4*u3+h2*a^4
*d^4*u0+b^4*c^4*u2*h0+a^4*d^4*u2*h0+2*a^2*b^2*d^4*u1*h3-a^3*b*d^4*u3*h0+6*a^4*c^2*d^2*u0*h0-3*a^2*b^2*c*d^3*u3*h0-3*a^2*b^2*c*d^3*u0*h3+4*a*b^3*c*d^3*u1*h3+
8*b^4*d^4*u3*h3)/det^4;

 l13:=2*(3*a^4*c^2*d^2*u0^2+3*a^2*b^2*c^4*u0^2+a^4*d^4*u0*u2+a^2*b^2*d^4*u2^2+b^4*c^4*u0*u2+b^4*c^2*d^2*u2^2+4*b^4*d^4*u3^2-3*a^2*b^2*c*d^3*u1*u2-3*a^2*
b^2*c*d^3*u0*u3-3*a*b^3*c^2*d^2*u0*u3+2*a^3*b*c*d^3*u1^2-2*a^3*b*c^2*d^2*u0*u1-3*a*b^3*c^2*d^2*u1*u2-a^3*b*d^4*u0*u3+2*a*b^3*c*d^3*u2^2+2*a*b^3*c^3*d*u1^2-2
*a^3*b*c^3*d*u0^2-2*a^4*c*d^3*u0*u1-4*a*b^3*d^4*u2*u3-2*a^2*b^2*c^3*d*u0*u1+6*a^2*b^2*c^2*d^2*u0*u2+4*a*b^3*c*d^3*u1*u3-2*a*b^3*c^4*u0*u1+2*a^2*b^2*d^4*u1*
u3-a^3*b*d^4*u1*u2-b^4*c^3*d*u0*u3-b^4*c^3*d*u1*u2+2*b^4*c^2*d^2*u1*u3-4*b^4*c*d^3*u2*u3)/det^4;

l21:=esq*(-4*f2*a^2*b^2*c^3*d+6*f1*a^3*b*c^3*d-4*f4*a^2*b^2*c*d^3+f1*a^2*b^2*c^4+6*f5*a*b^3*c*d^3+f3*a^3*b*c*d^3+f5*b^4*c^2*d^2+f1*a^4*c^2*d^2-4*a^3*b*c^4*f0-4*a^4*c^3*d*f0+6*f3*a^2*b^2*c^2*d^2+f5*a^2*b^2*d^4-4*f2*a^3*b*c^2*d^2-4*f4*a*b^3*c^2*d^2+f3*a*b^3*c^3*d-4*b^4*c*d^3*f6-4*a*b^3*d^4*f6)/det^4;

 l22:=e*(h1*a^4*c^2*d^2*u0+h1*a^3*b*c*d^3*u2+h1*a^2*b^2*c^4*u0+h2*b^4*c^2*d^2*u3+h1*a*b^3*c^3*d*u2+h2*a^3*b*c*d^3*u1+h2*a^2*b^2*d^4*u3+h2*a*b^3*c^3*d*u1+6*h2*a*b^3*c
*d^3*u3+6*h1*a^3*b*c^3*d*u0-4*h1*a^3*b*c^2*d^2*u1-4*h1*a^2*b^2*c^3*d*u1+6*h1*a^2*b^2*c^2*d^2*u2-4*h1*a^2*b^2*c*d^3*u3-4*h1*a*b^3*c^2*d^2*u3-4*h2*a^3*b*c^2*d
^2*u0-4*h2*a^2*b^2*c^3*d*u0+6*h2*a^2*b^2*c^2*d^2*u1-4*h2*a^2*b^2*c*d^3*u2-4*h2*a*b^3*c^2*d^2*u2-a^4*d^4*u3*h0-b^4*c^4*u3*h0+a^4*c^2*d^2*u1*h0-4*a^4*c^3*d*u0
*h0+6*a^3*b*c^3*d*u1*h0-4*a^3*b*c^4*u0*h0-4*a^2*b^2*c^3*d*u2*h0+5*a*b^3*c^3*d*u3*h0+a^2*b^2*c^4*u1*h0-4*a^3*b*c^2*d^2*u2*h0+5*a^3*b*c*d^3*u3*h0+b^4*c^2*d^2*
u2*h3+a^2*b^2*d^4*u2*h3+5*a^3*b*c*d^3*u0*h3+6*a*b^3*c*d^3*u2*h3-4*a^2*b^2*c*d^3*u1*h3+5*a*b^3*c^3*d*u0*h3-4*a*b^3*c^2*d^2*u1*h3-4*a*b^3*d^4*u3*h3-4*b^4*c*d^
3*u3*h3-a^4*d^4*u0*h3-b^4*c^4*u0*h3)/det^4;

 l23:=(4*a^4*c^3*d*u0^2+2*a^4*d^4*u0*u3+4*a^3*b*c^4*u0^2+4*a*b^3*d^4*u3^2+2*b^4*c^4*u0*u3+4*b^4*c*d^3*u3^2-2*a^4*c^2*d^2*u0*u1-12*a^3*b*c^3*d*u0*u1+8*a^3*b*c^2*d^2
*u0*u2+4*a^3*b*c^2*d^2*u1^2-10*a^3*b*c*d^3*u0*u3-2*a^3*b*c*d^3*u1*u2-2*a^2*b^2*c^4*u0*u1+8*a^2*b^2*c^3*d*u0*u2+4*a^2*b^2*c^3*d*u1^2-12*a^2*b^2*c^2*d^2*u1*u2
+8*a^2*b^2*c*d^3*u1*u3+4*a^2*b^2*c*d^3*u2^2-2*a^2*b^2*d^4*u2*u3-10*a*b^3*c^3*d*u0*u3-2*a*b^3*c^3*d*u1*u2+8*a*b^3*c^2*d^2*u1*u3+4*a*b^3*c^2*d^2*u2^2-12*a*b^3
*c*d^3*u2*u3-2*b^4*c^2*d^2*u2*u3)/det^4;


 l31:=-esq*(6*b^4*c^2*d^2*f6-4*a*b^3*c*d^3*f6+6*a^2*b^2*d^4*f6-2*f5*a^2*b^2*c*d^3+4*a*b^3*c^3*d*f4-2*f5*a*b^3*c^2*d^2-f3*a*b^3*c^4+8*a^4*c^4*f0-2*f5*
a^3*b*d^4-3*f3*a^3*b*c^2*d^2+4*f2*a^3*b*c^3*d+2*f2*a^2*b^2*c^4-3*f3*a^2*b^2*c^3*d-f3*a^4*c*d^3+4*a^3*b*c*d^3*f4-4*f1*a^3*b*c^4-4*f1*a^4*c^3*d+2*f2*a^4*c^2*d
^2-2*f5*b^4*c^3*d)/det^4;

 l32:=-e*(-4*h1*a^3*b*c^4*u0-2*a^3*b*d^4*u2*h3+2*h2*a^2*b^2*c^4*u0-4*h1*a^4*c^3*d*u0+2*a^2*b^2*c^4*u2*h0+2*a^4*c^2*d^2*u2*h0-4*a^4*c^3*d*u1*h0-a*b^3*c^4
*u3*h0-4*a^3*b*c^4*u1*h0-a^4*c*d^3*u3*h0-3*a^2*b^2*c^3*d*u3*h0+4*a^3*b*c^3*d*u2*h0-3*a^3*b*c^2*d^2*u3*h0-2*h2*a*b^3*c^2*d^2*u3-2*h2*a^3*b*d^4*u3-2*h2*b^4*c^
3*d*u3+4*h2*a*b^3*c^3*d*u2-h1*a*b^3*c^4*u2-2*h2*a^2*b^2*c*d^3*u3-h2*a*b^3*c^4*u1-h1*a^4*c*d^3*u2-3*h2*a^3*b*c^2*d^2*u1+8*a^4*c^4*u0*h0+6*a^2*b^2*d^4*u3*h3-a
^4*c*d^3*u0*h3-a*b^3*c^4*u0*h3-2*a*b^3*c^2*d^2*u2*h3-4*a*b^3*c*d^3*u3*h3+b^4*c^4*u1*h3+a^4*d^4*u1*h3-h2*a^4*c*d^3*u1+4*h1*a^3*b*c^3*d*u1-3*a^3*b*c^2*d^2*u0*
h3-2*a^2*b^2*c*d^3*u2*h3-3*a^2*b^2*c^3*d*u0*h3+6*a^2*b^2*c^2*d^2*u1*h3-2*b^4*c^3*d*u2*h3+6*b^4*c^2*d^2*u3*h3+4*h2*a^3*b*c^3*d*u0+4*h2*a^3*b*c*d^3*u2-3*h1*a^
3*b*c^2*d^2*u2-3*h1*a^2*b^2*c^3*d*u2+6*h1*a^2*b^2*c^2*d^2*u3+h1*a^4*d^4*u3+2*h1*a^4*c^2*d^2*u1+2*h1*a^2*b^2*c^4*u1+2*h2*a^4*c^2*d^2*u0-3*h2*a^2*b^2*c^3*d*u1
+h1*b^4*c^4*u3)/det^4;

 l33:=2*(3*b^4*c^2*d^2*u3^2+b^4*c^4*u1*u3+a^4*d^4*u1*u3+a^4*c^2*d^2*u1^2+a^2*b^2*c^4*u1^2+3*a^2*b^2*d^4*u3^2+4*a^4*c^4*u0^2-3*a^3*b*c^2*d^2*u1*u2-3*a^3*
b*c^2*d^2*u0*u3-3*a^2*b^2*c^3*d*u0*u3-3*a^2*b^2*c^3*d*u1*u2+6*a^2*b^2*c^2*d^2*u1*u3-2*a^2*b^2*c*d^3*u2*u3-4*a^4*c^3*d*u0*u1-2*a^3*b*d^4*u2*u3+2*a^3*b*c*d^3*
u2^2+2*a^3*b*c^3*d*u1^2+2*a^2*b^2*c^4*u0*u2+4*a^3*b*c^3*d*u0*u2-2*a*b^3*c*d^3*u3^2+2*a^4*c^2*d^2*u0*u2-2*b^4*c^3*d*u2*u3+2*a*b^3*c^3*d*u2^2-a*b^3*c^4*u0*u3-
a*b^3*c^4*u1*u2-2*a*b^3*c^2*d^2*u2*u3-4*a^3*b*c^4*u0*u1-a^4*c*d^3*u1*u2-a^4*c*d^3*u0*u3)/det^4;
 
 s:=[d^2*k[1]+c*d*k[2]+c^2*k[3],
2*b*d*k[1]+(a*d+b*c)*k[2]+2*a*c*k[3],b^2*k[1]+a*b*k[2]+a^2*k[3],
(esq*k[4]+(l11+l12+l13)*k[1]+(l21+l22+l23)*k[2]+(l31+l32+l33)*k[3])/det^2];
 return [s[i]/det:i in [1..4]];
end function;

function Kummer_transformation(K,J,t,e,u)
 f,h:=HyperellipticPolynomials(Curve(J));
 K1:=GeneralKummerSurface(Transformation(Curve(J),t,e,u));
 phi:= map< K -> K1 | P :-> K1!ktgen(f,h,t,e,u,Eltseq(P))>;
 return K1,phi;
end function;


//A special case of Kummer_transformation: Let C:y^2+h(x)*y=f(x) and C1 the curve obtained by the transformation phi given by [a,b,c,d],e,u. Let K and K1 be the respective Kummer surfaces.
//Then the isomorphism tau of Kummer surfaces induced by phi is given by:
//tau(x1,x2,x3,x4)=(a*d-b*c)^(-1)[d^2*x1+c*d*x2+c^2*x3, 2*b*d*x1+(a*d+b*c)*x2+2*a*c*x3, b^2*x1+a*b*x2+a^2*x3, 
//1/4/(a*d-b*c)^2*(e^2*(4*x4-2*h0*h2*x1-2*h0*h3*x2-2*h1*h3*x3)+(2*f6*b^6*x1^3+2*x3^3*f6*a^6+4*x3^2*f5*a^3*c*b^2*x1-2*x3^3*e^2*f6-2*e^2*f0*x1^3+2*f0*d^6*x1^3+3*f3*a*x2*d^3*b^2*x1^2+2*x3^3*f0*c^6+2*x3^2*f2*b^2*c^4*x1+f3*a^2*x2^3*d^2*b*c+f3*b^2*c^2*x2^3*a*d+f5*b^3*c*x2^3*a^2+f5*a^3*x2^3*d*b^2+f1*a*x2^3*d^3*c^2+x3*f3*b^2*c^3*x2^2*a+x3*f3*a^3*x2^2*d^2*c+x3^2*f1*b*c^5*x2+f3*b^3*c^2*x2^2*d*x1+f1*a*x2*d^5*x1^2+x3^2*f5*a^5*x2*d+f3*a^2*x2^2*d^3*b*x1+f5*b^5*c*x2*x1^2-x3*e^2*f3*x2*x1-x3^2*e^2*f5*x2-e^2*f1*x2*x1^2+2*f6*a^3*x2^3*b^3+2*f0*c^3*x2^3*d^3+2*x3^3*f4*a^4*c^2+2*x3^3*f1*a*c^5+2*x3^3*f5*a^5*c+2*x3^3*f3*a^3*c^3+2*x3^3*f2*a^2*c^4+2*f5*b^5*d*x1^3+2*f4*b^4*d^2*x1^3+2*f3*b^3*d^3*x1^3+2*f2*b^2*d^4*x1^3+2*f1*b*d^5*x1^3-2*x3^2*e^2*f4*x1-2*x3*e^2*f2*x1^2+f1*b*c^3*x2^3*d^2+x3*f3*a^3*x2*d^3*x1+x3*f3*b^3*c^3*x2*x1+2*f4*a^2*x2^3*b^2*c*d+4*x3*f3*a^2*x2^2*c^2*b*d+2*x3*f4*a^2*x2^2*b^2*c^2+4*x3*f4*a^3*x2^2*b*c*d+4*x3*f5*a^3*x2^2*c*b^2+2*x3*f5*a^4*x2^2*d*b+4*x3*f1*a*x2^2*c^3*d^2+2*x3*f1*b*c^4*x2^2*d+2*x3*f2*a^2*x2^2*c^2*d^2+4*x3*f2*a*x2^2*b*c^3*d+6*x3*f6*a^4*x2^2*b^2+6*x3^2*f0*c^5*x2*d+6*f6*a*x2*b^5*x1^2+3*f3*b^3*d^2*c*x2*x1^2+2*x3^2*f4*a^4*x2*c*d+5*x3^2*f5*a^4*x2*c*b+5*x3^2*f1*a*x2*c^4*d+3*x3^2*f3*a^2*x2*c^3*b+3*x3^2*f3*a^3*x2*c^2*d+2*x3^2*f2*a*x2*b*c^4+4*x3^2*f2*a^2*x2*c^3*d+4*f3*a*x2^2*d^2*b^2*c*x1+2*f4*a^2*x2^2*b^2*d^2*x1+4*f4*a*x2*b^3*d^2*x1^2+2*f4*b^4*c*x2*d*x1^2+4*f4*a*x2^2*b^3*c*d*x1+2*f5*b^4*c*x2^2*a*x1+4*f5*a^2*x2^2*d*b^3*x1+5*f5*a*x2*d*b^4*x1^2+6*f6*a^2*x2^2*b^4*x1+6*f0*c^2*x2^2*d^4*x1+6*f0*c*x2*d^5*x1^2+2*f1*a*x2^2*d^4*c*x1+4*f1*b*d^3*c^2*x2^2*x1+5*f1*b*d^4*c*x2*x1^2+2*f2*a*x2*b*d^4*x1^2+2*f2*b^2*c^2*x2^2*d^2*x1+4*f2*b^2*c*x2*d^3*x1^2+4*f2*a*x2^2*b*c*d^3*x1+2*x3*f3*b^3*c^2*d*x1^2+2*x3*f3*a^2*d^3*b*x1^2+4*x3*f2*b^2*c^2*d^2*x1^2+2*x3*f1*a*d^4*c*x1^2+4*x3*f1*b*d^3*c^2*x1^2+2*x3*f3*a*d^2*b^2*c*x1^2+4*x3*f4*a^2*b^2*d^2*x1^2+2*x3*f5*b^4*c*a*x1^2+4*x3*f5*a^2*d*b^3*x1^2+2*x3*f2*a^2*d^4*x1^2+6*x3*f6*a^2*b^4*x1^2+6*x3*f0*c^2*d^4*x1^2+2*x3*f4*b^4*c^2*x1^2+2*x3^2*f3*b^2*c^3*a*x1+2*x3^2*f3*a^3*d^2*c*x1+2*x3^2*f3*a^2*c^2*b*d*x1+4*x3^2*f4*a^2*b^2*c^2*x1+2*x3^2*f5*a^4*d*b*x1+4*x3^2*f1*a*c^3*d^2*x1+2*x3^2*f1*b*c^4*d*x1+4*x3^2*f2*a^2*c^2*d^2*x1+6*x3^2*f0*c^4*d^2*x1+6*x3^2*f6*a^4*b^2*x1+2*x3^2*f4*a^4*d^2*x1+5*x3*f3*a*x2*c^2*b^2*d*x1+4*x3*f4*a^3*x2*b*d^2*x1+4*x3*f2*a*x2*b*c^2*d^2*x1+4*x3*f4*a^2*x2*b^2*d*c*x1+4*x3*f4*a*x2*b^3*c^2*x1+6*x3*f5*a^2*x2*c*b^3*x1+6*x3*f5*a^3*x2*d*b^2*x1+6*x3*f1*a*x2*c^2*d^3*x1+6*x3*f1*b*c^3*x2*d^2*x1+4*x3*f2*a^2*x2*c*d^3*x1+4*x3*f2*b^2*c^3*x2*d*x1+5*x3*f3*a^2*x2*d^2*b*c*x1+12*x3*f6*a^3*x2*b^3*x1+12*x3*f0*c^3*x2*d^3*x1+2*f2*a*x2^3*b*c^2*d^2+4*x3^2*f4*a^3*x2*b*c^2+6*x3^2*f6*a^5*x2*b+6*x3*f0*c^4*x2^2*d^2)/(x2^2-4*x1*x3))+1/2*(h0*a^3*e-h1*a^2*b*e+h2*a*b^2*e-h3*b^3*e-2*a^3*u0+2*a^2*b*u1-2*a*b^2*u2+2*b^3*u3)/(a^3*d^3-3*b*a^2*d^2*c+3*b^2*a*d*c^2-b^3*c^3)^2*(3*h0*a*c^2*e-2*h1*a*c*d*e-h1*b*c^2*e+h2*a*d^2*e+2*h2*b*c*d*e-3*h3*b*d^2*e-6*a*c^2*u0+4*a*c*d*u1-2*a*d^2*u2+2*b*c^2*u1-4*b*c*d*u2+6*b*d^2*u3)*(d^2*x1+c*d*x2+c^2*x3)+1/2*(h0*a^3*e-h1*a^2*b*e+h2*a*b^2*e-h3*b^3*e-2*a^3*u0+2*a^2*b*u1-2*a*b^2*u2+2*b^3*u3)/(a^3*d^3-3*b*a^2*d^2*c+3*b^2*a*d*c^2-b^3*c^3)^2*(-h0*c^3*e+h1*c^2*d*e-h2*c*d^2*e+h3*d^3*e+2*c^3*u0-2*c^2*d*u1+2*c*d^2*u2-2*d^3*u3)*(2*b*d*x1+(a*d+b*c)*x2+2*a*c*x3)+1/2*(-3*h0*a^2*c*e+h1*a^2*d*e+2*h1*a*b*c*e-2*h2*a*b*d*e-h2*b^2*c*e+3*h3*b^2*d*e+6*a^2*c*u0-2*a^2*d*u1-4*a*b*c*u1+4*a*b*d*u2+2*b^2*c*u2-6*b^2*d*u3)/(a^3*d^3-3*b*a^2*d^2*c+3*b^2*a*d*c^2-b^3*c^3)^2*(-h0*c^3*e+h1*c^2*d*e-h2*c*d^2*e+h3*d^3*e+2*c^3*u0-2*c^2*d*u1+2*c*d^2*u2-2*d^3*u3)*(b^2*x1+a*b*x2+a^2*x3)];